export declare type Maybe<T> = T | null;
export declare type InputMaybe<T> = Maybe<T>;
export declare type Exact<T extends {
    [key: string]: unknown;
}> = {
    [K in keyof T]: T[K];
};
export declare type MakeOptional<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]?: Maybe<T[SubKey]>;
};
export declare type MakeMaybe<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]: Maybe<T[SubKey]>;
};
/** All built-in and custom scalars, mapped to their actual values */
export declare type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
    /** A date string, such as 2007-12-03, compliant with the ISO 8601 standard for representation of dates and times using the Gregorian calendar. */
    Date: any;
    /** The `JSON` scalar type represents JSON values as specified by [ECMA-404](http://www.ecma-international.org/publications/files/ECMA-ST/ECMA-404.pdf). */
    JSON: any;
};
export declare type ApiCatalogApi = {
    __typename?: 'ApiCatalogApi';
    defaultVersion: ApiCatalogVersion;
    link: Scalars['String'];
    name: Scalars['String'];
    permission?: Maybe<Scalars['String']>;
    title: Scalars['String'];
    versions: Array<ApiCatalogVersion>;
};
export declare type ApiCatalogVersion = {
    __typename?: 'ApiCatalogVersion';
    apiName?: Maybe<Scalars['String']>;
    apiVersion?: Maybe<Scalars['String']>;
    id?: Maybe<Scalars['String']>;
    isDefault?: Maybe<Scalars['Boolean']>;
    link?: Maybe<Scalars['String']>;
    metadata?: Maybe<Scalars['JSON']>;
    pathPrefix?: Maybe<Scalars['String']>;
    summary: Scalars['String'];
};
export declare type BooleanQueryOperatorInput = {
    eq?: InputMaybe<Scalars['Boolean']>;
    in?: InputMaybe<Array<InputMaybe<Scalars['Boolean']>>>;
    ne?: InputMaybe<Scalars['Boolean']>;
    nin?: InputMaybe<Array<InputMaybe<Scalars['Boolean']>>>;
};
export declare type CatalogInfo = {
    __typename?: 'CatalogInfo';
    apiName?: Maybe<Scalars['String']>;
    apiVersion?: Maybe<Scalars['String']>;
    metadata?: Maybe<Scalars['JSON']>;
    title?: Maybe<Scalars['String']>;
};
export declare type CatalogInfoFilterInput = {
    apiName?: InputMaybe<StringQueryOperatorInput>;
    apiVersion?: InputMaybe<StringQueryOperatorInput>;
    metadata?: InputMaybe<JsonQueryOperatorInput>;
    title?: InputMaybe<StringQueryOperatorInput>;
};
export declare type ContentItem = Node & {
    __typename?: 'ContentItem';
    baseLink?: Maybe<Scalars['String']>;
    catalogInfo?: Maybe<CatalogInfo>;
    children: Array<Node>;
    data?: Maybe<ContentItemData>;
    id: Scalars['ID'];
    internal: Internal;
    link: Scalars['String'];
    markdown?: Maybe<MarkdownRemark>;
    pageId: Scalars['String'];
    parent?: Maybe<Node>;
    permission?: Maybe<Scalars['String']>;
    seo?: Maybe<ContentItemSeo>;
    sourcePath?: Maybe<Scalars['String']>;
    type?: Maybe<Scalars['String']>;
};
export declare type ContentItemApiVersion = {
    __typename?: 'ContentItemApiVersion';
    apiId?: Maybe<Scalars['String']>;
    definitionId: Scalars['String'];
    id?: Maybe<Scalars['String']>;
    isDefault?: Maybe<Scalars['Boolean']>;
    label?: Maybe<Scalars['String']>;
    settings?: Maybe<ContentItemDataApiVersionsSettings>;
    title?: Maybe<Scalars['String']>;
};
export declare type ContentItemApiVersionFilterInput = {
    apiId?: InputMaybe<StringQueryOperatorInput>;
    definitionId?: InputMaybe<StringQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    isDefault?: InputMaybe<BooleanQueryOperatorInput>;
    label?: InputMaybe<StringQueryOperatorInput>;
    settings?: InputMaybe<ContentItemDataApiVersionsSettingsFilterInput>;
    title?: InputMaybe<StringQueryOperatorInput>;
};
export declare type ContentItemApiVersionFilterListInput = {
    elemMatch?: InputMaybe<ContentItemApiVersionFilterInput>;
};
export declare type ContentItemConnection = {
    __typename?: 'ContentItemConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<ContentItemEdge>;
    group: Array<ContentItemGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<ContentItem>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type ContentItemConnectionDistinctArgs = {
    field: ContentItemFieldsEnum;
};
export declare type ContentItemConnectionGroupArgs = {
    field: ContentItemFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type ContentItemConnectionMaxArgs = {
    field: ContentItemFieldsEnum;
};
export declare type ContentItemConnectionMinArgs = {
    field: ContentItemFieldsEnum;
};
export declare type ContentItemConnectionSumArgs = {
    field: ContentItemFieldsEnum;
};
export declare type ContentItemData = Node & {
    __typename?: 'ContentItemData';
    apiVersionId?: Maybe<Scalars['String']>;
    apiVersions?: Maybe<Array<ContentItemApiVersion>>;
    children: Array<Node>;
    customData?: Maybe<ContentItemDataCustomData>;
    customDataString?: Maybe<Scalars['String']>;
    customTemplate?: Maybe<Scalars['String']>;
    definitionId?: Maybe<Scalars['String']>;
    disableEditPage?: Maybe<Scalars['Boolean']>;
    disableLastModified?: Maybe<Scalars['Boolean']>;
    editPage?: Maybe<ContentItemDataEditPage>;
    enableToc?: Maybe<Scalars['Boolean']>;
    excludeFromSearch?: Maybe<Scalars['Boolean']>;
    httpVerb?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    image?: Maybe<Scalars['String']>;
    imageLink?: Maybe<Scalars['String']>;
    internal: Internal;
    isDefaultApiVersion?: Maybe<Scalars['Boolean']>;
    keywords?: Maybe<Scalars['String']>;
    label?: Maybe<Scalars['String']>;
    lang?: Maybe<Scalars['String']>;
    lastModified?: Maybe<Scalars['String']>;
    matchPath?: Maybe<Scalars['String']>;
    pageLink?: Maybe<File>;
    parent?: Maybe<Node>;
    permission?: Maybe<Scalars['String']>;
    redirect?: Maybe<Scalars['Boolean']>;
    redirectFrom?: Maybe<Array<Scalars['String']>>;
    redocHasInfoPage?: Maybe<Scalars['Boolean']>;
    redocHasSecurityDefinitions?: Maybe<Scalars['Boolean']>;
    redocInfoPageId?: Maybe<Scalars['String']>;
    redocInfoPageLink?: Maybe<Scalars['String']>;
    redocItemId?: Maybe<Scalars['String']>;
    redocMenuItems?: Maybe<Array<Maybe<ContentItemDataRedocMenuItems>>>;
    redocNextLabel?: Maybe<Scalars['String']>;
    redocNextLink?: Maybe<Scalars['String']>;
    redocPagination?: Maybe<Scalars['String']>;
    redocPrevLabel?: Maybe<Scalars['String']>;
    redocPrevLink?: Maybe<Scalars['String']>;
    redocStoreStr?: Maybe<Scalars['String']>;
    requestLogin?: Maybe<Scalars['Boolean']>;
    settings?: Maybe<Scalars['JSON']>;
    showNextButton?: Maybe<Scalars['Boolean']>;
    showPrevButton?: Maybe<Scalars['Boolean']>;
    sidebar?: Maybe<File>;
    sitemap?: Maybe<Sitemap>;
    sourcePath?: Maybe<Scalars['String']>;
    staticImageLink?: Maybe<File>;
    toc?: Maybe<TocInfo>;
    tocMaxDepth?: Maybe<Scalars['Int']>;
    type?: Maybe<Scalars['String']>;
    versions?: Maybe<Array<Maybe<ContentItemDataVersions>>>;
};
export declare type ContentItemDataApiVersionsSettings = {
    __typename?: 'ContentItemDataApiVersionsSettings';
    generateCodeSamples?: Maybe<ContentItemDataApiVersionsSettingsGenerateCodeSamples>;
    pagination?: Maybe<Scalars['String']>;
};
export declare type ContentItemDataApiVersionsSettingsFilterInput = {
    generateCodeSamples?: InputMaybe<ContentItemDataApiVersionsSettingsGenerateCodeSamplesFilterInput>;
    pagination?: InputMaybe<StringQueryOperatorInput>;
};
export declare type ContentItemDataApiVersionsSettingsGenerateCodeSamples = {
    __typename?: 'ContentItemDataApiVersionsSettingsGenerateCodeSamples';
    languages?: Maybe<Array<Maybe<ContentItemDataApiVersionsSettingsGenerateCodeSamplesLanguages>>>;
};
export declare type ContentItemDataApiVersionsSettingsGenerateCodeSamplesFilterInput = {
    languages?: InputMaybe<ContentItemDataApiVersionsSettingsGenerateCodeSamplesLanguagesFilterListInput>;
};
export declare type ContentItemDataApiVersionsSettingsGenerateCodeSamplesLanguages = {
    __typename?: 'ContentItemDataApiVersionsSettingsGenerateCodeSamplesLanguages';
    lang?: Maybe<Scalars['String']>;
};
export declare type ContentItemDataApiVersionsSettingsGenerateCodeSamplesLanguagesFilterInput = {
    lang?: InputMaybe<StringQueryOperatorInput>;
};
export declare type ContentItemDataApiVersionsSettingsGenerateCodeSamplesLanguagesFilterListInput = {
    elemMatch?: InputMaybe<ContentItemDataApiVersionsSettingsGenerateCodeSamplesLanguagesFilterInput>;
};
export declare type ContentItemDataConnection = {
    __typename?: 'ContentItemDataConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<ContentItemDataEdge>;
    group: Array<ContentItemDataGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<ContentItemData>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type ContentItemDataConnectionDistinctArgs = {
    field: ContentItemDataFieldsEnum;
};
export declare type ContentItemDataConnectionGroupArgs = {
    field: ContentItemDataFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type ContentItemDataConnectionMaxArgs = {
    field: ContentItemDataFieldsEnum;
};
export declare type ContentItemDataConnectionMinArgs = {
    field: ContentItemDataFieldsEnum;
};
export declare type ContentItemDataConnectionSumArgs = {
    field: ContentItemDataFieldsEnum;
};
export declare type ContentItemDataCustomData = {
    __typename?: 'ContentItemDataCustomData';
    description?: Maybe<Scalars['String']>;
    editPage?: Maybe<ContentItemDataCustomDataEditPage>;
    imageLink?: Maybe<Scalars['String']>;
    pageLink?: Maybe<File>;
    redirectFrom?: Maybe<Array<Maybe<Scalars['String']>>>;
    seo?: Maybe<ContentItemDataCustomDataSeo>;
    sidebar?: Maybe<File>;
    staticImageLink?: Maybe<File>;
    title?: Maybe<Scalars['String']>;
    toc?: Maybe<ContentItemDataCustomDataToc>;
};
export declare type ContentItemDataCustomDataEditPage = {
    __typename?: 'ContentItemDataCustomDataEditPage';
    disable?: Maybe<Scalars['Boolean']>;
};
export declare type ContentItemDataCustomDataEditPageFilterInput = {
    disable?: InputMaybe<BooleanQueryOperatorInput>;
};
export declare type ContentItemDataCustomDataFilterInput = {
    description?: InputMaybe<StringQueryOperatorInput>;
    editPage?: InputMaybe<ContentItemDataCustomDataEditPageFilterInput>;
    imageLink?: InputMaybe<StringQueryOperatorInput>;
    pageLink?: InputMaybe<FileFilterInput>;
    redirectFrom?: InputMaybe<StringQueryOperatorInput>;
    seo?: InputMaybe<ContentItemDataCustomDataSeoFilterInput>;
    sidebar?: InputMaybe<FileFilterInput>;
    staticImageLink?: InputMaybe<FileFilterInput>;
    title?: InputMaybe<StringQueryOperatorInput>;
    toc?: InputMaybe<ContentItemDataCustomDataTocFilterInput>;
};
export declare type ContentItemDataCustomDataSeo = {
    __typename?: 'ContentItemDataCustomDataSeo';
    description?: Maybe<Scalars['String']>;
    image?: Maybe<Scalars['String']>;
    keywords?: Maybe<Scalars['String']>;
    lang?: Maybe<Scalars['String']>;
    sitemap?: Maybe<ContentItemDataCustomDataSeoSitemap>;
    title?: Maybe<Scalars['String']>;
};
export declare type ContentItemDataCustomDataSeoFilterInput = {
    description?: InputMaybe<StringQueryOperatorInput>;
    image?: InputMaybe<StringQueryOperatorInput>;
    keywords?: InputMaybe<StringQueryOperatorInput>;
    lang?: InputMaybe<StringQueryOperatorInput>;
    sitemap?: InputMaybe<ContentItemDataCustomDataSeoSitemapFilterInput>;
    title?: InputMaybe<StringQueryOperatorInput>;
};
export declare type ContentItemDataCustomDataSeoSitemap = {
    __typename?: 'ContentItemDataCustomDataSeoSitemap';
    changefreq?: Maybe<Scalars['String']>;
    lastmod?: Maybe<Scalars['Date']>;
    priority?: Maybe<Scalars['Float']>;
};
export declare type ContentItemDataCustomDataSeoSitemapLastmodArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type ContentItemDataCustomDataSeoSitemapFilterInput = {
    changefreq?: InputMaybe<StringQueryOperatorInput>;
    lastmod?: InputMaybe<DateQueryOperatorInput>;
    priority?: InputMaybe<FloatQueryOperatorInput>;
};
export declare type ContentItemDataCustomDataToc = {
    __typename?: 'ContentItemDataCustomDataToc';
    enable?: Maybe<Scalars['Boolean']>;
};
export declare type ContentItemDataCustomDataTocFilterInput = {
    enable?: InputMaybe<BooleanQueryOperatorInput>;
};
export declare type ContentItemDataEdge = {
    __typename?: 'ContentItemDataEdge';
    next?: Maybe<ContentItemData>;
    node: ContentItemData;
    previous?: Maybe<ContentItemData>;
};
export declare type ContentItemDataEditPage = {
    __typename?: 'ContentItemDataEditPage';
    disable?: Maybe<Scalars['Boolean']>;
};
export declare type ContentItemDataEditPageFilterInput = {
    disable?: InputMaybe<BooleanQueryOperatorInput>;
};
export declare enum ContentItemDataFieldsEnum {
    apiVersionId = "apiVersionId",
    apiVersions = "apiVersions",
    apiVersions___apiId = "apiVersions___apiId",
    apiVersions___definitionId = "apiVersions___definitionId",
    apiVersions___id = "apiVersions___id",
    apiVersions___isDefault = "apiVersions___isDefault",
    apiVersions___label = "apiVersions___label",
    apiVersions___settings___generateCodeSamples___languages = "apiVersions___settings___generateCodeSamples___languages",
    apiVersions___settings___pagination = "apiVersions___settings___pagination",
    apiVersions___title = "apiVersions___title",
    children = "children",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    customDataString = "customDataString",
    customData___description = "customData___description",
    customData___editPage___disable = "customData___editPage___disable",
    customData___imageLink = "customData___imageLink",
    customData___pageLink___absolutePath = "customData___pageLink___absolutePath",
    customData___pageLink___accessTime = "customData___pageLink___accessTime",
    customData___pageLink___atime = "customData___pageLink___atime",
    customData___pageLink___atimeMs = "customData___pageLink___atimeMs",
    customData___pageLink___base = "customData___pageLink___base",
    customData___pageLink___birthTime = "customData___pageLink___birthTime",
    customData___pageLink___birthtime = "customData___pageLink___birthtime",
    customData___pageLink___birthtimeMs = "customData___pageLink___birthtimeMs",
    customData___pageLink___blksize = "customData___pageLink___blksize",
    customData___pageLink___blocks = "customData___pageLink___blocks",
    customData___pageLink___changeTime = "customData___pageLink___changeTime",
    customData___pageLink___childContentItem___baseLink = "customData___pageLink___childContentItem___baseLink",
    customData___pageLink___childContentItem___children = "customData___pageLink___childContentItem___children",
    customData___pageLink___childContentItem___id = "customData___pageLink___childContentItem___id",
    customData___pageLink___childContentItem___link = "customData___pageLink___childContentItem___link",
    customData___pageLink___childContentItem___pageId = "customData___pageLink___childContentItem___pageId",
    customData___pageLink___childContentItem___permission = "customData___pageLink___childContentItem___permission",
    customData___pageLink___childContentItem___sourcePath = "customData___pageLink___childContentItem___sourcePath",
    customData___pageLink___childContentItem___type = "customData___pageLink___childContentItem___type",
    customData___pageLink___childMarkdownRemark___children = "customData___pageLink___childMarkdownRemark___children",
    customData___pageLink___childMarkdownRemark___excerpt = "customData___pageLink___childMarkdownRemark___excerpt",
    customData___pageLink___childMarkdownRemark___excerptAst = "customData___pageLink___childMarkdownRemark___excerptAst",
    customData___pageLink___childMarkdownRemark___fileAbsolutePath = "customData___pageLink___childMarkdownRemark___fileAbsolutePath",
    customData___pageLink___childMarkdownRemark___headings = "customData___pageLink___childMarkdownRemark___headings",
    customData___pageLink___childMarkdownRemark___html = "customData___pageLink___childMarkdownRemark___html",
    customData___pageLink___childMarkdownRemark___htmlAst = "customData___pageLink___childMarkdownRemark___htmlAst",
    customData___pageLink___childMarkdownRemark___id = "customData___pageLink___childMarkdownRemark___id",
    customData___pageLink___childMarkdownRemark___rawMarkdownBody = "customData___pageLink___childMarkdownRemark___rawMarkdownBody",
    customData___pageLink___childMarkdownRemark___tableOfContents = "customData___pageLink___childMarkdownRemark___tableOfContents",
    customData___pageLink___childMarkdownRemark___timeToRead = "customData___pageLink___childMarkdownRemark___timeToRead",
    customData___pageLink___children = "customData___pageLink___children",
    customData___pageLink___childrenContentItem = "customData___pageLink___childrenContentItem",
    customData___pageLink___childrenContentItem___baseLink = "customData___pageLink___childrenContentItem___baseLink",
    customData___pageLink___childrenContentItem___children = "customData___pageLink___childrenContentItem___children",
    customData___pageLink___childrenContentItem___id = "customData___pageLink___childrenContentItem___id",
    customData___pageLink___childrenContentItem___link = "customData___pageLink___childrenContentItem___link",
    customData___pageLink___childrenContentItem___pageId = "customData___pageLink___childrenContentItem___pageId",
    customData___pageLink___childrenContentItem___permission = "customData___pageLink___childrenContentItem___permission",
    customData___pageLink___childrenContentItem___sourcePath = "customData___pageLink___childrenContentItem___sourcePath",
    customData___pageLink___childrenContentItem___type = "customData___pageLink___childrenContentItem___type",
    customData___pageLink___childrenMarkdownRemark = "customData___pageLink___childrenMarkdownRemark",
    customData___pageLink___childrenMarkdownRemark___children = "customData___pageLink___childrenMarkdownRemark___children",
    customData___pageLink___childrenMarkdownRemark___excerpt = "customData___pageLink___childrenMarkdownRemark___excerpt",
    customData___pageLink___childrenMarkdownRemark___excerptAst = "customData___pageLink___childrenMarkdownRemark___excerptAst",
    customData___pageLink___childrenMarkdownRemark___fileAbsolutePath = "customData___pageLink___childrenMarkdownRemark___fileAbsolutePath",
    customData___pageLink___childrenMarkdownRemark___headings = "customData___pageLink___childrenMarkdownRemark___headings",
    customData___pageLink___childrenMarkdownRemark___html = "customData___pageLink___childrenMarkdownRemark___html",
    customData___pageLink___childrenMarkdownRemark___htmlAst = "customData___pageLink___childrenMarkdownRemark___htmlAst",
    customData___pageLink___childrenMarkdownRemark___id = "customData___pageLink___childrenMarkdownRemark___id",
    customData___pageLink___childrenMarkdownRemark___rawMarkdownBody = "customData___pageLink___childrenMarkdownRemark___rawMarkdownBody",
    customData___pageLink___childrenMarkdownRemark___tableOfContents = "customData___pageLink___childrenMarkdownRemark___tableOfContents",
    customData___pageLink___childrenMarkdownRemark___timeToRead = "customData___pageLink___childrenMarkdownRemark___timeToRead",
    customData___pageLink___children___children = "customData___pageLink___children___children",
    customData___pageLink___children___id = "customData___pageLink___children___id",
    customData___pageLink___ctime = "customData___pageLink___ctime",
    customData___pageLink___ctimeMs = "customData___pageLink___ctimeMs",
    customData___pageLink___dev = "customData___pageLink___dev",
    customData___pageLink___dir = "customData___pageLink___dir",
    customData___pageLink___ext = "customData___pageLink___ext",
    customData___pageLink___extension = "customData___pageLink___extension",
    customData___pageLink___gid = "customData___pageLink___gid",
    customData___pageLink___id = "customData___pageLink___id",
    customData___pageLink___ino = "customData___pageLink___ino",
    customData___pageLink___internal___content = "customData___pageLink___internal___content",
    customData___pageLink___internal___contentDigest = "customData___pageLink___internal___contentDigest",
    customData___pageLink___internal___description = "customData___pageLink___internal___description",
    customData___pageLink___internal___fieldOwners = "customData___pageLink___internal___fieldOwners",
    customData___pageLink___internal___ignoreType = "customData___pageLink___internal___ignoreType",
    customData___pageLink___internal___mediaType = "customData___pageLink___internal___mediaType",
    customData___pageLink___internal___owner = "customData___pageLink___internal___owner",
    customData___pageLink___internal___type = "customData___pageLink___internal___type",
    customData___pageLink___mode = "customData___pageLink___mode",
    customData___pageLink___modifiedTime = "customData___pageLink___modifiedTime",
    customData___pageLink___mtime = "customData___pageLink___mtime",
    customData___pageLink___mtimeMs = "customData___pageLink___mtimeMs",
    customData___pageLink___name = "customData___pageLink___name",
    customData___pageLink___nlink = "customData___pageLink___nlink",
    customData___pageLink___parent___children = "customData___pageLink___parent___children",
    customData___pageLink___parent___id = "customData___pageLink___parent___id",
    customData___pageLink___prettySize = "customData___pageLink___prettySize",
    customData___pageLink___publicURL = "customData___pageLink___publicURL",
    customData___pageLink___rdev = "customData___pageLink___rdev",
    customData___pageLink___relativeDirectory = "customData___pageLink___relativeDirectory",
    customData___pageLink___relativePath = "customData___pageLink___relativePath",
    customData___pageLink___root = "customData___pageLink___root",
    customData___pageLink___size = "customData___pageLink___size",
    customData___pageLink___sourceInstanceName = "customData___pageLink___sourceInstanceName",
    customData___pageLink___uid = "customData___pageLink___uid",
    customData___redirectFrom = "customData___redirectFrom",
    customData___seo___description = "customData___seo___description",
    customData___seo___image = "customData___seo___image",
    customData___seo___keywords = "customData___seo___keywords",
    customData___seo___lang = "customData___seo___lang",
    customData___seo___sitemap___changefreq = "customData___seo___sitemap___changefreq",
    customData___seo___sitemap___lastmod = "customData___seo___sitemap___lastmod",
    customData___seo___sitemap___priority = "customData___seo___sitemap___priority",
    customData___seo___title = "customData___seo___title",
    customData___sidebar___absolutePath = "customData___sidebar___absolutePath",
    customData___sidebar___accessTime = "customData___sidebar___accessTime",
    customData___sidebar___atime = "customData___sidebar___atime",
    customData___sidebar___atimeMs = "customData___sidebar___atimeMs",
    customData___sidebar___base = "customData___sidebar___base",
    customData___sidebar___birthTime = "customData___sidebar___birthTime",
    customData___sidebar___birthtime = "customData___sidebar___birthtime",
    customData___sidebar___birthtimeMs = "customData___sidebar___birthtimeMs",
    customData___sidebar___blksize = "customData___sidebar___blksize",
    customData___sidebar___blocks = "customData___sidebar___blocks",
    customData___sidebar___changeTime = "customData___sidebar___changeTime",
    customData___sidebar___childContentItem___baseLink = "customData___sidebar___childContentItem___baseLink",
    customData___sidebar___childContentItem___children = "customData___sidebar___childContentItem___children",
    customData___sidebar___childContentItem___id = "customData___sidebar___childContentItem___id",
    customData___sidebar___childContentItem___link = "customData___sidebar___childContentItem___link",
    customData___sidebar___childContentItem___pageId = "customData___sidebar___childContentItem___pageId",
    customData___sidebar___childContentItem___permission = "customData___sidebar___childContentItem___permission",
    customData___sidebar___childContentItem___sourcePath = "customData___sidebar___childContentItem___sourcePath",
    customData___sidebar___childContentItem___type = "customData___sidebar___childContentItem___type",
    customData___sidebar___childMarkdownRemark___children = "customData___sidebar___childMarkdownRemark___children",
    customData___sidebar___childMarkdownRemark___excerpt = "customData___sidebar___childMarkdownRemark___excerpt",
    customData___sidebar___childMarkdownRemark___excerptAst = "customData___sidebar___childMarkdownRemark___excerptAst",
    customData___sidebar___childMarkdownRemark___fileAbsolutePath = "customData___sidebar___childMarkdownRemark___fileAbsolutePath",
    customData___sidebar___childMarkdownRemark___headings = "customData___sidebar___childMarkdownRemark___headings",
    customData___sidebar___childMarkdownRemark___html = "customData___sidebar___childMarkdownRemark___html",
    customData___sidebar___childMarkdownRemark___htmlAst = "customData___sidebar___childMarkdownRemark___htmlAst",
    customData___sidebar___childMarkdownRemark___id = "customData___sidebar___childMarkdownRemark___id",
    customData___sidebar___childMarkdownRemark___rawMarkdownBody = "customData___sidebar___childMarkdownRemark___rawMarkdownBody",
    customData___sidebar___childMarkdownRemark___tableOfContents = "customData___sidebar___childMarkdownRemark___tableOfContents",
    customData___sidebar___childMarkdownRemark___timeToRead = "customData___sidebar___childMarkdownRemark___timeToRead",
    customData___sidebar___children = "customData___sidebar___children",
    customData___sidebar___childrenContentItem = "customData___sidebar___childrenContentItem",
    customData___sidebar___childrenContentItem___baseLink = "customData___sidebar___childrenContentItem___baseLink",
    customData___sidebar___childrenContentItem___children = "customData___sidebar___childrenContentItem___children",
    customData___sidebar___childrenContentItem___id = "customData___sidebar___childrenContentItem___id",
    customData___sidebar___childrenContentItem___link = "customData___sidebar___childrenContentItem___link",
    customData___sidebar___childrenContentItem___pageId = "customData___sidebar___childrenContentItem___pageId",
    customData___sidebar___childrenContentItem___permission = "customData___sidebar___childrenContentItem___permission",
    customData___sidebar___childrenContentItem___sourcePath = "customData___sidebar___childrenContentItem___sourcePath",
    customData___sidebar___childrenContentItem___type = "customData___sidebar___childrenContentItem___type",
    customData___sidebar___childrenMarkdownRemark = "customData___sidebar___childrenMarkdownRemark",
    customData___sidebar___childrenMarkdownRemark___children = "customData___sidebar___childrenMarkdownRemark___children",
    customData___sidebar___childrenMarkdownRemark___excerpt = "customData___sidebar___childrenMarkdownRemark___excerpt",
    customData___sidebar___childrenMarkdownRemark___excerptAst = "customData___sidebar___childrenMarkdownRemark___excerptAst",
    customData___sidebar___childrenMarkdownRemark___fileAbsolutePath = "customData___sidebar___childrenMarkdownRemark___fileAbsolutePath",
    customData___sidebar___childrenMarkdownRemark___headings = "customData___sidebar___childrenMarkdownRemark___headings",
    customData___sidebar___childrenMarkdownRemark___html = "customData___sidebar___childrenMarkdownRemark___html",
    customData___sidebar___childrenMarkdownRemark___htmlAst = "customData___sidebar___childrenMarkdownRemark___htmlAst",
    customData___sidebar___childrenMarkdownRemark___id = "customData___sidebar___childrenMarkdownRemark___id",
    customData___sidebar___childrenMarkdownRemark___rawMarkdownBody = "customData___sidebar___childrenMarkdownRemark___rawMarkdownBody",
    customData___sidebar___childrenMarkdownRemark___tableOfContents = "customData___sidebar___childrenMarkdownRemark___tableOfContents",
    customData___sidebar___childrenMarkdownRemark___timeToRead = "customData___sidebar___childrenMarkdownRemark___timeToRead",
    customData___sidebar___children___children = "customData___sidebar___children___children",
    customData___sidebar___children___id = "customData___sidebar___children___id",
    customData___sidebar___ctime = "customData___sidebar___ctime",
    customData___sidebar___ctimeMs = "customData___sidebar___ctimeMs",
    customData___sidebar___dev = "customData___sidebar___dev",
    customData___sidebar___dir = "customData___sidebar___dir",
    customData___sidebar___ext = "customData___sidebar___ext",
    customData___sidebar___extension = "customData___sidebar___extension",
    customData___sidebar___gid = "customData___sidebar___gid",
    customData___sidebar___id = "customData___sidebar___id",
    customData___sidebar___ino = "customData___sidebar___ino",
    customData___sidebar___internal___content = "customData___sidebar___internal___content",
    customData___sidebar___internal___contentDigest = "customData___sidebar___internal___contentDigest",
    customData___sidebar___internal___description = "customData___sidebar___internal___description",
    customData___sidebar___internal___fieldOwners = "customData___sidebar___internal___fieldOwners",
    customData___sidebar___internal___ignoreType = "customData___sidebar___internal___ignoreType",
    customData___sidebar___internal___mediaType = "customData___sidebar___internal___mediaType",
    customData___sidebar___internal___owner = "customData___sidebar___internal___owner",
    customData___sidebar___internal___type = "customData___sidebar___internal___type",
    customData___sidebar___mode = "customData___sidebar___mode",
    customData___sidebar___modifiedTime = "customData___sidebar___modifiedTime",
    customData___sidebar___mtime = "customData___sidebar___mtime",
    customData___sidebar___mtimeMs = "customData___sidebar___mtimeMs",
    customData___sidebar___name = "customData___sidebar___name",
    customData___sidebar___nlink = "customData___sidebar___nlink",
    customData___sidebar___parent___children = "customData___sidebar___parent___children",
    customData___sidebar___parent___id = "customData___sidebar___parent___id",
    customData___sidebar___prettySize = "customData___sidebar___prettySize",
    customData___sidebar___publicURL = "customData___sidebar___publicURL",
    customData___sidebar___rdev = "customData___sidebar___rdev",
    customData___sidebar___relativeDirectory = "customData___sidebar___relativeDirectory",
    customData___sidebar___relativePath = "customData___sidebar___relativePath",
    customData___sidebar___root = "customData___sidebar___root",
    customData___sidebar___size = "customData___sidebar___size",
    customData___sidebar___sourceInstanceName = "customData___sidebar___sourceInstanceName",
    customData___sidebar___uid = "customData___sidebar___uid",
    customData___staticImageLink___absolutePath = "customData___staticImageLink___absolutePath",
    customData___staticImageLink___accessTime = "customData___staticImageLink___accessTime",
    customData___staticImageLink___atime = "customData___staticImageLink___atime",
    customData___staticImageLink___atimeMs = "customData___staticImageLink___atimeMs",
    customData___staticImageLink___base = "customData___staticImageLink___base",
    customData___staticImageLink___birthTime = "customData___staticImageLink___birthTime",
    customData___staticImageLink___birthtime = "customData___staticImageLink___birthtime",
    customData___staticImageLink___birthtimeMs = "customData___staticImageLink___birthtimeMs",
    customData___staticImageLink___blksize = "customData___staticImageLink___blksize",
    customData___staticImageLink___blocks = "customData___staticImageLink___blocks",
    customData___staticImageLink___changeTime = "customData___staticImageLink___changeTime",
    customData___staticImageLink___childContentItem___baseLink = "customData___staticImageLink___childContentItem___baseLink",
    customData___staticImageLink___childContentItem___children = "customData___staticImageLink___childContentItem___children",
    customData___staticImageLink___childContentItem___id = "customData___staticImageLink___childContentItem___id",
    customData___staticImageLink___childContentItem___link = "customData___staticImageLink___childContentItem___link",
    customData___staticImageLink___childContentItem___pageId = "customData___staticImageLink___childContentItem___pageId",
    customData___staticImageLink___childContentItem___permission = "customData___staticImageLink___childContentItem___permission",
    customData___staticImageLink___childContentItem___sourcePath = "customData___staticImageLink___childContentItem___sourcePath",
    customData___staticImageLink___childContentItem___type = "customData___staticImageLink___childContentItem___type",
    customData___staticImageLink___childMarkdownRemark___children = "customData___staticImageLink___childMarkdownRemark___children",
    customData___staticImageLink___childMarkdownRemark___excerpt = "customData___staticImageLink___childMarkdownRemark___excerpt",
    customData___staticImageLink___childMarkdownRemark___excerptAst = "customData___staticImageLink___childMarkdownRemark___excerptAst",
    customData___staticImageLink___childMarkdownRemark___fileAbsolutePath = "customData___staticImageLink___childMarkdownRemark___fileAbsolutePath",
    customData___staticImageLink___childMarkdownRemark___headings = "customData___staticImageLink___childMarkdownRemark___headings",
    customData___staticImageLink___childMarkdownRemark___html = "customData___staticImageLink___childMarkdownRemark___html",
    customData___staticImageLink___childMarkdownRemark___htmlAst = "customData___staticImageLink___childMarkdownRemark___htmlAst",
    customData___staticImageLink___childMarkdownRemark___id = "customData___staticImageLink___childMarkdownRemark___id",
    customData___staticImageLink___childMarkdownRemark___rawMarkdownBody = "customData___staticImageLink___childMarkdownRemark___rawMarkdownBody",
    customData___staticImageLink___childMarkdownRemark___tableOfContents = "customData___staticImageLink___childMarkdownRemark___tableOfContents",
    customData___staticImageLink___childMarkdownRemark___timeToRead = "customData___staticImageLink___childMarkdownRemark___timeToRead",
    customData___staticImageLink___children = "customData___staticImageLink___children",
    customData___staticImageLink___childrenContentItem = "customData___staticImageLink___childrenContentItem",
    customData___staticImageLink___childrenContentItem___baseLink = "customData___staticImageLink___childrenContentItem___baseLink",
    customData___staticImageLink___childrenContentItem___children = "customData___staticImageLink___childrenContentItem___children",
    customData___staticImageLink___childrenContentItem___id = "customData___staticImageLink___childrenContentItem___id",
    customData___staticImageLink___childrenContentItem___link = "customData___staticImageLink___childrenContentItem___link",
    customData___staticImageLink___childrenContentItem___pageId = "customData___staticImageLink___childrenContentItem___pageId",
    customData___staticImageLink___childrenContentItem___permission = "customData___staticImageLink___childrenContentItem___permission",
    customData___staticImageLink___childrenContentItem___sourcePath = "customData___staticImageLink___childrenContentItem___sourcePath",
    customData___staticImageLink___childrenContentItem___type = "customData___staticImageLink___childrenContentItem___type",
    customData___staticImageLink___childrenMarkdownRemark = "customData___staticImageLink___childrenMarkdownRemark",
    customData___staticImageLink___childrenMarkdownRemark___children = "customData___staticImageLink___childrenMarkdownRemark___children",
    customData___staticImageLink___childrenMarkdownRemark___excerpt = "customData___staticImageLink___childrenMarkdownRemark___excerpt",
    customData___staticImageLink___childrenMarkdownRemark___excerptAst = "customData___staticImageLink___childrenMarkdownRemark___excerptAst",
    customData___staticImageLink___childrenMarkdownRemark___fileAbsolutePath = "customData___staticImageLink___childrenMarkdownRemark___fileAbsolutePath",
    customData___staticImageLink___childrenMarkdownRemark___headings = "customData___staticImageLink___childrenMarkdownRemark___headings",
    customData___staticImageLink___childrenMarkdownRemark___html = "customData___staticImageLink___childrenMarkdownRemark___html",
    customData___staticImageLink___childrenMarkdownRemark___htmlAst = "customData___staticImageLink___childrenMarkdownRemark___htmlAst",
    customData___staticImageLink___childrenMarkdownRemark___id = "customData___staticImageLink___childrenMarkdownRemark___id",
    customData___staticImageLink___childrenMarkdownRemark___rawMarkdownBody = "customData___staticImageLink___childrenMarkdownRemark___rawMarkdownBody",
    customData___staticImageLink___childrenMarkdownRemark___tableOfContents = "customData___staticImageLink___childrenMarkdownRemark___tableOfContents",
    customData___staticImageLink___childrenMarkdownRemark___timeToRead = "customData___staticImageLink___childrenMarkdownRemark___timeToRead",
    customData___staticImageLink___children___children = "customData___staticImageLink___children___children",
    customData___staticImageLink___children___id = "customData___staticImageLink___children___id",
    customData___staticImageLink___ctime = "customData___staticImageLink___ctime",
    customData___staticImageLink___ctimeMs = "customData___staticImageLink___ctimeMs",
    customData___staticImageLink___dev = "customData___staticImageLink___dev",
    customData___staticImageLink___dir = "customData___staticImageLink___dir",
    customData___staticImageLink___ext = "customData___staticImageLink___ext",
    customData___staticImageLink___extension = "customData___staticImageLink___extension",
    customData___staticImageLink___gid = "customData___staticImageLink___gid",
    customData___staticImageLink___id = "customData___staticImageLink___id",
    customData___staticImageLink___ino = "customData___staticImageLink___ino",
    customData___staticImageLink___internal___content = "customData___staticImageLink___internal___content",
    customData___staticImageLink___internal___contentDigest = "customData___staticImageLink___internal___contentDigest",
    customData___staticImageLink___internal___description = "customData___staticImageLink___internal___description",
    customData___staticImageLink___internal___fieldOwners = "customData___staticImageLink___internal___fieldOwners",
    customData___staticImageLink___internal___ignoreType = "customData___staticImageLink___internal___ignoreType",
    customData___staticImageLink___internal___mediaType = "customData___staticImageLink___internal___mediaType",
    customData___staticImageLink___internal___owner = "customData___staticImageLink___internal___owner",
    customData___staticImageLink___internal___type = "customData___staticImageLink___internal___type",
    customData___staticImageLink___mode = "customData___staticImageLink___mode",
    customData___staticImageLink___modifiedTime = "customData___staticImageLink___modifiedTime",
    customData___staticImageLink___mtime = "customData___staticImageLink___mtime",
    customData___staticImageLink___mtimeMs = "customData___staticImageLink___mtimeMs",
    customData___staticImageLink___name = "customData___staticImageLink___name",
    customData___staticImageLink___nlink = "customData___staticImageLink___nlink",
    customData___staticImageLink___parent___children = "customData___staticImageLink___parent___children",
    customData___staticImageLink___parent___id = "customData___staticImageLink___parent___id",
    customData___staticImageLink___prettySize = "customData___staticImageLink___prettySize",
    customData___staticImageLink___publicURL = "customData___staticImageLink___publicURL",
    customData___staticImageLink___rdev = "customData___staticImageLink___rdev",
    customData___staticImageLink___relativeDirectory = "customData___staticImageLink___relativeDirectory",
    customData___staticImageLink___relativePath = "customData___staticImageLink___relativePath",
    customData___staticImageLink___root = "customData___staticImageLink___root",
    customData___staticImageLink___size = "customData___staticImageLink___size",
    customData___staticImageLink___sourceInstanceName = "customData___staticImageLink___sourceInstanceName",
    customData___staticImageLink___uid = "customData___staticImageLink___uid",
    customData___title = "customData___title",
    customData___toc___enable = "customData___toc___enable",
    customTemplate = "customTemplate",
    definitionId = "definitionId",
    disableEditPage = "disableEditPage",
    disableLastModified = "disableLastModified",
    editPage___disable = "editPage___disable",
    enableToc = "enableToc",
    excludeFromSearch = "excludeFromSearch",
    httpVerb = "httpVerb",
    id = "id",
    image = "image",
    imageLink = "imageLink",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    isDefaultApiVersion = "isDefaultApiVersion",
    keywords = "keywords",
    label = "label",
    lang = "lang",
    lastModified = "lastModified",
    matchPath = "matchPath",
    pageLink___absolutePath = "pageLink___absolutePath",
    pageLink___accessTime = "pageLink___accessTime",
    pageLink___atime = "pageLink___atime",
    pageLink___atimeMs = "pageLink___atimeMs",
    pageLink___base = "pageLink___base",
    pageLink___birthTime = "pageLink___birthTime",
    pageLink___birthtime = "pageLink___birthtime",
    pageLink___birthtimeMs = "pageLink___birthtimeMs",
    pageLink___blksize = "pageLink___blksize",
    pageLink___blocks = "pageLink___blocks",
    pageLink___changeTime = "pageLink___changeTime",
    pageLink___childContentItem___baseLink = "pageLink___childContentItem___baseLink",
    pageLink___childContentItem___catalogInfo___apiName = "pageLink___childContentItem___catalogInfo___apiName",
    pageLink___childContentItem___catalogInfo___apiVersion = "pageLink___childContentItem___catalogInfo___apiVersion",
    pageLink___childContentItem___catalogInfo___metadata = "pageLink___childContentItem___catalogInfo___metadata",
    pageLink___childContentItem___catalogInfo___title = "pageLink___childContentItem___catalogInfo___title",
    pageLink___childContentItem___children = "pageLink___childContentItem___children",
    pageLink___childContentItem___children___children = "pageLink___childContentItem___children___children",
    pageLink___childContentItem___children___id = "pageLink___childContentItem___children___id",
    pageLink___childContentItem___data___apiVersionId = "pageLink___childContentItem___data___apiVersionId",
    pageLink___childContentItem___data___apiVersions = "pageLink___childContentItem___data___apiVersions",
    pageLink___childContentItem___data___children = "pageLink___childContentItem___data___children",
    pageLink___childContentItem___data___customDataString = "pageLink___childContentItem___data___customDataString",
    pageLink___childContentItem___data___customTemplate = "pageLink___childContentItem___data___customTemplate",
    pageLink___childContentItem___data___definitionId = "pageLink___childContentItem___data___definitionId",
    pageLink___childContentItem___data___disableEditPage = "pageLink___childContentItem___data___disableEditPage",
    pageLink___childContentItem___data___disableLastModified = "pageLink___childContentItem___data___disableLastModified",
    pageLink___childContentItem___data___enableToc = "pageLink___childContentItem___data___enableToc",
    pageLink___childContentItem___data___excludeFromSearch = "pageLink___childContentItem___data___excludeFromSearch",
    pageLink___childContentItem___data___httpVerb = "pageLink___childContentItem___data___httpVerb",
    pageLink___childContentItem___data___id = "pageLink___childContentItem___data___id",
    pageLink___childContentItem___data___image = "pageLink___childContentItem___data___image",
    pageLink___childContentItem___data___imageLink = "pageLink___childContentItem___data___imageLink",
    pageLink___childContentItem___data___isDefaultApiVersion = "pageLink___childContentItem___data___isDefaultApiVersion",
    pageLink___childContentItem___data___keywords = "pageLink___childContentItem___data___keywords",
    pageLink___childContentItem___data___label = "pageLink___childContentItem___data___label",
    pageLink___childContentItem___data___lang = "pageLink___childContentItem___data___lang",
    pageLink___childContentItem___data___lastModified = "pageLink___childContentItem___data___lastModified",
    pageLink___childContentItem___data___matchPath = "pageLink___childContentItem___data___matchPath",
    pageLink___childContentItem___data___permission = "pageLink___childContentItem___data___permission",
    pageLink___childContentItem___data___redirect = "pageLink___childContentItem___data___redirect",
    pageLink___childContentItem___data___redirectFrom = "pageLink___childContentItem___data___redirectFrom",
    pageLink___childContentItem___data___redocHasInfoPage = "pageLink___childContentItem___data___redocHasInfoPage",
    pageLink___childContentItem___data___redocHasSecurityDefinitions = "pageLink___childContentItem___data___redocHasSecurityDefinitions",
    pageLink___childContentItem___data___redocInfoPageId = "pageLink___childContentItem___data___redocInfoPageId",
    pageLink___childContentItem___data___redocInfoPageLink = "pageLink___childContentItem___data___redocInfoPageLink",
    pageLink___childContentItem___data___redocItemId = "pageLink___childContentItem___data___redocItemId",
    pageLink___childContentItem___data___redocMenuItems = "pageLink___childContentItem___data___redocMenuItems",
    pageLink___childContentItem___data___redocNextLabel = "pageLink___childContentItem___data___redocNextLabel",
    pageLink___childContentItem___data___redocNextLink = "pageLink___childContentItem___data___redocNextLink",
    pageLink___childContentItem___data___redocPagination = "pageLink___childContentItem___data___redocPagination",
    pageLink___childContentItem___data___redocPrevLabel = "pageLink___childContentItem___data___redocPrevLabel",
    pageLink___childContentItem___data___redocPrevLink = "pageLink___childContentItem___data___redocPrevLink",
    pageLink___childContentItem___data___redocStoreStr = "pageLink___childContentItem___data___redocStoreStr",
    pageLink___childContentItem___data___requestLogin = "pageLink___childContentItem___data___requestLogin",
    pageLink___childContentItem___data___settings = "pageLink___childContentItem___data___settings",
    pageLink___childContentItem___data___showNextButton = "pageLink___childContentItem___data___showNextButton",
    pageLink___childContentItem___data___showPrevButton = "pageLink___childContentItem___data___showPrevButton",
    pageLink___childContentItem___data___sourcePath = "pageLink___childContentItem___data___sourcePath",
    pageLink___childContentItem___data___tocMaxDepth = "pageLink___childContentItem___data___tocMaxDepth",
    pageLink___childContentItem___data___type = "pageLink___childContentItem___data___type",
    pageLink___childContentItem___data___versions = "pageLink___childContentItem___data___versions",
    pageLink___childContentItem___id = "pageLink___childContentItem___id",
    pageLink___childContentItem___internal___content = "pageLink___childContentItem___internal___content",
    pageLink___childContentItem___internal___contentDigest = "pageLink___childContentItem___internal___contentDigest",
    pageLink___childContentItem___internal___description = "pageLink___childContentItem___internal___description",
    pageLink___childContentItem___internal___fieldOwners = "pageLink___childContentItem___internal___fieldOwners",
    pageLink___childContentItem___internal___ignoreType = "pageLink___childContentItem___internal___ignoreType",
    pageLink___childContentItem___internal___mediaType = "pageLink___childContentItem___internal___mediaType",
    pageLink___childContentItem___internal___owner = "pageLink___childContentItem___internal___owner",
    pageLink___childContentItem___internal___type = "pageLink___childContentItem___internal___type",
    pageLink___childContentItem___link = "pageLink___childContentItem___link",
    pageLink___childContentItem___markdown___children = "pageLink___childContentItem___markdown___children",
    pageLink___childContentItem___markdown___excerpt = "pageLink___childContentItem___markdown___excerpt",
    pageLink___childContentItem___markdown___excerptAst = "pageLink___childContentItem___markdown___excerptAst",
    pageLink___childContentItem___markdown___fileAbsolutePath = "pageLink___childContentItem___markdown___fileAbsolutePath",
    pageLink___childContentItem___markdown___headings = "pageLink___childContentItem___markdown___headings",
    pageLink___childContentItem___markdown___html = "pageLink___childContentItem___markdown___html",
    pageLink___childContentItem___markdown___htmlAst = "pageLink___childContentItem___markdown___htmlAst",
    pageLink___childContentItem___markdown___id = "pageLink___childContentItem___markdown___id",
    pageLink___childContentItem___markdown___rawMarkdownBody = "pageLink___childContentItem___markdown___rawMarkdownBody",
    pageLink___childContentItem___markdown___tableOfContents = "pageLink___childContentItem___markdown___tableOfContents",
    pageLink___childContentItem___markdown___timeToRead = "pageLink___childContentItem___markdown___timeToRead",
    pageLink___childContentItem___pageId = "pageLink___childContentItem___pageId",
    pageLink___childContentItem___parent___children = "pageLink___childContentItem___parent___children",
    pageLink___childContentItem___parent___id = "pageLink___childContentItem___parent___id",
    pageLink___childContentItem___permission = "pageLink___childContentItem___permission",
    pageLink___childContentItem___seo___children = "pageLink___childContentItem___seo___children",
    pageLink___childContentItem___seo___description = "pageLink___childContentItem___seo___description",
    pageLink___childContentItem___seo___id = "pageLink___childContentItem___seo___id",
    pageLink___childContentItem___seo___image = "pageLink___childContentItem___seo___image",
    pageLink___childContentItem___seo___jsonLd = "pageLink___childContentItem___seo___jsonLd",
    pageLink___childContentItem___seo___keywords = "pageLink___childContentItem___seo___keywords",
    pageLink___childContentItem___seo___lang = "pageLink___childContentItem___seo___lang",
    pageLink___childContentItem___seo___title = "pageLink___childContentItem___seo___title",
    pageLink___childContentItem___sourcePath = "pageLink___childContentItem___sourcePath",
    pageLink___childContentItem___type = "pageLink___childContentItem___type",
    pageLink___childMarkdownRemark___children = "pageLink___childMarkdownRemark___children",
    pageLink___childMarkdownRemark___children___children = "pageLink___childMarkdownRemark___children___children",
    pageLink___childMarkdownRemark___children___id = "pageLink___childMarkdownRemark___children___id",
    pageLink___childMarkdownRemark___excerpt = "pageLink___childMarkdownRemark___excerpt",
    pageLink___childMarkdownRemark___excerptAst = "pageLink___childMarkdownRemark___excerptAst",
    pageLink___childMarkdownRemark___fields___contentId = "pageLink___childMarkdownRemark___fields___contentId",
    pageLink___childMarkdownRemark___fileAbsolutePath = "pageLink___childMarkdownRemark___fileAbsolutePath",
    pageLink___childMarkdownRemark___frontmatter___children = "pageLink___childMarkdownRemark___frontmatter___children",
    pageLink___childMarkdownRemark___frontmatter___description = "pageLink___childMarkdownRemark___frontmatter___description",
    pageLink___childMarkdownRemark___frontmatter___disableLastModified = "pageLink___childMarkdownRemark___frontmatter___disableLastModified",
    pageLink___childMarkdownRemark___frontmatter___enableToc = "pageLink___childMarkdownRemark___frontmatter___enableToc",
    pageLink___childMarkdownRemark___frontmatter___id = "pageLink___childMarkdownRemark___frontmatter___id",
    pageLink___childMarkdownRemark___frontmatter___redirectFrom = "pageLink___childMarkdownRemark___frontmatter___redirectFrom",
    pageLink___childMarkdownRemark___frontmatter___sidebar = "pageLink___childMarkdownRemark___frontmatter___sidebar",
    pageLink___childMarkdownRemark___frontmatter___title = "pageLink___childMarkdownRemark___frontmatter___title",
    pageLink___childMarkdownRemark___frontmatter___tocMaxDepth = "pageLink___childMarkdownRemark___frontmatter___tocMaxDepth",
    pageLink___childMarkdownRemark___headings = "pageLink___childMarkdownRemark___headings",
    pageLink___childMarkdownRemark___headings___depth = "pageLink___childMarkdownRemark___headings___depth",
    pageLink___childMarkdownRemark___headings___id = "pageLink___childMarkdownRemark___headings___id",
    pageLink___childMarkdownRemark___headings___value = "pageLink___childMarkdownRemark___headings___value",
    pageLink___childMarkdownRemark___html = "pageLink___childMarkdownRemark___html",
    pageLink___childMarkdownRemark___htmlAst = "pageLink___childMarkdownRemark___htmlAst",
    pageLink___childMarkdownRemark___id = "pageLink___childMarkdownRemark___id",
    pageLink___childMarkdownRemark___internal___content = "pageLink___childMarkdownRemark___internal___content",
    pageLink___childMarkdownRemark___internal___contentDigest = "pageLink___childMarkdownRemark___internal___contentDigest",
    pageLink___childMarkdownRemark___internal___description = "pageLink___childMarkdownRemark___internal___description",
    pageLink___childMarkdownRemark___internal___fieldOwners = "pageLink___childMarkdownRemark___internal___fieldOwners",
    pageLink___childMarkdownRemark___internal___ignoreType = "pageLink___childMarkdownRemark___internal___ignoreType",
    pageLink___childMarkdownRemark___internal___mediaType = "pageLink___childMarkdownRemark___internal___mediaType",
    pageLink___childMarkdownRemark___internal___owner = "pageLink___childMarkdownRemark___internal___owner",
    pageLink___childMarkdownRemark___internal___type = "pageLink___childMarkdownRemark___internal___type",
    pageLink___childMarkdownRemark___parent___children = "pageLink___childMarkdownRemark___parent___children",
    pageLink___childMarkdownRemark___parent___id = "pageLink___childMarkdownRemark___parent___id",
    pageLink___childMarkdownRemark___rawMarkdownBody = "pageLink___childMarkdownRemark___rawMarkdownBody",
    pageLink___childMarkdownRemark___tableOfContents = "pageLink___childMarkdownRemark___tableOfContents",
    pageLink___childMarkdownRemark___timeToRead = "pageLink___childMarkdownRemark___timeToRead",
    pageLink___childMarkdownRemark___wordCount___paragraphs = "pageLink___childMarkdownRemark___wordCount___paragraphs",
    pageLink___childMarkdownRemark___wordCount___sentences = "pageLink___childMarkdownRemark___wordCount___sentences",
    pageLink___childMarkdownRemark___wordCount___words = "pageLink___childMarkdownRemark___wordCount___words",
    pageLink___children = "pageLink___children",
    pageLink___childrenContentItem = "pageLink___childrenContentItem",
    pageLink___childrenContentItem___baseLink = "pageLink___childrenContentItem___baseLink",
    pageLink___childrenContentItem___catalogInfo___apiName = "pageLink___childrenContentItem___catalogInfo___apiName",
    pageLink___childrenContentItem___catalogInfo___apiVersion = "pageLink___childrenContentItem___catalogInfo___apiVersion",
    pageLink___childrenContentItem___catalogInfo___metadata = "pageLink___childrenContentItem___catalogInfo___metadata",
    pageLink___childrenContentItem___catalogInfo___title = "pageLink___childrenContentItem___catalogInfo___title",
    pageLink___childrenContentItem___children = "pageLink___childrenContentItem___children",
    pageLink___childrenContentItem___children___children = "pageLink___childrenContentItem___children___children",
    pageLink___childrenContentItem___children___id = "pageLink___childrenContentItem___children___id",
    pageLink___childrenContentItem___data___apiVersionId = "pageLink___childrenContentItem___data___apiVersionId",
    pageLink___childrenContentItem___data___apiVersions = "pageLink___childrenContentItem___data___apiVersions",
    pageLink___childrenContentItem___data___children = "pageLink___childrenContentItem___data___children",
    pageLink___childrenContentItem___data___customDataString = "pageLink___childrenContentItem___data___customDataString",
    pageLink___childrenContentItem___data___customTemplate = "pageLink___childrenContentItem___data___customTemplate",
    pageLink___childrenContentItem___data___definitionId = "pageLink___childrenContentItem___data___definitionId",
    pageLink___childrenContentItem___data___disableEditPage = "pageLink___childrenContentItem___data___disableEditPage",
    pageLink___childrenContentItem___data___disableLastModified = "pageLink___childrenContentItem___data___disableLastModified",
    pageLink___childrenContentItem___data___enableToc = "pageLink___childrenContentItem___data___enableToc",
    pageLink___childrenContentItem___data___excludeFromSearch = "pageLink___childrenContentItem___data___excludeFromSearch",
    pageLink___childrenContentItem___data___httpVerb = "pageLink___childrenContentItem___data___httpVerb",
    pageLink___childrenContentItem___data___id = "pageLink___childrenContentItem___data___id",
    pageLink___childrenContentItem___data___image = "pageLink___childrenContentItem___data___image",
    pageLink___childrenContentItem___data___imageLink = "pageLink___childrenContentItem___data___imageLink",
    pageLink___childrenContentItem___data___isDefaultApiVersion = "pageLink___childrenContentItem___data___isDefaultApiVersion",
    pageLink___childrenContentItem___data___keywords = "pageLink___childrenContentItem___data___keywords",
    pageLink___childrenContentItem___data___label = "pageLink___childrenContentItem___data___label",
    pageLink___childrenContentItem___data___lang = "pageLink___childrenContentItem___data___lang",
    pageLink___childrenContentItem___data___lastModified = "pageLink___childrenContentItem___data___lastModified",
    pageLink___childrenContentItem___data___matchPath = "pageLink___childrenContentItem___data___matchPath",
    pageLink___childrenContentItem___data___permission = "pageLink___childrenContentItem___data___permission",
    pageLink___childrenContentItem___data___redirect = "pageLink___childrenContentItem___data___redirect",
    pageLink___childrenContentItem___data___redirectFrom = "pageLink___childrenContentItem___data___redirectFrom",
    pageLink___childrenContentItem___data___redocHasInfoPage = "pageLink___childrenContentItem___data___redocHasInfoPage",
    pageLink___childrenContentItem___data___redocHasSecurityDefinitions = "pageLink___childrenContentItem___data___redocHasSecurityDefinitions",
    pageLink___childrenContentItem___data___redocInfoPageId = "pageLink___childrenContentItem___data___redocInfoPageId",
    pageLink___childrenContentItem___data___redocInfoPageLink = "pageLink___childrenContentItem___data___redocInfoPageLink",
    pageLink___childrenContentItem___data___redocItemId = "pageLink___childrenContentItem___data___redocItemId",
    pageLink___childrenContentItem___data___redocMenuItems = "pageLink___childrenContentItem___data___redocMenuItems",
    pageLink___childrenContentItem___data___redocNextLabel = "pageLink___childrenContentItem___data___redocNextLabel",
    pageLink___childrenContentItem___data___redocNextLink = "pageLink___childrenContentItem___data___redocNextLink",
    pageLink___childrenContentItem___data___redocPagination = "pageLink___childrenContentItem___data___redocPagination",
    pageLink___childrenContentItem___data___redocPrevLabel = "pageLink___childrenContentItem___data___redocPrevLabel",
    pageLink___childrenContentItem___data___redocPrevLink = "pageLink___childrenContentItem___data___redocPrevLink",
    pageLink___childrenContentItem___data___redocStoreStr = "pageLink___childrenContentItem___data___redocStoreStr",
    pageLink___childrenContentItem___data___requestLogin = "pageLink___childrenContentItem___data___requestLogin",
    pageLink___childrenContentItem___data___settings = "pageLink___childrenContentItem___data___settings",
    pageLink___childrenContentItem___data___showNextButton = "pageLink___childrenContentItem___data___showNextButton",
    pageLink___childrenContentItem___data___showPrevButton = "pageLink___childrenContentItem___data___showPrevButton",
    pageLink___childrenContentItem___data___sourcePath = "pageLink___childrenContentItem___data___sourcePath",
    pageLink___childrenContentItem___data___tocMaxDepth = "pageLink___childrenContentItem___data___tocMaxDepth",
    pageLink___childrenContentItem___data___type = "pageLink___childrenContentItem___data___type",
    pageLink___childrenContentItem___data___versions = "pageLink___childrenContentItem___data___versions",
    pageLink___childrenContentItem___id = "pageLink___childrenContentItem___id",
    pageLink___childrenContentItem___internal___content = "pageLink___childrenContentItem___internal___content",
    pageLink___childrenContentItem___internal___contentDigest = "pageLink___childrenContentItem___internal___contentDigest",
    pageLink___childrenContentItem___internal___description = "pageLink___childrenContentItem___internal___description",
    pageLink___childrenContentItem___internal___fieldOwners = "pageLink___childrenContentItem___internal___fieldOwners",
    pageLink___childrenContentItem___internal___ignoreType = "pageLink___childrenContentItem___internal___ignoreType",
    pageLink___childrenContentItem___internal___mediaType = "pageLink___childrenContentItem___internal___mediaType",
    pageLink___childrenContentItem___internal___owner = "pageLink___childrenContentItem___internal___owner",
    pageLink___childrenContentItem___internal___type = "pageLink___childrenContentItem___internal___type",
    pageLink___childrenContentItem___link = "pageLink___childrenContentItem___link",
    pageLink___childrenContentItem___markdown___children = "pageLink___childrenContentItem___markdown___children",
    pageLink___childrenContentItem___markdown___excerpt = "pageLink___childrenContentItem___markdown___excerpt",
    pageLink___childrenContentItem___markdown___excerptAst = "pageLink___childrenContentItem___markdown___excerptAst",
    pageLink___childrenContentItem___markdown___fileAbsolutePath = "pageLink___childrenContentItem___markdown___fileAbsolutePath",
    pageLink___childrenContentItem___markdown___headings = "pageLink___childrenContentItem___markdown___headings",
    pageLink___childrenContentItem___markdown___html = "pageLink___childrenContentItem___markdown___html",
    pageLink___childrenContentItem___markdown___htmlAst = "pageLink___childrenContentItem___markdown___htmlAst",
    pageLink___childrenContentItem___markdown___id = "pageLink___childrenContentItem___markdown___id",
    pageLink___childrenContentItem___markdown___rawMarkdownBody = "pageLink___childrenContentItem___markdown___rawMarkdownBody",
    pageLink___childrenContentItem___markdown___tableOfContents = "pageLink___childrenContentItem___markdown___tableOfContents",
    pageLink___childrenContentItem___markdown___timeToRead = "pageLink___childrenContentItem___markdown___timeToRead",
    pageLink___childrenContentItem___pageId = "pageLink___childrenContentItem___pageId",
    pageLink___childrenContentItem___parent___children = "pageLink___childrenContentItem___parent___children",
    pageLink___childrenContentItem___parent___id = "pageLink___childrenContentItem___parent___id",
    pageLink___childrenContentItem___permission = "pageLink___childrenContentItem___permission",
    pageLink___childrenContentItem___seo___children = "pageLink___childrenContentItem___seo___children",
    pageLink___childrenContentItem___seo___description = "pageLink___childrenContentItem___seo___description",
    pageLink___childrenContentItem___seo___id = "pageLink___childrenContentItem___seo___id",
    pageLink___childrenContentItem___seo___image = "pageLink___childrenContentItem___seo___image",
    pageLink___childrenContentItem___seo___jsonLd = "pageLink___childrenContentItem___seo___jsonLd",
    pageLink___childrenContentItem___seo___keywords = "pageLink___childrenContentItem___seo___keywords",
    pageLink___childrenContentItem___seo___lang = "pageLink___childrenContentItem___seo___lang",
    pageLink___childrenContentItem___seo___title = "pageLink___childrenContentItem___seo___title",
    pageLink___childrenContentItem___sourcePath = "pageLink___childrenContentItem___sourcePath",
    pageLink___childrenContentItem___type = "pageLink___childrenContentItem___type",
    pageLink___childrenMarkdownRemark = "pageLink___childrenMarkdownRemark",
    pageLink___childrenMarkdownRemark___children = "pageLink___childrenMarkdownRemark___children",
    pageLink___childrenMarkdownRemark___children___children = "pageLink___childrenMarkdownRemark___children___children",
    pageLink___childrenMarkdownRemark___children___id = "pageLink___childrenMarkdownRemark___children___id",
    pageLink___childrenMarkdownRemark___excerpt = "pageLink___childrenMarkdownRemark___excerpt",
    pageLink___childrenMarkdownRemark___excerptAst = "pageLink___childrenMarkdownRemark___excerptAst",
    pageLink___childrenMarkdownRemark___fields___contentId = "pageLink___childrenMarkdownRemark___fields___contentId",
    pageLink___childrenMarkdownRemark___fileAbsolutePath = "pageLink___childrenMarkdownRemark___fileAbsolutePath",
    pageLink___childrenMarkdownRemark___frontmatter___children = "pageLink___childrenMarkdownRemark___frontmatter___children",
    pageLink___childrenMarkdownRemark___frontmatter___description = "pageLink___childrenMarkdownRemark___frontmatter___description",
    pageLink___childrenMarkdownRemark___frontmatter___disableLastModified = "pageLink___childrenMarkdownRemark___frontmatter___disableLastModified",
    pageLink___childrenMarkdownRemark___frontmatter___enableToc = "pageLink___childrenMarkdownRemark___frontmatter___enableToc",
    pageLink___childrenMarkdownRemark___frontmatter___id = "pageLink___childrenMarkdownRemark___frontmatter___id",
    pageLink___childrenMarkdownRemark___frontmatter___redirectFrom = "pageLink___childrenMarkdownRemark___frontmatter___redirectFrom",
    pageLink___childrenMarkdownRemark___frontmatter___sidebar = "pageLink___childrenMarkdownRemark___frontmatter___sidebar",
    pageLink___childrenMarkdownRemark___frontmatter___title = "pageLink___childrenMarkdownRemark___frontmatter___title",
    pageLink___childrenMarkdownRemark___frontmatter___tocMaxDepth = "pageLink___childrenMarkdownRemark___frontmatter___tocMaxDepth",
    pageLink___childrenMarkdownRemark___headings = "pageLink___childrenMarkdownRemark___headings",
    pageLink___childrenMarkdownRemark___headings___depth = "pageLink___childrenMarkdownRemark___headings___depth",
    pageLink___childrenMarkdownRemark___headings___id = "pageLink___childrenMarkdownRemark___headings___id",
    pageLink___childrenMarkdownRemark___headings___value = "pageLink___childrenMarkdownRemark___headings___value",
    pageLink___childrenMarkdownRemark___html = "pageLink___childrenMarkdownRemark___html",
    pageLink___childrenMarkdownRemark___htmlAst = "pageLink___childrenMarkdownRemark___htmlAst",
    pageLink___childrenMarkdownRemark___id = "pageLink___childrenMarkdownRemark___id",
    pageLink___childrenMarkdownRemark___internal___content = "pageLink___childrenMarkdownRemark___internal___content",
    pageLink___childrenMarkdownRemark___internal___contentDigest = "pageLink___childrenMarkdownRemark___internal___contentDigest",
    pageLink___childrenMarkdownRemark___internal___description = "pageLink___childrenMarkdownRemark___internal___description",
    pageLink___childrenMarkdownRemark___internal___fieldOwners = "pageLink___childrenMarkdownRemark___internal___fieldOwners",
    pageLink___childrenMarkdownRemark___internal___ignoreType = "pageLink___childrenMarkdownRemark___internal___ignoreType",
    pageLink___childrenMarkdownRemark___internal___mediaType = "pageLink___childrenMarkdownRemark___internal___mediaType",
    pageLink___childrenMarkdownRemark___internal___owner = "pageLink___childrenMarkdownRemark___internal___owner",
    pageLink___childrenMarkdownRemark___internal___type = "pageLink___childrenMarkdownRemark___internal___type",
    pageLink___childrenMarkdownRemark___parent___children = "pageLink___childrenMarkdownRemark___parent___children",
    pageLink___childrenMarkdownRemark___parent___id = "pageLink___childrenMarkdownRemark___parent___id",
    pageLink___childrenMarkdownRemark___rawMarkdownBody = "pageLink___childrenMarkdownRemark___rawMarkdownBody",
    pageLink___childrenMarkdownRemark___tableOfContents = "pageLink___childrenMarkdownRemark___tableOfContents",
    pageLink___childrenMarkdownRemark___timeToRead = "pageLink___childrenMarkdownRemark___timeToRead",
    pageLink___childrenMarkdownRemark___wordCount___paragraphs = "pageLink___childrenMarkdownRemark___wordCount___paragraphs",
    pageLink___childrenMarkdownRemark___wordCount___sentences = "pageLink___childrenMarkdownRemark___wordCount___sentences",
    pageLink___childrenMarkdownRemark___wordCount___words = "pageLink___childrenMarkdownRemark___wordCount___words",
    pageLink___children___children = "pageLink___children___children",
    pageLink___children___children___children = "pageLink___children___children___children",
    pageLink___children___children___id = "pageLink___children___children___id",
    pageLink___children___id = "pageLink___children___id",
    pageLink___children___internal___content = "pageLink___children___internal___content",
    pageLink___children___internal___contentDigest = "pageLink___children___internal___contentDigest",
    pageLink___children___internal___description = "pageLink___children___internal___description",
    pageLink___children___internal___fieldOwners = "pageLink___children___internal___fieldOwners",
    pageLink___children___internal___ignoreType = "pageLink___children___internal___ignoreType",
    pageLink___children___internal___mediaType = "pageLink___children___internal___mediaType",
    pageLink___children___internal___owner = "pageLink___children___internal___owner",
    pageLink___children___internal___type = "pageLink___children___internal___type",
    pageLink___children___parent___children = "pageLink___children___parent___children",
    pageLink___children___parent___id = "pageLink___children___parent___id",
    pageLink___ctime = "pageLink___ctime",
    pageLink___ctimeMs = "pageLink___ctimeMs",
    pageLink___dev = "pageLink___dev",
    pageLink___dir = "pageLink___dir",
    pageLink___ext = "pageLink___ext",
    pageLink___extension = "pageLink___extension",
    pageLink___gid = "pageLink___gid",
    pageLink___id = "pageLink___id",
    pageLink___ino = "pageLink___ino",
    pageLink___internal___content = "pageLink___internal___content",
    pageLink___internal___contentDigest = "pageLink___internal___contentDigest",
    pageLink___internal___description = "pageLink___internal___description",
    pageLink___internal___fieldOwners = "pageLink___internal___fieldOwners",
    pageLink___internal___ignoreType = "pageLink___internal___ignoreType",
    pageLink___internal___mediaType = "pageLink___internal___mediaType",
    pageLink___internal___owner = "pageLink___internal___owner",
    pageLink___internal___type = "pageLink___internal___type",
    pageLink___mode = "pageLink___mode",
    pageLink___modifiedTime = "pageLink___modifiedTime",
    pageLink___mtime = "pageLink___mtime",
    pageLink___mtimeMs = "pageLink___mtimeMs",
    pageLink___name = "pageLink___name",
    pageLink___nlink = "pageLink___nlink",
    pageLink___parent___children = "pageLink___parent___children",
    pageLink___parent___children___children = "pageLink___parent___children___children",
    pageLink___parent___children___id = "pageLink___parent___children___id",
    pageLink___parent___id = "pageLink___parent___id",
    pageLink___parent___internal___content = "pageLink___parent___internal___content",
    pageLink___parent___internal___contentDigest = "pageLink___parent___internal___contentDigest",
    pageLink___parent___internal___description = "pageLink___parent___internal___description",
    pageLink___parent___internal___fieldOwners = "pageLink___parent___internal___fieldOwners",
    pageLink___parent___internal___ignoreType = "pageLink___parent___internal___ignoreType",
    pageLink___parent___internal___mediaType = "pageLink___parent___internal___mediaType",
    pageLink___parent___internal___owner = "pageLink___parent___internal___owner",
    pageLink___parent___internal___type = "pageLink___parent___internal___type",
    pageLink___parent___parent___children = "pageLink___parent___parent___children",
    pageLink___parent___parent___id = "pageLink___parent___parent___id",
    pageLink___prettySize = "pageLink___prettySize",
    pageLink___publicURL = "pageLink___publicURL",
    pageLink___rdev = "pageLink___rdev",
    pageLink___relativeDirectory = "pageLink___relativeDirectory",
    pageLink___relativePath = "pageLink___relativePath",
    pageLink___root = "pageLink___root",
    pageLink___size = "pageLink___size",
    pageLink___sourceInstanceName = "pageLink___sourceInstanceName",
    pageLink___uid = "pageLink___uid",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id",
    permission = "permission",
    redirect = "redirect",
    redirectFrom = "redirectFrom",
    redocHasInfoPage = "redocHasInfoPage",
    redocHasSecurityDefinitions = "redocHasSecurityDefinitions",
    redocInfoPageId = "redocInfoPageId",
    redocInfoPageLink = "redocInfoPageLink",
    redocItemId = "redocItemId",
    redocMenuItems = "redocMenuItems",
    redocMenuItems___apiVersionId = "redocMenuItems___apiVersionId",
    redocMenuItems___httpVerb = "redocMenuItems___httpVerb",
    redocMenuItems___isDefaultApiVersion = "redocMenuItems___isDefaultApiVersion",
    redocMenuItems___label = "redocMenuItems___label",
    redocMenuItems___link = "redocMenuItems___link",
    redocMenuItems___page = "redocMenuItems___page",
    redocMenuItems___pages = "redocMenuItems___pages",
    redocMenuItems___pages___apiVersionId = "redocMenuItems___pages___apiVersionId",
    redocMenuItems___pages___httpVerb = "redocMenuItems___pages___httpVerb",
    redocMenuItems___pages___isDefaultApiVersion = "redocMenuItems___pages___isDefaultApiVersion",
    redocMenuItems___pages___label = "redocMenuItems___pages___label",
    redocMenuItems___pages___page = "redocMenuItems___pages___page",
    redocMenuItems___pages___pagination = "redocMenuItems___pages___pagination",
    redocMenuItems___pages___parentPageId = "redocMenuItems___pages___parentPageId",
    redocMenuItems___pages___permission = "redocMenuItems___pages___permission",
    redocMenuItems___pages___redocFakePage = "redocMenuItems___pages___redocFakePage",
    redocMenuItems___pages___redocInfoPageLink = "redocMenuItems___pages___redocInfoPageLink",
    redocMenuItems___pagination = "redocMenuItems___pagination",
    redocMenuItems___parentPageId = "redocMenuItems___parentPageId",
    redocMenuItems___permission = "redocMenuItems___permission",
    redocMenuItems___redocFakePage = "redocMenuItems___redocFakePage",
    redocMenuItems___redocInfoPageLink = "redocMenuItems___redocInfoPageLink",
    redocMenuItems___separator = "redocMenuItems___separator",
    redocNextLabel = "redocNextLabel",
    redocNextLink = "redocNextLink",
    redocPagination = "redocPagination",
    redocPrevLabel = "redocPrevLabel",
    redocPrevLink = "redocPrevLink",
    redocStoreStr = "redocStoreStr",
    requestLogin = "requestLogin",
    settings = "settings",
    showNextButton = "showNextButton",
    showPrevButton = "showPrevButton",
    sidebar___absolutePath = "sidebar___absolutePath",
    sidebar___accessTime = "sidebar___accessTime",
    sidebar___atime = "sidebar___atime",
    sidebar___atimeMs = "sidebar___atimeMs",
    sidebar___base = "sidebar___base",
    sidebar___birthTime = "sidebar___birthTime",
    sidebar___birthtime = "sidebar___birthtime",
    sidebar___birthtimeMs = "sidebar___birthtimeMs",
    sidebar___blksize = "sidebar___blksize",
    sidebar___blocks = "sidebar___blocks",
    sidebar___changeTime = "sidebar___changeTime",
    sidebar___childContentItem___baseLink = "sidebar___childContentItem___baseLink",
    sidebar___childContentItem___catalogInfo___apiName = "sidebar___childContentItem___catalogInfo___apiName",
    sidebar___childContentItem___catalogInfo___apiVersion = "sidebar___childContentItem___catalogInfo___apiVersion",
    sidebar___childContentItem___catalogInfo___metadata = "sidebar___childContentItem___catalogInfo___metadata",
    sidebar___childContentItem___catalogInfo___title = "sidebar___childContentItem___catalogInfo___title",
    sidebar___childContentItem___children = "sidebar___childContentItem___children",
    sidebar___childContentItem___children___children = "sidebar___childContentItem___children___children",
    sidebar___childContentItem___children___id = "sidebar___childContentItem___children___id",
    sidebar___childContentItem___data___apiVersionId = "sidebar___childContentItem___data___apiVersionId",
    sidebar___childContentItem___data___apiVersions = "sidebar___childContentItem___data___apiVersions",
    sidebar___childContentItem___data___children = "sidebar___childContentItem___data___children",
    sidebar___childContentItem___data___customDataString = "sidebar___childContentItem___data___customDataString",
    sidebar___childContentItem___data___customTemplate = "sidebar___childContentItem___data___customTemplate",
    sidebar___childContentItem___data___definitionId = "sidebar___childContentItem___data___definitionId",
    sidebar___childContentItem___data___disableEditPage = "sidebar___childContentItem___data___disableEditPage",
    sidebar___childContentItem___data___disableLastModified = "sidebar___childContentItem___data___disableLastModified",
    sidebar___childContentItem___data___enableToc = "sidebar___childContentItem___data___enableToc",
    sidebar___childContentItem___data___excludeFromSearch = "sidebar___childContentItem___data___excludeFromSearch",
    sidebar___childContentItem___data___httpVerb = "sidebar___childContentItem___data___httpVerb",
    sidebar___childContentItem___data___id = "sidebar___childContentItem___data___id",
    sidebar___childContentItem___data___image = "sidebar___childContentItem___data___image",
    sidebar___childContentItem___data___imageLink = "sidebar___childContentItem___data___imageLink",
    sidebar___childContentItem___data___isDefaultApiVersion = "sidebar___childContentItem___data___isDefaultApiVersion",
    sidebar___childContentItem___data___keywords = "sidebar___childContentItem___data___keywords",
    sidebar___childContentItem___data___label = "sidebar___childContentItem___data___label",
    sidebar___childContentItem___data___lang = "sidebar___childContentItem___data___lang",
    sidebar___childContentItem___data___lastModified = "sidebar___childContentItem___data___lastModified",
    sidebar___childContentItem___data___matchPath = "sidebar___childContentItem___data___matchPath",
    sidebar___childContentItem___data___permission = "sidebar___childContentItem___data___permission",
    sidebar___childContentItem___data___redirect = "sidebar___childContentItem___data___redirect",
    sidebar___childContentItem___data___redirectFrom = "sidebar___childContentItem___data___redirectFrom",
    sidebar___childContentItem___data___redocHasInfoPage = "sidebar___childContentItem___data___redocHasInfoPage",
    sidebar___childContentItem___data___redocHasSecurityDefinitions = "sidebar___childContentItem___data___redocHasSecurityDefinitions",
    sidebar___childContentItem___data___redocInfoPageId = "sidebar___childContentItem___data___redocInfoPageId",
    sidebar___childContentItem___data___redocInfoPageLink = "sidebar___childContentItem___data___redocInfoPageLink",
    sidebar___childContentItem___data___redocItemId = "sidebar___childContentItem___data___redocItemId",
    sidebar___childContentItem___data___redocMenuItems = "sidebar___childContentItem___data___redocMenuItems",
    sidebar___childContentItem___data___redocNextLabel = "sidebar___childContentItem___data___redocNextLabel",
    sidebar___childContentItem___data___redocNextLink = "sidebar___childContentItem___data___redocNextLink",
    sidebar___childContentItem___data___redocPagination = "sidebar___childContentItem___data___redocPagination",
    sidebar___childContentItem___data___redocPrevLabel = "sidebar___childContentItem___data___redocPrevLabel",
    sidebar___childContentItem___data___redocPrevLink = "sidebar___childContentItem___data___redocPrevLink",
    sidebar___childContentItem___data___redocStoreStr = "sidebar___childContentItem___data___redocStoreStr",
    sidebar___childContentItem___data___requestLogin = "sidebar___childContentItem___data___requestLogin",
    sidebar___childContentItem___data___settings = "sidebar___childContentItem___data___settings",
    sidebar___childContentItem___data___showNextButton = "sidebar___childContentItem___data___showNextButton",
    sidebar___childContentItem___data___showPrevButton = "sidebar___childContentItem___data___showPrevButton",
    sidebar___childContentItem___data___sourcePath = "sidebar___childContentItem___data___sourcePath",
    sidebar___childContentItem___data___tocMaxDepth = "sidebar___childContentItem___data___tocMaxDepth",
    sidebar___childContentItem___data___type = "sidebar___childContentItem___data___type",
    sidebar___childContentItem___data___versions = "sidebar___childContentItem___data___versions",
    sidebar___childContentItem___id = "sidebar___childContentItem___id",
    sidebar___childContentItem___internal___content = "sidebar___childContentItem___internal___content",
    sidebar___childContentItem___internal___contentDigest = "sidebar___childContentItem___internal___contentDigest",
    sidebar___childContentItem___internal___description = "sidebar___childContentItem___internal___description",
    sidebar___childContentItem___internal___fieldOwners = "sidebar___childContentItem___internal___fieldOwners",
    sidebar___childContentItem___internal___ignoreType = "sidebar___childContentItem___internal___ignoreType",
    sidebar___childContentItem___internal___mediaType = "sidebar___childContentItem___internal___mediaType",
    sidebar___childContentItem___internal___owner = "sidebar___childContentItem___internal___owner",
    sidebar___childContentItem___internal___type = "sidebar___childContentItem___internal___type",
    sidebar___childContentItem___link = "sidebar___childContentItem___link",
    sidebar___childContentItem___markdown___children = "sidebar___childContentItem___markdown___children",
    sidebar___childContentItem___markdown___excerpt = "sidebar___childContentItem___markdown___excerpt",
    sidebar___childContentItem___markdown___excerptAst = "sidebar___childContentItem___markdown___excerptAst",
    sidebar___childContentItem___markdown___fileAbsolutePath = "sidebar___childContentItem___markdown___fileAbsolutePath",
    sidebar___childContentItem___markdown___headings = "sidebar___childContentItem___markdown___headings",
    sidebar___childContentItem___markdown___html = "sidebar___childContentItem___markdown___html",
    sidebar___childContentItem___markdown___htmlAst = "sidebar___childContentItem___markdown___htmlAst",
    sidebar___childContentItem___markdown___id = "sidebar___childContentItem___markdown___id",
    sidebar___childContentItem___markdown___rawMarkdownBody = "sidebar___childContentItem___markdown___rawMarkdownBody",
    sidebar___childContentItem___markdown___tableOfContents = "sidebar___childContentItem___markdown___tableOfContents",
    sidebar___childContentItem___markdown___timeToRead = "sidebar___childContentItem___markdown___timeToRead",
    sidebar___childContentItem___pageId = "sidebar___childContentItem___pageId",
    sidebar___childContentItem___parent___children = "sidebar___childContentItem___parent___children",
    sidebar___childContentItem___parent___id = "sidebar___childContentItem___parent___id",
    sidebar___childContentItem___permission = "sidebar___childContentItem___permission",
    sidebar___childContentItem___seo___children = "sidebar___childContentItem___seo___children",
    sidebar___childContentItem___seo___description = "sidebar___childContentItem___seo___description",
    sidebar___childContentItem___seo___id = "sidebar___childContentItem___seo___id",
    sidebar___childContentItem___seo___image = "sidebar___childContentItem___seo___image",
    sidebar___childContentItem___seo___jsonLd = "sidebar___childContentItem___seo___jsonLd",
    sidebar___childContentItem___seo___keywords = "sidebar___childContentItem___seo___keywords",
    sidebar___childContentItem___seo___lang = "sidebar___childContentItem___seo___lang",
    sidebar___childContentItem___seo___title = "sidebar___childContentItem___seo___title",
    sidebar___childContentItem___sourcePath = "sidebar___childContentItem___sourcePath",
    sidebar___childContentItem___type = "sidebar___childContentItem___type",
    sidebar___childMarkdownRemark___children = "sidebar___childMarkdownRemark___children",
    sidebar___childMarkdownRemark___children___children = "sidebar___childMarkdownRemark___children___children",
    sidebar___childMarkdownRemark___children___id = "sidebar___childMarkdownRemark___children___id",
    sidebar___childMarkdownRemark___excerpt = "sidebar___childMarkdownRemark___excerpt",
    sidebar___childMarkdownRemark___excerptAst = "sidebar___childMarkdownRemark___excerptAst",
    sidebar___childMarkdownRemark___fields___contentId = "sidebar___childMarkdownRemark___fields___contentId",
    sidebar___childMarkdownRemark___fileAbsolutePath = "sidebar___childMarkdownRemark___fileAbsolutePath",
    sidebar___childMarkdownRemark___frontmatter___children = "sidebar___childMarkdownRemark___frontmatter___children",
    sidebar___childMarkdownRemark___frontmatter___description = "sidebar___childMarkdownRemark___frontmatter___description",
    sidebar___childMarkdownRemark___frontmatter___disableLastModified = "sidebar___childMarkdownRemark___frontmatter___disableLastModified",
    sidebar___childMarkdownRemark___frontmatter___enableToc = "sidebar___childMarkdownRemark___frontmatter___enableToc",
    sidebar___childMarkdownRemark___frontmatter___id = "sidebar___childMarkdownRemark___frontmatter___id",
    sidebar___childMarkdownRemark___frontmatter___redirectFrom = "sidebar___childMarkdownRemark___frontmatter___redirectFrom",
    sidebar___childMarkdownRemark___frontmatter___sidebar = "sidebar___childMarkdownRemark___frontmatter___sidebar",
    sidebar___childMarkdownRemark___frontmatter___title = "sidebar___childMarkdownRemark___frontmatter___title",
    sidebar___childMarkdownRemark___frontmatter___tocMaxDepth = "sidebar___childMarkdownRemark___frontmatter___tocMaxDepth",
    sidebar___childMarkdownRemark___headings = "sidebar___childMarkdownRemark___headings",
    sidebar___childMarkdownRemark___headings___depth = "sidebar___childMarkdownRemark___headings___depth",
    sidebar___childMarkdownRemark___headings___id = "sidebar___childMarkdownRemark___headings___id",
    sidebar___childMarkdownRemark___headings___value = "sidebar___childMarkdownRemark___headings___value",
    sidebar___childMarkdownRemark___html = "sidebar___childMarkdownRemark___html",
    sidebar___childMarkdownRemark___htmlAst = "sidebar___childMarkdownRemark___htmlAst",
    sidebar___childMarkdownRemark___id = "sidebar___childMarkdownRemark___id",
    sidebar___childMarkdownRemark___internal___content = "sidebar___childMarkdownRemark___internal___content",
    sidebar___childMarkdownRemark___internal___contentDigest = "sidebar___childMarkdownRemark___internal___contentDigest",
    sidebar___childMarkdownRemark___internal___description = "sidebar___childMarkdownRemark___internal___description",
    sidebar___childMarkdownRemark___internal___fieldOwners = "sidebar___childMarkdownRemark___internal___fieldOwners",
    sidebar___childMarkdownRemark___internal___ignoreType = "sidebar___childMarkdownRemark___internal___ignoreType",
    sidebar___childMarkdownRemark___internal___mediaType = "sidebar___childMarkdownRemark___internal___mediaType",
    sidebar___childMarkdownRemark___internal___owner = "sidebar___childMarkdownRemark___internal___owner",
    sidebar___childMarkdownRemark___internal___type = "sidebar___childMarkdownRemark___internal___type",
    sidebar___childMarkdownRemark___parent___children = "sidebar___childMarkdownRemark___parent___children",
    sidebar___childMarkdownRemark___parent___id = "sidebar___childMarkdownRemark___parent___id",
    sidebar___childMarkdownRemark___rawMarkdownBody = "sidebar___childMarkdownRemark___rawMarkdownBody",
    sidebar___childMarkdownRemark___tableOfContents = "sidebar___childMarkdownRemark___tableOfContents",
    sidebar___childMarkdownRemark___timeToRead = "sidebar___childMarkdownRemark___timeToRead",
    sidebar___childMarkdownRemark___wordCount___paragraphs = "sidebar___childMarkdownRemark___wordCount___paragraphs",
    sidebar___childMarkdownRemark___wordCount___sentences = "sidebar___childMarkdownRemark___wordCount___sentences",
    sidebar___childMarkdownRemark___wordCount___words = "sidebar___childMarkdownRemark___wordCount___words",
    sidebar___children = "sidebar___children",
    sidebar___childrenContentItem = "sidebar___childrenContentItem",
    sidebar___childrenContentItem___baseLink = "sidebar___childrenContentItem___baseLink",
    sidebar___childrenContentItem___catalogInfo___apiName = "sidebar___childrenContentItem___catalogInfo___apiName",
    sidebar___childrenContentItem___catalogInfo___apiVersion = "sidebar___childrenContentItem___catalogInfo___apiVersion",
    sidebar___childrenContentItem___catalogInfo___metadata = "sidebar___childrenContentItem___catalogInfo___metadata",
    sidebar___childrenContentItem___catalogInfo___title = "sidebar___childrenContentItem___catalogInfo___title",
    sidebar___childrenContentItem___children = "sidebar___childrenContentItem___children",
    sidebar___childrenContentItem___children___children = "sidebar___childrenContentItem___children___children",
    sidebar___childrenContentItem___children___id = "sidebar___childrenContentItem___children___id",
    sidebar___childrenContentItem___data___apiVersionId = "sidebar___childrenContentItem___data___apiVersionId",
    sidebar___childrenContentItem___data___apiVersions = "sidebar___childrenContentItem___data___apiVersions",
    sidebar___childrenContentItem___data___children = "sidebar___childrenContentItem___data___children",
    sidebar___childrenContentItem___data___customDataString = "sidebar___childrenContentItem___data___customDataString",
    sidebar___childrenContentItem___data___customTemplate = "sidebar___childrenContentItem___data___customTemplate",
    sidebar___childrenContentItem___data___definitionId = "sidebar___childrenContentItem___data___definitionId",
    sidebar___childrenContentItem___data___disableEditPage = "sidebar___childrenContentItem___data___disableEditPage",
    sidebar___childrenContentItem___data___disableLastModified = "sidebar___childrenContentItem___data___disableLastModified",
    sidebar___childrenContentItem___data___enableToc = "sidebar___childrenContentItem___data___enableToc",
    sidebar___childrenContentItem___data___excludeFromSearch = "sidebar___childrenContentItem___data___excludeFromSearch",
    sidebar___childrenContentItem___data___httpVerb = "sidebar___childrenContentItem___data___httpVerb",
    sidebar___childrenContentItem___data___id = "sidebar___childrenContentItem___data___id",
    sidebar___childrenContentItem___data___image = "sidebar___childrenContentItem___data___image",
    sidebar___childrenContentItem___data___imageLink = "sidebar___childrenContentItem___data___imageLink",
    sidebar___childrenContentItem___data___isDefaultApiVersion = "sidebar___childrenContentItem___data___isDefaultApiVersion",
    sidebar___childrenContentItem___data___keywords = "sidebar___childrenContentItem___data___keywords",
    sidebar___childrenContentItem___data___label = "sidebar___childrenContentItem___data___label",
    sidebar___childrenContentItem___data___lang = "sidebar___childrenContentItem___data___lang",
    sidebar___childrenContentItem___data___lastModified = "sidebar___childrenContentItem___data___lastModified",
    sidebar___childrenContentItem___data___matchPath = "sidebar___childrenContentItem___data___matchPath",
    sidebar___childrenContentItem___data___permission = "sidebar___childrenContentItem___data___permission",
    sidebar___childrenContentItem___data___redirect = "sidebar___childrenContentItem___data___redirect",
    sidebar___childrenContentItem___data___redirectFrom = "sidebar___childrenContentItem___data___redirectFrom",
    sidebar___childrenContentItem___data___redocHasInfoPage = "sidebar___childrenContentItem___data___redocHasInfoPage",
    sidebar___childrenContentItem___data___redocHasSecurityDefinitions = "sidebar___childrenContentItem___data___redocHasSecurityDefinitions",
    sidebar___childrenContentItem___data___redocInfoPageId = "sidebar___childrenContentItem___data___redocInfoPageId",
    sidebar___childrenContentItem___data___redocInfoPageLink = "sidebar___childrenContentItem___data___redocInfoPageLink",
    sidebar___childrenContentItem___data___redocItemId = "sidebar___childrenContentItem___data___redocItemId",
    sidebar___childrenContentItem___data___redocMenuItems = "sidebar___childrenContentItem___data___redocMenuItems",
    sidebar___childrenContentItem___data___redocNextLabel = "sidebar___childrenContentItem___data___redocNextLabel",
    sidebar___childrenContentItem___data___redocNextLink = "sidebar___childrenContentItem___data___redocNextLink",
    sidebar___childrenContentItem___data___redocPagination = "sidebar___childrenContentItem___data___redocPagination",
    sidebar___childrenContentItem___data___redocPrevLabel = "sidebar___childrenContentItem___data___redocPrevLabel",
    sidebar___childrenContentItem___data___redocPrevLink = "sidebar___childrenContentItem___data___redocPrevLink",
    sidebar___childrenContentItem___data___redocStoreStr = "sidebar___childrenContentItem___data___redocStoreStr",
    sidebar___childrenContentItem___data___requestLogin = "sidebar___childrenContentItem___data___requestLogin",
    sidebar___childrenContentItem___data___settings = "sidebar___childrenContentItem___data___settings",
    sidebar___childrenContentItem___data___showNextButton = "sidebar___childrenContentItem___data___showNextButton",
    sidebar___childrenContentItem___data___showPrevButton = "sidebar___childrenContentItem___data___showPrevButton",
    sidebar___childrenContentItem___data___sourcePath = "sidebar___childrenContentItem___data___sourcePath",
    sidebar___childrenContentItem___data___tocMaxDepth = "sidebar___childrenContentItem___data___tocMaxDepth",
    sidebar___childrenContentItem___data___type = "sidebar___childrenContentItem___data___type",
    sidebar___childrenContentItem___data___versions = "sidebar___childrenContentItem___data___versions",
    sidebar___childrenContentItem___id = "sidebar___childrenContentItem___id",
    sidebar___childrenContentItem___internal___content = "sidebar___childrenContentItem___internal___content",
    sidebar___childrenContentItem___internal___contentDigest = "sidebar___childrenContentItem___internal___contentDigest",
    sidebar___childrenContentItem___internal___description = "sidebar___childrenContentItem___internal___description",
    sidebar___childrenContentItem___internal___fieldOwners = "sidebar___childrenContentItem___internal___fieldOwners",
    sidebar___childrenContentItem___internal___ignoreType = "sidebar___childrenContentItem___internal___ignoreType",
    sidebar___childrenContentItem___internal___mediaType = "sidebar___childrenContentItem___internal___mediaType",
    sidebar___childrenContentItem___internal___owner = "sidebar___childrenContentItem___internal___owner",
    sidebar___childrenContentItem___internal___type = "sidebar___childrenContentItem___internal___type",
    sidebar___childrenContentItem___link = "sidebar___childrenContentItem___link",
    sidebar___childrenContentItem___markdown___children = "sidebar___childrenContentItem___markdown___children",
    sidebar___childrenContentItem___markdown___excerpt = "sidebar___childrenContentItem___markdown___excerpt",
    sidebar___childrenContentItem___markdown___excerptAst = "sidebar___childrenContentItem___markdown___excerptAst",
    sidebar___childrenContentItem___markdown___fileAbsolutePath = "sidebar___childrenContentItem___markdown___fileAbsolutePath",
    sidebar___childrenContentItem___markdown___headings = "sidebar___childrenContentItem___markdown___headings",
    sidebar___childrenContentItem___markdown___html = "sidebar___childrenContentItem___markdown___html",
    sidebar___childrenContentItem___markdown___htmlAst = "sidebar___childrenContentItem___markdown___htmlAst",
    sidebar___childrenContentItem___markdown___id = "sidebar___childrenContentItem___markdown___id",
    sidebar___childrenContentItem___markdown___rawMarkdownBody = "sidebar___childrenContentItem___markdown___rawMarkdownBody",
    sidebar___childrenContentItem___markdown___tableOfContents = "sidebar___childrenContentItem___markdown___tableOfContents",
    sidebar___childrenContentItem___markdown___timeToRead = "sidebar___childrenContentItem___markdown___timeToRead",
    sidebar___childrenContentItem___pageId = "sidebar___childrenContentItem___pageId",
    sidebar___childrenContentItem___parent___children = "sidebar___childrenContentItem___parent___children",
    sidebar___childrenContentItem___parent___id = "sidebar___childrenContentItem___parent___id",
    sidebar___childrenContentItem___permission = "sidebar___childrenContentItem___permission",
    sidebar___childrenContentItem___seo___children = "sidebar___childrenContentItem___seo___children",
    sidebar___childrenContentItem___seo___description = "sidebar___childrenContentItem___seo___description",
    sidebar___childrenContentItem___seo___id = "sidebar___childrenContentItem___seo___id",
    sidebar___childrenContentItem___seo___image = "sidebar___childrenContentItem___seo___image",
    sidebar___childrenContentItem___seo___jsonLd = "sidebar___childrenContentItem___seo___jsonLd",
    sidebar___childrenContentItem___seo___keywords = "sidebar___childrenContentItem___seo___keywords",
    sidebar___childrenContentItem___seo___lang = "sidebar___childrenContentItem___seo___lang",
    sidebar___childrenContentItem___seo___title = "sidebar___childrenContentItem___seo___title",
    sidebar___childrenContentItem___sourcePath = "sidebar___childrenContentItem___sourcePath",
    sidebar___childrenContentItem___type = "sidebar___childrenContentItem___type",
    sidebar___childrenMarkdownRemark = "sidebar___childrenMarkdownRemark",
    sidebar___childrenMarkdownRemark___children = "sidebar___childrenMarkdownRemark___children",
    sidebar___childrenMarkdownRemark___children___children = "sidebar___childrenMarkdownRemark___children___children",
    sidebar___childrenMarkdownRemark___children___id = "sidebar___childrenMarkdownRemark___children___id",
    sidebar___childrenMarkdownRemark___excerpt = "sidebar___childrenMarkdownRemark___excerpt",
    sidebar___childrenMarkdownRemark___excerptAst = "sidebar___childrenMarkdownRemark___excerptAst",
    sidebar___childrenMarkdownRemark___fields___contentId = "sidebar___childrenMarkdownRemark___fields___contentId",
    sidebar___childrenMarkdownRemark___fileAbsolutePath = "sidebar___childrenMarkdownRemark___fileAbsolutePath",
    sidebar___childrenMarkdownRemark___frontmatter___children = "sidebar___childrenMarkdownRemark___frontmatter___children",
    sidebar___childrenMarkdownRemark___frontmatter___description = "sidebar___childrenMarkdownRemark___frontmatter___description",
    sidebar___childrenMarkdownRemark___frontmatter___disableLastModified = "sidebar___childrenMarkdownRemark___frontmatter___disableLastModified",
    sidebar___childrenMarkdownRemark___frontmatter___enableToc = "sidebar___childrenMarkdownRemark___frontmatter___enableToc",
    sidebar___childrenMarkdownRemark___frontmatter___id = "sidebar___childrenMarkdownRemark___frontmatter___id",
    sidebar___childrenMarkdownRemark___frontmatter___redirectFrom = "sidebar___childrenMarkdownRemark___frontmatter___redirectFrom",
    sidebar___childrenMarkdownRemark___frontmatter___sidebar = "sidebar___childrenMarkdownRemark___frontmatter___sidebar",
    sidebar___childrenMarkdownRemark___frontmatter___title = "sidebar___childrenMarkdownRemark___frontmatter___title",
    sidebar___childrenMarkdownRemark___frontmatter___tocMaxDepth = "sidebar___childrenMarkdownRemark___frontmatter___tocMaxDepth",
    sidebar___childrenMarkdownRemark___headings = "sidebar___childrenMarkdownRemark___headings",
    sidebar___childrenMarkdownRemark___headings___depth = "sidebar___childrenMarkdownRemark___headings___depth",
    sidebar___childrenMarkdownRemark___headings___id = "sidebar___childrenMarkdownRemark___headings___id",
    sidebar___childrenMarkdownRemark___headings___value = "sidebar___childrenMarkdownRemark___headings___value",
    sidebar___childrenMarkdownRemark___html = "sidebar___childrenMarkdownRemark___html",
    sidebar___childrenMarkdownRemark___htmlAst = "sidebar___childrenMarkdownRemark___htmlAst",
    sidebar___childrenMarkdownRemark___id = "sidebar___childrenMarkdownRemark___id",
    sidebar___childrenMarkdownRemark___internal___content = "sidebar___childrenMarkdownRemark___internal___content",
    sidebar___childrenMarkdownRemark___internal___contentDigest = "sidebar___childrenMarkdownRemark___internal___contentDigest",
    sidebar___childrenMarkdownRemark___internal___description = "sidebar___childrenMarkdownRemark___internal___description",
    sidebar___childrenMarkdownRemark___internal___fieldOwners = "sidebar___childrenMarkdownRemark___internal___fieldOwners",
    sidebar___childrenMarkdownRemark___internal___ignoreType = "sidebar___childrenMarkdownRemark___internal___ignoreType",
    sidebar___childrenMarkdownRemark___internal___mediaType = "sidebar___childrenMarkdownRemark___internal___mediaType",
    sidebar___childrenMarkdownRemark___internal___owner = "sidebar___childrenMarkdownRemark___internal___owner",
    sidebar___childrenMarkdownRemark___internal___type = "sidebar___childrenMarkdownRemark___internal___type",
    sidebar___childrenMarkdownRemark___parent___children = "sidebar___childrenMarkdownRemark___parent___children",
    sidebar___childrenMarkdownRemark___parent___id = "sidebar___childrenMarkdownRemark___parent___id",
    sidebar___childrenMarkdownRemark___rawMarkdownBody = "sidebar___childrenMarkdownRemark___rawMarkdownBody",
    sidebar___childrenMarkdownRemark___tableOfContents = "sidebar___childrenMarkdownRemark___tableOfContents",
    sidebar___childrenMarkdownRemark___timeToRead = "sidebar___childrenMarkdownRemark___timeToRead",
    sidebar___childrenMarkdownRemark___wordCount___paragraphs = "sidebar___childrenMarkdownRemark___wordCount___paragraphs",
    sidebar___childrenMarkdownRemark___wordCount___sentences = "sidebar___childrenMarkdownRemark___wordCount___sentences",
    sidebar___childrenMarkdownRemark___wordCount___words = "sidebar___childrenMarkdownRemark___wordCount___words",
    sidebar___children___children = "sidebar___children___children",
    sidebar___children___children___children = "sidebar___children___children___children",
    sidebar___children___children___id = "sidebar___children___children___id",
    sidebar___children___id = "sidebar___children___id",
    sidebar___children___internal___content = "sidebar___children___internal___content",
    sidebar___children___internal___contentDigest = "sidebar___children___internal___contentDigest",
    sidebar___children___internal___description = "sidebar___children___internal___description",
    sidebar___children___internal___fieldOwners = "sidebar___children___internal___fieldOwners",
    sidebar___children___internal___ignoreType = "sidebar___children___internal___ignoreType",
    sidebar___children___internal___mediaType = "sidebar___children___internal___mediaType",
    sidebar___children___internal___owner = "sidebar___children___internal___owner",
    sidebar___children___internal___type = "sidebar___children___internal___type",
    sidebar___children___parent___children = "sidebar___children___parent___children",
    sidebar___children___parent___id = "sidebar___children___parent___id",
    sidebar___ctime = "sidebar___ctime",
    sidebar___ctimeMs = "sidebar___ctimeMs",
    sidebar___dev = "sidebar___dev",
    sidebar___dir = "sidebar___dir",
    sidebar___ext = "sidebar___ext",
    sidebar___extension = "sidebar___extension",
    sidebar___gid = "sidebar___gid",
    sidebar___id = "sidebar___id",
    sidebar___ino = "sidebar___ino",
    sidebar___internal___content = "sidebar___internal___content",
    sidebar___internal___contentDigest = "sidebar___internal___contentDigest",
    sidebar___internal___description = "sidebar___internal___description",
    sidebar___internal___fieldOwners = "sidebar___internal___fieldOwners",
    sidebar___internal___ignoreType = "sidebar___internal___ignoreType",
    sidebar___internal___mediaType = "sidebar___internal___mediaType",
    sidebar___internal___owner = "sidebar___internal___owner",
    sidebar___internal___type = "sidebar___internal___type",
    sidebar___mode = "sidebar___mode",
    sidebar___modifiedTime = "sidebar___modifiedTime",
    sidebar___mtime = "sidebar___mtime",
    sidebar___mtimeMs = "sidebar___mtimeMs",
    sidebar___name = "sidebar___name",
    sidebar___nlink = "sidebar___nlink",
    sidebar___parent___children = "sidebar___parent___children",
    sidebar___parent___children___children = "sidebar___parent___children___children",
    sidebar___parent___children___id = "sidebar___parent___children___id",
    sidebar___parent___id = "sidebar___parent___id",
    sidebar___parent___internal___content = "sidebar___parent___internal___content",
    sidebar___parent___internal___contentDigest = "sidebar___parent___internal___contentDigest",
    sidebar___parent___internal___description = "sidebar___parent___internal___description",
    sidebar___parent___internal___fieldOwners = "sidebar___parent___internal___fieldOwners",
    sidebar___parent___internal___ignoreType = "sidebar___parent___internal___ignoreType",
    sidebar___parent___internal___mediaType = "sidebar___parent___internal___mediaType",
    sidebar___parent___internal___owner = "sidebar___parent___internal___owner",
    sidebar___parent___internal___type = "sidebar___parent___internal___type",
    sidebar___parent___parent___children = "sidebar___parent___parent___children",
    sidebar___parent___parent___id = "sidebar___parent___parent___id",
    sidebar___prettySize = "sidebar___prettySize",
    sidebar___publicURL = "sidebar___publicURL",
    sidebar___rdev = "sidebar___rdev",
    sidebar___relativeDirectory = "sidebar___relativeDirectory",
    sidebar___relativePath = "sidebar___relativePath",
    sidebar___root = "sidebar___root",
    sidebar___size = "sidebar___size",
    sidebar___sourceInstanceName = "sidebar___sourceInstanceName",
    sidebar___uid = "sidebar___uid",
    sitemap___changefreq = "sitemap___changefreq",
    sitemap___lastmod = "sitemap___lastmod",
    sitemap___priority = "sitemap___priority",
    sourcePath = "sourcePath",
    staticImageLink___absolutePath = "staticImageLink___absolutePath",
    staticImageLink___accessTime = "staticImageLink___accessTime",
    staticImageLink___atime = "staticImageLink___atime",
    staticImageLink___atimeMs = "staticImageLink___atimeMs",
    staticImageLink___base = "staticImageLink___base",
    staticImageLink___birthTime = "staticImageLink___birthTime",
    staticImageLink___birthtime = "staticImageLink___birthtime",
    staticImageLink___birthtimeMs = "staticImageLink___birthtimeMs",
    staticImageLink___blksize = "staticImageLink___blksize",
    staticImageLink___blocks = "staticImageLink___blocks",
    staticImageLink___changeTime = "staticImageLink___changeTime",
    staticImageLink___childContentItem___baseLink = "staticImageLink___childContentItem___baseLink",
    staticImageLink___childContentItem___catalogInfo___apiName = "staticImageLink___childContentItem___catalogInfo___apiName",
    staticImageLink___childContentItem___catalogInfo___apiVersion = "staticImageLink___childContentItem___catalogInfo___apiVersion",
    staticImageLink___childContentItem___catalogInfo___metadata = "staticImageLink___childContentItem___catalogInfo___metadata",
    staticImageLink___childContentItem___catalogInfo___title = "staticImageLink___childContentItem___catalogInfo___title",
    staticImageLink___childContentItem___children = "staticImageLink___childContentItem___children",
    staticImageLink___childContentItem___children___children = "staticImageLink___childContentItem___children___children",
    staticImageLink___childContentItem___children___id = "staticImageLink___childContentItem___children___id",
    staticImageLink___childContentItem___data___apiVersionId = "staticImageLink___childContentItem___data___apiVersionId",
    staticImageLink___childContentItem___data___apiVersions = "staticImageLink___childContentItem___data___apiVersions",
    staticImageLink___childContentItem___data___children = "staticImageLink___childContentItem___data___children",
    staticImageLink___childContentItem___data___customDataString = "staticImageLink___childContentItem___data___customDataString",
    staticImageLink___childContentItem___data___customTemplate = "staticImageLink___childContentItem___data___customTemplate",
    staticImageLink___childContentItem___data___definitionId = "staticImageLink___childContentItem___data___definitionId",
    staticImageLink___childContentItem___data___disableEditPage = "staticImageLink___childContentItem___data___disableEditPage",
    staticImageLink___childContentItem___data___disableLastModified = "staticImageLink___childContentItem___data___disableLastModified",
    staticImageLink___childContentItem___data___enableToc = "staticImageLink___childContentItem___data___enableToc",
    staticImageLink___childContentItem___data___excludeFromSearch = "staticImageLink___childContentItem___data___excludeFromSearch",
    staticImageLink___childContentItem___data___httpVerb = "staticImageLink___childContentItem___data___httpVerb",
    staticImageLink___childContentItem___data___id = "staticImageLink___childContentItem___data___id",
    staticImageLink___childContentItem___data___image = "staticImageLink___childContentItem___data___image",
    staticImageLink___childContentItem___data___imageLink = "staticImageLink___childContentItem___data___imageLink",
    staticImageLink___childContentItem___data___isDefaultApiVersion = "staticImageLink___childContentItem___data___isDefaultApiVersion",
    staticImageLink___childContentItem___data___keywords = "staticImageLink___childContentItem___data___keywords",
    staticImageLink___childContentItem___data___label = "staticImageLink___childContentItem___data___label",
    staticImageLink___childContentItem___data___lang = "staticImageLink___childContentItem___data___lang",
    staticImageLink___childContentItem___data___lastModified = "staticImageLink___childContentItem___data___lastModified",
    staticImageLink___childContentItem___data___matchPath = "staticImageLink___childContentItem___data___matchPath",
    staticImageLink___childContentItem___data___permission = "staticImageLink___childContentItem___data___permission",
    staticImageLink___childContentItem___data___redirect = "staticImageLink___childContentItem___data___redirect",
    staticImageLink___childContentItem___data___redirectFrom = "staticImageLink___childContentItem___data___redirectFrom",
    staticImageLink___childContentItem___data___redocHasInfoPage = "staticImageLink___childContentItem___data___redocHasInfoPage",
    staticImageLink___childContentItem___data___redocHasSecurityDefinitions = "staticImageLink___childContentItem___data___redocHasSecurityDefinitions",
    staticImageLink___childContentItem___data___redocInfoPageId = "staticImageLink___childContentItem___data___redocInfoPageId",
    staticImageLink___childContentItem___data___redocInfoPageLink = "staticImageLink___childContentItem___data___redocInfoPageLink",
    staticImageLink___childContentItem___data___redocItemId = "staticImageLink___childContentItem___data___redocItemId",
    staticImageLink___childContentItem___data___redocMenuItems = "staticImageLink___childContentItem___data___redocMenuItems",
    staticImageLink___childContentItem___data___redocNextLabel = "staticImageLink___childContentItem___data___redocNextLabel",
    staticImageLink___childContentItem___data___redocNextLink = "staticImageLink___childContentItem___data___redocNextLink",
    staticImageLink___childContentItem___data___redocPagination = "staticImageLink___childContentItem___data___redocPagination",
    staticImageLink___childContentItem___data___redocPrevLabel = "staticImageLink___childContentItem___data___redocPrevLabel",
    staticImageLink___childContentItem___data___redocPrevLink = "staticImageLink___childContentItem___data___redocPrevLink",
    staticImageLink___childContentItem___data___redocStoreStr = "staticImageLink___childContentItem___data___redocStoreStr",
    staticImageLink___childContentItem___data___requestLogin = "staticImageLink___childContentItem___data___requestLogin",
    staticImageLink___childContentItem___data___settings = "staticImageLink___childContentItem___data___settings",
    staticImageLink___childContentItem___data___showNextButton = "staticImageLink___childContentItem___data___showNextButton",
    staticImageLink___childContentItem___data___showPrevButton = "staticImageLink___childContentItem___data___showPrevButton",
    staticImageLink___childContentItem___data___sourcePath = "staticImageLink___childContentItem___data___sourcePath",
    staticImageLink___childContentItem___data___tocMaxDepth = "staticImageLink___childContentItem___data___tocMaxDepth",
    staticImageLink___childContentItem___data___type = "staticImageLink___childContentItem___data___type",
    staticImageLink___childContentItem___data___versions = "staticImageLink___childContentItem___data___versions",
    staticImageLink___childContentItem___id = "staticImageLink___childContentItem___id",
    staticImageLink___childContentItem___internal___content = "staticImageLink___childContentItem___internal___content",
    staticImageLink___childContentItem___internal___contentDigest = "staticImageLink___childContentItem___internal___contentDigest",
    staticImageLink___childContentItem___internal___description = "staticImageLink___childContentItem___internal___description",
    staticImageLink___childContentItem___internal___fieldOwners = "staticImageLink___childContentItem___internal___fieldOwners",
    staticImageLink___childContentItem___internal___ignoreType = "staticImageLink___childContentItem___internal___ignoreType",
    staticImageLink___childContentItem___internal___mediaType = "staticImageLink___childContentItem___internal___mediaType",
    staticImageLink___childContentItem___internal___owner = "staticImageLink___childContentItem___internal___owner",
    staticImageLink___childContentItem___internal___type = "staticImageLink___childContentItem___internal___type",
    staticImageLink___childContentItem___link = "staticImageLink___childContentItem___link",
    staticImageLink___childContentItem___markdown___children = "staticImageLink___childContentItem___markdown___children",
    staticImageLink___childContentItem___markdown___excerpt = "staticImageLink___childContentItem___markdown___excerpt",
    staticImageLink___childContentItem___markdown___excerptAst = "staticImageLink___childContentItem___markdown___excerptAst",
    staticImageLink___childContentItem___markdown___fileAbsolutePath = "staticImageLink___childContentItem___markdown___fileAbsolutePath",
    staticImageLink___childContentItem___markdown___headings = "staticImageLink___childContentItem___markdown___headings",
    staticImageLink___childContentItem___markdown___html = "staticImageLink___childContentItem___markdown___html",
    staticImageLink___childContentItem___markdown___htmlAst = "staticImageLink___childContentItem___markdown___htmlAst",
    staticImageLink___childContentItem___markdown___id = "staticImageLink___childContentItem___markdown___id",
    staticImageLink___childContentItem___markdown___rawMarkdownBody = "staticImageLink___childContentItem___markdown___rawMarkdownBody",
    staticImageLink___childContentItem___markdown___tableOfContents = "staticImageLink___childContentItem___markdown___tableOfContents",
    staticImageLink___childContentItem___markdown___timeToRead = "staticImageLink___childContentItem___markdown___timeToRead",
    staticImageLink___childContentItem___pageId = "staticImageLink___childContentItem___pageId",
    staticImageLink___childContentItem___parent___children = "staticImageLink___childContentItem___parent___children",
    staticImageLink___childContentItem___parent___id = "staticImageLink___childContentItem___parent___id",
    staticImageLink___childContentItem___permission = "staticImageLink___childContentItem___permission",
    staticImageLink___childContentItem___seo___children = "staticImageLink___childContentItem___seo___children",
    staticImageLink___childContentItem___seo___description = "staticImageLink___childContentItem___seo___description",
    staticImageLink___childContentItem___seo___id = "staticImageLink___childContentItem___seo___id",
    staticImageLink___childContentItem___seo___image = "staticImageLink___childContentItem___seo___image",
    staticImageLink___childContentItem___seo___jsonLd = "staticImageLink___childContentItem___seo___jsonLd",
    staticImageLink___childContentItem___seo___keywords = "staticImageLink___childContentItem___seo___keywords",
    staticImageLink___childContentItem___seo___lang = "staticImageLink___childContentItem___seo___lang",
    staticImageLink___childContentItem___seo___title = "staticImageLink___childContentItem___seo___title",
    staticImageLink___childContentItem___sourcePath = "staticImageLink___childContentItem___sourcePath",
    staticImageLink___childContentItem___type = "staticImageLink___childContentItem___type",
    staticImageLink___childMarkdownRemark___children = "staticImageLink___childMarkdownRemark___children",
    staticImageLink___childMarkdownRemark___children___children = "staticImageLink___childMarkdownRemark___children___children",
    staticImageLink___childMarkdownRemark___children___id = "staticImageLink___childMarkdownRemark___children___id",
    staticImageLink___childMarkdownRemark___excerpt = "staticImageLink___childMarkdownRemark___excerpt",
    staticImageLink___childMarkdownRemark___excerptAst = "staticImageLink___childMarkdownRemark___excerptAst",
    staticImageLink___childMarkdownRemark___fields___contentId = "staticImageLink___childMarkdownRemark___fields___contentId",
    staticImageLink___childMarkdownRemark___fileAbsolutePath = "staticImageLink___childMarkdownRemark___fileAbsolutePath",
    staticImageLink___childMarkdownRemark___frontmatter___children = "staticImageLink___childMarkdownRemark___frontmatter___children",
    staticImageLink___childMarkdownRemark___frontmatter___description = "staticImageLink___childMarkdownRemark___frontmatter___description",
    staticImageLink___childMarkdownRemark___frontmatter___disableLastModified = "staticImageLink___childMarkdownRemark___frontmatter___disableLastModified",
    staticImageLink___childMarkdownRemark___frontmatter___enableToc = "staticImageLink___childMarkdownRemark___frontmatter___enableToc",
    staticImageLink___childMarkdownRemark___frontmatter___id = "staticImageLink___childMarkdownRemark___frontmatter___id",
    staticImageLink___childMarkdownRemark___frontmatter___redirectFrom = "staticImageLink___childMarkdownRemark___frontmatter___redirectFrom",
    staticImageLink___childMarkdownRemark___frontmatter___sidebar = "staticImageLink___childMarkdownRemark___frontmatter___sidebar",
    staticImageLink___childMarkdownRemark___frontmatter___title = "staticImageLink___childMarkdownRemark___frontmatter___title",
    staticImageLink___childMarkdownRemark___frontmatter___tocMaxDepth = "staticImageLink___childMarkdownRemark___frontmatter___tocMaxDepth",
    staticImageLink___childMarkdownRemark___headings = "staticImageLink___childMarkdownRemark___headings",
    staticImageLink___childMarkdownRemark___headings___depth = "staticImageLink___childMarkdownRemark___headings___depth",
    staticImageLink___childMarkdownRemark___headings___id = "staticImageLink___childMarkdownRemark___headings___id",
    staticImageLink___childMarkdownRemark___headings___value = "staticImageLink___childMarkdownRemark___headings___value",
    staticImageLink___childMarkdownRemark___html = "staticImageLink___childMarkdownRemark___html",
    staticImageLink___childMarkdownRemark___htmlAst = "staticImageLink___childMarkdownRemark___htmlAst",
    staticImageLink___childMarkdownRemark___id = "staticImageLink___childMarkdownRemark___id",
    staticImageLink___childMarkdownRemark___internal___content = "staticImageLink___childMarkdownRemark___internal___content",
    staticImageLink___childMarkdownRemark___internal___contentDigest = "staticImageLink___childMarkdownRemark___internal___contentDigest",
    staticImageLink___childMarkdownRemark___internal___description = "staticImageLink___childMarkdownRemark___internal___description",
    staticImageLink___childMarkdownRemark___internal___fieldOwners = "staticImageLink___childMarkdownRemark___internal___fieldOwners",
    staticImageLink___childMarkdownRemark___internal___ignoreType = "staticImageLink___childMarkdownRemark___internal___ignoreType",
    staticImageLink___childMarkdownRemark___internal___mediaType = "staticImageLink___childMarkdownRemark___internal___mediaType",
    staticImageLink___childMarkdownRemark___internal___owner = "staticImageLink___childMarkdownRemark___internal___owner",
    staticImageLink___childMarkdownRemark___internal___type = "staticImageLink___childMarkdownRemark___internal___type",
    staticImageLink___childMarkdownRemark___parent___children = "staticImageLink___childMarkdownRemark___parent___children",
    staticImageLink___childMarkdownRemark___parent___id = "staticImageLink___childMarkdownRemark___parent___id",
    staticImageLink___childMarkdownRemark___rawMarkdownBody = "staticImageLink___childMarkdownRemark___rawMarkdownBody",
    staticImageLink___childMarkdownRemark___tableOfContents = "staticImageLink___childMarkdownRemark___tableOfContents",
    staticImageLink___childMarkdownRemark___timeToRead = "staticImageLink___childMarkdownRemark___timeToRead",
    staticImageLink___childMarkdownRemark___wordCount___paragraphs = "staticImageLink___childMarkdownRemark___wordCount___paragraphs",
    staticImageLink___childMarkdownRemark___wordCount___sentences = "staticImageLink___childMarkdownRemark___wordCount___sentences",
    staticImageLink___childMarkdownRemark___wordCount___words = "staticImageLink___childMarkdownRemark___wordCount___words",
    staticImageLink___children = "staticImageLink___children",
    staticImageLink___childrenContentItem = "staticImageLink___childrenContentItem",
    staticImageLink___childrenContentItem___baseLink = "staticImageLink___childrenContentItem___baseLink",
    staticImageLink___childrenContentItem___catalogInfo___apiName = "staticImageLink___childrenContentItem___catalogInfo___apiName",
    staticImageLink___childrenContentItem___catalogInfo___apiVersion = "staticImageLink___childrenContentItem___catalogInfo___apiVersion",
    staticImageLink___childrenContentItem___catalogInfo___metadata = "staticImageLink___childrenContentItem___catalogInfo___metadata",
    staticImageLink___childrenContentItem___catalogInfo___title = "staticImageLink___childrenContentItem___catalogInfo___title",
    staticImageLink___childrenContentItem___children = "staticImageLink___childrenContentItem___children",
    staticImageLink___childrenContentItem___children___children = "staticImageLink___childrenContentItem___children___children",
    staticImageLink___childrenContentItem___children___id = "staticImageLink___childrenContentItem___children___id",
    staticImageLink___childrenContentItem___data___apiVersionId = "staticImageLink___childrenContentItem___data___apiVersionId",
    staticImageLink___childrenContentItem___data___apiVersions = "staticImageLink___childrenContentItem___data___apiVersions",
    staticImageLink___childrenContentItem___data___children = "staticImageLink___childrenContentItem___data___children",
    staticImageLink___childrenContentItem___data___customDataString = "staticImageLink___childrenContentItem___data___customDataString",
    staticImageLink___childrenContentItem___data___customTemplate = "staticImageLink___childrenContentItem___data___customTemplate",
    staticImageLink___childrenContentItem___data___definitionId = "staticImageLink___childrenContentItem___data___definitionId",
    staticImageLink___childrenContentItem___data___disableEditPage = "staticImageLink___childrenContentItem___data___disableEditPage",
    staticImageLink___childrenContentItem___data___disableLastModified = "staticImageLink___childrenContentItem___data___disableLastModified",
    staticImageLink___childrenContentItem___data___enableToc = "staticImageLink___childrenContentItem___data___enableToc",
    staticImageLink___childrenContentItem___data___excludeFromSearch = "staticImageLink___childrenContentItem___data___excludeFromSearch",
    staticImageLink___childrenContentItem___data___httpVerb = "staticImageLink___childrenContentItem___data___httpVerb",
    staticImageLink___childrenContentItem___data___id = "staticImageLink___childrenContentItem___data___id",
    staticImageLink___childrenContentItem___data___image = "staticImageLink___childrenContentItem___data___image",
    staticImageLink___childrenContentItem___data___imageLink = "staticImageLink___childrenContentItem___data___imageLink",
    staticImageLink___childrenContentItem___data___isDefaultApiVersion = "staticImageLink___childrenContentItem___data___isDefaultApiVersion",
    staticImageLink___childrenContentItem___data___keywords = "staticImageLink___childrenContentItem___data___keywords",
    staticImageLink___childrenContentItem___data___label = "staticImageLink___childrenContentItem___data___label",
    staticImageLink___childrenContentItem___data___lang = "staticImageLink___childrenContentItem___data___lang",
    staticImageLink___childrenContentItem___data___lastModified = "staticImageLink___childrenContentItem___data___lastModified",
    staticImageLink___childrenContentItem___data___matchPath = "staticImageLink___childrenContentItem___data___matchPath",
    staticImageLink___childrenContentItem___data___permission = "staticImageLink___childrenContentItem___data___permission",
    staticImageLink___childrenContentItem___data___redirect = "staticImageLink___childrenContentItem___data___redirect",
    staticImageLink___childrenContentItem___data___redirectFrom = "staticImageLink___childrenContentItem___data___redirectFrom",
    staticImageLink___childrenContentItem___data___redocHasInfoPage = "staticImageLink___childrenContentItem___data___redocHasInfoPage",
    staticImageLink___childrenContentItem___data___redocHasSecurityDefinitions = "staticImageLink___childrenContentItem___data___redocHasSecurityDefinitions",
    staticImageLink___childrenContentItem___data___redocInfoPageId = "staticImageLink___childrenContentItem___data___redocInfoPageId",
    staticImageLink___childrenContentItem___data___redocInfoPageLink = "staticImageLink___childrenContentItem___data___redocInfoPageLink",
    staticImageLink___childrenContentItem___data___redocItemId = "staticImageLink___childrenContentItem___data___redocItemId",
    staticImageLink___childrenContentItem___data___redocMenuItems = "staticImageLink___childrenContentItem___data___redocMenuItems",
    staticImageLink___childrenContentItem___data___redocNextLabel = "staticImageLink___childrenContentItem___data___redocNextLabel",
    staticImageLink___childrenContentItem___data___redocNextLink = "staticImageLink___childrenContentItem___data___redocNextLink",
    staticImageLink___childrenContentItem___data___redocPagination = "staticImageLink___childrenContentItem___data___redocPagination",
    staticImageLink___childrenContentItem___data___redocPrevLabel = "staticImageLink___childrenContentItem___data___redocPrevLabel",
    staticImageLink___childrenContentItem___data___redocPrevLink = "staticImageLink___childrenContentItem___data___redocPrevLink",
    staticImageLink___childrenContentItem___data___redocStoreStr = "staticImageLink___childrenContentItem___data___redocStoreStr",
    staticImageLink___childrenContentItem___data___requestLogin = "staticImageLink___childrenContentItem___data___requestLogin",
    staticImageLink___childrenContentItem___data___settings = "staticImageLink___childrenContentItem___data___settings",
    staticImageLink___childrenContentItem___data___showNextButton = "staticImageLink___childrenContentItem___data___showNextButton",
    staticImageLink___childrenContentItem___data___showPrevButton = "staticImageLink___childrenContentItem___data___showPrevButton",
    staticImageLink___childrenContentItem___data___sourcePath = "staticImageLink___childrenContentItem___data___sourcePath",
    staticImageLink___childrenContentItem___data___tocMaxDepth = "staticImageLink___childrenContentItem___data___tocMaxDepth",
    staticImageLink___childrenContentItem___data___type = "staticImageLink___childrenContentItem___data___type",
    staticImageLink___childrenContentItem___data___versions = "staticImageLink___childrenContentItem___data___versions",
    staticImageLink___childrenContentItem___id = "staticImageLink___childrenContentItem___id",
    staticImageLink___childrenContentItem___internal___content = "staticImageLink___childrenContentItem___internal___content",
    staticImageLink___childrenContentItem___internal___contentDigest = "staticImageLink___childrenContentItem___internal___contentDigest",
    staticImageLink___childrenContentItem___internal___description = "staticImageLink___childrenContentItem___internal___description",
    staticImageLink___childrenContentItem___internal___fieldOwners = "staticImageLink___childrenContentItem___internal___fieldOwners",
    staticImageLink___childrenContentItem___internal___ignoreType = "staticImageLink___childrenContentItem___internal___ignoreType",
    staticImageLink___childrenContentItem___internal___mediaType = "staticImageLink___childrenContentItem___internal___mediaType",
    staticImageLink___childrenContentItem___internal___owner = "staticImageLink___childrenContentItem___internal___owner",
    staticImageLink___childrenContentItem___internal___type = "staticImageLink___childrenContentItem___internal___type",
    staticImageLink___childrenContentItem___link = "staticImageLink___childrenContentItem___link",
    staticImageLink___childrenContentItem___markdown___children = "staticImageLink___childrenContentItem___markdown___children",
    staticImageLink___childrenContentItem___markdown___excerpt = "staticImageLink___childrenContentItem___markdown___excerpt",
    staticImageLink___childrenContentItem___markdown___excerptAst = "staticImageLink___childrenContentItem___markdown___excerptAst",
    staticImageLink___childrenContentItem___markdown___fileAbsolutePath = "staticImageLink___childrenContentItem___markdown___fileAbsolutePath",
    staticImageLink___childrenContentItem___markdown___headings = "staticImageLink___childrenContentItem___markdown___headings",
    staticImageLink___childrenContentItem___markdown___html = "staticImageLink___childrenContentItem___markdown___html",
    staticImageLink___childrenContentItem___markdown___htmlAst = "staticImageLink___childrenContentItem___markdown___htmlAst",
    staticImageLink___childrenContentItem___markdown___id = "staticImageLink___childrenContentItem___markdown___id",
    staticImageLink___childrenContentItem___markdown___rawMarkdownBody = "staticImageLink___childrenContentItem___markdown___rawMarkdownBody",
    staticImageLink___childrenContentItem___markdown___tableOfContents = "staticImageLink___childrenContentItem___markdown___tableOfContents",
    staticImageLink___childrenContentItem___markdown___timeToRead = "staticImageLink___childrenContentItem___markdown___timeToRead",
    staticImageLink___childrenContentItem___pageId = "staticImageLink___childrenContentItem___pageId",
    staticImageLink___childrenContentItem___parent___children = "staticImageLink___childrenContentItem___parent___children",
    staticImageLink___childrenContentItem___parent___id = "staticImageLink___childrenContentItem___parent___id",
    staticImageLink___childrenContentItem___permission = "staticImageLink___childrenContentItem___permission",
    staticImageLink___childrenContentItem___seo___children = "staticImageLink___childrenContentItem___seo___children",
    staticImageLink___childrenContentItem___seo___description = "staticImageLink___childrenContentItem___seo___description",
    staticImageLink___childrenContentItem___seo___id = "staticImageLink___childrenContentItem___seo___id",
    staticImageLink___childrenContentItem___seo___image = "staticImageLink___childrenContentItem___seo___image",
    staticImageLink___childrenContentItem___seo___jsonLd = "staticImageLink___childrenContentItem___seo___jsonLd",
    staticImageLink___childrenContentItem___seo___keywords = "staticImageLink___childrenContentItem___seo___keywords",
    staticImageLink___childrenContentItem___seo___lang = "staticImageLink___childrenContentItem___seo___lang",
    staticImageLink___childrenContentItem___seo___title = "staticImageLink___childrenContentItem___seo___title",
    staticImageLink___childrenContentItem___sourcePath = "staticImageLink___childrenContentItem___sourcePath",
    staticImageLink___childrenContentItem___type = "staticImageLink___childrenContentItem___type",
    staticImageLink___childrenMarkdownRemark = "staticImageLink___childrenMarkdownRemark",
    staticImageLink___childrenMarkdownRemark___children = "staticImageLink___childrenMarkdownRemark___children",
    staticImageLink___childrenMarkdownRemark___children___children = "staticImageLink___childrenMarkdownRemark___children___children",
    staticImageLink___childrenMarkdownRemark___children___id = "staticImageLink___childrenMarkdownRemark___children___id",
    staticImageLink___childrenMarkdownRemark___excerpt = "staticImageLink___childrenMarkdownRemark___excerpt",
    staticImageLink___childrenMarkdownRemark___excerptAst = "staticImageLink___childrenMarkdownRemark___excerptAst",
    staticImageLink___childrenMarkdownRemark___fields___contentId = "staticImageLink___childrenMarkdownRemark___fields___contentId",
    staticImageLink___childrenMarkdownRemark___fileAbsolutePath = "staticImageLink___childrenMarkdownRemark___fileAbsolutePath",
    staticImageLink___childrenMarkdownRemark___frontmatter___children = "staticImageLink___childrenMarkdownRemark___frontmatter___children",
    staticImageLink___childrenMarkdownRemark___frontmatter___description = "staticImageLink___childrenMarkdownRemark___frontmatter___description",
    staticImageLink___childrenMarkdownRemark___frontmatter___disableLastModified = "staticImageLink___childrenMarkdownRemark___frontmatter___disableLastModified",
    staticImageLink___childrenMarkdownRemark___frontmatter___enableToc = "staticImageLink___childrenMarkdownRemark___frontmatter___enableToc",
    staticImageLink___childrenMarkdownRemark___frontmatter___id = "staticImageLink___childrenMarkdownRemark___frontmatter___id",
    staticImageLink___childrenMarkdownRemark___frontmatter___redirectFrom = "staticImageLink___childrenMarkdownRemark___frontmatter___redirectFrom",
    staticImageLink___childrenMarkdownRemark___frontmatter___sidebar = "staticImageLink___childrenMarkdownRemark___frontmatter___sidebar",
    staticImageLink___childrenMarkdownRemark___frontmatter___title = "staticImageLink___childrenMarkdownRemark___frontmatter___title",
    staticImageLink___childrenMarkdownRemark___frontmatter___tocMaxDepth = "staticImageLink___childrenMarkdownRemark___frontmatter___tocMaxDepth",
    staticImageLink___childrenMarkdownRemark___headings = "staticImageLink___childrenMarkdownRemark___headings",
    staticImageLink___childrenMarkdownRemark___headings___depth = "staticImageLink___childrenMarkdownRemark___headings___depth",
    staticImageLink___childrenMarkdownRemark___headings___id = "staticImageLink___childrenMarkdownRemark___headings___id",
    staticImageLink___childrenMarkdownRemark___headings___value = "staticImageLink___childrenMarkdownRemark___headings___value",
    staticImageLink___childrenMarkdownRemark___html = "staticImageLink___childrenMarkdownRemark___html",
    staticImageLink___childrenMarkdownRemark___htmlAst = "staticImageLink___childrenMarkdownRemark___htmlAst",
    staticImageLink___childrenMarkdownRemark___id = "staticImageLink___childrenMarkdownRemark___id",
    staticImageLink___childrenMarkdownRemark___internal___content = "staticImageLink___childrenMarkdownRemark___internal___content",
    staticImageLink___childrenMarkdownRemark___internal___contentDigest = "staticImageLink___childrenMarkdownRemark___internal___contentDigest",
    staticImageLink___childrenMarkdownRemark___internal___description = "staticImageLink___childrenMarkdownRemark___internal___description",
    staticImageLink___childrenMarkdownRemark___internal___fieldOwners = "staticImageLink___childrenMarkdownRemark___internal___fieldOwners",
    staticImageLink___childrenMarkdownRemark___internal___ignoreType = "staticImageLink___childrenMarkdownRemark___internal___ignoreType",
    staticImageLink___childrenMarkdownRemark___internal___mediaType = "staticImageLink___childrenMarkdownRemark___internal___mediaType",
    staticImageLink___childrenMarkdownRemark___internal___owner = "staticImageLink___childrenMarkdownRemark___internal___owner",
    staticImageLink___childrenMarkdownRemark___internal___type = "staticImageLink___childrenMarkdownRemark___internal___type",
    staticImageLink___childrenMarkdownRemark___parent___children = "staticImageLink___childrenMarkdownRemark___parent___children",
    staticImageLink___childrenMarkdownRemark___parent___id = "staticImageLink___childrenMarkdownRemark___parent___id",
    staticImageLink___childrenMarkdownRemark___rawMarkdownBody = "staticImageLink___childrenMarkdownRemark___rawMarkdownBody",
    staticImageLink___childrenMarkdownRemark___tableOfContents = "staticImageLink___childrenMarkdownRemark___tableOfContents",
    staticImageLink___childrenMarkdownRemark___timeToRead = "staticImageLink___childrenMarkdownRemark___timeToRead",
    staticImageLink___childrenMarkdownRemark___wordCount___paragraphs = "staticImageLink___childrenMarkdownRemark___wordCount___paragraphs",
    staticImageLink___childrenMarkdownRemark___wordCount___sentences = "staticImageLink___childrenMarkdownRemark___wordCount___sentences",
    staticImageLink___childrenMarkdownRemark___wordCount___words = "staticImageLink___childrenMarkdownRemark___wordCount___words",
    staticImageLink___children___children = "staticImageLink___children___children",
    staticImageLink___children___children___children = "staticImageLink___children___children___children",
    staticImageLink___children___children___id = "staticImageLink___children___children___id",
    staticImageLink___children___id = "staticImageLink___children___id",
    staticImageLink___children___internal___content = "staticImageLink___children___internal___content",
    staticImageLink___children___internal___contentDigest = "staticImageLink___children___internal___contentDigest",
    staticImageLink___children___internal___description = "staticImageLink___children___internal___description",
    staticImageLink___children___internal___fieldOwners = "staticImageLink___children___internal___fieldOwners",
    staticImageLink___children___internal___ignoreType = "staticImageLink___children___internal___ignoreType",
    staticImageLink___children___internal___mediaType = "staticImageLink___children___internal___mediaType",
    staticImageLink___children___internal___owner = "staticImageLink___children___internal___owner",
    staticImageLink___children___internal___type = "staticImageLink___children___internal___type",
    staticImageLink___children___parent___children = "staticImageLink___children___parent___children",
    staticImageLink___children___parent___id = "staticImageLink___children___parent___id",
    staticImageLink___ctime = "staticImageLink___ctime",
    staticImageLink___ctimeMs = "staticImageLink___ctimeMs",
    staticImageLink___dev = "staticImageLink___dev",
    staticImageLink___dir = "staticImageLink___dir",
    staticImageLink___ext = "staticImageLink___ext",
    staticImageLink___extension = "staticImageLink___extension",
    staticImageLink___gid = "staticImageLink___gid",
    staticImageLink___id = "staticImageLink___id",
    staticImageLink___ino = "staticImageLink___ino",
    staticImageLink___internal___content = "staticImageLink___internal___content",
    staticImageLink___internal___contentDigest = "staticImageLink___internal___contentDigest",
    staticImageLink___internal___description = "staticImageLink___internal___description",
    staticImageLink___internal___fieldOwners = "staticImageLink___internal___fieldOwners",
    staticImageLink___internal___ignoreType = "staticImageLink___internal___ignoreType",
    staticImageLink___internal___mediaType = "staticImageLink___internal___mediaType",
    staticImageLink___internal___owner = "staticImageLink___internal___owner",
    staticImageLink___internal___type = "staticImageLink___internal___type",
    staticImageLink___mode = "staticImageLink___mode",
    staticImageLink___modifiedTime = "staticImageLink___modifiedTime",
    staticImageLink___mtime = "staticImageLink___mtime",
    staticImageLink___mtimeMs = "staticImageLink___mtimeMs",
    staticImageLink___name = "staticImageLink___name",
    staticImageLink___nlink = "staticImageLink___nlink",
    staticImageLink___parent___children = "staticImageLink___parent___children",
    staticImageLink___parent___children___children = "staticImageLink___parent___children___children",
    staticImageLink___parent___children___id = "staticImageLink___parent___children___id",
    staticImageLink___parent___id = "staticImageLink___parent___id",
    staticImageLink___parent___internal___content = "staticImageLink___parent___internal___content",
    staticImageLink___parent___internal___contentDigest = "staticImageLink___parent___internal___contentDigest",
    staticImageLink___parent___internal___description = "staticImageLink___parent___internal___description",
    staticImageLink___parent___internal___fieldOwners = "staticImageLink___parent___internal___fieldOwners",
    staticImageLink___parent___internal___ignoreType = "staticImageLink___parent___internal___ignoreType",
    staticImageLink___parent___internal___mediaType = "staticImageLink___parent___internal___mediaType",
    staticImageLink___parent___internal___owner = "staticImageLink___parent___internal___owner",
    staticImageLink___parent___internal___type = "staticImageLink___parent___internal___type",
    staticImageLink___parent___parent___children = "staticImageLink___parent___parent___children",
    staticImageLink___parent___parent___id = "staticImageLink___parent___parent___id",
    staticImageLink___prettySize = "staticImageLink___prettySize",
    staticImageLink___publicURL = "staticImageLink___publicURL",
    staticImageLink___rdev = "staticImageLink___rdev",
    staticImageLink___relativeDirectory = "staticImageLink___relativeDirectory",
    staticImageLink___relativePath = "staticImageLink___relativePath",
    staticImageLink___root = "staticImageLink___root",
    staticImageLink___size = "staticImageLink___size",
    staticImageLink___sourceInstanceName = "staticImageLink___sourceInstanceName",
    staticImageLink___uid = "staticImageLink___uid",
    tocMaxDepth = "tocMaxDepth",
    toc___enable = "toc___enable",
    toc___headings = "toc___headings",
    toc___headings___depth = "toc___headings___depth",
    toc___headings___id = "toc___headings___id",
    toc___headings___value = "toc___headings___value",
    toc___maxDepth = "toc___maxDepth",
    type = "type",
    versions = "versions",
    versions___definitionId = "versions___definitionId",
    versions___id = "versions___id",
    versions___isDefault = "versions___isDefault",
    versions___label = "versions___label",
    versions___settings___generateCodeSamples___languages = "versions___settings___generateCodeSamples___languages",
    versions___settings___pagination = "versions___settings___pagination",
    versions___title = "versions___title"
}
export declare type ContentItemDataFilterInput = {
    apiVersionId?: InputMaybe<StringQueryOperatorInput>;
    apiVersions?: InputMaybe<ContentItemApiVersionFilterListInput>;
    children?: InputMaybe<NodeFilterListInput>;
    customData?: InputMaybe<ContentItemDataCustomDataFilterInput>;
    customDataString?: InputMaybe<StringQueryOperatorInput>;
    customTemplate?: InputMaybe<StringQueryOperatorInput>;
    definitionId?: InputMaybe<StringQueryOperatorInput>;
    disableEditPage?: InputMaybe<BooleanQueryOperatorInput>;
    disableLastModified?: InputMaybe<BooleanQueryOperatorInput>;
    editPage?: InputMaybe<ContentItemDataEditPageFilterInput>;
    enableToc?: InputMaybe<BooleanQueryOperatorInput>;
    excludeFromSearch?: InputMaybe<BooleanQueryOperatorInput>;
    httpVerb?: InputMaybe<StringQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    image?: InputMaybe<StringQueryOperatorInput>;
    imageLink?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    isDefaultApiVersion?: InputMaybe<BooleanQueryOperatorInput>;
    keywords?: InputMaybe<StringQueryOperatorInput>;
    label?: InputMaybe<StringQueryOperatorInput>;
    lang?: InputMaybe<StringQueryOperatorInput>;
    lastModified?: InputMaybe<StringQueryOperatorInput>;
    matchPath?: InputMaybe<StringQueryOperatorInput>;
    pageLink?: InputMaybe<FileFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
    permission?: InputMaybe<StringQueryOperatorInput>;
    redirect?: InputMaybe<BooleanQueryOperatorInput>;
    redirectFrom?: InputMaybe<StringQueryOperatorInput>;
    redocHasInfoPage?: InputMaybe<BooleanQueryOperatorInput>;
    redocHasSecurityDefinitions?: InputMaybe<BooleanQueryOperatorInput>;
    redocInfoPageId?: InputMaybe<StringQueryOperatorInput>;
    redocInfoPageLink?: InputMaybe<StringQueryOperatorInput>;
    redocItemId?: InputMaybe<StringQueryOperatorInput>;
    redocMenuItems?: InputMaybe<ContentItemDataRedocMenuItemsFilterListInput>;
    redocNextLabel?: InputMaybe<StringQueryOperatorInput>;
    redocNextLink?: InputMaybe<StringQueryOperatorInput>;
    redocPagination?: InputMaybe<StringQueryOperatorInput>;
    redocPrevLabel?: InputMaybe<StringQueryOperatorInput>;
    redocPrevLink?: InputMaybe<StringQueryOperatorInput>;
    redocStoreStr?: InputMaybe<StringQueryOperatorInput>;
    requestLogin?: InputMaybe<BooleanQueryOperatorInput>;
    settings?: InputMaybe<JsonQueryOperatorInput>;
    showNextButton?: InputMaybe<BooleanQueryOperatorInput>;
    showPrevButton?: InputMaybe<BooleanQueryOperatorInput>;
    sidebar?: InputMaybe<FileFilterInput>;
    sitemap?: InputMaybe<SitemapFilterInput>;
    sourcePath?: InputMaybe<StringQueryOperatorInput>;
    staticImageLink?: InputMaybe<FileFilterInput>;
    toc?: InputMaybe<TocInfoFilterInput>;
    tocMaxDepth?: InputMaybe<IntQueryOperatorInput>;
    type?: InputMaybe<StringQueryOperatorInput>;
    versions?: InputMaybe<ContentItemDataVersionsFilterListInput>;
};
export declare type ContentItemDataGroupConnection = {
    __typename?: 'ContentItemDataGroupConnection';
    edges: Array<ContentItemDataEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<ContentItemData>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type ContentItemDataRedocMenuItems = {
    __typename?: 'ContentItemDataRedocMenuItems';
    apiVersionId?: Maybe<Scalars['String']>;
    httpVerb?: Maybe<Scalars['String']>;
    isDefaultApiVersion?: Maybe<Scalars['Boolean']>;
    label?: Maybe<Scalars['String']>;
    link?: Maybe<Scalars['String']>;
    page?: Maybe<Scalars['String']>;
    pages?: Maybe<Array<Maybe<ContentItemDataRedocMenuItemsPages>>>;
    pagination?: Maybe<Scalars['String']>;
    parentPageId?: Maybe<Scalars['String']>;
    permission?: Maybe<Scalars['String']>;
    redocFakePage?: Maybe<Scalars['Boolean']>;
    redocInfoPageLink?: Maybe<Scalars['String']>;
    separator?: Maybe<Scalars['String']>;
};
export declare type ContentItemDataRedocMenuItemsFilterInput = {
    apiVersionId?: InputMaybe<StringQueryOperatorInput>;
    httpVerb?: InputMaybe<StringQueryOperatorInput>;
    isDefaultApiVersion?: InputMaybe<BooleanQueryOperatorInput>;
    label?: InputMaybe<StringQueryOperatorInput>;
    link?: InputMaybe<StringQueryOperatorInput>;
    page?: InputMaybe<StringQueryOperatorInput>;
    pages?: InputMaybe<ContentItemDataRedocMenuItemsPagesFilterListInput>;
    pagination?: InputMaybe<StringQueryOperatorInput>;
    parentPageId?: InputMaybe<StringQueryOperatorInput>;
    permission?: InputMaybe<StringQueryOperatorInput>;
    redocFakePage?: InputMaybe<BooleanQueryOperatorInput>;
    redocInfoPageLink?: InputMaybe<StringQueryOperatorInput>;
    separator?: InputMaybe<StringQueryOperatorInput>;
};
export declare type ContentItemDataRedocMenuItemsFilterListInput = {
    elemMatch?: InputMaybe<ContentItemDataRedocMenuItemsFilterInput>;
};
export declare type ContentItemDataRedocMenuItemsPages = {
    __typename?: 'ContentItemDataRedocMenuItemsPages';
    apiVersionId?: Maybe<Scalars['String']>;
    httpVerb?: Maybe<Scalars['String']>;
    isDefaultApiVersion?: Maybe<Scalars['Boolean']>;
    label?: Maybe<Scalars['String']>;
    page?: Maybe<Scalars['String']>;
    pagination?: Maybe<Scalars['String']>;
    parentPageId?: Maybe<Scalars['String']>;
    permission?: Maybe<Scalars['String']>;
    redocFakePage?: Maybe<Scalars['Boolean']>;
    redocInfoPageLink?: Maybe<Scalars['String']>;
};
export declare type ContentItemDataRedocMenuItemsPagesFilterInput = {
    apiVersionId?: InputMaybe<StringQueryOperatorInput>;
    httpVerb?: InputMaybe<StringQueryOperatorInput>;
    isDefaultApiVersion?: InputMaybe<BooleanQueryOperatorInput>;
    label?: InputMaybe<StringQueryOperatorInput>;
    page?: InputMaybe<StringQueryOperatorInput>;
    pagination?: InputMaybe<StringQueryOperatorInput>;
    parentPageId?: InputMaybe<StringQueryOperatorInput>;
    permission?: InputMaybe<StringQueryOperatorInput>;
    redocFakePage?: InputMaybe<BooleanQueryOperatorInput>;
    redocInfoPageLink?: InputMaybe<StringQueryOperatorInput>;
};
export declare type ContentItemDataRedocMenuItemsPagesFilterListInput = {
    elemMatch?: InputMaybe<ContentItemDataRedocMenuItemsPagesFilterInput>;
};
export declare type ContentItemDataSortInput = {
    fields?: InputMaybe<Array<InputMaybe<ContentItemDataFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare type ContentItemDataVersions = {
    __typename?: 'ContentItemDataVersions';
    definitionId?: Maybe<Scalars['String']>;
    id?: Maybe<Scalars['String']>;
    isDefault?: Maybe<Scalars['Boolean']>;
    label?: Maybe<Scalars['String']>;
    settings?: Maybe<ContentItemDataVersionsSettings>;
    title?: Maybe<Scalars['String']>;
};
export declare type ContentItemDataVersionsFilterInput = {
    definitionId?: InputMaybe<StringQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    isDefault?: InputMaybe<BooleanQueryOperatorInput>;
    label?: InputMaybe<StringQueryOperatorInput>;
    settings?: InputMaybe<ContentItemDataVersionsSettingsFilterInput>;
    title?: InputMaybe<StringQueryOperatorInput>;
};
export declare type ContentItemDataVersionsFilterListInput = {
    elemMatch?: InputMaybe<ContentItemDataVersionsFilterInput>;
};
export declare type ContentItemDataVersionsSettings = {
    __typename?: 'ContentItemDataVersionsSettings';
    generateCodeSamples?: Maybe<ContentItemDataVersionsSettingsGenerateCodeSamples>;
    pagination?: Maybe<Scalars['String']>;
};
export declare type ContentItemDataVersionsSettingsFilterInput = {
    generateCodeSamples?: InputMaybe<ContentItemDataVersionsSettingsGenerateCodeSamplesFilterInput>;
    pagination?: InputMaybe<StringQueryOperatorInput>;
};
export declare type ContentItemDataVersionsSettingsGenerateCodeSamples = {
    __typename?: 'ContentItemDataVersionsSettingsGenerateCodeSamples';
    languages?: Maybe<Array<Maybe<ContentItemDataVersionsSettingsGenerateCodeSamplesLanguages>>>;
};
export declare type ContentItemDataVersionsSettingsGenerateCodeSamplesFilterInput = {
    languages?: InputMaybe<ContentItemDataVersionsSettingsGenerateCodeSamplesLanguagesFilterListInput>;
};
export declare type ContentItemDataVersionsSettingsGenerateCodeSamplesLanguages = {
    __typename?: 'ContentItemDataVersionsSettingsGenerateCodeSamplesLanguages';
    lang?: Maybe<Scalars['String']>;
};
export declare type ContentItemDataVersionsSettingsGenerateCodeSamplesLanguagesFilterInput = {
    lang?: InputMaybe<StringQueryOperatorInput>;
};
export declare type ContentItemDataVersionsSettingsGenerateCodeSamplesLanguagesFilterListInput = {
    elemMatch?: InputMaybe<ContentItemDataVersionsSettingsGenerateCodeSamplesLanguagesFilterInput>;
};
export declare type ContentItemEdge = {
    __typename?: 'ContentItemEdge';
    next?: Maybe<ContentItem>;
    node: ContentItem;
    previous?: Maybe<ContentItem>;
};
export declare enum ContentItemFieldsEnum {
    baseLink = "baseLink",
    catalogInfo___apiName = "catalogInfo___apiName",
    catalogInfo___apiVersion = "catalogInfo___apiVersion",
    catalogInfo___metadata = "catalogInfo___metadata",
    catalogInfo___title = "catalogInfo___title",
    children = "children",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    data___apiVersionId = "data___apiVersionId",
    data___apiVersions = "data___apiVersions",
    data___apiVersions___apiId = "data___apiVersions___apiId",
    data___apiVersions___definitionId = "data___apiVersions___definitionId",
    data___apiVersions___id = "data___apiVersions___id",
    data___apiVersions___isDefault = "data___apiVersions___isDefault",
    data___apiVersions___label = "data___apiVersions___label",
    data___apiVersions___settings___pagination = "data___apiVersions___settings___pagination",
    data___apiVersions___title = "data___apiVersions___title",
    data___children = "data___children",
    data___children___children = "data___children___children",
    data___children___children___children = "data___children___children___children",
    data___children___children___id = "data___children___children___id",
    data___children___id = "data___children___id",
    data___children___internal___content = "data___children___internal___content",
    data___children___internal___contentDigest = "data___children___internal___contentDigest",
    data___children___internal___description = "data___children___internal___description",
    data___children___internal___fieldOwners = "data___children___internal___fieldOwners",
    data___children___internal___ignoreType = "data___children___internal___ignoreType",
    data___children___internal___mediaType = "data___children___internal___mediaType",
    data___children___internal___owner = "data___children___internal___owner",
    data___children___internal___type = "data___children___internal___type",
    data___children___parent___children = "data___children___parent___children",
    data___children___parent___id = "data___children___parent___id",
    data___customDataString = "data___customDataString",
    data___customData___description = "data___customData___description",
    data___customData___editPage___disable = "data___customData___editPage___disable",
    data___customData___imageLink = "data___customData___imageLink",
    data___customData___pageLink___absolutePath = "data___customData___pageLink___absolutePath",
    data___customData___pageLink___accessTime = "data___customData___pageLink___accessTime",
    data___customData___pageLink___atime = "data___customData___pageLink___atime",
    data___customData___pageLink___atimeMs = "data___customData___pageLink___atimeMs",
    data___customData___pageLink___base = "data___customData___pageLink___base",
    data___customData___pageLink___birthTime = "data___customData___pageLink___birthTime",
    data___customData___pageLink___birthtime = "data___customData___pageLink___birthtime",
    data___customData___pageLink___birthtimeMs = "data___customData___pageLink___birthtimeMs",
    data___customData___pageLink___blksize = "data___customData___pageLink___blksize",
    data___customData___pageLink___blocks = "data___customData___pageLink___blocks",
    data___customData___pageLink___changeTime = "data___customData___pageLink___changeTime",
    data___customData___pageLink___children = "data___customData___pageLink___children",
    data___customData___pageLink___childrenContentItem = "data___customData___pageLink___childrenContentItem",
    data___customData___pageLink___childrenMarkdownRemark = "data___customData___pageLink___childrenMarkdownRemark",
    data___customData___pageLink___ctime = "data___customData___pageLink___ctime",
    data___customData___pageLink___ctimeMs = "data___customData___pageLink___ctimeMs",
    data___customData___pageLink___dev = "data___customData___pageLink___dev",
    data___customData___pageLink___dir = "data___customData___pageLink___dir",
    data___customData___pageLink___ext = "data___customData___pageLink___ext",
    data___customData___pageLink___extension = "data___customData___pageLink___extension",
    data___customData___pageLink___gid = "data___customData___pageLink___gid",
    data___customData___pageLink___id = "data___customData___pageLink___id",
    data___customData___pageLink___ino = "data___customData___pageLink___ino",
    data___customData___pageLink___mode = "data___customData___pageLink___mode",
    data___customData___pageLink___modifiedTime = "data___customData___pageLink___modifiedTime",
    data___customData___pageLink___mtime = "data___customData___pageLink___mtime",
    data___customData___pageLink___mtimeMs = "data___customData___pageLink___mtimeMs",
    data___customData___pageLink___name = "data___customData___pageLink___name",
    data___customData___pageLink___nlink = "data___customData___pageLink___nlink",
    data___customData___pageLink___prettySize = "data___customData___pageLink___prettySize",
    data___customData___pageLink___publicURL = "data___customData___pageLink___publicURL",
    data___customData___pageLink___rdev = "data___customData___pageLink___rdev",
    data___customData___pageLink___relativeDirectory = "data___customData___pageLink___relativeDirectory",
    data___customData___pageLink___relativePath = "data___customData___pageLink___relativePath",
    data___customData___pageLink___root = "data___customData___pageLink___root",
    data___customData___pageLink___size = "data___customData___pageLink___size",
    data___customData___pageLink___sourceInstanceName = "data___customData___pageLink___sourceInstanceName",
    data___customData___pageLink___uid = "data___customData___pageLink___uid",
    data___customData___redirectFrom = "data___customData___redirectFrom",
    data___customData___seo___description = "data___customData___seo___description",
    data___customData___seo___image = "data___customData___seo___image",
    data___customData___seo___keywords = "data___customData___seo___keywords",
    data___customData___seo___lang = "data___customData___seo___lang",
    data___customData___seo___title = "data___customData___seo___title",
    data___customData___sidebar___absolutePath = "data___customData___sidebar___absolutePath",
    data___customData___sidebar___accessTime = "data___customData___sidebar___accessTime",
    data___customData___sidebar___atime = "data___customData___sidebar___atime",
    data___customData___sidebar___atimeMs = "data___customData___sidebar___atimeMs",
    data___customData___sidebar___base = "data___customData___sidebar___base",
    data___customData___sidebar___birthTime = "data___customData___sidebar___birthTime",
    data___customData___sidebar___birthtime = "data___customData___sidebar___birthtime",
    data___customData___sidebar___birthtimeMs = "data___customData___sidebar___birthtimeMs",
    data___customData___sidebar___blksize = "data___customData___sidebar___blksize",
    data___customData___sidebar___blocks = "data___customData___sidebar___blocks",
    data___customData___sidebar___changeTime = "data___customData___sidebar___changeTime",
    data___customData___sidebar___children = "data___customData___sidebar___children",
    data___customData___sidebar___childrenContentItem = "data___customData___sidebar___childrenContentItem",
    data___customData___sidebar___childrenMarkdownRemark = "data___customData___sidebar___childrenMarkdownRemark",
    data___customData___sidebar___ctime = "data___customData___sidebar___ctime",
    data___customData___sidebar___ctimeMs = "data___customData___sidebar___ctimeMs",
    data___customData___sidebar___dev = "data___customData___sidebar___dev",
    data___customData___sidebar___dir = "data___customData___sidebar___dir",
    data___customData___sidebar___ext = "data___customData___sidebar___ext",
    data___customData___sidebar___extension = "data___customData___sidebar___extension",
    data___customData___sidebar___gid = "data___customData___sidebar___gid",
    data___customData___sidebar___id = "data___customData___sidebar___id",
    data___customData___sidebar___ino = "data___customData___sidebar___ino",
    data___customData___sidebar___mode = "data___customData___sidebar___mode",
    data___customData___sidebar___modifiedTime = "data___customData___sidebar___modifiedTime",
    data___customData___sidebar___mtime = "data___customData___sidebar___mtime",
    data___customData___sidebar___mtimeMs = "data___customData___sidebar___mtimeMs",
    data___customData___sidebar___name = "data___customData___sidebar___name",
    data___customData___sidebar___nlink = "data___customData___sidebar___nlink",
    data___customData___sidebar___prettySize = "data___customData___sidebar___prettySize",
    data___customData___sidebar___publicURL = "data___customData___sidebar___publicURL",
    data___customData___sidebar___rdev = "data___customData___sidebar___rdev",
    data___customData___sidebar___relativeDirectory = "data___customData___sidebar___relativeDirectory",
    data___customData___sidebar___relativePath = "data___customData___sidebar___relativePath",
    data___customData___sidebar___root = "data___customData___sidebar___root",
    data___customData___sidebar___size = "data___customData___sidebar___size",
    data___customData___sidebar___sourceInstanceName = "data___customData___sidebar___sourceInstanceName",
    data___customData___sidebar___uid = "data___customData___sidebar___uid",
    data___customData___staticImageLink___absolutePath = "data___customData___staticImageLink___absolutePath",
    data___customData___staticImageLink___accessTime = "data___customData___staticImageLink___accessTime",
    data___customData___staticImageLink___atime = "data___customData___staticImageLink___atime",
    data___customData___staticImageLink___atimeMs = "data___customData___staticImageLink___atimeMs",
    data___customData___staticImageLink___base = "data___customData___staticImageLink___base",
    data___customData___staticImageLink___birthTime = "data___customData___staticImageLink___birthTime",
    data___customData___staticImageLink___birthtime = "data___customData___staticImageLink___birthtime",
    data___customData___staticImageLink___birthtimeMs = "data___customData___staticImageLink___birthtimeMs",
    data___customData___staticImageLink___blksize = "data___customData___staticImageLink___blksize",
    data___customData___staticImageLink___blocks = "data___customData___staticImageLink___blocks",
    data___customData___staticImageLink___changeTime = "data___customData___staticImageLink___changeTime",
    data___customData___staticImageLink___children = "data___customData___staticImageLink___children",
    data___customData___staticImageLink___childrenContentItem = "data___customData___staticImageLink___childrenContentItem",
    data___customData___staticImageLink___childrenMarkdownRemark = "data___customData___staticImageLink___childrenMarkdownRemark",
    data___customData___staticImageLink___ctime = "data___customData___staticImageLink___ctime",
    data___customData___staticImageLink___ctimeMs = "data___customData___staticImageLink___ctimeMs",
    data___customData___staticImageLink___dev = "data___customData___staticImageLink___dev",
    data___customData___staticImageLink___dir = "data___customData___staticImageLink___dir",
    data___customData___staticImageLink___ext = "data___customData___staticImageLink___ext",
    data___customData___staticImageLink___extension = "data___customData___staticImageLink___extension",
    data___customData___staticImageLink___gid = "data___customData___staticImageLink___gid",
    data___customData___staticImageLink___id = "data___customData___staticImageLink___id",
    data___customData___staticImageLink___ino = "data___customData___staticImageLink___ino",
    data___customData___staticImageLink___mode = "data___customData___staticImageLink___mode",
    data___customData___staticImageLink___modifiedTime = "data___customData___staticImageLink___modifiedTime",
    data___customData___staticImageLink___mtime = "data___customData___staticImageLink___mtime",
    data___customData___staticImageLink___mtimeMs = "data___customData___staticImageLink___mtimeMs",
    data___customData___staticImageLink___name = "data___customData___staticImageLink___name",
    data___customData___staticImageLink___nlink = "data___customData___staticImageLink___nlink",
    data___customData___staticImageLink___prettySize = "data___customData___staticImageLink___prettySize",
    data___customData___staticImageLink___publicURL = "data___customData___staticImageLink___publicURL",
    data___customData___staticImageLink___rdev = "data___customData___staticImageLink___rdev",
    data___customData___staticImageLink___relativeDirectory = "data___customData___staticImageLink___relativeDirectory",
    data___customData___staticImageLink___relativePath = "data___customData___staticImageLink___relativePath",
    data___customData___staticImageLink___root = "data___customData___staticImageLink___root",
    data___customData___staticImageLink___size = "data___customData___staticImageLink___size",
    data___customData___staticImageLink___sourceInstanceName = "data___customData___staticImageLink___sourceInstanceName",
    data___customData___staticImageLink___uid = "data___customData___staticImageLink___uid",
    data___customData___title = "data___customData___title",
    data___customData___toc___enable = "data___customData___toc___enable",
    data___customTemplate = "data___customTemplate",
    data___definitionId = "data___definitionId",
    data___disableEditPage = "data___disableEditPage",
    data___disableLastModified = "data___disableLastModified",
    data___editPage___disable = "data___editPage___disable",
    data___enableToc = "data___enableToc",
    data___excludeFromSearch = "data___excludeFromSearch",
    data___httpVerb = "data___httpVerb",
    data___id = "data___id",
    data___image = "data___image",
    data___imageLink = "data___imageLink",
    data___internal___content = "data___internal___content",
    data___internal___contentDigest = "data___internal___contentDigest",
    data___internal___description = "data___internal___description",
    data___internal___fieldOwners = "data___internal___fieldOwners",
    data___internal___ignoreType = "data___internal___ignoreType",
    data___internal___mediaType = "data___internal___mediaType",
    data___internal___owner = "data___internal___owner",
    data___internal___type = "data___internal___type",
    data___isDefaultApiVersion = "data___isDefaultApiVersion",
    data___keywords = "data___keywords",
    data___label = "data___label",
    data___lang = "data___lang",
    data___lastModified = "data___lastModified",
    data___matchPath = "data___matchPath",
    data___pageLink___absolutePath = "data___pageLink___absolutePath",
    data___pageLink___accessTime = "data___pageLink___accessTime",
    data___pageLink___atime = "data___pageLink___atime",
    data___pageLink___atimeMs = "data___pageLink___atimeMs",
    data___pageLink___base = "data___pageLink___base",
    data___pageLink___birthTime = "data___pageLink___birthTime",
    data___pageLink___birthtime = "data___pageLink___birthtime",
    data___pageLink___birthtimeMs = "data___pageLink___birthtimeMs",
    data___pageLink___blksize = "data___pageLink___blksize",
    data___pageLink___blocks = "data___pageLink___blocks",
    data___pageLink___changeTime = "data___pageLink___changeTime",
    data___pageLink___childContentItem___baseLink = "data___pageLink___childContentItem___baseLink",
    data___pageLink___childContentItem___children = "data___pageLink___childContentItem___children",
    data___pageLink___childContentItem___id = "data___pageLink___childContentItem___id",
    data___pageLink___childContentItem___link = "data___pageLink___childContentItem___link",
    data___pageLink___childContentItem___pageId = "data___pageLink___childContentItem___pageId",
    data___pageLink___childContentItem___permission = "data___pageLink___childContentItem___permission",
    data___pageLink___childContentItem___sourcePath = "data___pageLink___childContentItem___sourcePath",
    data___pageLink___childContentItem___type = "data___pageLink___childContentItem___type",
    data___pageLink___childMarkdownRemark___children = "data___pageLink___childMarkdownRemark___children",
    data___pageLink___childMarkdownRemark___excerpt = "data___pageLink___childMarkdownRemark___excerpt",
    data___pageLink___childMarkdownRemark___excerptAst = "data___pageLink___childMarkdownRemark___excerptAst",
    data___pageLink___childMarkdownRemark___fileAbsolutePath = "data___pageLink___childMarkdownRemark___fileAbsolutePath",
    data___pageLink___childMarkdownRemark___headings = "data___pageLink___childMarkdownRemark___headings",
    data___pageLink___childMarkdownRemark___html = "data___pageLink___childMarkdownRemark___html",
    data___pageLink___childMarkdownRemark___htmlAst = "data___pageLink___childMarkdownRemark___htmlAst",
    data___pageLink___childMarkdownRemark___id = "data___pageLink___childMarkdownRemark___id",
    data___pageLink___childMarkdownRemark___rawMarkdownBody = "data___pageLink___childMarkdownRemark___rawMarkdownBody",
    data___pageLink___childMarkdownRemark___tableOfContents = "data___pageLink___childMarkdownRemark___tableOfContents",
    data___pageLink___childMarkdownRemark___timeToRead = "data___pageLink___childMarkdownRemark___timeToRead",
    data___pageLink___children = "data___pageLink___children",
    data___pageLink___childrenContentItem = "data___pageLink___childrenContentItem",
    data___pageLink___childrenContentItem___baseLink = "data___pageLink___childrenContentItem___baseLink",
    data___pageLink___childrenContentItem___children = "data___pageLink___childrenContentItem___children",
    data___pageLink___childrenContentItem___id = "data___pageLink___childrenContentItem___id",
    data___pageLink___childrenContentItem___link = "data___pageLink___childrenContentItem___link",
    data___pageLink___childrenContentItem___pageId = "data___pageLink___childrenContentItem___pageId",
    data___pageLink___childrenContentItem___permission = "data___pageLink___childrenContentItem___permission",
    data___pageLink___childrenContentItem___sourcePath = "data___pageLink___childrenContentItem___sourcePath",
    data___pageLink___childrenContentItem___type = "data___pageLink___childrenContentItem___type",
    data___pageLink___childrenMarkdownRemark = "data___pageLink___childrenMarkdownRemark",
    data___pageLink___childrenMarkdownRemark___children = "data___pageLink___childrenMarkdownRemark___children",
    data___pageLink___childrenMarkdownRemark___excerpt = "data___pageLink___childrenMarkdownRemark___excerpt",
    data___pageLink___childrenMarkdownRemark___excerptAst = "data___pageLink___childrenMarkdownRemark___excerptAst",
    data___pageLink___childrenMarkdownRemark___fileAbsolutePath = "data___pageLink___childrenMarkdownRemark___fileAbsolutePath",
    data___pageLink___childrenMarkdownRemark___headings = "data___pageLink___childrenMarkdownRemark___headings",
    data___pageLink___childrenMarkdownRemark___html = "data___pageLink___childrenMarkdownRemark___html",
    data___pageLink___childrenMarkdownRemark___htmlAst = "data___pageLink___childrenMarkdownRemark___htmlAst",
    data___pageLink___childrenMarkdownRemark___id = "data___pageLink___childrenMarkdownRemark___id",
    data___pageLink___childrenMarkdownRemark___rawMarkdownBody = "data___pageLink___childrenMarkdownRemark___rawMarkdownBody",
    data___pageLink___childrenMarkdownRemark___tableOfContents = "data___pageLink___childrenMarkdownRemark___tableOfContents",
    data___pageLink___childrenMarkdownRemark___timeToRead = "data___pageLink___childrenMarkdownRemark___timeToRead",
    data___pageLink___children___children = "data___pageLink___children___children",
    data___pageLink___children___id = "data___pageLink___children___id",
    data___pageLink___ctime = "data___pageLink___ctime",
    data___pageLink___ctimeMs = "data___pageLink___ctimeMs",
    data___pageLink___dev = "data___pageLink___dev",
    data___pageLink___dir = "data___pageLink___dir",
    data___pageLink___ext = "data___pageLink___ext",
    data___pageLink___extension = "data___pageLink___extension",
    data___pageLink___gid = "data___pageLink___gid",
    data___pageLink___id = "data___pageLink___id",
    data___pageLink___ino = "data___pageLink___ino",
    data___pageLink___internal___content = "data___pageLink___internal___content",
    data___pageLink___internal___contentDigest = "data___pageLink___internal___contentDigest",
    data___pageLink___internal___description = "data___pageLink___internal___description",
    data___pageLink___internal___fieldOwners = "data___pageLink___internal___fieldOwners",
    data___pageLink___internal___ignoreType = "data___pageLink___internal___ignoreType",
    data___pageLink___internal___mediaType = "data___pageLink___internal___mediaType",
    data___pageLink___internal___owner = "data___pageLink___internal___owner",
    data___pageLink___internal___type = "data___pageLink___internal___type",
    data___pageLink___mode = "data___pageLink___mode",
    data___pageLink___modifiedTime = "data___pageLink___modifiedTime",
    data___pageLink___mtime = "data___pageLink___mtime",
    data___pageLink___mtimeMs = "data___pageLink___mtimeMs",
    data___pageLink___name = "data___pageLink___name",
    data___pageLink___nlink = "data___pageLink___nlink",
    data___pageLink___parent___children = "data___pageLink___parent___children",
    data___pageLink___parent___id = "data___pageLink___parent___id",
    data___pageLink___prettySize = "data___pageLink___prettySize",
    data___pageLink___publicURL = "data___pageLink___publicURL",
    data___pageLink___rdev = "data___pageLink___rdev",
    data___pageLink___relativeDirectory = "data___pageLink___relativeDirectory",
    data___pageLink___relativePath = "data___pageLink___relativePath",
    data___pageLink___root = "data___pageLink___root",
    data___pageLink___size = "data___pageLink___size",
    data___pageLink___sourceInstanceName = "data___pageLink___sourceInstanceName",
    data___pageLink___uid = "data___pageLink___uid",
    data___parent___children = "data___parent___children",
    data___parent___children___children = "data___parent___children___children",
    data___parent___children___id = "data___parent___children___id",
    data___parent___id = "data___parent___id",
    data___parent___internal___content = "data___parent___internal___content",
    data___parent___internal___contentDigest = "data___parent___internal___contentDigest",
    data___parent___internal___description = "data___parent___internal___description",
    data___parent___internal___fieldOwners = "data___parent___internal___fieldOwners",
    data___parent___internal___ignoreType = "data___parent___internal___ignoreType",
    data___parent___internal___mediaType = "data___parent___internal___mediaType",
    data___parent___internal___owner = "data___parent___internal___owner",
    data___parent___internal___type = "data___parent___internal___type",
    data___parent___parent___children = "data___parent___parent___children",
    data___parent___parent___id = "data___parent___parent___id",
    data___permission = "data___permission",
    data___redirect = "data___redirect",
    data___redirectFrom = "data___redirectFrom",
    data___redocHasInfoPage = "data___redocHasInfoPage",
    data___redocHasSecurityDefinitions = "data___redocHasSecurityDefinitions",
    data___redocInfoPageId = "data___redocInfoPageId",
    data___redocInfoPageLink = "data___redocInfoPageLink",
    data___redocItemId = "data___redocItemId",
    data___redocMenuItems = "data___redocMenuItems",
    data___redocMenuItems___apiVersionId = "data___redocMenuItems___apiVersionId",
    data___redocMenuItems___httpVerb = "data___redocMenuItems___httpVerb",
    data___redocMenuItems___isDefaultApiVersion = "data___redocMenuItems___isDefaultApiVersion",
    data___redocMenuItems___label = "data___redocMenuItems___label",
    data___redocMenuItems___link = "data___redocMenuItems___link",
    data___redocMenuItems___page = "data___redocMenuItems___page",
    data___redocMenuItems___pages = "data___redocMenuItems___pages",
    data___redocMenuItems___pages___apiVersionId = "data___redocMenuItems___pages___apiVersionId",
    data___redocMenuItems___pages___httpVerb = "data___redocMenuItems___pages___httpVerb",
    data___redocMenuItems___pages___isDefaultApiVersion = "data___redocMenuItems___pages___isDefaultApiVersion",
    data___redocMenuItems___pages___label = "data___redocMenuItems___pages___label",
    data___redocMenuItems___pages___page = "data___redocMenuItems___pages___page",
    data___redocMenuItems___pages___pagination = "data___redocMenuItems___pages___pagination",
    data___redocMenuItems___pages___parentPageId = "data___redocMenuItems___pages___parentPageId",
    data___redocMenuItems___pages___permission = "data___redocMenuItems___pages___permission",
    data___redocMenuItems___pages___redocFakePage = "data___redocMenuItems___pages___redocFakePage",
    data___redocMenuItems___pages___redocInfoPageLink = "data___redocMenuItems___pages___redocInfoPageLink",
    data___redocMenuItems___pagination = "data___redocMenuItems___pagination",
    data___redocMenuItems___parentPageId = "data___redocMenuItems___parentPageId",
    data___redocMenuItems___permission = "data___redocMenuItems___permission",
    data___redocMenuItems___redocFakePage = "data___redocMenuItems___redocFakePage",
    data___redocMenuItems___redocInfoPageLink = "data___redocMenuItems___redocInfoPageLink",
    data___redocMenuItems___separator = "data___redocMenuItems___separator",
    data___redocNextLabel = "data___redocNextLabel",
    data___redocNextLink = "data___redocNextLink",
    data___redocPagination = "data___redocPagination",
    data___redocPrevLabel = "data___redocPrevLabel",
    data___redocPrevLink = "data___redocPrevLink",
    data___redocStoreStr = "data___redocStoreStr",
    data___requestLogin = "data___requestLogin",
    data___settings = "data___settings",
    data___showNextButton = "data___showNextButton",
    data___showPrevButton = "data___showPrevButton",
    data___sidebar___absolutePath = "data___sidebar___absolutePath",
    data___sidebar___accessTime = "data___sidebar___accessTime",
    data___sidebar___atime = "data___sidebar___atime",
    data___sidebar___atimeMs = "data___sidebar___atimeMs",
    data___sidebar___base = "data___sidebar___base",
    data___sidebar___birthTime = "data___sidebar___birthTime",
    data___sidebar___birthtime = "data___sidebar___birthtime",
    data___sidebar___birthtimeMs = "data___sidebar___birthtimeMs",
    data___sidebar___blksize = "data___sidebar___blksize",
    data___sidebar___blocks = "data___sidebar___blocks",
    data___sidebar___changeTime = "data___sidebar___changeTime",
    data___sidebar___childContentItem___baseLink = "data___sidebar___childContentItem___baseLink",
    data___sidebar___childContentItem___children = "data___sidebar___childContentItem___children",
    data___sidebar___childContentItem___id = "data___sidebar___childContentItem___id",
    data___sidebar___childContentItem___link = "data___sidebar___childContentItem___link",
    data___sidebar___childContentItem___pageId = "data___sidebar___childContentItem___pageId",
    data___sidebar___childContentItem___permission = "data___sidebar___childContentItem___permission",
    data___sidebar___childContentItem___sourcePath = "data___sidebar___childContentItem___sourcePath",
    data___sidebar___childContentItem___type = "data___sidebar___childContentItem___type",
    data___sidebar___childMarkdownRemark___children = "data___sidebar___childMarkdownRemark___children",
    data___sidebar___childMarkdownRemark___excerpt = "data___sidebar___childMarkdownRemark___excerpt",
    data___sidebar___childMarkdownRemark___excerptAst = "data___sidebar___childMarkdownRemark___excerptAst",
    data___sidebar___childMarkdownRemark___fileAbsolutePath = "data___sidebar___childMarkdownRemark___fileAbsolutePath",
    data___sidebar___childMarkdownRemark___headings = "data___sidebar___childMarkdownRemark___headings",
    data___sidebar___childMarkdownRemark___html = "data___sidebar___childMarkdownRemark___html",
    data___sidebar___childMarkdownRemark___htmlAst = "data___sidebar___childMarkdownRemark___htmlAst",
    data___sidebar___childMarkdownRemark___id = "data___sidebar___childMarkdownRemark___id",
    data___sidebar___childMarkdownRemark___rawMarkdownBody = "data___sidebar___childMarkdownRemark___rawMarkdownBody",
    data___sidebar___childMarkdownRemark___tableOfContents = "data___sidebar___childMarkdownRemark___tableOfContents",
    data___sidebar___childMarkdownRemark___timeToRead = "data___sidebar___childMarkdownRemark___timeToRead",
    data___sidebar___children = "data___sidebar___children",
    data___sidebar___childrenContentItem = "data___sidebar___childrenContentItem",
    data___sidebar___childrenContentItem___baseLink = "data___sidebar___childrenContentItem___baseLink",
    data___sidebar___childrenContentItem___children = "data___sidebar___childrenContentItem___children",
    data___sidebar___childrenContentItem___id = "data___sidebar___childrenContentItem___id",
    data___sidebar___childrenContentItem___link = "data___sidebar___childrenContentItem___link",
    data___sidebar___childrenContentItem___pageId = "data___sidebar___childrenContentItem___pageId",
    data___sidebar___childrenContentItem___permission = "data___sidebar___childrenContentItem___permission",
    data___sidebar___childrenContentItem___sourcePath = "data___sidebar___childrenContentItem___sourcePath",
    data___sidebar___childrenContentItem___type = "data___sidebar___childrenContentItem___type",
    data___sidebar___childrenMarkdownRemark = "data___sidebar___childrenMarkdownRemark",
    data___sidebar___childrenMarkdownRemark___children = "data___sidebar___childrenMarkdownRemark___children",
    data___sidebar___childrenMarkdownRemark___excerpt = "data___sidebar___childrenMarkdownRemark___excerpt",
    data___sidebar___childrenMarkdownRemark___excerptAst = "data___sidebar___childrenMarkdownRemark___excerptAst",
    data___sidebar___childrenMarkdownRemark___fileAbsolutePath = "data___sidebar___childrenMarkdownRemark___fileAbsolutePath",
    data___sidebar___childrenMarkdownRemark___headings = "data___sidebar___childrenMarkdownRemark___headings",
    data___sidebar___childrenMarkdownRemark___html = "data___sidebar___childrenMarkdownRemark___html",
    data___sidebar___childrenMarkdownRemark___htmlAst = "data___sidebar___childrenMarkdownRemark___htmlAst",
    data___sidebar___childrenMarkdownRemark___id = "data___sidebar___childrenMarkdownRemark___id",
    data___sidebar___childrenMarkdownRemark___rawMarkdownBody = "data___sidebar___childrenMarkdownRemark___rawMarkdownBody",
    data___sidebar___childrenMarkdownRemark___tableOfContents = "data___sidebar___childrenMarkdownRemark___tableOfContents",
    data___sidebar___childrenMarkdownRemark___timeToRead = "data___sidebar___childrenMarkdownRemark___timeToRead",
    data___sidebar___children___children = "data___sidebar___children___children",
    data___sidebar___children___id = "data___sidebar___children___id",
    data___sidebar___ctime = "data___sidebar___ctime",
    data___sidebar___ctimeMs = "data___sidebar___ctimeMs",
    data___sidebar___dev = "data___sidebar___dev",
    data___sidebar___dir = "data___sidebar___dir",
    data___sidebar___ext = "data___sidebar___ext",
    data___sidebar___extension = "data___sidebar___extension",
    data___sidebar___gid = "data___sidebar___gid",
    data___sidebar___id = "data___sidebar___id",
    data___sidebar___ino = "data___sidebar___ino",
    data___sidebar___internal___content = "data___sidebar___internal___content",
    data___sidebar___internal___contentDigest = "data___sidebar___internal___contentDigest",
    data___sidebar___internal___description = "data___sidebar___internal___description",
    data___sidebar___internal___fieldOwners = "data___sidebar___internal___fieldOwners",
    data___sidebar___internal___ignoreType = "data___sidebar___internal___ignoreType",
    data___sidebar___internal___mediaType = "data___sidebar___internal___mediaType",
    data___sidebar___internal___owner = "data___sidebar___internal___owner",
    data___sidebar___internal___type = "data___sidebar___internal___type",
    data___sidebar___mode = "data___sidebar___mode",
    data___sidebar___modifiedTime = "data___sidebar___modifiedTime",
    data___sidebar___mtime = "data___sidebar___mtime",
    data___sidebar___mtimeMs = "data___sidebar___mtimeMs",
    data___sidebar___name = "data___sidebar___name",
    data___sidebar___nlink = "data___sidebar___nlink",
    data___sidebar___parent___children = "data___sidebar___parent___children",
    data___sidebar___parent___id = "data___sidebar___parent___id",
    data___sidebar___prettySize = "data___sidebar___prettySize",
    data___sidebar___publicURL = "data___sidebar___publicURL",
    data___sidebar___rdev = "data___sidebar___rdev",
    data___sidebar___relativeDirectory = "data___sidebar___relativeDirectory",
    data___sidebar___relativePath = "data___sidebar___relativePath",
    data___sidebar___root = "data___sidebar___root",
    data___sidebar___size = "data___sidebar___size",
    data___sidebar___sourceInstanceName = "data___sidebar___sourceInstanceName",
    data___sidebar___uid = "data___sidebar___uid",
    data___sitemap___changefreq = "data___sitemap___changefreq",
    data___sitemap___lastmod = "data___sitemap___lastmod",
    data___sitemap___priority = "data___sitemap___priority",
    data___sourcePath = "data___sourcePath",
    data___staticImageLink___absolutePath = "data___staticImageLink___absolutePath",
    data___staticImageLink___accessTime = "data___staticImageLink___accessTime",
    data___staticImageLink___atime = "data___staticImageLink___atime",
    data___staticImageLink___atimeMs = "data___staticImageLink___atimeMs",
    data___staticImageLink___base = "data___staticImageLink___base",
    data___staticImageLink___birthTime = "data___staticImageLink___birthTime",
    data___staticImageLink___birthtime = "data___staticImageLink___birthtime",
    data___staticImageLink___birthtimeMs = "data___staticImageLink___birthtimeMs",
    data___staticImageLink___blksize = "data___staticImageLink___blksize",
    data___staticImageLink___blocks = "data___staticImageLink___blocks",
    data___staticImageLink___changeTime = "data___staticImageLink___changeTime",
    data___staticImageLink___childContentItem___baseLink = "data___staticImageLink___childContentItem___baseLink",
    data___staticImageLink___childContentItem___children = "data___staticImageLink___childContentItem___children",
    data___staticImageLink___childContentItem___id = "data___staticImageLink___childContentItem___id",
    data___staticImageLink___childContentItem___link = "data___staticImageLink___childContentItem___link",
    data___staticImageLink___childContentItem___pageId = "data___staticImageLink___childContentItem___pageId",
    data___staticImageLink___childContentItem___permission = "data___staticImageLink___childContentItem___permission",
    data___staticImageLink___childContentItem___sourcePath = "data___staticImageLink___childContentItem___sourcePath",
    data___staticImageLink___childContentItem___type = "data___staticImageLink___childContentItem___type",
    data___staticImageLink___childMarkdownRemark___children = "data___staticImageLink___childMarkdownRemark___children",
    data___staticImageLink___childMarkdownRemark___excerpt = "data___staticImageLink___childMarkdownRemark___excerpt",
    data___staticImageLink___childMarkdownRemark___excerptAst = "data___staticImageLink___childMarkdownRemark___excerptAst",
    data___staticImageLink___childMarkdownRemark___fileAbsolutePath = "data___staticImageLink___childMarkdownRemark___fileAbsolutePath",
    data___staticImageLink___childMarkdownRemark___headings = "data___staticImageLink___childMarkdownRemark___headings",
    data___staticImageLink___childMarkdownRemark___html = "data___staticImageLink___childMarkdownRemark___html",
    data___staticImageLink___childMarkdownRemark___htmlAst = "data___staticImageLink___childMarkdownRemark___htmlAst",
    data___staticImageLink___childMarkdownRemark___id = "data___staticImageLink___childMarkdownRemark___id",
    data___staticImageLink___childMarkdownRemark___rawMarkdownBody = "data___staticImageLink___childMarkdownRemark___rawMarkdownBody",
    data___staticImageLink___childMarkdownRemark___tableOfContents = "data___staticImageLink___childMarkdownRemark___tableOfContents",
    data___staticImageLink___childMarkdownRemark___timeToRead = "data___staticImageLink___childMarkdownRemark___timeToRead",
    data___staticImageLink___children = "data___staticImageLink___children",
    data___staticImageLink___childrenContentItem = "data___staticImageLink___childrenContentItem",
    data___staticImageLink___childrenContentItem___baseLink = "data___staticImageLink___childrenContentItem___baseLink",
    data___staticImageLink___childrenContentItem___children = "data___staticImageLink___childrenContentItem___children",
    data___staticImageLink___childrenContentItem___id = "data___staticImageLink___childrenContentItem___id",
    data___staticImageLink___childrenContentItem___link = "data___staticImageLink___childrenContentItem___link",
    data___staticImageLink___childrenContentItem___pageId = "data___staticImageLink___childrenContentItem___pageId",
    data___staticImageLink___childrenContentItem___permission = "data___staticImageLink___childrenContentItem___permission",
    data___staticImageLink___childrenContentItem___sourcePath = "data___staticImageLink___childrenContentItem___sourcePath",
    data___staticImageLink___childrenContentItem___type = "data___staticImageLink___childrenContentItem___type",
    data___staticImageLink___childrenMarkdownRemark = "data___staticImageLink___childrenMarkdownRemark",
    data___staticImageLink___childrenMarkdownRemark___children = "data___staticImageLink___childrenMarkdownRemark___children",
    data___staticImageLink___childrenMarkdownRemark___excerpt = "data___staticImageLink___childrenMarkdownRemark___excerpt",
    data___staticImageLink___childrenMarkdownRemark___excerptAst = "data___staticImageLink___childrenMarkdownRemark___excerptAst",
    data___staticImageLink___childrenMarkdownRemark___fileAbsolutePath = "data___staticImageLink___childrenMarkdownRemark___fileAbsolutePath",
    data___staticImageLink___childrenMarkdownRemark___headings = "data___staticImageLink___childrenMarkdownRemark___headings",
    data___staticImageLink___childrenMarkdownRemark___html = "data___staticImageLink___childrenMarkdownRemark___html",
    data___staticImageLink___childrenMarkdownRemark___htmlAst = "data___staticImageLink___childrenMarkdownRemark___htmlAst",
    data___staticImageLink___childrenMarkdownRemark___id = "data___staticImageLink___childrenMarkdownRemark___id",
    data___staticImageLink___childrenMarkdownRemark___rawMarkdownBody = "data___staticImageLink___childrenMarkdownRemark___rawMarkdownBody",
    data___staticImageLink___childrenMarkdownRemark___tableOfContents = "data___staticImageLink___childrenMarkdownRemark___tableOfContents",
    data___staticImageLink___childrenMarkdownRemark___timeToRead = "data___staticImageLink___childrenMarkdownRemark___timeToRead",
    data___staticImageLink___children___children = "data___staticImageLink___children___children",
    data___staticImageLink___children___id = "data___staticImageLink___children___id",
    data___staticImageLink___ctime = "data___staticImageLink___ctime",
    data___staticImageLink___ctimeMs = "data___staticImageLink___ctimeMs",
    data___staticImageLink___dev = "data___staticImageLink___dev",
    data___staticImageLink___dir = "data___staticImageLink___dir",
    data___staticImageLink___ext = "data___staticImageLink___ext",
    data___staticImageLink___extension = "data___staticImageLink___extension",
    data___staticImageLink___gid = "data___staticImageLink___gid",
    data___staticImageLink___id = "data___staticImageLink___id",
    data___staticImageLink___ino = "data___staticImageLink___ino",
    data___staticImageLink___internal___content = "data___staticImageLink___internal___content",
    data___staticImageLink___internal___contentDigest = "data___staticImageLink___internal___contentDigest",
    data___staticImageLink___internal___description = "data___staticImageLink___internal___description",
    data___staticImageLink___internal___fieldOwners = "data___staticImageLink___internal___fieldOwners",
    data___staticImageLink___internal___ignoreType = "data___staticImageLink___internal___ignoreType",
    data___staticImageLink___internal___mediaType = "data___staticImageLink___internal___mediaType",
    data___staticImageLink___internal___owner = "data___staticImageLink___internal___owner",
    data___staticImageLink___internal___type = "data___staticImageLink___internal___type",
    data___staticImageLink___mode = "data___staticImageLink___mode",
    data___staticImageLink___modifiedTime = "data___staticImageLink___modifiedTime",
    data___staticImageLink___mtime = "data___staticImageLink___mtime",
    data___staticImageLink___mtimeMs = "data___staticImageLink___mtimeMs",
    data___staticImageLink___name = "data___staticImageLink___name",
    data___staticImageLink___nlink = "data___staticImageLink___nlink",
    data___staticImageLink___parent___children = "data___staticImageLink___parent___children",
    data___staticImageLink___parent___id = "data___staticImageLink___parent___id",
    data___staticImageLink___prettySize = "data___staticImageLink___prettySize",
    data___staticImageLink___publicURL = "data___staticImageLink___publicURL",
    data___staticImageLink___rdev = "data___staticImageLink___rdev",
    data___staticImageLink___relativeDirectory = "data___staticImageLink___relativeDirectory",
    data___staticImageLink___relativePath = "data___staticImageLink___relativePath",
    data___staticImageLink___root = "data___staticImageLink___root",
    data___staticImageLink___size = "data___staticImageLink___size",
    data___staticImageLink___sourceInstanceName = "data___staticImageLink___sourceInstanceName",
    data___staticImageLink___uid = "data___staticImageLink___uid",
    data___tocMaxDepth = "data___tocMaxDepth",
    data___toc___enable = "data___toc___enable",
    data___toc___headings = "data___toc___headings",
    data___toc___headings___depth = "data___toc___headings___depth",
    data___toc___headings___id = "data___toc___headings___id",
    data___toc___headings___value = "data___toc___headings___value",
    data___toc___maxDepth = "data___toc___maxDepth",
    data___type = "data___type",
    data___versions = "data___versions",
    data___versions___definitionId = "data___versions___definitionId",
    data___versions___id = "data___versions___id",
    data___versions___isDefault = "data___versions___isDefault",
    data___versions___label = "data___versions___label",
    data___versions___settings___pagination = "data___versions___settings___pagination",
    data___versions___title = "data___versions___title",
    id = "id",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    link = "link",
    markdown___children = "markdown___children",
    markdown___children___children = "markdown___children___children",
    markdown___children___children___children = "markdown___children___children___children",
    markdown___children___children___id = "markdown___children___children___id",
    markdown___children___id = "markdown___children___id",
    markdown___children___internal___content = "markdown___children___internal___content",
    markdown___children___internal___contentDigest = "markdown___children___internal___contentDigest",
    markdown___children___internal___description = "markdown___children___internal___description",
    markdown___children___internal___fieldOwners = "markdown___children___internal___fieldOwners",
    markdown___children___internal___ignoreType = "markdown___children___internal___ignoreType",
    markdown___children___internal___mediaType = "markdown___children___internal___mediaType",
    markdown___children___internal___owner = "markdown___children___internal___owner",
    markdown___children___internal___type = "markdown___children___internal___type",
    markdown___children___parent___children = "markdown___children___parent___children",
    markdown___children___parent___id = "markdown___children___parent___id",
    markdown___excerpt = "markdown___excerpt",
    markdown___excerptAst = "markdown___excerptAst",
    markdown___fields___contentId = "markdown___fields___contentId",
    markdown___fileAbsolutePath = "markdown___fileAbsolutePath",
    markdown___frontmatter___children = "markdown___frontmatter___children",
    markdown___frontmatter___children___children = "markdown___frontmatter___children___children",
    markdown___frontmatter___children___id = "markdown___frontmatter___children___id",
    markdown___frontmatter___description = "markdown___frontmatter___description",
    markdown___frontmatter___disableLastModified = "markdown___frontmatter___disableLastModified",
    markdown___frontmatter___editPage___disable = "markdown___frontmatter___editPage___disable",
    markdown___frontmatter___enableToc = "markdown___frontmatter___enableToc",
    markdown___frontmatter___id = "markdown___frontmatter___id",
    markdown___frontmatter___internal___content = "markdown___frontmatter___internal___content",
    markdown___frontmatter___internal___contentDigest = "markdown___frontmatter___internal___contentDigest",
    markdown___frontmatter___internal___description = "markdown___frontmatter___internal___description",
    markdown___frontmatter___internal___fieldOwners = "markdown___frontmatter___internal___fieldOwners",
    markdown___frontmatter___internal___ignoreType = "markdown___frontmatter___internal___ignoreType",
    markdown___frontmatter___internal___mediaType = "markdown___frontmatter___internal___mediaType",
    markdown___frontmatter___internal___owner = "markdown___frontmatter___internal___owner",
    markdown___frontmatter___internal___type = "markdown___frontmatter___internal___type",
    markdown___frontmatter___parent___children = "markdown___frontmatter___parent___children",
    markdown___frontmatter___parent___id = "markdown___frontmatter___parent___id",
    markdown___frontmatter___redirectFrom = "markdown___frontmatter___redirectFrom",
    markdown___frontmatter___sidebar = "markdown___frontmatter___sidebar",
    markdown___frontmatter___title = "markdown___frontmatter___title",
    markdown___frontmatter___tocMaxDepth = "markdown___frontmatter___tocMaxDepth",
    markdown___frontmatter___toc___enable = "markdown___frontmatter___toc___enable",
    markdown___headings = "markdown___headings",
    markdown___headings___depth = "markdown___headings___depth",
    markdown___headings___id = "markdown___headings___id",
    markdown___headings___value = "markdown___headings___value",
    markdown___html = "markdown___html",
    markdown___htmlAst = "markdown___htmlAst",
    markdown___id = "markdown___id",
    markdown___internal___content = "markdown___internal___content",
    markdown___internal___contentDigest = "markdown___internal___contentDigest",
    markdown___internal___description = "markdown___internal___description",
    markdown___internal___fieldOwners = "markdown___internal___fieldOwners",
    markdown___internal___ignoreType = "markdown___internal___ignoreType",
    markdown___internal___mediaType = "markdown___internal___mediaType",
    markdown___internal___owner = "markdown___internal___owner",
    markdown___internal___type = "markdown___internal___type",
    markdown___parent___children = "markdown___parent___children",
    markdown___parent___children___children = "markdown___parent___children___children",
    markdown___parent___children___id = "markdown___parent___children___id",
    markdown___parent___id = "markdown___parent___id",
    markdown___parent___internal___content = "markdown___parent___internal___content",
    markdown___parent___internal___contentDigest = "markdown___parent___internal___contentDigest",
    markdown___parent___internal___description = "markdown___parent___internal___description",
    markdown___parent___internal___fieldOwners = "markdown___parent___internal___fieldOwners",
    markdown___parent___internal___ignoreType = "markdown___parent___internal___ignoreType",
    markdown___parent___internal___mediaType = "markdown___parent___internal___mediaType",
    markdown___parent___internal___owner = "markdown___parent___internal___owner",
    markdown___parent___internal___type = "markdown___parent___internal___type",
    markdown___parent___parent___children = "markdown___parent___parent___children",
    markdown___parent___parent___id = "markdown___parent___parent___id",
    markdown___rawMarkdownBody = "markdown___rawMarkdownBody",
    markdown___tableOfContents = "markdown___tableOfContents",
    markdown___timeToRead = "markdown___timeToRead",
    markdown___wordCount___paragraphs = "markdown___wordCount___paragraphs",
    markdown___wordCount___sentences = "markdown___wordCount___sentences",
    markdown___wordCount___words = "markdown___wordCount___words",
    pageId = "pageId",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id",
    permission = "permission",
    seo___children = "seo___children",
    seo___children___children = "seo___children___children",
    seo___children___children___children = "seo___children___children___children",
    seo___children___children___id = "seo___children___children___id",
    seo___children___id = "seo___children___id",
    seo___children___internal___content = "seo___children___internal___content",
    seo___children___internal___contentDigest = "seo___children___internal___contentDigest",
    seo___children___internal___description = "seo___children___internal___description",
    seo___children___internal___fieldOwners = "seo___children___internal___fieldOwners",
    seo___children___internal___ignoreType = "seo___children___internal___ignoreType",
    seo___children___internal___mediaType = "seo___children___internal___mediaType",
    seo___children___internal___owner = "seo___children___internal___owner",
    seo___children___internal___type = "seo___children___internal___type",
    seo___children___parent___children = "seo___children___parent___children",
    seo___children___parent___id = "seo___children___parent___id",
    seo___description = "seo___description",
    seo___id = "seo___id",
    seo___image = "seo___image",
    seo___internal___content = "seo___internal___content",
    seo___internal___contentDigest = "seo___internal___contentDigest",
    seo___internal___description = "seo___internal___description",
    seo___internal___fieldOwners = "seo___internal___fieldOwners",
    seo___internal___ignoreType = "seo___internal___ignoreType",
    seo___internal___mediaType = "seo___internal___mediaType",
    seo___internal___owner = "seo___internal___owner",
    seo___internal___type = "seo___internal___type",
    seo___jsonLd = "seo___jsonLd",
    seo___keywords = "seo___keywords",
    seo___lang = "seo___lang",
    seo___parent___children = "seo___parent___children",
    seo___parent___children___children = "seo___parent___children___children",
    seo___parent___children___id = "seo___parent___children___id",
    seo___parent___id = "seo___parent___id",
    seo___parent___internal___content = "seo___parent___internal___content",
    seo___parent___internal___contentDigest = "seo___parent___internal___contentDigest",
    seo___parent___internal___description = "seo___parent___internal___description",
    seo___parent___internal___fieldOwners = "seo___parent___internal___fieldOwners",
    seo___parent___internal___ignoreType = "seo___parent___internal___ignoreType",
    seo___parent___internal___mediaType = "seo___parent___internal___mediaType",
    seo___parent___internal___owner = "seo___parent___internal___owner",
    seo___parent___internal___type = "seo___parent___internal___type",
    seo___parent___parent___children = "seo___parent___parent___children",
    seo___parent___parent___id = "seo___parent___parent___id",
    seo___sitemap___changefreq = "seo___sitemap___changefreq",
    seo___sitemap___lastmod = "seo___sitemap___lastmod",
    seo___sitemap___priority = "seo___sitemap___priority",
    seo___title = "seo___title",
    sourcePath = "sourcePath",
    type = "type"
}
export declare type ContentItemFilterInput = {
    baseLink?: InputMaybe<StringQueryOperatorInput>;
    catalogInfo?: InputMaybe<CatalogInfoFilterInput>;
    children?: InputMaybe<NodeFilterListInput>;
    data?: InputMaybe<ContentItemDataFilterInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    link?: InputMaybe<StringQueryOperatorInput>;
    markdown?: InputMaybe<MarkdownRemarkFilterInput>;
    pageId?: InputMaybe<StringQueryOperatorInput>;
    parent?: InputMaybe<NodeFilterInput>;
    permission?: InputMaybe<StringQueryOperatorInput>;
    seo?: InputMaybe<ContentItemSeoFilterInput>;
    sourcePath?: InputMaybe<StringQueryOperatorInput>;
    type?: InputMaybe<StringQueryOperatorInput>;
};
export declare type ContentItemFilterListInput = {
    elemMatch?: InputMaybe<ContentItemFilterInput>;
};
export declare type ContentItemGroupConnection = {
    __typename?: 'ContentItemGroupConnection';
    edges: Array<ContentItemEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<ContentItem>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type ContentItemSeo = Node & {
    __typename?: 'ContentItemSeo';
    children: Array<Node>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    image?: Maybe<Scalars['String']>;
    internal: Internal;
    jsonLd?: Maybe<Scalars['JSON']>;
    keywords?: Maybe<Scalars['String']>;
    lang?: Maybe<Scalars['String']>;
    parent?: Maybe<Node>;
    sitemap?: Maybe<Sitemap>;
    title?: Maybe<Scalars['String']>;
};
export declare type ContentItemSeoConnection = {
    __typename?: 'ContentItemSeoConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<ContentItemSeoEdge>;
    group: Array<ContentItemSeoGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<ContentItemSeo>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type ContentItemSeoConnectionDistinctArgs = {
    field: ContentItemSeoFieldsEnum;
};
export declare type ContentItemSeoConnectionGroupArgs = {
    field: ContentItemSeoFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type ContentItemSeoConnectionMaxArgs = {
    field: ContentItemSeoFieldsEnum;
};
export declare type ContentItemSeoConnectionMinArgs = {
    field: ContentItemSeoFieldsEnum;
};
export declare type ContentItemSeoConnectionSumArgs = {
    field: ContentItemSeoFieldsEnum;
};
export declare type ContentItemSeoEdge = {
    __typename?: 'ContentItemSeoEdge';
    next?: Maybe<ContentItemSeo>;
    node: ContentItemSeo;
    previous?: Maybe<ContentItemSeo>;
};
export declare enum ContentItemSeoFieldsEnum {
    children = "children",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    description = "description",
    id = "id",
    image = "image",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    jsonLd = "jsonLd",
    keywords = "keywords",
    lang = "lang",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id",
    sitemap___changefreq = "sitemap___changefreq",
    sitemap___lastmod = "sitemap___lastmod",
    sitemap___priority = "sitemap___priority",
    title = "title"
}
export declare type ContentItemSeoFilterInput = {
    children?: InputMaybe<NodeFilterListInput>;
    description?: InputMaybe<StringQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    image?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    jsonLd?: InputMaybe<JsonQueryOperatorInput>;
    keywords?: InputMaybe<StringQueryOperatorInput>;
    lang?: InputMaybe<StringQueryOperatorInput>;
    parent?: InputMaybe<NodeFilterInput>;
    sitemap?: InputMaybe<SitemapFilterInput>;
    title?: InputMaybe<StringQueryOperatorInput>;
};
export declare type ContentItemSeoGroupConnection = {
    __typename?: 'ContentItemSeoGroupConnection';
    edges: Array<ContentItemSeoEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<ContentItemSeo>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type ContentItemSeoSortInput = {
    fields?: InputMaybe<Array<InputMaybe<ContentItemSeoFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare type ContentItemSortInput = {
    fields?: InputMaybe<Array<InputMaybe<ContentItemFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare type DateQueryOperatorInput = {
    eq?: InputMaybe<Scalars['Date']>;
    gt?: InputMaybe<Scalars['Date']>;
    gte?: InputMaybe<Scalars['Date']>;
    in?: InputMaybe<Array<InputMaybe<Scalars['Date']>>>;
    lt?: InputMaybe<Scalars['Date']>;
    lte?: InputMaybe<Scalars['Date']>;
    ne?: InputMaybe<Scalars['Date']>;
    nin?: InputMaybe<Array<InputMaybe<Scalars['Date']>>>;
};
export declare type Directory = Node & {
    __typename?: 'Directory';
    absolutePath: Scalars['String'];
    accessTime: Scalars['Date'];
    atime: Scalars['Date'];
    atimeMs: Scalars['Float'];
    base: Scalars['String'];
    birthTime: Scalars['Date'];
    /** @deprecated Use `birthTime` instead */
    birthtime?: Maybe<Scalars['Date']>;
    /** @deprecated Use `birthTime` instead */
    birthtimeMs?: Maybe<Scalars['Float']>;
    blksize?: Maybe<Scalars['Int']>;
    blocks?: Maybe<Scalars['Int']>;
    changeTime: Scalars['Date'];
    children: Array<Node>;
    ctime: Scalars['Date'];
    ctimeMs: Scalars['Float'];
    dev: Scalars['Int'];
    dir: Scalars['String'];
    ext: Scalars['String'];
    extension: Scalars['String'];
    gid: Scalars['Int'];
    id: Scalars['ID'];
    ino: Scalars['Float'];
    internal: Internal;
    mode: Scalars['Int'];
    modifiedTime: Scalars['Date'];
    mtime: Scalars['Date'];
    mtimeMs: Scalars['Float'];
    name: Scalars['String'];
    nlink: Scalars['Int'];
    parent?: Maybe<Node>;
    prettySize: Scalars['String'];
    rdev: Scalars['Int'];
    relativeDirectory: Scalars['String'];
    relativePath: Scalars['String'];
    root: Scalars['String'];
    size: Scalars['Int'];
    sourceInstanceName: Scalars['String'];
    uid: Scalars['Int'];
};
export declare type DirectoryAccessTimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type DirectoryAtimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type DirectoryBirthTimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type DirectoryChangeTimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type DirectoryCtimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type DirectoryModifiedTimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type DirectoryMtimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type DirectoryConnection = {
    __typename?: 'DirectoryConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<DirectoryEdge>;
    group: Array<DirectoryGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<Directory>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type DirectoryConnectionDistinctArgs = {
    field: DirectoryFieldsEnum;
};
export declare type DirectoryConnectionGroupArgs = {
    field: DirectoryFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type DirectoryConnectionMaxArgs = {
    field: DirectoryFieldsEnum;
};
export declare type DirectoryConnectionMinArgs = {
    field: DirectoryFieldsEnum;
};
export declare type DirectoryConnectionSumArgs = {
    field: DirectoryFieldsEnum;
};
export declare type DirectoryEdge = {
    __typename?: 'DirectoryEdge';
    next?: Maybe<Directory>;
    node: Directory;
    previous?: Maybe<Directory>;
};
export declare enum DirectoryFieldsEnum {
    absolutePath = "absolutePath",
    accessTime = "accessTime",
    atime = "atime",
    atimeMs = "atimeMs",
    base = "base",
    birthTime = "birthTime",
    birthtime = "birthtime",
    birthtimeMs = "birthtimeMs",
    blksize = "blksize",
    blocks = "blocks",
    changeTime = "changeTime",
    children = "children",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    ctime = "ctime",
    ctimeMs = "ctimeMs",
    dev = "dev",
    dir = "dir",
    ext = "ext",
    extension = "extension",
    gid = "gid",
    id = "id",
    ino = "ino",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    mode = "mode",
    modifiedTime = "modifiedTime",
    mtime = "mtime",
    mtimeMs = "mtimeMs",
    name = "name",
    nlink = "nlink",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id",
    prettySize = "prettySize",
    rdev = "rdev",
    relativeDirectory = "relativeDirectory",
    relativePath = "relativePath",
    root = "root",
    size = "size",
    sourceInstanceName = "sourceInstanceName",
    uid = "uid"
}
export declare type DirectoryFilterInput = {
    absolutePath?: InputMaybe<StringQueryOperatorInput>;
    accessTime?: InputMaybe<DateQueryOperatorInput>;
    atime?: InputMaybe<DateQueryOperatorInput>;
    atimeMs?: InputMaybe<FloatQueryOperatorInput>;
    base?: InputMaybe<StringQueryOperatorInput>;
    birthTime?: InputMaybe<DateQueryOperatorInput>;
    birthtime?: InputMaybe<DateQueryOperatorInput>;
    birthtimeMs?: InputMaybe<FloatQueryOperatorInput>;
    blksize?: InputMaybe<IntQueryOperatorInput>;
    blocks?: InputMaybe<IntQueryOperatorInput>;
    changeTime?: InputMaybe<DateQueryOperatorInput>;
    children?: InputMaybe<NodeFilterListInput>;
    ctime?: InputMaybe<DateQueryOperatorInput>;
    ctimeMs?: InputMaybe<FloatQueryOperatorInput>;
    dev?: InputMaybe<IntQueryOperatorInput>;
    dir?: InputMaybe<StringQueryOperatorInput>;
    ext?: InputMaybe<StringQueryOperatorInput>;
    extension?: InputMaybe<StringQueryOperatorInput>;
    gid?: InputMaybe<IntQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    ino?: InputMaybe<FloatQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    mode?: InputMaybe<IntQueryOperatorInput>;
    modifiedTime?: InputMaybe<DateQueryOperatorInput>;
    mtime?: InputMaybe<DateQueryOperatorInput>;
    mtimeMs?: InputMaybe<FloatQueryOperatorInput>;
    name?: InputMaybe<StringQueryOperatorInput>;
    nlink?: InputMaybe<IntQueryOperatorInput>;
    parent?: InputMaybe<NodeFilterInput>;
    prettySize?: InputMaybe<StringQueryOperatorInput>;
    rdev?: InputMaybe<IntQueryOperatorInput>;
    relativeDirectory?: InputMaybe<StringQueryOperatorInput>;
    relativePath?: InputMaybe<StringQueryOperatorInput>;
    root?: InputMaybe<StringQueryOperatorInput>;
    size?: InputMaybe<IntQueryOperatorInput>;
    sourceInstanceName?: InputMaybe<StringQueryOperatorInput>;
    uid?: InputMaybe<IntQueryOperatorInput>;
};
export declare type DirectoryGroupConnection = {
    __typename?: 'DirectoryGroupConnection';
    edges: Array<DirectoryEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<Directory>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type DirectorySortInput = {
    fields?: InputMaybe<Array<InputMaybe<DirectoryFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare type EditPageConfig = {
    __typename?: 'EditPageConfig';
    baseUrl?: Maybe<Scalars['String']>;
    icon?: Maybe<Scalars['String']>;
    text?: Maybe<Scalars['String']>;
};
export declare type EditPageConfigFilterInput = {
    baseUrl?: InputMaybe<StringQueryOperatorInput>;
    icon?: InputMaybe<StringQueryOperatorInput>;
    text?: InputMaybe<StringQueryOperatorInput>;
};
export declare type File = Node & {
    __typename?: 'File';
    absolutePath: Scalars['String'];
    accessTime: Scalars['Date'];
    atime: Scalars['Date'];
    atimeMs: Scalars['Float'];
    base: Scalars['String'];
    birthTime: Scalars['Date'];
    /** @deprecated Use `birthTime` instead */
    birthtime?: Maybe<Scalars['Date']>;
    /** @deprecated Use `birthTime` instead */
    birthtimeMs?: Maybe<Scalars['Float']>;
    blksize?: Maybe<Scalars['Int']>;
    blocks?: Maybe<Scalars['Int']>;
    changeTime: Scalars['Date'];
    /** Returns the first child node of type ContentItem or null if there are no children of given type on this node */
    childContentItem?: Maybe<ContentItem>;
    /** Returns the first child node of type MarkdownRemark or null if there are no children of given type on this node */
    childMarkdownRemark?: Maybe<MarkdownRemark>;
    children: Array<Node>;
    /** Returns all children nodes filtered by type ContentItem */
    childrenContentItem?: Maybe<Array<Maybe<ContentItem>>>;
    /** Returns all children nodes filtered by type MarkdownRemark */
    childrenMarkdownRemark?: Maybe<Array<Maybe<MarkdownRemark>>>;
    ctime: Scalars['Date'];
    ctimeMs: Scalars['Float'];
    dev: Scalars['Int'];
    dir: Scalars['String'];
    ext: Scalars['String'];
    extension: Scalars['String'];
    gid: Scalars['Int'];
    id: Scalars['ID'];
    ino: Scalars['Float'];
    internal: Internal;
    mode: Scalars['Int'];
    modifiedTime: Scalars['Date'];
    mtime: Scalars['Date'];
    mtimeMs: Scalars['Float'];
    name: Scalars['String'];
    nlink: Scalars['Int'];
    parent?: Maybe<Node>;
    prettySize: Scalars['String'];
    /** Copy file to static directory and return public url to it */
    publicURL?: Maybe<Scalars['String']>;
    rdev: Scalars['Int'];
    relativeDirectory: Scalars['String'];
    relativePath: Scalars['String'];
    root: Scalars['String'];
    size: Scalars['Int'];
    sourceInstanceName: Scalars['String'];
    uid: Scalars['Int'];
};
export declare type FileAccessTimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type FileAtimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type FileBirthTimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type FileChangeTimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type FileCtimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type FileModifiedTimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type FileMtimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type FileConnection = {
    __typename?: 'FileConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<FileEdge>;
    group: Array<FileGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<File>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type FileConnectionDistinctArgs = {
    field: FileFieldsEnum;
};
export declare type FileConnectionGroupArgs = {
    field: FileFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type FileConnectionMaxArgs = {
    field: FileFieldsEnum;
};
export declare type FileConnectionMinArgs = {
    field: FileFieldsEnum;
};
export declare type FileConnectionSumArgs = {
    field: FileFieldsEnum;
};
export declare type FileEdge = {
    __typename?: 'FileEdge';
    next?: Maybe<File>;
    node: File;
    previous?: Maybe<File>;
};
export declare enum FileFieldsEnum {
    absolutePath = "absolutePath",
    accessTime = "accessTime",
    atime = "atime",
    atimeMs = "atimeMs",
    base = "base",
    birthTime = "birthTime",
    birthtime = "birthtime",
    birthtimeMs = "birthtimeMs",
    blksize = "blksize",
    blocks = "blocks",
    changeTime = "changeTime",
    childContentItem___baseLink = "childContentItem___baseLink",
    childContentItem___catalogInfo___apiName = "childContentItem___catalogInfo___apiName",
    childContentItem___catalogInfo___apiVersion = "childContentItem___catalogInfo___apiVersion",
    childContentItem___catalogInfo___metadata = "childContentItem___catalogInfo___metadata",
    childContentItem___catalogInfo___title = "childContentItem___catalogInfo___title",
    childContentItem___children = "childContentItem___children",
    childContentItem___children___children = "childContentItem___children___children",
    childContentItem___children___children___children = "childContentItem___children___children___children",
    childContentItem___children___children___id = "childContentItem___children___children___id",
    childContentItem___children___id = "childContentItem___children___id",
    childContentItem___children___internal___content = "childContentItem___children___internal___content",
    childContentItem___children___internal___contentDigest = "childContentItem___children___internal___contentDigest",
    childContentItem___children___internal___description = "childContentItem___children___internal___description",
    childContentItem___children___internal___fieldOwners = "childContentItem___children___internal___fieldOwners",
    childContentItem___children___internal___ignoreType = "childContentItem___children___internal___ignoreType",
    childContentItem___children___internal___mediaType = "childContentItem___children___internal___mediaType",
    childContentItem___children___internal___owner = "childContentItem___children___internal___owner",
    childContentItem___children___internal___type = "childContentItem___children___internal___type",
    childContentItem___children___parent___children = "childContentItem___children___parent___children",
    childContentItem___children___parent___id = "childContentItem___children___parent___id",
    childContentItem___data___apiVersionId = "childContentItem___data___apiVersionId",
    childContentItem___data___apiVersions = "childContentItem___data___apiVersions",
    childContentItem___data___apiVersions___apiId = "childContentItem___data___apiVersions___apiId",
    childContentItem___data___apiVersions___definitionId = "childContentItem___data___apiVersions___definitionId",
    childContentItem___data___apiVersions___id = "childContentItem___data___apiVersions___id",
    childContentItem___data___apiVersions___isDefault = "childContentItem___data___apiVersions___isDefault",
    childContentItem___data___apiVersions___label = "childContentItem___data___apiVersions___label",
    childContentItem___data___apiVersions___title = "childContentItem___data___apiVersions___title",
    childContentItem___data___children = "childContentItem___data___children",
    childContentItem___data___children___children = "childContentItem___data___children___children",
    childContentItem___data___children___id = "childContentItem___data___children___id",
    childContentItem___data___customDataString = "childContentItem___data___customDataString",
    childContentItem___data___customData___description = "childContentItem___data___customData___description",
    childContentItem___data___customData___imageLink = "childContentItem___data___customData___imageLink",
    childContentItem___data___customData___redirectFrom = "childContentItem___data___customData___redirectFrom",
    childContentItem___data___customData___title = "childContentItem___data___customData___title",
    childContentItem___data___customTemplate = "childContentItem___data___customTemplate",
    childContentItem___data___definitionId = "childContentItem___data___definitionId",
    childContentItem___data___disableEditPage = "childContentItem___data___disableEditPage",
    childContentItem___data___disableLastModified = "childContentItem___data___disableLastModified",
    childContentItem___data___editPage___disable = "childContentItem___data___editPage___disable",
    childContentItem___data___enableToc = "childContentItem___data___enableToc",
    childContentItem___data___excludeFromSearch = "childContentItem___data___excludeFromSearch",
    childContentItem___data___httpVerb = "childContentItem___data___httpVerb",
    childContentItem___data___id = "childContentItem___data___id",
    childContentItem___data___image = "childContentItem___data___image",
    childContentItem___data___imageLink = "childContentItem___data___imageLink",
    childContentItem___data___internal___content = "childContentItem___data___internal___content",
    childContentItem___data___internal___contentDigest = "childContentItem___data___internal___contentDigest",
    childContentItem___data___internal___description = "childContentItem___data___internal___description",
    childContentItem___data___internal___fieldOwners = "childContentItem___data___internal___fieldOwners",
    childContentItem___data___internal___ignoreType = "childContentItem___data___internal___ignoreType",
    childContentItem___data___internal___mediaType = "childContentItem___data___internal___mediaType",
    childContentItem___data___internal___owner = "childContentItem___data___internal___owner",
    childContentItem___data___internal___type = "childContentItem___data___internal___type",
    childContentItem___data___isDefaultApiVersion = "childContentItem___data___isDefaultApiVersion",
    childContentItem___data___keywords = "childContentItem___data___keywords",
    childContentItem___data___label = "childContentItem___data___label",
    childContentItem___data___lang = "childContentItem___data___lang",
    childContentItem___data___lastModified = "childContentItem___data___lastModified",
    childContentItem___data___matchPath = "childContentItem___data___matchPath",
    childContentItem___data___pageLink___absolutePath = "childContentItem___data___pageLink___absolutePath",
    childContentItem___data___pageLink___accessTime = "childContentItem___data___pageLink___accessTime",
    childContentItem___data___pageLink___atime = "childContentItem___data___pageLink___atime",
    childContentItem___data___pageLink___atimeMs = "childContentItem___data___pageLink___atimeMs",
    childContentItem___data___pageLink___base = "childContentItem___data___pageLink___base",
    childContentItem___data___pageLink___birthTime = "childContentItem___data___pageLink___birthTime",
    childContentItem___data___pageLink___birthtime = "childContentItem___data___pageLink___birthtime",
    childContentItem___data___pageLink___birthtimeMs = "childContentItem___data___pageLink___birthtimeMs",
    childContentItem___data___pageLink___blksize = "childContentItem___data___pageLink___blksize",
    childContentItem___data___pageLink___blocks = "childContentItem___data___pageLink___blocks",
    childContentItem___data___pageLink___changeTime = "childContentItem___data___pageLink___changeTime",
    childContentItem___data___pageLink___children = "childContentItem___data___pageLink___children",
    childContentItem___data___pageLink___childrenContentItem = "childContentItem___data___pageLink___childrenContentItem",
    childContentItem___data___pageLink___childrenMarkdownRemark = "childContentItem___data___pageLink___childrenMarkdownRemark",
    childContentItem___data___pageLink___ctime = "childContentItem___data___pageLink___ctime",
    childContentItem___data___pageLink___ctimeMs = "childContentItem___data___pageLink___ctimeMs",
    childContentItem___data___pageLink___dev = "childContentItem___data___pageLink___dev",
    childContentItem___data___pageLink___dir = "childContentItem___data___pageLink___dir",
    childContentItem___data___pageLink___ext = "childContentItem___data___pageLink___ext",
    childContentItem___data___pageLink___extension = "childContentItem___data___pageLink___extension",
    childContentItem___data___pageLink___gid = "childContentItem___data___pageLink___gid",
    childContentItem___data___pageLink___id = "childContentItem___data___pageLink___id",
    childContentItem___data___pageLink___ino = "childContentItem___data___pageLink___ino",
    childContentItem___data___pageLink___mode = "childContentItem___data___pageLink___mode",
    childContentItem___data___pageLink___modifiedTime = "childContentItem___data___pageLink___modifiedTime",
    childContentItem___data___pageLink___mtime = "childContentItem___data___pageLink___mtime",
    childContentItem___data___pageLink___mtimeMs = "childContentItem___data___pageLink___mtimeMs",
    childContentItem___data___pageLink___name = "childContentItem___data___pageLink___name",
    childContentItem___data___pageLink___nlink = "childContentItem___data___pageLink___nlink",
    childContentItem___data___pageLink___prettySize = "childContentItem___data___pageLink___prettySize",
    childContentItem___data___pageLink___publicURL = "childContentItem___data___pageLink___publicURL",
    childContentItem___data___pageLink___rdev = "childContentItem___data___pageLink___rdev",
    childContentItem___data___pageLink___relativeDirectory = "childContentItem___data___pageLink___relativeDirectory",
    childContentItem___data___pageLink___relativePath = "childContentItem___data___pageLink___relativePath",
    childContentItem___data___pageLink___root = "childContentItem___data___pageLink___root",
    childContentItem___data___pageLink___size = "childContentItem___data___pageLink___size",
    childContentItem___data___pageLink___sourceInstanceName = "childContentItem___data___pageLink___sourceInstanceName",
    childContentItem___data___pageLink___uid = "childContentItem___data___pageLink___uid",
    childContentItem___data___parent___children = "childContentItem___data___parent___children",
    childContentItem___data___parent___id = "childContentItem___data___parent___id",
    childContentItem___data___permission = "childContentItem___data___permission",
    childContentItem___data___redirect = "childContentItem___data___redirect",
    childContentItem___data___redirectFrom = "childContentItem___data___redirectFrom",
    childContentItem___data___redocHasInfoPage = "childContentItem___data___redocHasInfoPage",
    childContentItem___data___redocHasSecurityDefinitions = "childContentItem___data___redocHasSecurityDefinitions",
    childContentItem___data___redocInfoPageId = "childContentItem___data___redocInfoPageId",
    childContentItem___data___redocInfoPageLink = "childContentItem___data___redocInfoPageLink",
    childContentItem___data___redocItemId = "childContentItem___data___redocItemId",
    childContentItem___data___redocMenuItems = "childContentItem___data___redocMenuItems",
    childContentItem___data___redocMenuItems___apiVersionId = "childContentItem___data___redocMenuItems___apiVersionId",
    childContentItem___data___redocMenuItems___httpVerb = "childContentItem___data___redocMenuItems___httpVerb",
    childContentItem___data___redocMenuItems___isDefaultApiVersion = "childContentItem___data___redocMenuItems___isDefaultApiVersion",
    childContentItem___data___redocMenuItems___label = "childContentItem___data___redocMenuItems___label",
    childContentItem___data___redocMenuItems___link = "childContentItem___data___redocMenuItems___link",
    childContentItem___data___redocMenuItems___page = "childContentItem___data___redocMenuItems___page",
    childContentItem___data___redocMenuItems___pages = "childContentItem___data___redocMenuItems___pages",
    childContentItem___data___redocMenuItems___pagination = "childContentItem___data___redocMenuItems___pagination",
    childContentItem___data___redocMenuItems___parentPageId = "childContentItem___data___redocMenuItems___parentPageId",
    childContentItem___data___redocMenuItems___permission = "childContentItem___data___redocMenuItems___permission",
    childContentItem___data___redocMenuItems___redocFakePage = "childContentItem___data___redocMenuItems___redocFakePage",
    childContentItem___data___redocMenuItems___redocInfoPageLink = "childContentItem___data___redocMenuItems___redocInfoPageLink",
    childContentItem___data___redocMenuItems___separator = "childContentItem___data___redocMenuItems___separator",
    childContentItem___data___redocNextLabel = "childContentItem___data___redocNextLabel",
    childContentItem___data___redocNextLink = "childContentItem___data___redocNextLink",
    childContentItem___data___redocPagination = "childContentItem___data___redocPagination",
    childContentItem___data___redocPrevLabel = "childContentItem___data___redocPrevLabel",
    childContentItem___data___redocPrevLink = "childContentItem___data___redocPrevLink",
    childContentItem___data___redocStoreStr = "childContentItem___data___redocStoreStr",
    childContentItem___data___requestLogin = "childContentItem___data___requestLogin",
    childContentItem___data___settings = "childContentItem___data___settings",
    childContentItem___data___showNextButton = "childContentItem___data___showNextButton",
    childContentItem___data___showPrevButton = "childContentItem___data___showPrevButton",
    childContentItem___data___sidebar___absolutePath = "childContentItem___data___sidebar___absolutePath",
    childContentItem___data___sidebar___accessTime = "childContentItem___data___sidebar___accessTime",
    childContentItem___data___sidebar___atime = "childContentItem___data___sidebar___atime",
    childContentItem___data___sidebar___atimeMs = "childContentItem___data___sidebar___atimeMs",
    childContentItem___data___sidebar___base = "childContentItem___data___sidebar___base",
    childContentItem___data___sidebar___birthTime = "childContentItem___data___sidebar___birthTime",
    childContentItem___data___sidebar___birthtime = "childContentItem___data___sidebar___birthtime",
    childContentItem___data___sidebar___birthtimeMs = "childContentItem___data___sidebar___birthtimeMs",
    childContentItem___data___sidebar___blksize = "childContentItem___data___sidebar___blksize",
    childContentItem___data___sidebar___blocks = "childContentItem___data___sidebar___blocks",
    childContentItem___data___sidebar___changeTime = "childContentItem___data___sidebar___changeTime",
    childContentItem___data___sidebar___children = "childContentItem___data___sidebar___children",
    childContentItem___data___sidebar___childrenContentItem = "childContentItem___data___sidebar___childrenContentItem",
    childContentItem___data___sidebar___childrenMarkdownRemark = "childContentItem___data___sidebar___childrenMarkdownRemark",
    childContentItem___data___sidebar___ctime = "childContentItem___data___sidebar___ctime",
    childContentItem___data___sidebar___ctimeMs = "childContentItem___data___sidebar___ctimeMs",
    childContentItem___data___sidebar___dev = "childContentItem___data___sidebar___dev",
    childContentItem___data___sidebar___dir = "childContentItem___data___sidebar___dir",
    childContentItem___data___sidebar___ext = "childContentItem___data___sidebar___ext",
    childContentItem___data___sidebar___extension = "childContentItem___data___sidebar___extension",
    childContentItem___data___sidebar___gid = "childContentItem___data___sidebar___gid",
    childContentItem___data___sidebar___id = "childContentItem___data___sidebar___id",
    childContentItem___data___sidebar___ino = "childContentItem___data___sidebar___ino",
    childContentItem___data___sidebar___mode = "childContentItem___data___sidebar___mode",
    childContentItem___data___sidebar___modifiedTime = "childContentItem___data___sidebar___modifiedTime",
    childContentItem___data___sidebar___mtime = "childContentItem___data___sidebar___mtime",
    childContentItem___data___sidebar___mtimeMs = "childContentItem___data___sidebar___mtimeMs",
    childContentItem___data___sidebar___name = "childContentItem___data___sidebar___name",
    childContentItem___data___sidebar___nlink = "childContentItem___data___sidebar___nlink",
    childContentItem___data___sidebar___prettySize = "childContentItem___data___sidebar___prettySize",
    childContentItem___data___sidebar___publicURL = "childContentItem___data___sidebar___publicURL",
    childContentItem___data___sidebar___rdev = "childContentItem___data___sidebar___rdev",
    childContentItem___data___sidebar___relativeDirectory = "childContentItem___data___sidebar___relativeDirectory",
    childContentItem___data___sidebar___relativePath = "childContentItem___data___sidebar___relativePath",
    childContentItem___data___sidebar___root = "childContentItem___data___sidebar___root",
    childContentItem___data___sidebar___size = "childContentItem___data___sidebar___size",
    childContentItem___data___sidebar___sourceInstanceName = "childContentItem___data___sidebar___sourceInstanceName",
    childContentItem___data___sidebar___uid = "childContentItem___data___sidebar___uid",
    childContentItem___data___sitemap___changefreq = "childContentItem___data___sitemap___changefreq",
    childContentItem___data___sitemap___lastmod = "childContentItem___data___sitemap___lastmod",
    childContentItem___data___sitemap___priority = "childContentItem___data___sitemap___priority",
    childContentItem___data___sourcePath = "childContentItem___data___sourcePath",
    childContentItem___data___staticImageLink___absolutePath = "childContentItem___data___staticImageLink___absolutePath",
    childContentItem___data___staticImageLink___accessTime = "childContentItem___data___staticImageLink___accessTime",
    childContentItem___data___staticImageLink___atime = "childContentItem___data___staticImageLink___atime",
    childContentItem___data___staticImageLink___atimeMs = "childContentItem___data___staticImageLink___atimeMs",
    childContentItem___data___staticImageLink___base = "childContentItem___data___staticImageLink___base",
    childContentItem___data___staticImageLink___birthTime = "childContentItem___data___staticImageLink___birthTime",
    childContentItem___data___staticImageLink___birthtime = "childContentItem___data___staticImageLink___birthtime",
    childContentItem___data___staticImageLink___birthtimeMs = "childContentItem___data___staticImageLink___birthtimeMs",
    childContentItem___data___staticImageLink___blksize = "childContentItem___data___staticImageLink___blksize",
    childContentItem___data___staticImageLink___blocks = "childContentItem___data___staticImageLink___blocks",
    childContentItem___data___staticImageLink___changeTime = "childContentItem___data___staticImageLink___changeTime",
    childContentItem___data___staticImageLink___children = "childContentItem___data___staticImageLink___children",
    childContentItem___data___staticImageLink___childrenContentItem = "childContentItem___data___staticImageLink___childrenContentItem",
    childContentItem___data___staticImageLink___childrenMarkdownRemark = "childContentItem___data___staticImageLink___childrenMarkdownRemark",
    childContentItem___data___staticImageLink___ctime = "childContentItem___data___staticImageLink___ctime",
    childContentItem___data___staticImageLink___ctimeMs = "childContentItem___data___staticImageLink___ctimeMs",
    childContentItem___data___staticImageLink___dev = "childContentItem___data___staticImageLink___dev",
    childContentItem___data___staticImageLink___dir = "childContentItem___data___staticImageLink___dir",
    childContentItem___data___staticImageLink___ext = "childContentItem___data___staticImageLink___ext",
    childContentItem___data___staticImageLink___extension = "childContentItem___data___staticImageLink___extension",
    childContentItem___data___staticImageLink___gid = "childContentItem___data___staticImageLink___gid",
    childContentItem___data___staticImageLink___id = "childContentItem___data___staticImageLink___id",
    childContentItem___data___staticImageLink___ino = "childContentItem___data___staticImageLink___ino",
    childContentItem___data___staticImageLink___mode = "childContentItem___data___staticImageLink___mode",
    childContentItem___data___staticImageLink___modifiedTime = "childContentItem___data___staticImageLink___modifiedTime",
    childContentItem___data___staticImageLink___mtime = "childContentItem___data___staticImageLink___mtime",
    childContentItem___data___staticImageLink___mtimeMs = "childContentItem___data___staticImageLink___mtimeMs",
    childContentItem___data___staticImageLink___name = "childContentItem___data___staticImageLink___name",
    childContentItem___data___staticImageLink___nlink = "childContentItem___data___staticImageLink___nlink",
    childContentItem___data___staticImageLink___prettySize = "childContentItem___data___staticImageLink___prettySize",
    childContentItem___data___staticImageLink___publicURL = "childContentItem___data___staticImageLink___publicURL",
    childContentItem___data___staticImageLink___rdev = "childContentItem___data___staticImageLink___rdev",
    childContentItem___data___staticImageLink___relativeDirectory = "childContentItem___data___staticImageLink___relativeDirectory",
    childContentItem___data___staticImageLink___relativePath = "childContentItem___data___staticImageLink___relativePath",
    childContentItem___data___staticImageLink___root = "childContentItem___data___staticImageLink___root",
    childContentItem___data___staticImageLink___size = "childContentItem___data___staticImageLink___size",
    childContentItem___data___staticImageLink___sourceInstanceName = "childContentItem___data___staticImageLink___sourceInstanceName",
    childContentItem___data___staticImageLink___uid = "childContentItem___data___staticImageLink___uid",
    childContentItem___data___tocMaxDepth = "childContentItem___data___tocMaxDepth",
    childContentItem___data___toc___enable = "childContentItem___data___toc___enable",
    childContentItem___data___toc___headings = "childContentItem___data___toc___headings",
    childContentItem___data___toc___maxDepth = "childContentItem___data___toc___maxDepth",
    childContentItem___data___type = "childContentItem___data___type",
    childContentItem___data___versions = "childContentItem___data___versions",
    childContentItem___data___versions___definitionId = "childContentItem___data___versions___definitionId",
    childContentItem___data___versions___id = "childContentItem___data___versions___id",
    childContentItem___data___versions___isDefault = "childContentItem___data___versions___isDefault",
    childContentItem___data___versions___label = "childContentItem___data___versions___label",
    childContentItem___data___versions___title = "childContentItem___data___versions___title",
    childContentItem___id = "childContentItem___id",
    childContentItem___internal___content = "childContentItem___internal___content",
    childContentItem___internal___contentDigest = "childContentItem___internal___contentDigest",
    childContentItem___internal___description = "childContentItem___internal___description",
    childContentItem___internal___fieldOwners = "childContentItem___internal___fieldOwners",
    childContentItem___internal___ignoreType = "childContentItem___internal___ignoreType",
    childContentItem___internal___mediaType = "childContentItem___internal___mediaType",
    childContentItem___internal___owner = "childContentItem___internal___owner",
    childContentItem___internal___type = "childContentItem___internal___type",
    childContentItem___link = "childContentItem___link",
    childContentItem___markdown___children = "childContentItem___markdown___children",
    childContentItem___markdown___children___children = "childContentItem___markdown___children___children",
    childContentItem___markdown___children___id = "childContentItem___markdown___children___id",
    childContentItem___markdown___excerpt = "childContentItem___markdown___excerpt",
    childContentItem___markdown___excerptAst = "childContentItem___markdown___excerptAst",
    childContentItem___markdown___fields___contentId = "childContentItem___markdown___fields___contentId",
    childContentItem___markdown___fileAbsolutePath = "childContentItem___markdown___fileAbsolutePath",
    childContentItem___markdown___frontmatter___children = "childContentItem___markdown___frontmatter___children",
    childContentItem___markdown___frontmatter___description = "childContentItem___markdown___frontmatter___description",
    childContentItem___markdown___frontmatter___disableLastModified = "childContentItem___markdown___frontmatter___disableLastModified",
    childContentItem___markdown___frontmatter___enableToc = "childContentItem___markdown___frontmatter___enableToc",
    childContentItem___markdown___frontmatter___id = "childContentItem___markdown___frontmatter___id",
    childContentItem___markdown___frontmatter___redirectFrom = "childContentItem___markdown___frontmatter___redirectFrom",
    childContentItem___markdown___frontmatter___sidebar = "childContentItem___markdown___frontmatter___sidebar",
    childContentItem___markdown___frontmatter___title = "childContentItem___markdown___frontmatter___title",
    childContentItem___markdown___frontmatter___tocMaxDepth = "childContentItem___markdown___frontmatter___tocMaxDepth",
    childContentItem___markdown___headings = "childContentItem___markdown___headings",
    childContentItem___markdown___headings___depth = "childContentItem___markdown___headings___depth",
    childContentItem___markdown___headings___id = "childContentItem___markdown___headings___id",
    childContentItem___markdown___headings___value = "childContentItem___markdown___headings___value",
    childContentItem___markdown___html = "childContentItem___markdown___html",
    childContentItem___markdown___htmlAst = "childContentItem___markdown___htmlAst",
    childContentItem___markdown___id = "childContentItem___markdown___id",
    childContentItem___markdown___internal___content = "childContentItem___markdown___internal___content",
    childContentItem___markdown___internal___contentDigest = "childContentItem___markdown___internal___contentDigest",
    childContentItem___markdown___internal___description = "childContentItem___markdown___internal___description",
    childContentItem___markdown___internal___fieldOwners = "childContentItem___markdown___internal___fieldOwners",
    childContentItem___markdown___internal___ignoreType = "childContentItem___markdown___internal___ignoreType",
    childContentItem___markdown___internal___mediaType = "childContentItem___markdown___internal___mediaType",
    childContentItem___markdown___internal___owner = "childContentItem___markdown___internal___owner",
    childContentItem___markdown___internal___type = "childContentItem___markdown___internal___type",
    childContentItem___markdown___parent___children = "childContentItem___markdown___parent___children",
    childContentItem___markdown___parent___id = "childContentItem___markdown___parent___id",
    childContentItem___markdown___rawMarkdownBody = "childContentItem___markdown___rawMarkdownBody",
    childContentItem___markdown___tableOfContents = "childContentItem___markdown___tableOfContents",
    childContentItem___markdown___timeToRead = "childContentItem___markdown___timeToRead",
    childContentItem___markdown___wordCount___paragraphs = "childContentItem___markdown___wordCount___paragraphs",
    childContentItem___markdown___wordCount___sentences = "childContentItem___markdown___wordCount___sentences",
    childContentItem___markdown___wordCount___words = "childContentItem___markdown___wordCount___words",
    childContentItem___pageId = "childContentItem___pageId",
    childContentItem___parent___children = "childContentItem___parent___children",
    childContentItem___parent___children___children = "childContentItem___parent___children___children",
    childContentItem___parent___children___id = "childContentItem___parent___children___id",
    childContentItem___parent___id = "childContentItem___parent___id",
    childContentItem___parent___internal___content = "childContentItem___parent___internal___content",
    childContentItem___parent___internal___contentDigest = "childContentItem___parent___internal___contentDigest",
    childContentItem___parent___internal___description = "childContentItem___parent___internal___description",
    childContentItem___parent___internal___fieldOwners = "childContentItem___parent___internal___fieldOwners",
    childContentItem___parent___internal___ignoreType = "childContentItem___parent___internal___ignoreType",
    childContentItem___parent___internal___mediaType = "childContentItem___parent___internal___mediaType",
    childContentItem___parent___internal___owner = "childContentItem___parent___internal___owner",
    childContentItem___parent___internal___type = "childContentItem___parent___internal___type",
    childContentItem___parent___parent___children = "childContentItem___parent___parent___children",
    childContentItem___parent___parent___id = "childContentItem___parent___parent___id",
    childContentItem___permission = "childContentItem___permission",
    childContentItem___seo___children = "childContentItem___seo___children",
    childContentItem___seo___children___children = "childContentItem___seo___children___children",
    childContentItem___seo___children___id = "childContentItem___seo___children___id",
    childContentItem___seo___description = "childContentItem___seo___description",
    childContentItem___seo___id = "childContentItem___seo___id",
    childContentItem___seo___image = "childContentItem___seo___image",
    childContentItem___seo___internal___content = "childContentItem___seo___internal___content",
    childContentItem___seo___internal___contentDigest = "childContentItem___seo___internal___contentDigest",
    childContentItem___seo___internal___description = "childContentItem___seo___internal___description",
    childContentItem___seo___internal___fieldOwners = "childContentItem___seo___internal___fieldOwners",
    childContentItem___seo___internal___ignoreType = "childContentItem___seo___internal___ignoreType",
    childContentItem___seo___internal___mediaType = "childContentItem___seo___internal___mediaType",
    childContentItem___seo___internal___owner = "childContentItem___seo___internal___owner",
    childContentItem___seo___internal___type = "childContentItem___seo___internal___type",
    childContentItem___seo___jsonLd = "childContentItem___seo___jsonLd",
    childContentItem___seo___keywords = "childContentItem___seo___keywords",
    childContentItem___seo___lang = "childContentItem___seo___lang",
    childContentItem___seo___parent___children = "childContentItem___seo___parent___children",
    childContentItem___seo___parent___id = "childContentItem___seo___parent___id",
    childContentItem___seo___sitemap___changefreq = "childContentItem___seo___sitemap___changefreq",
    childContentItem___seo___sitemap___lastmod = "childContentItem___seo___sitemap___lastmod",
    childContentItem___seo___sitemap___priority = "childContentItem___seo___sitemap___priority",
    childContentItem___seo___title = "childContentItem___seo___title",
    childContentItem___sourcePath = "childContentItem___sourcePath",
    childContentItem___type = "childContentItem___type",
    childMarkdownRemark___children = "childMarkdownRemark___children",
    childMarkdownRemark___children___children = "childMarkdownRemark___children___children",
    childMarkdownRemark___children___children___children = "childMarkdownRemark___children___children___children",
    childMarkdownRemark___children___children___id = "childMarkdownRemark___children___children___id",
    childMarkdownRemark___children___id = "childMarkdownRemark___children___id",
    childMarkdownRemark___children___internal___content = "childMarkdownRemark___children___internal___content",
    childMarkdownRemark___children___internal___contentDigest = "childMarkdownRemark___children___internal___contentDigest",
    childMarkdownRemark___children___internal___description = "childMarkdownRemark___children___internal___description",
    childMarkdownRemark___children___internal___fieldOwners = "childMarkdownRemark___children___internal___fieldOwners",
    childMarkdownRemark___children___internal___ignoreType = "childMarkdownRemark___children___internal___ignoreType",
    childMarkdownRemark___children___internal___mediaType = "childMarkdownRemark___children___internal___mediaType",
    childMarkdownRemark___children___internal___owner = "childMarkdownRemark___children___internal___owner",
    childMarkdownRemark___children___internal___type = "childMarkdownRemark___children___internal___type",
    childMarkdownRemark___children___parent___children = "childMarkdownRemark___children___parent___children",
    childMarkdownRemark___children___parent___id = "childMarkdownRemark___children___parent___id",
    childMarkdownRemark___excerpt = "childMarkdownRemark___excerpt",
    childMarkdownRemark___excerptAst = "childMarkdownRemark___excerptAst",
    childMarkdownRemark___fields___contentId = "childMarkdownRemark___fields___contentId",
    childMarkdownRemark___fileAbsolutePath = "childMarkdownRemark___fileAbsolutePath",
    childMarkdownRemark___frontmatter___children = "childMarkdownRemark___frontmatter___children",
    childMarkdownRemark___frontmatter___children___children = "childMarkdownRemark___frontmatter___children___children",
    childMarkdownRemark___frontmatter___children___id = "childMarkdownRemark___frontmatter___children___id",
    childMarkdownRemark___frontmatter___description = "childMarkdownRemark___frontmatter___description",
    childMarkdownRemark___frontmatter___disableLastModified = "childMarkdownRemark___frontmatter___disableLastModified",
    childMarkdownRemark___frontmatter___editPage___disable = "childMarkdownRemark___frontmatter___editPage___disable",
    childMarkdownRemark___frontmatter___enableToc = "childMarkdownRemark___frontmatter___enableToc",
    childMarkdownRemark___frontmatter___id = "childMarkdownRemark___frontmatter___id",
    childMarkdownRemark___frontmatter___internal___content = "childMarkdownRemark___frontmatter___internal___content",
    childMarkdownRemark___frontmatter___internal___contentDigest = "childMarkdownRemark___frontmatter___internal___contentDigest",
    childMarkdownRemark___frontmatter___internal___description = "childMarkdownRemark___frontmatter___internal___description",
    childMarkdownRemark___frontmatter___internal___fieldOwners = "childMarkdownRemark___frontmatter___internal___fieldOwners",
    childMarkdownRemark___frontmatter___internal___ignoreType = "childMarkdownRemark___frontmatter___internal___ignoreType",
    childMarkdownRemark___frontmatter___internal___mediaType = "childMarkdownRemark___frontmatter___internal___mediaType",
    childMarkdownRemark___frontmatter___internal___owner = "childMarkdownRemark___frontmatter___internal___owner",
    childMarkdownRemark___frontmatter___internal___type = "childMarkdownRemark___frontmatter___internal___type",
    childMarkdownRemark___frontmatter___parent___children = "childMarkdownRemark___frontmatter___parent___children",
    childMarkdownRemark___frontmatter___parent___id = "childMarkdownRemark___frontmatter___parent___id",
    childMarkdownRemark___frontmatter___redirectFrom = "childMarkdownRemark___frontmatter___redirectFrom",
    childMarkdownRemark___frontmatter___sidebar = "childMarkdownRemark___frontmatter___sidebar",
    childMarkdownRemark___frontmatter___title = "childMarkdownRemark___frontmatter___title",
    childMarkdownRemark___frontmatter___tocMaxDepth = "childMarkdownRemark___frontmatter___tocMaxDepth",
    childMarkdownRemark___frontmatter___toc___enable = "childMarkdownRemark___frontmatter___toc___enable",
    childMarkdownRemark___headings = "childMarkdownRemark___headings",
    childMarkdownRemark___headings___depth = "childMarkdownRemark___headings___depth",
    childMarkdownRemark___headings___id = "childMarkdownRemark___headings___id",
    childMarkdownRemark___headings___value = "childMarkdownRemark___headings___value",
    childMarkdownRemark___html = "childMarkdownRemark___html",
    childMarkdownRemark___htmlAst = "childMarkdownRemark___htmlAst",
    childMarkdownRemark___id = "childMarkdownRemark___id",
    childMarkdownRemark___internal___content = "childMarkdownRemark___internal___content",
    childMarkdownRemark___internal___contentDigest = "childMarkdownRemark___internal___contentDigest",
    childMarkdownRemark___internal___description = "childMarkdownRemark___internal___description",
    childMarkdownRemark___internal___fieldOwners = "childMarkdownRemark___internal___fieldOwners",
    childMarkdownRemark___internal___ignoreType = "childMarkdownRemark___internal___ignoreType",
    childMarkdownRemark___internal___mediaType = "childMarkdownRemark___internal___mediaType",
    childMarkdownRemark___internal___owner = "childMarkdownRemark___internal___owner",
    childMarkdownRemark___internal___type = "childMarkdownRemark___internal___type",
    childMarkdownRemark___parent___children = "childMarkdownRemark___parent___children",
    childMarkdownRemark___parent___children___children = "childMarkdownRemark___parent___children___children",
    childMarkdownRemark___parent___children___id = "childMarkdownRemark___parent___children___id",
    childMarkdownRemark___parent___id = "childMarkdownRemark___parent___id",
    childMarkdownRemark___parent___internal___content = "childMarkdownRemark___parent___internal___content",
    childMarkdownRemark___parent___internal___contentDigest = "childMarkdownRemark___parent___internal___contentDigest",
    childMarkdownRemark___parent___internal___description = "childMarkdownRemark___parent___internal___description",
    childMarkdownRemark___parent___internal___fieldOwners = "childMarkdownRemark___parent___internal___fieldOwners",
    childMarkdownRemark___parent___internal___ignoreType = "childMarkdownRemark___parent___internal___ignoreType",
    childMarkdownRemark___parent___internal___mediaType = "childMarkdownRemark___parent___internal___mediaType",
    childMarkdownRemark___parent___internal___owner = "childMarkdownRemark___parent___internal___owner",
    childMarkdownRemark___parent___internal___type = "childMarkdownRemark___parent___internal___type",
    childMarkdownRemark___parent___parent___children = "childMarkdownRemark___parent___parent___children",
    childMarkdownRemark___parent___parent___id = "childMarkdownRemark___parent___parent___id",
    childMarkdownRemark___rawMarkdownBody = "childMarkdownRemark___rawMarkdownBody",
    childMarkdownRemark___tableOfContents = "childMarkdownRemark___tableOfContents",
    childMarkdownRemark___timeToRead = "childMarkdownRemark___timeToRead",
    childMarkdownRemark___wordCount___paragraphs = "childMarkdownRemark___wordCount___paragraphs",
    childMarkdownRemark___wordCount___sentences = "childMarkdownRemark___wordCount___sentences",
    childMarkdownRemark___wordCount___words = "childMarkdownRemark___wordCount___words",
    children = "children",
    childrenContentItem = "childrenContentItem",
    childrenContentItem___baseLink = "childrenContentItem___baseLink",
    childrenContentItem___catalogInfo___apiName = "childrenContentItem___catalogInfo___apiName",
    childrenContentItem___catalogInfo___apiVersion = "childrenContentItem___catalogInfo___apiVersion",
    childrenContentItem___catalogInfo___metadata = "childrenContentItem___catalogInfo___metadata",
    childrenContentItem___catalogInfo___title = "childrenContentItem___catalogInfo___title",
    childrenContentItem___children = "childrenContentItem___children",
    childrenContentItem___children___children = "childrenContentItem___children___children",
    childrenContentItem___children___children___children = "childrenContentItem___children___children___children",
    childrenContentItem___children___children___id = "childrenContentItem___children___children___id",
    childrenContentItem___children___id = "childrenContentItem___children___id",
    childrenContentItem___children___internal___content = "childrenContentItem___children___internal___content",
    childrenContentItem___children___internal___contentDigest = "childrenContentItem___children___internal___contentDigest",
    childrenContentItem___children___internal___description = "childrenContentItem___children___internal___description",
    childrenContentItem___children___internal___fieldOwners = "childrenContentItem___children___internal___fieldOwners",
    childrenContentItem___children___internal___ignoreType = "childrenContentItem___children___internal___ignoreType",
    childrenContentItem___children___internal___mediaType = "childrenContentItem___children___internal___mediaType",
    childrenContentItem___children___internal___owner = "childrenContentItem___children___internal___owner",
    childrenContentItem___children___internal___type = "childrenContentItem___children___internal___type",
    childrenContentItem___children___parent___children = "childrenContentItem___children___parent___children",
    childrenContentItem___children___parent___id = "childrenContentItem___children___parent___id",
    childrenContentItem___data___apiVersionId = "childrenContentItem___data___apiVersionId",
    childrenContentItem___data___apiVersions = "childrenContentItem___data___apiVersions",
    childrenContentItem___data___apiVersions___apiId = "childrenContentItem___data___apiVersions___apiId",
    childrenContentItem___data___apiVersions___definitionId = "childrenContentItem___data___apiVersions___definitionId",
    childrenContentItem___data___apiVersions___id = "childrenContentItem___data___apiVersions___id",
    childrenContentItem___data___apiVersions___isDefault = "childrenContentItem___data___apiVersions___isDefault",
    childrenContentItem___data___apiVersions___label = "childrenContentItem___data___apiVersions___label",
    childrenContentItem___data___apiVersions___title = "childrenContentItem___data___apiVersions___title",
    childrenContentItem___data___children = "childrenContentItem___data___children",
    childrenContentItem___data___children___children = "childrenContentItem___data___children___children",
    childrenContentItem___data___children___id = "childrenContentItem___data___children___id",
    childrenContentItem___data___customDataString = "childrenContentItem___data___customDataString",
    childrenContentItem___data___customData___description = "childrenContentItem___data___customData___description",
    childrenContentItem___data___customData___imageLink = "childrenContentItem___data___customData___imageLink",
    childrenContentItem___data___customData___redirectFrom = "childrenContentItem___data___customData___redirectFrom",
    childrenContentItem___data___customData___title = "childrenContentItem___data___customData___title",
    childrenContentItem___data___customTemplate = "childrenContentItem___data___customTemplate",
    childrenContentItem___data___definitionId = "childrenContentItem___data___definitionId",
    childrenContentItem___data___disableEditPage = "childrenContentItem___data___disableEditPage",
    childrenContentItem___data___disableLastModified = "childrenContentItem___data___disableLastModified",
    childrenContentItem___data___editPage___disable = "childrenContentItem___data___editPage___disable",
    childrenContentItem___data___enableToc = "childrenContentItem___data___enableToc",
    childrenContentItem___data___excludeFromSearch = "childrenContentItem___data___excludeFromSearch",
    childrenContentItem___data___httpVerb = "childrenContentItem___data___httpVerb",
    childrenContentItem___data___id = "childrenContentItem___data___id",
    childrenContentItem___data___image = "childrenContentItem___data___image",
    childrenContentItem___data___imageLink = "childrenContentItem___data___imageLink",
    childrenContentItem___data___internal___content = "childrenContentItem___data___internal___content",
    childrenContentItem___data___internal___contentDigest = "childrenContentItem___data___internal___contentDigest",
    childrenContentItem___data___internal___description = "childrenContentItem___data___internal___description",
    childrenContentItem___data___internal___fieldOwners = "childrenContentItem___data___internal___fieldOwners",
    childrenContentItem___data___internal___ignoreType = "childrenContentItem___data___internal___ignoreType",
    childrenContentItem___data___internal___mediaType = "childrenContentItem___data___internal___mediaType",
    childrenContentItem___data___internal___owner = "childrenContentItem___data___internal___owner",
    childrenContentItem___data___internal___type = "childrenContentItem___data___internal___type",
    childrenContentItem___data___isDefaultApiVersion = "childrenContentItem___data___isDefaultApiVersion",
    childrenContentItem___data___keywords = "childrenContentItem___data___keywords",
    childrenContentItem___data___label = "childrenContentItem___data___label",
    childrenContentItem___data___lang = "childrenContentItem___data___lang",
    childrenContentItem___data___lastModified = "childrenContentItem___data___lastModified",
    childrenContentItem___data___matchPath = "childrenContentItem___data___matchPath",
    childrenContentItem___data___pageLink___absolutePath = "childrenContentItem___data___pageLink___absolutePath",
    childrenContentItem___data___pageLink___accessTime = "childrenContentItem___data___pageLink___accessTime",
    childrenContentItem___data___pageLink___atime = "childrenContentItem___data___pageLink___atime",
    childrenContentItem___data___pageLink___atimeMs = "childrenContentItem___data___pageLink___atimeMs",
    childrenContentItem___data___pageLink___base = "childrenContentItem___data___pageLink___base",
    childrenContentItem___data___pageLink___birthTime = "childrenContentItem___data___pageLink___birthTime",
    childrenContentItem___data___pageLink___birthtime = "childrenContentItem___data___pageLink___birthtime",
    childrenContentItem___data___pageLink___birthtimeMs = "childrenContentItem___data___pageLink___birthtimeMs",
    childrenContentItem___data___pageLink___blksize = "childrenContentItem___data___pageLink___blksize",
    childrenContentItem___data___pageLink___blocks = "childrenContentItem___data___pageLink___blocks",
    childrenContentItem___data___pageLink___changeTime = "childrenContentItem___data___pageLink___changeTime",
    childrenContentItem___data___pageLink___children = "childrenContentItem___data___pageLink___children",
    childrenContentItem___data___pageLink___childrenContentItem = "childrenContentItem___data___pageLink___childrenContentItem",
    childrenContentItem___data___pageLink___childrenMarkdownRemark = "childrenContentItem___data___pageLink___childrenMarkdownRemark",
    childrenContentItem___data___pageLink___ctime = "childrenContentItem___data___pageLink___ctime",
    childrenContentItem___data___pageLink___ctimeMs = "childrenContentItem___data___pageLink___ctimeMs",
    childrenContentItem___data___pageLink___dev = "childrenContentItem___data___pageLink___dev",
    childrenContentItem___data___pageLink___dir = "childrenContentItem___data___pageLink___dir",
    childrenContentItem___data___pageLink___ext = "childrenContentItem___data___pageLink___ext",
    childrenContentItem___data___pageLink___extension = "childrenContentItem___data___pageLink___extension",
    childrenContentItem___data___pageLink___gid = "childrenContentItem___data___pageLink___gid",
    childrenContentItem___data___pageLink___id = "childrenContentItem___data___pageLink___id",
    childrenContentItem___data___pageLink___ino = "childrenContentItem___data___pageLink___ino",
    childrenContentItem___data___pageLink___mode = "childrenContentItem___data___pageLink___mode",
    childrenContentItem___data___pageLink___modifiedTime = "childrenContentItem___data___pageLink___modifiedTime",
    childrenContentItem___data___pageLink___mtime = "childrenContentItem___data___pageLink___mtime",
    childrenContentItem___data___pageLink___mtimeMs = "childrenContentItem___data___pageLink___mtimeMs",
    childrenContentItem___data___pageLink___name = "childrenContentItem___data___pageLink___name",
    childrenContentItem___data___pageLink___nlink = "childrenContentItem___data___pageLink___nlink",
    childrenContentItem___data___pageLink___prettySize = "childrenContentItem___data___pageLink___prettySize",
    childrenContentItem___data___pageLink___publicURL = "childrenContentItem___data___pageLink___publicURL",
    childrenContentItem___data___pageLink___rdev = "childrenContentItem___data___pageLink___rdev",
    childrenContentItem___data___pageLink___relativeDirectory = "childrenContentItem___data___pageLink___relativeDirectory",
    childrenContentItem___data___pageLink___relativePath = "childrenContentItem___data___pageLink___relativePath",
    childrenContentItem___data___pageLink___root = "childrenContentItem___data___pageLink___root",
    childrenContentItem___data___pageLink___size = "childrenContentItem___data___pageLink___size",
    childrenContentItem___data___pageLink___sourceInstanceName = "childrenContentItem___data___pageLink___sourceInstanceName",
    childrenContentItem___data___pageLink___uid = "childrenContentItem___data___pageLink___uid",
    childrenContentItem___data___parent___children = "childrenContentItem___data___parent___children",
    childrenContentItem___data___parent___id = "childrenContentItem___data___parent___id",
    childrenContentItem___data___permission = "childrenContentItem___data___permission",
    childrenContentItem___data___redirect = "childrenContentItem___data___redirect",
    childrenContentItem___data___redirectFrom = "childrenContentItem___data___redirectFrom",
    childrenContentItem___data___redocHasInfoPage = "childrenContentItem___data___redocHasInfoPage",
    childrenContentItem___data___redocHasSecurityDefinitions = "childrenContentItem___data___redocHasSecurityDefinitions",
    childrenContentItem___data___redocInfoPageId = "childrenContentItem___data___redocInfoPageId",
    childrenContentItem___data___redocInfoPageLink = "childrenContentItem___data___redocInfoPageLink",
    childrenContentItem___data___redocItemId = "childrenContentItem___data___redocItemId",
    childrenContentItem___data___redocMenuItems = "childrenContentItem___data___redocMenuItems",
    childrenContentItem___data___redocMenuItems___apiVersionId = "childrenContentItem___data___redocMenuItems___apiVersionId",
    childrenContentItem___data___redocMenuItems___httpVerb = "childrenContentItem___data___redocMenuItems___httpVerb",
    childrenContentItem___data___redocMenuItems___isDefaultApiVersion = "childrenContentItem___data___redocMenuItems___isDefaultApiVersion",
    childrenContentItem___data___redocMenuItems___label = "childrenContentItem___data___redocMenuItems___label",
    childrenContentItem___data___redocMenuItems___link = "childrenContentItem___data___redocMenuItems___link",
    childrenContentItem___data___redocMenuItems___page = "childrenContentItem___data___redocMenuItems___page",
    childrenContentItem___data___redocMenuItems___pages = "childrenContentItem___data___redocMenuItems___pages",
    childrenContentItem___data___redocMenuItems___pagination = "childrenContentItem___data___redocMenuItems___pagination",
    childrenContentItem___data___redocMenuItems___parentPageId = "childrenContentItem___data___redocMenuItems___parentPageId",
    childrenContentItem___data___redocMenuItems___permission = "childrenContentItem___data___redocMenuItems___permission",
    childrenContentItem___data___redocMenuItems___redocFakePage = "childrenContentItem___data___redocMenuItems___redocFakePage",
    childrenContentItem___data___redocMenuItems___redocInfoPageLink = "childrenContentItem___data___redocMenuItems___redocInfoPageLink",
    childrenContentItem___data___redocMenuItems___separator = "childrenContentItem___data___redocMenuItems___separator",
    childrenContentItem___data___redocNextLabel = "childrenContentItem___data___redocNextLabel",
    childrenContentItem___data___redocNextLink = "childrenContentItem___data___redocNextLink",
    childrenContentItem___data___redocPagination = "childrenContentItem___data___redocPagination",
    childrenContentItem___data___redocPrevLabel = "childrenContentItem___data___redocPrevLabel",
    childrenContentItem___data___redocPrevLink = "childrenContentItem___data___redocPrevLink",
    childrenContentItem___data___redocStoreStr = "childrenContentItem___data___redocStoreStr",
    childrenContentItem___data___requestLogin = "childrenContentItem___data___requestLogin",
    childrenContentItem___data___settings = "childrenContentItem___data___settings",
    childrenContentItem___data___showNextButton = "childrenContentItem___data___showNextButton",
    childrenContentItem___data___showPrevButton = "childrenContentItem___data___showPrevButton",
    childrenContentItem___data___sidebar___absolutePath = "childrenContentItem___data___sidebar___absolutePath",
    childrenContentItem___data___sidebar___accessTime = "childrenContentItem___data___sidebar___accessTime",
    childrenContentItem___data___sidebar___atime = "childrenContentItem___data___sidebar___atime",
    childrenContentItem___data___sidebar___atimeMs = "childrenContentItem___data___sidebar___atimeMs",
    childrenContentItem___data___sidebar___base = "childrenContentItem___data___sidebar___base",
    childrenContentItem___data___sidebar___birthTime = "childrenContentItem___data___sidebar___birthTime",
    childrenContentItem___data___sidebar___birthtime = "childrenContentItem___data___sidebar___birthtime",
    childrenContentItem___data___sidebar___birthtimeMs = "childrenContentItem___data___sidebar___birthtimeMs",
    childrenContentItem___data___sidebar___blksize = "childrenContentItem___data___sidebar___blksize",
    childrenContentItem___data___sidebar___blocks = "childrenContentItem___data___sidebar___blocks",
    childrenContentItem___data___sidebar___changeTime = "childrenContentItem___data___sidebar___changeTime",
    childrenContentItem___data___sidebar___children = "childrenContentItem___data___sidebar___children",
    childrenContentItem___data___sidebar___childrenContentItem = "childrenContentItem___data___sidebar___childrenContentItem",
    childrenContentItem___data___sidebar___childrenMarkdownRemark = "childrenContentItem___data___sidebar___childrenMarkdownRemark",
    childrenContentItem___data___sidebar___ctime = "childrenContentItem___data___sidebar___ctime",
    childrenContentItem___data___sidebar___ctimeMs = "childrenContentItem___data___sidebar___ctimeMs",
    childrenContentItem___data___sidebar___dev = "childrenContentItem___data___sidebar___dev",
    childrenContentItem___data___sidebar___dir = "childrenContentItem___data___sidebar___dir",
    childrenContentItem___data___sidebar___ext = "childrenContentItem___data___sidebar___ext",
    childrenContentItem___data___sidebar___extension = "childrenContentItem___data___sidebar___extension",
    childrenContentItem___data___sidebar___gid = "childrenContentItem___data___sidebar___gid",
    childrenContentItem___data___sidebar___id = "childrenContentItem___data___sidebar___id",
    childrenContentItem___data___sidebar___ino = "childrenContentItem___data___sidebar___ino",
    childrenContentItem___data___sidebar___mode = "childrenContentItem___data___sidebar___mode",
    childrenContentItem___data___sidebar___modifiedTime = "childrenContentItem___data___sidebar___modifiedTime",
    childrenContentItem___data___sidebar___mtime = "childrenContentItem___data___sidebar___mtime",
    childrenContentItem___data___sidebar___mtimeMs = "childrenContentItem___data___sidebar___mtimeMs",
    childrenContentItem___data___sidebar___name = "childrenContentItem___data___sidebar___name",
    childrenContentItem___data___sidebar___nlink = "childrenContentItem___data___sidebar___nlink",
    childrenContentItem___data___sidebar___prettySize = "childrenContentItem___data___sidebar___prettySize",
    childrenContentItem___data___sidebar___publicURL = "childrenContentItem___data___sidebar___publicURL",
    childrenContentItem___data___sidebar___rdev = "childrenContentItem___data___sidebar___rdev",
    childrenContentItem___data___sidebar___relativeDirectory = "childrenContentItem___data___sidebar___relativeDirectory",
    childrenContentItem___data___sidebar___relativePath = "childrenContentItem___data___sidebar___relativePath",
    childrenContentItem___data___sidebar___root = "childrenContentItem___data___sidebar___root",
    childrenContentItem___data___sidebar___size = "childrenContentItem___data___sidebar___size",
    childrenContentItem___data___sidebar___sourceInstanceName = "childrenContentItem___data___sidebar___sourceInstanceName",
    childrenContentItem___data___sidebar___uid = "childrenContentItem___data___sidebar___uid",
    childrenContentItem___data___sitemap___changefreq = "childrenContentItem___data___sitemap___changefreq",
    childrenContentItem___data___sitemap___lastmod = "childrenContentItem___data___sitemap___lastmod",
    childrenContentItem___data___sitemap___priority = "childrenContentItem___data___sitemap___priority",
    childrenContentItem___data___sourcePath = "childrenContentItem___data___sourcePath",
    childrenContentItem___data___staticImageLink___absolutePath = "childrenContentItem___data___staticImageLink___absolutePath",
    childrenContentItem___data___staticImageLink___accessTime = "childrenContentItem___data___staticImageLink___accessTime",
    childrenContentItem___data___staticImageLink___atime = "childrenContentItem___data___staticImageLink___atime",
    childrenContentItem___data___staticImageLink___atimeMs = "childrenContentItem___data___staticImageLink___atimeMs",
    childrenContentItem___data___staticImageLink___base = "childrenContentItem___data___staticImageLink___base",
    childrenContentItem___data___staticImageLink___birthTime = "childrenContentItem___data___staticImageLink___birthTime",
    childrenContentItem___data___staticImageLink___birthtime = "childrenContentItem___data___staticImageLink___birthtime",
    childrenContentItem___data___staticImageLink___birthtimeMs = "childrenContentItem___data___staticImageLink___birthtimeMs",
    childrenContentItem___data___staticImageLink___blksize = "childrenContentItem___data___staticImageLink___blksize",
    childrenContentItem___data___staticImageLink___blocks = "childrenContentItem___data___staticImageLink___blocks",
    childrenContentItem___data___staticImageLink___changeTime = "childrenContentItem___data___staticImageLink___changeTime",
    childrenContentItem___data___staticImageLink___children = "childrenContentItem___data___staticImageLink___children",
    childrenContentItem___data___staticImageLink___childrenContentItem = "childrenContentItem___data___staticImageLink___childrenContentItem",
    childrenContentItem___data___staticImageLink___childrenMarkdownRemark = "childrenContentItem___data___staticImageLink___childrenMarkdownRemark",
    childrenContentItem___data___staticImageLink___ctime = "childrenContentItem___data___staticImageLink___ctime",
    childrenContentItem___data___staticImageLink___ctimeMs = "childrenContentItem___data___staticImageLink___ctimeMs",
    childrenContentItem___data___staticImageLink___dev = "childrenContentItem___data___staticImageLink___dev",
    childrenContentItem___data___staticImageLink___dir = "childrenContentItem___data___staticImageLink___dir",
    childrenContentItem___data___staticImageLink___ext = "childrenContentItem___data___staticImageLink___ext",
    childrenContentItem___data___staticImageLink___extension = "childrenContentItem___data___staticImageLink___extension",
    childrenContentItem___data___staticImageLink___gid = "childrenContentItem___data___staticImageLink___gid",
    childrenContentItem___data___staticImageLink___id = "childrenContentItem___data___staticImageLink___id",
    childrenContentItem___data___staticImageLink___ino = "childrenContentItem___data___staticImageLink___ino",
    childrenContentItem___data___staticImageLink___mode = "childrenContentItem___data___staticImageLink___mode",
    childrenContentItem___data___staticImageLink___modifiedTime = "childrenContentItem___data___staticImageLink___modifiedTime",
    childrenContentItem___data___staticImageLink___mtime = "childrenContentItem___data___staticImageLink___mtime",
    childrenContentItem___data___staticImageLink___mtimeMs = "childrenContentItem___data___staticImageLink___mtimeMs",
    childrenContentItem___data___staticImageLink___name = "childrenContentItem___data___staticImageLink___name",
    childrenContentItem___data___staticImageLink___nlink = "childrenContentItem___data___staticImageLink___nlink",
    childrenContentItem___data___staticImageLink___prettySize = "childrenContentItem___data___staticImageLink___prettySize",
    childrenContentItem___data___staticImageLink___publicURL = "childrenContentItem___data___staticImageLink___publicURL",
    childrenContentItem___data___staticImageLink___rdev = "childrenContentItem___data___staticImageLink___rdev",
    childrenContentItem___data___staticImageLink___relativeDirectory = "childrenContentItem___data___staticImageLink___relativeDirectory",
    childrenContentItem___data___staticImageLink___relativePath = "childrenContentItem___data___staticImageLink___relativePath",
    childrenContentItem___data___staticImageLink___root = "childrenContentItem___data___staticImageLink___root",
    childrenContentItem___data___staticImageLink___size = "childrenContentItem___data___staticImageLink___size",
    childrenContentItem___data___staticImageLink___sourceInstanceName = "childrenContentItem___data___staticImageLink___sourceInstanceName",
    childrenContentItem___data___staticImageLink___uid = "childrenContentItem___data___staticImageLink___uid",
    childrenContentItem___data___tocMaxDepth = "childrenContentItem___data___tocMaxDepth",
    childrenContentItem___data___toc___enable = "childrenContentItem___data___toc___enable",
    childrenContentItem___data___toc___headings = "childrenContentItem___data___toc___headings",
    childrenContentItem___data___toc___maxDepth = "childrenContentItem___data___toc___maxDepth",
    childrenContentItem___data___type = "childrenContentItem___data___type",
    childrenContentItem___data___versions = "childrenContentItem___data___versions",
    childrenContentItem___data___versions___definitionId = "childrenContentItem___data___versions___definitionId",
    childrenContentItem___data___versions___id = "childrenContentItem___data___versions___id",
    childrenContentItem___data___versions___isDefault = "childrenContentItem___data___versions___isDefault",
    childrenContentItem___data___versions___label = "childrenContentItem___data___versions___label",
    childrenContentItem___data___versions___title = "childrenContentItem___data___versions___title",
    childrenContentItem___id = "childrenContentItem___id",
    childrenContentItem___internal___content = "childrenContentItem___internal___content",
    childrenContentItem___internal___contentDigest = "childrenContentItem___internal___contentDigest",
    childrenContentItem___internal___description = "childrenContentItem___internal___description",
    childrenContentItem___internal___fieldOwners = "childrenContentItem___internal___fieldOwners",
    childrenContentItem___internal___ignoreType = "childrenContentItem___internal___ignoreType",
    childrenContentItem___internal___mediaType = "childrenContentItem___internal___mediaType",
    childrenContentItem___internal___owner = "childrenContentItem___internal___owner",
    childrenContentItem___internal___type = "childrenContentItem___internal___type",
    childrenContentItem___link = "childrenContentItem___link",
    childrenContentItem___markdown___children = "childrenContentItem___markdown___children",
    childrenContentItem___markdown___children___children = "childrenContentItem___markdown___children___children",
    childrenContentItem___markdown___children___id = "childrenContentItem___markdown___children___id",
    childrenContentItem___markdown___excerpt = "childrenContentItem___markdown___excerpt",
    childrenContentItem___markdown___excerptAst = "childrenContentItem___markdown___excerptAst",
    childrenContentItem___markdown___fields___contentId = "childrenContentItem___markdown___fields___contentId",
    childrenContentItem___markdown___fileAbsolutePath = "childrenContentItem___markdown___fileAbsolutePath",
    childrenContentItem___markdown___frontmatter___children = "childrenContentItem___markdown___frontmatter___children",
    childrenContentItem___markdown___frontmatter___description = "childrenContentItem___markdown___frontmatter___description",
    childrenContentItem___markdown___frontmatter___disableLastModified = "childrenContentItem___markdown___frontmatter___disableLastModified",
    childrenContentItem___markdown___frontmatter___enableToc = "childrenContentItem___markdown___frontmatter___enableToc",
    childrenContentItem___markdown___frontmatter___id = "childrenContentItem___markdown___frontmatter___id",
    childrenContentItem___markdown___frontmatter___redirectFrom = "childrenContentItem___markdown___frontmatter___redirectFrom",
    childrenContentItem___markdown___frontmatter___sidebar = "childrenContentItem___markdown___frontmatter___sidebar",
    childrenContentItem___markdown___frontmatter___title = "childrenContentItem___markdown___frontmatter___title",
    childrenContentItem___markdown___frontmatter___tocMaxDepth = "childrenContentItem___markdown___frontmatter___tocMaxDepth",
    childrenContentItem___markdown___headings = "childrenContentItem___markdown___headings",
    childrenContentItem___markdown___headings___depth = "childrenContentItem___markdown___headings___depth",
    childrenContentItem___markdown___headings___id = "childrenContentItem___markdown___headings___id",
    childrenContentItem___markdown___headings___value = "childrenContentItem___markdown___headings___value",
    childrenContentItem___markdown___html = "childrenContentItem___markdown___html",
    childrenContentItem___markdown___htmlAst = "childrenContentItem___markdown___htmlAst",
    childrenContentItem___markdown___id = "childrenContentItem___markdown___id",
    childrenContentItem___markdown___internal___content = "childrenContentItem___markdown___internal___content",
    childrenContentItem___markdown___internal___contentDigest = "childrenContentItem___markdown___internal___contentDigest",
    childrenContentItem___markdown___internal___description = "childrenContentItem___markdown___internal___description",
    childrenContentItem___markdown___internal___fieldOwners = "childrenContentItem___markdown___internal___fieldOwners",
    childrenContentItem___markdown___internal___ignoreType = "childrenContentItem___markdown___internal___ignoreType",
    childrenContentItem___markdown___internal___mediaType = "childrenContentItem___markdown___internal___mediaType",
    childrenContentItem___markdown___internal___owner = "childrenContentItem___markdown___internal___owner",
    childrenContentItem___markdown___internal___type = "childrenContentItem___markdown___internal___type",
    childrenContentItem___markdown___parent___children = "childrenContentItem___markdown___parent___children",
    childrenContentItem___markdown___parent___id = "childrenContentItem___markdown___parent___id",
    childrenContentItem___markdown___rawMarkdownBody = "childrenContentItem___markdown___rawMarkdownBody",
    childrenContentItem___markdown___tableOfContents = "childrenContentItem___markdown___tableOfContents",
    childrenContentItem___markdown___timeToRead = "childrenContentItem___markdown___timeToRead",
    childrenContentItem___markdown___wordCount___paragraphs = "childrenContentItem___markdown___wordCount___paragraphs",
    childrenContentItem___markdown___wordCount___sentences = "childrenContentItem___markdown___wordCount___sentences",
    childrenContentItem___markdown___wordCount___words = "childrenContentItem___markdown___wordCount___words",
    childrenContentItem___pageId = "childrenContentItem___pageId",
    childrenContentItem___parent___children = "childrenContentItem___parent___children",
    childrenContentItem___parent___children___children = "childrenContentItem___parent___children___children",
    childrenContentItem___parent___children___id = "childrenContentItem___parent___children___id",
    childrenContentItem___parent___id = "childrenContentItem___parent___id",
    childrenContentItem___parent___internal___content = "childrenContentItem___parent___internal___content",
    childrenContentItem___parent___internal___contentDigest = "childrenContentItem___parent___internal___contentDigest",
    childrenContentItem___parent___internal___description = "childrenContentItem___parent___internal___description",
    childrenContentItem___parent___internal___fieldOwners = "childrenContentItem___parent___internal___fieldOwners",
    childrenContentItem___parent___internal___ignoreType = "childrenContentItem___parent___internal___ignoreType",
    childrenContentItem___parent___internal___mediaType = "childrenContentItem___parent___internal___mediaType",
    childrenContentItem___parent___internal___owner = "childrenContentItem___parent___internal___owner",
    childrenContentItem___parent___internal___type = "childrenContentItem___parent___internal___type",
    childrenContentItem___parent___parent___children = "childrenContentItem___parent___parent___children",
    childrenContentItem___parent___parent___id = "childrenContentItem___parent___parent___id",
    childrenContentItem___permission = "childrenContentItem___permission",
    childrenContentItem___seo___children = "childrenContentItem___seo___children",
    childrenContentItem___seo___children___children = "childrenContentItem___seo___children___children",
    childrenContentItem___seo___children___id = "childrenContentItem___seo___children___id",
    childrenContentItem___seo___description = "childrenContentItem___seo___description",
    childrenContentItem___seo___id = "childrenContentItem___seo___id",
    childrenContentItem___seo___image = "childrenContentItem___seo___image",
    childrenContentItem___seo___internal___content = "childrenContentItem___seo___internal___content",
    childrenContentItem___seo___internal___contentDigest = "childrenContentItem___seo___internal___contentDigest",
    childrenContentItem___seo___internal___description = "childrenContentItem___seo___internal___description",
    childrenContentItem___seo___internal___fieldOwners = "childrenContentItem___seo___internal___fieldOwners",
    childrenContentItem___seo___internal___ignoreType = "childrenContentItem___seo___internal___ignoreType",
    childrenContentItem___seo___internal___mediaType = "childrenContentItem___seo___internal___mediaType",
    childrenContentItem___seo___internal___owner = "childrenContentItem___seo___internal___owner",
    childrenContentItem___seo___internal___type = "childrenContentItem___seo___internal___type",
    childrenContentItem___seo___jsonLd = "childrenContentItem___seo___jsonLd",
    childrenContentItem___seo___keywords = "childrenContentItem___seo___keywords",
    childrenContentItem___seo___lang = "childrenContentItem___seo___lang",
    childrenContentItem___seo___parent___children = "childrenContentItem___seo___parent___children",
    childrenContentItem___seo___parent___id = "childrenContentItem___seo___parent___id",
    childrenContentItem___seo___sitemap___changefreq = "childrenContentItem___seo___sitemap___changefreq",
    childrenContentItem___seo___sitemap___lastmod = "childrenContentItem___seo___sitemap___lastmod",
    childrenContentItem___seo___sitemap___priority = "childrenContentItem___seo___sitemap___priority",
    childrenContentItem___seo___title = "childrenContentItem___seo___title",
    childrenContentItem___sourcePath = "childrenContentItem___sourcePath",
    childrenContentItem___type = "childrenContentItem___type",
    childrenMarkdownRemark = "childrenMarkdownRemark",
    childrenMarkdownRemark___children = "childrenMarkdownRemark___children",
    childrenMarkdownRemark___children___children = "childrenMarkdownRemark___children___children",
    childrenMarkdownRemark___children___children___children = "childrenMarkdownRemark___children___children___children",
    childrenMarkdownRemark___children___children___id = "childrenMarkdownRemark___children___children___id",
    childrenMarkdownRemark___children___id = "childrenMarkdownRemark___children___id",
    childrenMarkdownRemark___children___internal___content = "childrenMarkdownRemark___children___internal___content",
    childrenMarkdownRemark___children___internal___contentDigest = "childrenMarkdownRemark___children___internal___contentDigest",
    childrenMarkdownRemark___children___internal___description = "childrenMarkdownRemark___children___internal___description",
    childrenMarkdownRemark___children___internal___fieldOwners = "childrenMarkdownRemark___children___internal___fieldOwners",
    childrenMarkdownRemark___children___internal___ignoreType = "childrenMarkdownRemark___children___internal___ignoreType",
    childrenMarkdownRemark___children___internal___mediaType = "childrenMarkdownRemark___children___internal___mediaType",
    childrenMarkdownRemark___children___internal___owner = "childrenMarkdownRemark___children___internal___owner",
    childrenMarkdownRemark___children___internal___type = "childrenMarkdownRemark___children___internal___type",
    childrenMarkdownRemark___children___parent___children = "childrenMarkdownRemark___children___parent___children",
    childrenMarkdownRemark___children___parent___id = "childrenMarkdownRemark___children___parent___id",
    childrenMarkdownRemark___excerpt = "childrenMarkdownRemark___excerpt",
    childrenMarkdownRemark___excerptAst = "childrenMarkdownRemark___excerptAst",
    childrenMarkdownRemark___fields___contentId = "childrenMarkdownRemark___fields___contentId",
    childrenMarkdownRemark___fileAbsolutePath = "childrenMarkdownRemark___fileAbsolutePath",
    childrenMarkdownRemark___frontmatter___children = "childrenMarkdownRemark___frontmatter___children",
    childrenMarkdownRemark___frontmatter___children___children = "childrenMarkdownRemark___frontmatter___children___children",
    childrenMarkdownRemark___frontmatter___children___id = "childrenMarkdownRemark___frontmatter___children___id",
    childrenMarkdownRemark___frontmatter___description = "childrenMarkdownRemark___frontmatter___description",
    childrenMarkdownRemark___frontmatter___disableLastModified = "childrenMarkdownRemark___frontmatter___disableLastModified",
    childrenMarkdownRemark___frontmatter___editPage___disable = "childrenMarkdownRemark___frontmatter___editPage___disable",
    childrenMarkdownRemark___frontmatter___enableToc = "childrenMarkdownRemark___frontmatter___enableToc",
    childrenMarkdownRemark___frontmatter___id = "childrenMarkdownRemark___frontmatter___id",
    childrenMarkdownRemark___frontmatter___internal___content = "childrenMarkdownRemark___frontmatter___internal___content",
    childrenMarkdownRemark___frontmatter___internal___contentDigest = "childrenMarkdownRemark___frontmatter___internal___contentDigest",
    childrenMarkdownRemark___frontmatter___internal___description = "childrenMarkdownRemark___frontmatter___internal___description",
    childrenMarkdownRemark___frontmatter___internal___fieldOwners = "childrenMarkdownRemark___frontmatter___internal___fieldOwners",
    childrenMarkdownRemark___frontmatter___internal___ignoreType = "childrenMarkdownRemark___frontmatter___internal___ignoreType",
    childrenMarkdownRemark___frontmatter___internal___mediaType = "childrenMarkdownRemark___frontmatter___internal___mediaType",
    childrenMarkdownRemark___frontmatter___internal___owner = "childrenMarkdownRemark___frontmatter___internal___owner",
    childrenMarkdownRemark___frontmatter___internal___type = "childrenMarkdownRemark___frontmatter___internal___type",
    childrenMarkdownRemark___frontmatter___parent___children = "childrenMarkdownRemark___frontmatter___parent___children",
    childrenMarkdownRemark___frontmatter___parent___id = "childrenMarkdownRemark___frontmatter___parent___id",
    childrenMarkdownRemark___frontmatter___redirectFrom = "childrenMarkdownRemark___frontmatter___redirectFrom",
    childrenMarkdownRemark___frontmatter___sidebar = "childrenMarkdownRemark___frontmatter___sidebar",
    childrenMarkdownRemark___frontmatter___title = "childrenMarkdownRemark___frontmatter___title",
    childrenMarkdownRemark___frontmatter___tocMaxDepth = "childrenMarkdownRemark___frontmatter___tocMaxDepth",
    childrenMarkdownRemark___frontmatter___toc___enable = "childrenMarkdownRemark___frontmatter___toc___enable",
    childrenMarkdownRemark___headings = "childrenMarkdownRemark___headings",
    childrenMarkdownRemark___headings___depth = "childrenMarkdownRemark___headings___depth",
    childrenMarkdownRemark___headings___id = "childrenMarkdownRemark___headings___id",
    childrenMarkdownRemark___headings___value = "childrenMarkdownRemark___headings___value",
    childrenMarkdownRemark___html = "childrenMarkdownRemark___html",
    childrenMarkdownRemark___htmlAst = "childrenMarkdownRemark___htmlAst",
    childrenMarkdownRemark___id = "childrenMarkdownRemark___id",
    childrenMarkdownRemark___internal___content = "childrenMarkdownRemark___internal___content",
    childrenMarkdownRemark___internal___contentDigest = "childrenMarkdownRemark___internal___contentDigest",
    childrenMarkdownRemark___internal___description = "childrenMarkdownRemark___internal___description",
    childrenMarkdownRemark___internal___fieldOwners = "childrenMarkdownRemark___internal___fieldOwners",
    childrenMarkdownRemark___internal___ignoreType = "childrenMarkdownRemark___internal___ignoreType",
    childrenMarkdownRemark___internal___mediaType = "childrenMarkdownRemark___internal___mediaType",
    childrenMarkdownRemark___internal___owner = "childrenMarkdownRemark___internal___owner",
    childrenMarkdownRemark___internal___type = "childrenMarkdownRemark___internal___type",
    childrenMarkdownRemark___parent___children = "childrenMarkdownRemark___parent___children",
    childrenMarkdownRemark___parent___children___children = "childrenMarkdownRemark___parent___children___children",
    childrenMarkdownRemark___parent___children___id = "childrenMarkdownRemark___parent___children___id",
    childrenMarkdownRemark___parent___id = "childrenMarkdownRemark___parent___id",
    childrenMarkdownRemark___parent___internal___content = "childrenMarkdownRemark___parent___internal___content",
    childrenMarkdownRemark___parent___internal___contentDigest = "childrenMarkdownRemark___parent___internal___contentDigest",
    childrenMarkdownRemark___parent___internal___description = "childrenMarkdownRemark___parent___internal___description",
    childrenMarkdownRemark___parent___internal___fieldOwners = "childrenMarkdownRemark___parent___internal___fieldOwners",
    childrenMarkdownRemark___parent___internal___ignoreType = "childrenMarkdownRemark___parent___internal___ignoreType",
    childrenMarkdownRemark___parent___internal___mediaType = "childrenMarkdownRemark___parent___internal___mediaType",
    childrenMarkdownRemark___parent___internal___owner = "childrenMarkdownRemark___parent___internal___owner",
    childrenMarkdownRemark___parent___internal___type = "childrenMarkdownRemark___parent___internal___type",
    childrenMarkdownRemark___parent___parent___children = "childrenMarkdownRemark___parent___parent___children",
    childrenMarkdownRemark___parent___parent___id = "childrenMarkdownRemark___parent___parent___id",
    childrenMarkdownRemark___rawMarkdownBody = "childrenMarkdownRemark___rawMarkdownBody",
    childrenMarkdownRemark___tableOfContents = "childrenMarkdownRemark___tableOfContents",
    childrenMarkdownRemark___timeToRead = "childrenMarkdownRemark___timeToRead",
    childrenMarkdownRemark___wordCount___paragraphs = "childrenMarkdownRemark___wordCount___paragraphs",
    childrenMarkdownRemark___wordCount___sentences = "childrenMarkdownRemark___wordCount___sentences",
    childrenMarkdownRemark___wordCount___words = "childrenMarkdownRemark___wordCount___words",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    ctime = "ctime",
    ctimeMs = "ctimeMs",
    dev = "dev",
    dir = "dir",
    ext = "ext",
    extension = "extension",
    gid = "gid",
    id = "id",
    ino = "ino",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    mode = "mode",
    modifiedTime = "modifiedTime",
    mtime = "mtime",
    mtimeMs = "mtimeMs",
    name = "name",
    nlink = "nlink",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id",
    prettySize = "prettySize",
    publicURL = "publicURL",
    rdev = "rdev",
    relativeDirectory = "relativeDirectory",
    relativePath = "relativePath",
    root = "root",
    size = "size",
    sourceInstanceName = "sourceInstanceName",
    uid = "uid"
}
export declare type FileFilterInput = {
    absolutePath?: InputMaybe<StringQueryOperatorInput>;
    accessTime?: InputMaybe<DateQueryOperatorInput>;
    atime?: InputMaybe<DateQueryOperatorInput>;
    atimeMs?: InputMaybe<FloatQueryOperatorInput>;
    base?: InputMaybe<StringQueryOperatorInput>;
    birthTime?: InputMaybe<DateQueryOperatorInput>;
    birthtime?: InputMaybe<DateQueryOperatorInput>;
    birthtimeMs?: InputMaybe<FloatQueryOperatorInput>;
    blksize?: InputMaybe<IntQueryOperatorInput>;
    blocks?: InputMaybe<IntQueryOperatorInput>;
    changeTime?: InputMaybe<DateQueryOperatorInput>;
    childContentItem?: InputMaybe<ContentItemFilterInput>;
    childMarkdownRemark?: InputMaybe<MarkdownRemarkFilterInput>;
    children?: InputMaybe<NodeFilterListInput>;
    childrenContentItem?: InputMaybe<ContentItemFilterListInput>;
    childrenMarkdownRemark?: InputMaybe<MarkdownRemarkFilterListInput>;
    ctime?: InputMaybe<DateQueryOperatorInput>;
    ctimeMs?: InputMaybe<FloatQueryOperatorInput>;
    dev?: InputMaybe<IntQueryOperatorInput>;
    dir?: InputMaybe<StringQueryOperatorInput>;
    ext?: InputMaybe<StringQueryOperatorInput>;
    extension?: InputMaybe<StringQueryOperatorInput>;
    gid?: InputMaybe<IntQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    ino?: InputMaybe<FloatQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    mode?: InputMaybe<IntQueryOperatorInput>;
    modifiedTime?: InputMaybe<DateQueryOperatorInput>;
    mtime?: InputMaybe<DateQueryOperatorInput>;
    mtimeMs?: InputMaybe<FloatQueryOperatorInput>;
    name?: InputMaybe<StringQueryOperatorInput>;
    nlink?: InputMaybe<IntQueryOperatorInput>;
    parent?: InputMaybe<NodeFilterInput>;
    prettySize?: InputMaybe<StringQueryOperatorInput>;
    publicURL?: InputMaybe<StringQueryOperatorInput>;
    rdev?: InputMaybe<IntQueryOperatorInput>;
    relativeDirectory?: InputMaybe<StringQueryOperatorInput>;
    relativePath?: InputMaybe<StringQueryOperatorInput>;
    root?: InputMaybe<StringQueryOperatorInput>;
    size?: InputMaybe<IntQueryOperatorInput>;
    sourceInstanceName?: InputMaybe<StringQueryOperatorInput>;
    uid?: InputMaybe<IntQueryOperatorInput>;
};
export declare type FileGroupConnection = {
    __typename?: 'FileGroupConnection';
    edges: Array<FileEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<File>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type FileSortInput = {
    fields?: InputMaybe<Array<InputMaybe<FileFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare type FloatQueryOperatorInput = {
    eq?: InputMaybe<Scalars['Float']>;
    gt?: InputMaybe<Scalars['Float']>;
    gte?: InputMaybe<Scalars['Float']>;
    in?: InputMaybe<Array<InputMaybe<Scalars['Float']>>>;
    lt?: InputMaybe<Scalars['Float']>;
    lte?: InputMaybe<Scalars['Float']>;
    ne?: InputMaybe<Scalars['Float']>;
    nin?: InputMaybe<Array<InputMaybe<Scalars['Float']>>>;
};
export declare type FooterColumn = {
    __typename?: 'FooterColumn';
    group?: Maybe<Scalars['String']>;
    items: Array<NavItem>;
    label?: Maybe<Scalars['String']>;
    permission?: Maybe<Scalars['String']>;
};
export declare type FooterColumnItemsArgs = {
    ignoreRBAC?: InputMaybe<Scalars['Boolean']>;
};
export declare type FooterColumnFilterInput = {
    group?: InputMaybe<StringQueryOperatorInput>;
    items?: InputMaybe<NavItemFilterListInput>;
    label?: InputMaybe<StringQueryOperatorInput>;
    permission?: InputMaybe<StringQueryOperatorInput>;
};
export declare type FooterColumnFilterListInput = {
    elemMatch?: InputMaybe<FooterColumnFilterInput>;
};
export declare type FooterConfig = {
    __typename?: 'FooterConfig';
    columns: Array<FooterColumn>;
    copyrightText?: Maybe<Scalars['String']>;
    links?: Maybe<Array<NavItem>>;
};
export declare type FooterConfigColumnsArgs = {
    ignoreRBAC?: InputMaybe<Scalars['Boolean']>;
};
export declare type FooterConfigFilterInput = {
    columns?: InputMaybe<FooterColumnFilterListInput>;
    copyrightText?: InputMaybe<StringQueryOperatorInput>;
    links?: InputMaybe<NavItemFilterListInput>;
};
export declare type IntQueryOperatorInput = {
    eq?: InputMaybe<Scalars['Int']>;
    gt?: InputMaybe<Scalars['Int']>;
    gte?: InputMaybe<Scalars['Int']>;
    in?: InputMaybe<Array<InputMaybe<Scalars['Int']>>>;
    lt?: InputMaybe<Scalars['Int']>;
    lte?: InputMaybe<Scalars['Int']>;
    ne?: InputMaybe<Scalars['Int']>;
    nin?: InputMaybe<Array<InputMaybe<Scalars['Int']>>>;
};
export declare type Internal = {
    __typename?: 'Internal';
    content?: Maybe<Scalars['String']>;
    contentDigest: Scalars['String'];
    description?: Maybe<Scalars['String']>;
    fieldOwners?: Maybe<Array<Maybe<Scalars['String']>>>;
    ignoreType?: Maybe<Scalars['Boolean']>;
    mediaType?: Maybe<Scalars['String']>;
    owner: Scalars['String'];
    type: Scalars['String'];
};
export declare type InternalFilterInput = {
    content?: InputMaybe<StringQueryOperatorInput>;
    contentDigest?: InputMaybe<StringQueryOperatorInput>;
    description?: InputMaybe<StringQueryOperatorInput>;
    fieldOwners?: InputMaybe<StringQueryOperatorInput>;
    ignoreType?: InputMaybe<BooleanQueryOperatorInput>;
    mediaType?: InputMaybe<StringQueryOperatorInput>;
    owner?: InputMaybe<StringQueryOperatorInput>;
    type?: InputMaybe<StringQueryOperatorInput>;
};
export declare type JsonQueryOperatorInput = {
    eq?: InputMaybe<Scalars['JSON']>;
    glob?: InputMaybe<Scalars['JSON']>;
    in?: InputMaybe<Array<InputMaybe<Scalars['JSON']>>>;
    ne?: InputMaybe<Scalars['JSON']>;
    nin?: InputMaybe<Array<InputMaybe<Scalars['JSON']>>>;
    regex?: InputMaybe<Scalars['JSON']>;
};
export declare type LoginSettings = {
    __typename?: 'LoginSettings';
    label: Scalars['String'];
    menu: Array<NavItem>;
    userAvatar?: Maybe<LoginSettingsUserAvatar>;
    userLabel?: Maybe<LoginSettingsUserLabel>;
};
export declare type LoginSettingsFilterInput = {
    label?: InputMaybe<StringQueryOperatorInput>;
    menu?: InputMaybe<NavItemFilterListInput>;
    userAvatar?: InputMaybe<LoginSettingsUserAvatarFilterInput>;
    userLabel?: InputMaybe<LoginSettingsUserLabelFilterInput>;
};
export declare type LoginSettingsUserAvatar = {
    __typename?: 'LoginSettingsUserAvatar';
    claim: Scalars['String'];
    fallbackLettersClaim?: Maybe<Scalars['String']>;
};
export declare type LoginSettingsUserAvatarFilterInput = {
    claim?: InputMaybe<StringQueryOperatorInput>;
    fallbackLettersClaim?: InputMaybe<StringQueryOperatorInput>;
};
export declare type LoginSettingsUserLabel = {
    __typename?: 'LoginSettingsUserLabel';
    claim: Scalars['String'];
    fallback?: Maybe<Scalars['String']>;
};
export declare type LoginSettingsUserLabelFilterInput = {
    claim?: InputMaybe<StringQueryOperatorInput>;
    fallback?: InputMaybe<StringQueryOperatorInput>;
};
export declare type LogoConfig = {
    __typename?: 'LogoConfig';
    altText?: Maybe<Scalars['String']>;
    href?: Maybe<Scalars['String']>;
    image?: Maybe<Scalars['String']>;
};
export declare type LogoConfigFilterInput = {
    altText?: InputMaybe<StringQueryOperatorInput>;
    href?: InputMaybe<StringQueryOperatorInput>;
    image?: InputMaybe<StringQueryOperatorInput>;
};
export declare enum MarkdownExcerptFormats {
    HTML = "HTML",
    MARKDOWN = "MARKDOWN",
    PLAIN = "PLAIN"
}
export declare type MarkdownHeading = {
    __typename?: 'MarkdownHeading';
    depth?: Maybe<Scalars['Int']>;
    id?: Maybe<Scalars['String']>;
    value?: Maybe<Scalars['String']>;
};
export declare type MarkdownHeadingFilterInput = {
    depth?: InputMaybe<IntQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    value?: InputMaybe<StringQueryOperatorInput>;
};
export declare type MarkdownHeadingFilterListInput = {
    elemMatch?: InputMaybe<MarkdownHeadingFilterInput>;
};
export declare enum MarkdownHeadingLevels {
    h1 = "h1",
    h2 = "h2",
    h3 = "h3",
    h4 = "h4",
    h5 = "h5",
    h6 = "h6"
}
export declare type MarkdownRemark = Node & {
    __typename?: 'MarkdownRemark';
    children: Array<Node>;
    excerpt?: Maybe<Scalars['String']>;
    excerptAst?: Maybe<Scalars['JSON']>;
    fields?: Maybe<MarkdownRemarkFields>;
    fileAbsolutePath?: Maybe<Scalars['String']>;
    frontmatter?: Maybe<MarkdownRemarkFrontmatter>;
    headings?: Maybe<Array<Maybe<MarkdownHeading>>>;
    html?: Maybe<Scalars['String']>;
    htmlAst?: Maybe<Scalars['JSON']>;
    id: Scalars['ID'];
    internal: Internal;
    parent?: Maybe<Node>;
    rawMarkdownBody?: Maybe<Scalars['String']>;
    tableOfContents?: Maybe<Scalars['String']>;
    timeToRead?: Maybe<Scalars['Int']>;
    wordCount?: Maybe<MarkdownWordCount>;
};
export declare type MarkdownRemarkExcerptArgs = {
    format?: InputMaybe<MarkdownExcerptFormats>;
    pruneLength?: InputMaybe<Scalars['Int']>;
    truncate?: InputMaybe<Scalars['Boolean']>;
};
export declare type MarkdownRemarkExcerptAstArgs = {
    pruneLength?: InputMaybe<Scalars['Int']>;
    truncate?: InputMaybe<Scalars['Boolean']>;
};
export declare type MarkdownRemarkHeadingsArgs = {
    depth?: InputMaybe<MarkdownHeadingLevels>;
};
export declare type MarkdownRemarkTableOfContentsArgs = {
    absolute?: InputMaybe<Scalars['Boolean']>;
    heading?: InputMaybe<Scalars['String']>;
    maxDepth?: InputMaybe<Scalars['Int']>;
    pathToSlugField?: InputMaybe<Scalars['String']>;
};
export declare type MarkdownRemarkConnection = {
    __typename?: 'MarkdownRemarkConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<MarkdownRemarkEdge>;
    group: Array<MarkdownRemarkGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<MarkdownRemark>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type MarkdownRemarkConnectionDistinctArgs = {
    field: MarkdownRemarkFieldsEnum;
};
export declare type MarkdownRemarkConnectionGroupArgs = {
    field: MarkdownRemarkFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type MarkdownRemarkConnectionMaxArgs = {
    field: MarkdownRemarkFieldsEnum;
};
export declare type MarkdownRemarkConnectionMinArgs = {
    field: MarkdownRemarkFieldsEnum;
};
export declare type MarkdownRemarkConnectionSumArgs = {
    field: MarkdownRemarkFieldsEnum;
};
export declare type MarkdownRemarkEdge = {
    __typename?: 'MarkdownRemarkEdge';
    next?: Maybe<MarkdownRemark>;
    node: MarkdownRemark;
    previous?: Maybe<MarkdownRemark>;
};
export declare type MarkdownRemarkFields = {
    __typename?: 'MarkdownRemarkFields';
    contentId?: Maybe<Scalars['String']>;
};
export declare enum MarkdownRemarkFieldsEnum {
    children = "children",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    excerpt = "excerpt",
    excerptAst = "excerptAst",
    fields___contentId = "fields___contentId",
    fileAbsolutePath = "fileAbsolutePath",
    frontmatter___children = "frontmatter___children",
    frontmatter___children___children = "frontmatter___children___children",
    frontmatter___children___children___children = "frontmatter___children___children___children",
    frontmatter___children___children___id = "frontmatter___children___children___id",
    frontmatter___children___id = "frontmatter___children___id",
    frontmatter___children___internal___content = "frontmatter___children___internal___content",
    frontmatter___children___internal___contentDigest = "frontmatter___children___internal___contentDigest",
    frontmatter___children___internal___description = "frontmatter___children___internal___description",
    frontmatter___children___internal___fieldOwners = "frontmatter___children___internal___fieldOwners",
    frontmatter___children___internal___ignoreType = "frontmatter___children___internal___ignoreType",
    frontmatter___children___internal___mediaType = "frontmatter___children___internal___mediaType",
    frontmatter___children___internal___owner = "frontmatter___children___internal___owner",
    frontmatter___children___internal___type = "frontmatter___children___internal___type",
    frontmatter___children___parent___children = "frontmatter___children___parent___children",
    frontmatter___children___parent___id = "frontmatter___children___parent___id",
    frontmatter___description = "frontmatter___description",
    frontmatter___disableLastModified = "frontmatter___disableLastModified",
    frontmatter___editPage___disable = "frontmatter___editPage___disable",
    frontmatter___enableToc = "frontmatter___enableToc",
    frontmatter___id = "frontmatter___id",
    frontmatter___internal___content = "frontmatter___internal___content",
    frontmatter___internal___contentDigest = "frontmatter___internal___contentDigest",
    frontmatter___internal___description = "frontmatter___internal___description",
    frontmatter___internal___fieldOwners = "frontmatter___internal___fieldOwners",
    frontmatter___internal___ignoreType = "frontmatter___internal___ignoreType",
    frontmatter___internal___mediaType = "frontmatter___internal___mediaType",
    frontmatter___internal___owner = "frontmatter___internal___owner",
    frontmatter___internal___type = "frontmatter___internal___type",
    frontmatter___parent___children = "frontmatter___parent___children",
    frontmatter___parent___children___children = "frontmatter___parent___children___children",
    frontmatter___parent___children___id = "frontmatter___parent___children___id",
    frontmatter___parent___id = "frontmatter___parent___id",
    frontmatter___parent___internal___content = "frontmatter___parent___internal___content",
    frontmatter___parent___internal___contentDigest = "frontmatter___parent___internal___contentDigest",
    frontmatter___parent___internal___description = "frontmatter___parent___internal___description",
    frontmatter___parent___internal___fieldOwners = "frontmatter___parent___internal___fieldOwners",
    frontmatter___parent___internal___ignoreType = "frontmatter___parent___internal___ignoreType",
    frontmatter___parent___internal___mediaType = "frontmatter___parent___internal___mediaType",
    frontmatter___parent___internal___owner = "frontmatter___parent___internal___owner",
    frontmatter___parent___internal___type = "frontmatter___parent___internal___type",
    frontmatter___parent___parent___children = "frontmatter___parent___parent___children",
    frontmatter___parent___parent___id = "frontmatter___parent___parent___id",
    frontmatter___redirectFrom = "frontmatter___redirectFrom",
    frontmatter___sidebar = "frontmatter___sidebar",
    frontmatter___title = "frontmatter___title",
    frontmatter___tocMaxDepth = "frontmatter___tocMaxDepth",
    frontmatter___toc___enable = "frontmatter___toc___enable",
    headings = "headings",
    headings___depth = "headings___depth",
    headings___id = "headings___id",
    headings___value = "headings___value",
    html = "html",
    htmlAst = "htmlAst",
    id = "id",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id",
    rawMarkdownBody = "rawMarkdownBody",
    tableOfContents = "tableOfContents",
    timeToRead = "timeToRead",
    wordCount___paragraphs = "wordCount___paragraphs",
    wordCount___sentences = "wordCount___sentences",
    wordCount___words = "wordCount___words"
}
export declare type MarkdownRemarkFieldsFilterInput = {
    contentId?: InputMaybe<StringQueryOperatorInput>;
};
export declare type MarkdownRemarkFilterInput = {
    children?: InputMaybe<NodeFilterListInput>;
    excerpt?: InputMaybe<StringQueryOperatorInput>;
    excerptAst?: InputMaybe<JsonQueryOperatorInput>;
    fields?: InputMaybe<MarkdownRemarkFieldsFilterInput>;
    fileAbsolutePath?: InputMaybe<StringQueryOperatorInput>;
    frontmatter?: InputMaybe<MarkdownRemarkFrontmatterFilterInput>;
    headings?: InputMaybe<MarkdownHeadingFilterListInput>;
    html?: InputMaybe<StringQueryOperatorInput>;
    htmlAst?: InputMaybe<JsonQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
    rawMarkdownBody?: InputMaybe<StringQueryOperatorInput>;
    tableOfContents?: InputMaybe<StringQueryOperatorInput>;
    timeToRead?: InputMaybe<IntQueryOperatorInput>;
    wordCount?: InputMaybe<MarkdownWordCountFilterInput>;
};
export declare type MarkdownRemarkFilterListInput = {
    elemMatch?: InputMaybe<MarkdownRemarkFilterInput>;
};
export declare type MarkdownRemarkFrontmatter = Node & {
    __typename?: 'MarkdownRemarkFrontmatter';
    children: Array<Node>;
    description?: Maybe<Scalars['String']>;
    disableLastModified?: Maybe<Scalars['Boolean']>;
    editPage?: Maybe<MarkdownRemarkFrontmatterEditPage>;
    enableToc?: Maybe<Scalars['Boolean']>;
    id: Scalars['ID'];
    internal: Internal;
    parent?: Maybe<Node>;
    redirectFrom?: Maybe<Array<Maybe<Scalars['String']>>>;
    sidebar?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    toc?: Maybe<MarkdownRemarkFrontmatterToc>;
    tocMaxDepth?: Maybe<Scalars['Int']>;
};
export declare type MarkdownRemarkFrontmatterConnection = {
    __typename?: 'MarkdownRemarkFrontmatterConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<MarkdownRemarkFrontmatterEdge>;
    group: Array<MarkdownRemarkFrontmatterGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<MarkdownRemarkFrontmatter>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type MarkdownRemarkFrontmatterConnectionDistinctArgs = {
    field: MarkdownRemarkFrontmatterFieldsEnum;
};
export declare type MarkdownRemarkFrontmatterConnectionGroupArgs = {
    field: MarkdownRemarkFrontmatterFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type MarkdownRemarkFrontmatterConnectionMaxArgs = {
    field: MarkdownRemarkFrontmatterFieldsEnum;
};
export declare type MarkdownRemarkFrontmatterConnectionMinArgs = {
    field: MarkdownRemarkFrontmatterFieldsEnum;
};
export declare type MarkdownRemarkFrontmatterConnectionSumArgs = {
    field: MarkdownRemarkFrontmatterFieldsEnum;
};
export declare type MarkdownRemarkFrontmatterEdge = {
    __typename?: 'MarkdownRemarkFrontmatterEdge';
    next?: Maybe<MarkdownRemarkFrontmatter>;
    node: MarkdownRemarkFrontmatter;
    previous?: Maybe<MarkdownRemarkFrontmatter>;
};
export declare type MarkdownRemarkFrontmatterEditPage = {
    __typename?: 'MarkdownRemarkFrontmatterEditPage';
    disable?: Maybe<Scalars['Boolean']>;
};
export declare type MarkdownRemarkFrontmatterEditPageFilterInput = {
    disable?: InputMaybe<BooleanQueryOperatorInput>;
};
export declare enum MarkdownRemarkFrontmatterFieldsEnum {
    children = "children",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    description = "description",
    disableLastModified = "disableLastModified",
    editPage___disable = "editPage___disable",
    enableToc = "enableToc",
    id = "id",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id",
    redirectFrom = "redirectFrom",
    sidebar = "sidebar",
    title = "title",
    tocMaxDepth = "tocMaxDepth",
    toc___enable = "toc___enable"
}
export declare type MarkdownRemarkFrontmatterFilterInput = {
    children?: InputMaybe<NodeFilterListInput>;
    description?: InputMaybe<StringQueryOperatorInput>;
    disableLastModified?: InputMaybe<BooleanQueryOperatorInput>;
    editPage?: InputMaybe<MarkdownRemarkFrontmatterEditPageFilterInput>;
    enableToc?: InputMaybe<BooleanQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
    redirectFrom?: InputMaybe<StringQueryOperatorInput>;
    sidebar?: InputMaybe<StringQueryOperatorInput>;
    title?: InputMaybe<StringQueryOperatorInput>;
    toc?: InputMaybe<MarkdownRemarkFrontmatterTocFilterInput>;
    tocMaxDepth?: InputMaybe<IntQueryOperatorInput>;
};
export declare type MarkdownRemarkFrontmatterGroupConnection = {
    __typename?: 'MarkdownRemarkFrontmatterGroupConnection';
    edges: Array<MarkdownRemarkFrontmatterEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<MarkdownRemarkFrontmatter>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type MarkdownRemarkFrontmatterSortInput = {
    fields?: InputMaybe<Array<InputMaybe<MarkdownRemarkFrontmatterFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare type MarkdownRemarkFrontmatterToc = {
    __typename?: 'MarkdownRemarkFrontmatterToc';
    enable?: Maybe<Scalars['Boolean']>;
};
export declare type MarkdownRemarkFrontmatterTocFilterInput = {
    enable?: InputMaybe<BooleanQueryOperatorInput>;
};
export declare type MarkdownRemarkGroupConnection = {
    __typename?: 'MarkdownRemarkGroupConnection';
    edges: Array<MarkdownRemarkEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<MarkdownRemark>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type MarkdownRemarkSortInput = {
    fields?: InputMaybe<Array<InputMaybe<MarkdownRemarkFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare type MarkdownWordCount = {
    __typename?: 'MarkdownWordCount';
    paragraphs?: Maybe<Scalars['Int']>;
    sentences?: Maybe<Scalars['Int']>;
    words?: Maybe<Scalars['Int']>;
};
export declare type MarkdownWordCountFilterInput = {
    paragraphs?: InputMaybe<IntQueryOperatorInput>;
    sentences?: InputMaybe<IntQueryOperatorInput>;
    words?: InputMaybe<IntQueryOperatorInput>;
};
export declare type Mdx = Node & {
    __typename?: 'Mdx';
    children: Array<Node>;
    fields?: Maybe<MdxFields>;
    fileAbsolutePath?: Maybe<Scalars['String']>;
    frontmatter?: Maybe<MdxFrontmatter>;
    id: Scalars['ID'];
    internal: Internal;
    parent?: Maybe<Node>;
    rawBody?: Maybe<Scalars['String']>;
};
export declare type MdxConnection = {
    __typename?: 'MdxConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<MdxEdge>;
    group: Array<MdxGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<Mdx>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type MdxConnectionDistinctArgs = {
    field: MdxFieldsEnum;
};
export declare type MdxConnectionGroupArgs = {
    field: MdxFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type MdxConnectionMaxArgs = {
    field: MdxFieldsEnum;
};
export declare type MdxConnectionMinArgs = {
    field: MdxFieldsEnum;
};
export declare type MdxConnectionSumArgs = {
    field: MdxFieldsEnum;
};
export declare type MdxEdge = {
    __typename?: 'MdxEdge';
    next?: Maybe<Mdx>;
    node: Mdx;
    previous?: Maybe<Mdx>;
};
export declare type MdxFields = {
    __typename?: 'MdxFields';
    _snippetDeps?: Maybe<Array<Maybe<Scalars['String']>>>;
};
export declare enum MdxFieldsEnum {
    children = "children",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    fields____snippetDeps = "fields____snippetDeps",
    fileAbsolutePath = "fileAbsolutePath",
    frontmatter____PARENT = "frontmatter____PARENT",
    id = "id",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id",
    rawBody = "rawBody"
}
export declare type MdxFieldsFilterInput = {
    _snippetDeps?: InputMaybe<StringQueryOperatorInput>;
};
export declare type MdxFilterInput = {
    children?: InputMaybe<NodeFilterListInput>;
    fields?: InputMaybe<MdxFieldsFilterInput>;
    fileAbsolutePath?: InputMaybe<StringQueryOperatorInput>;
    frontmatter?: InputMaybe<MdxFrontmatterFilterInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
    rawBody?: InputMaybe<StringQueryOperatorInput>;
};
export declare type MdxFrontmatter = {
    __typename?: 'MdxFrontmatter';
    _PARENT?: Maybe<Scalars['String']>;
};
export declare type MdxFrontmatterFilterInput = {
    _PARENT?: InputMaybe<StringQueryOperatorInput>;
};
export declare type MdxGroupConnection = {
    __typename?: 'MdxGroupConnection';
    edges: Array<MdxEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<Mdx>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type MdxSortInput = {
    fields?: InputMaybe<Array<InputMaybe<MdxFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare enum MenuStyle {
    drilldown = "drilldown"
}
export declare type MenuStyleQueryOperatorInput = {
    eq?: InputMaybe<MenuStyle>;
    in?: InputMaybe<Array<InputMaybe<MenuStyle>>>;
    ne?: InputMaybe<MenuStyle>;
    nin?: InputMaybe<Array<InputMaybe<MenuStyle>>>;
};
export declare type MulesoftAnypointConfig = {
    __typename?: 'MulesoftAnypointConfig';
    appClientId?: Maybe<Scalars['String']>;
    orgId?: Maybe<Scalars['String']>;
};
export declare type MulesoftAnypointConfigFilterInput = {
    appClientId?: InputMaybe<StringQueryOperatorInput>;
    orgId?: InputMaybe<StringQueryOperatorInput>;
};
export declare type NavItem = {
    __typename?: 'NavItem';
    activateWithSidebar?: Maybe<Scalars['String']>;
    apiVersionId?: Maybe<Scalars['String']>;
    expanded?: Maybe<Scalars['String']>;
    external?: Maybe<Scalars['Boolean']>;
    httpVerb?: Maybe<Scalars['String']>;
    deprecated?: Maybe<Scalars['Boolean']>;
    icon?: Maybe<Scalars['String']>;
    isDefaultApiVersion?: Maybe<Scalars['Boolean']>;
    items?: Maybe<Array<NavItem>>;
    label?: Maybe<Scalars['String']>;
    link?: Maybe<Scalars['String']>;
    menuStyle?: Maybe<MenuStyle>;
    pageId?: Maybe<Scalars['String']>;
    permission?: Maybe<Scalars['String']>;
    redocFakePage?: Maybe<Scalars['Boolean']>;
    redocInfoPageId?: Maybe<Scalars['String']>;
    redocNextLabel?: Maybe<Scalars['String']>;
    redocNextLink?: Maybe<Scalars['String']>;
    redocPrevLabel?: Maybe<Scalars['String']>;
    redocPrevLink?: Maybe<Scalars['String']>;
    selectFirstItemOnExpand?: Maybe<Scalars['Boolean']>;
    separatorLine?: Maybe<Scalars['Boolean']>;
    sublabel?: Maybe<Scalars['String']>;
    target?: Maybe<Scalars['String']>;
    type?: Maybe<Scalars['String']>;
};
export declare type NavItemItemsArgs = {
    ignoreRBAC?: InputMaybe<Scalars['Boolean']>;
};
export declare type NavItemFilterInput = {
    activateWithSidebar?: InputMaybe<StringQueryOperatorInput>;
    apiVersionId?: InputMaybe<StringQueryOperatorInput>;
    expanded?: InputMaybe<StringQueryOperatorInput>;
    external?: InputMaybe<BooleanQueryOperatorInput>;
    httpVerb?: InputMaybe<StringQueryOperatorInput>;
    icon?: InputMaybe<StringQueryOperatorInput>;
    isDefaultApiVersion?: InputMaybe<BooleanQueryOperatorInput>;
    items?: InputMaybe<NavItemFilterListInput>;
    label?: InputMaybe<StringQueryOperatorInput>;
    link?: InputMaybe<StringQueryOperatorInput>;
    menuStyle?: InputMaybe<MenuStyleQueryOperatorInput>;
    pageId?: InputMaybe<StringQueryOperatorInput>;
    permission?: InputMaybe<StringQueryOperatorInput>;
    redocFakePage?: InputMaybe<BooleanQueryOperatorInput>;
    redocInfoPageId?: InputMaybe<StringQueryOperatorInput>;
    redocNextLabel?: InputMaybe<StringQueryOperatorInput>;
    redocNextLink?: InputMaybe<StringQueryOperatorInput>;
    redocPrevLabel?: InputMaybe<StringQueryOperatorInput>;
    redocPrevLink?: InputMaybe<StringQueryOperatorInput>;
    selectFirstItemOnExpand?: InputMaybe<BooleanQueryOperatorInput>;
    separatorLine?: InputMaybe<BooleanQueryOperatorInput>;
    sublabel?: InputMaybe<StringQueryOperatorInput>;
    target?: InputMaybe<StringQueryOperatorInput>;
    type?: InputMaybe<StringQueryOperatorInput>;
};
export declare type NavItemFilterListInput = {
    elemMatch?: InputMaybe<NavItemFilterInput>;
};
/** Node Interface */
export declare type Node = {
    children: Array<Node>;
    id: Scalars['ID'];
    internal: Internal;
    parent?: Maybe<Node>;
};
export declare type NodeFilterInput = {
    children?: InputMaybe<NodeFilterListInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
};
export declare type NodeFilterListInput = {
    elemMatch?: InputMaybe<NodeFilterInput>;
};
export declare type OasDefinition = {
    __typename?: 'OASDefinition';
    absolutePath?: Maybe<Scalars['String']>;
    id?: Maybe<Scalars['String']>;
    redocStoreStr?: Maybe<Scalars['String']>;
};
export declare type OasDefinitionInfo = {
    __typename?: 'OASDefinitionInfo';
    data?: Maybe<Scalars['JSON']>;
    definitionId: Scalars['String'];
    definitionProperties?: Maybe<Scalars['JSON']>;
    id?: Maybe<Scalars['String']>;
    info?: Maybe<Scalars['JSON']>;
    label?: Maybe<Scalars['String']>;
    link?: Maybe<Scalars['String']>;
    permission?: Maybe<Scalars['String']>;
    sourcePath?: Maybe<Scalars['String']>;
    versions?: Maybe<Array<OasDefinitionVersionInfo>>;
};
export declare type OasDefinitionVersionInfo = {
    __typename?: 'OASDefinitionVersionInfo';
    definitionId: Scalars['String'];
    id?: Maybe<Scalars['String']>;
    isDefault?: Maybe<Scalars['Boolean']>;
    link?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
};
export declare type PageInfo = {
    __typename?: 'PageInfo';
    currentPage: Scalars['Int'];
    hasNextPage: Scalars['Boolean'];
    hasPreviousPage: Scalars['Boolean'];
    itemCount: Scalars['Int'];
    pageCount: Scalars['Int'];
    perPage?: Maybe<Scalars['Int']>;
    totalCount: Scalars['Int'];
};
export declare type Query = {
    __typename?: 'Query';
    allContentItem: ContentItemConnection;
    allContentItemData: ContentItemDataConnection;
    allContentItemSeo: ContentItemSeoConnection;
    allDirectory: DirectoryConnection;
    allFile: FileConnection;
    allMarkdownRemark: MarkdownRemarkConnection;
    allMarkdownRemarkFrontmatter: MarkdownRemarkFrontmatterConnection;
    allMdx: MdxConnection;
    allSidebar: SidebarConnection;
    allSite: SiteConnection;
    allSiteBuildMetadata: SiteBuildMetadataConnection;
    allSiteConfig: SiteConfigConnection;
    allSiteFunction: SiteFunctionConnection;
    allSitePage: SitePageConnection;
    allSitePlugin: SitePluginConnection;
    apiCatalog: Array<ApiCatalogApi>;
    apis: Array<OasDefinitionInfo>;
    contentItem?: Maybe<ContentItem>;
    contentItemData?: Maybe<ContentItemData>;
    contentItemSeo?: Maybe<ContentItemSeo>;
    directory?: Maybe<Directory>;
    file?: Maybe<File>;
    markdownRemark?: Maybe<MarkdownRemark>;
    markdownRemarkFrontmatter?: Maybe<MarkdownRemarkFrontmatter>;
    mdx?: Maybe<Mdx>;
    oasDefinition?: Maybe<OasDefinition>;
    sidebar?: Maybe<Sidebar>;
    site?: Maybe<Site>;
    siteBuildMetadata?: Maybe<SiteBuildMetadata>;
    siteConfig?: Maybe<SiteConfig>;
    siteFunction?: Maybe<SiteFunction>;
    sitePage?: Maybe<SitePage>;
    sitePlugin?: Maybe<SitePlugin>;
};
export declare type QueryAllContentItemArgs = {
    filter?: InputMaybe<ContentItemFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<ContentItemSortInput>;
};
export declare type QueryAllContentItemDataArgs = {
    filter?: InputMaybe<ContentItemDataFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<ContentItemDataSortInput>;
};
export declare type QueryAllContentItemSeoArgs = {
    filter?: InputMaybe<ContentItemSeoFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<ContentItemSeoSortInput>;
};
export declare type QueryAllDirectoryArgs = {
    filter?: InputMaybe<DirectoryFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<DirectorySortInput>;
};
export declare type QueryAllFileArgs = {
    filter?: InputMaybe<FileFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<FileSortInput>;
};
export declare type QueryAllMarkdownRemarkArgs = {
    filter?: InputMaybe<MarkdownRemarkFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<MarkdownRemarkSortInput>;
};
export declare type QueryAllMarkdownRemarkFrontmatterArgs = {
    filter?: InputMaybe<MarkdownRemarkFrontmatterFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<MarkdownRemarkFrontmatterSortInput>;
};
export declare type QueryAllMdxArgs = {
    filter?: InputMaybe<MdxFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<MdxSortInput>;
};
export declare type QueryAllSidebarArgs = {
    filter?: InputMaybe<SidebarFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<SidebarSortInput>;
};
export declare type QueryAllSiteArgs = {
    filter?: InputMaybe<SiteFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<SiteSortInput>;
};
export declare type QueryAllSiteBuildMetadataArgs = {
    filter?: InputMaybe<SiteBuildMetadataFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<SiteBuildMetadataSortInput>;
};
export declare type QueryAllSiteConfigArgs = {
    filter?: InputMaybe<SiteConfigFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<SiteConfigSortInput>;
};
export declare type QueryAllSiteFunctionArgs = {
    filter?: InputMaybe<SiteFunctionFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<SiteFunctionSortInput>;
};
export declare type QueryAllSitePageArgs = {
    filter?: InputMaybe<SitePageFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<SitePageSortInput>;
};
export declare type QueryAllSitePluginArgs = {
    filter?: InputMaybe<SitePluginFilterInput>;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
    sort?: InputMaybe<SitePluginSortInput>;
};
export declare type QueryApiCatalogArgs = {
    ignoreRBAC?: InputMaybe<Scalars['Boolean']>;
};
export declare type QueryApisArgs = {
    definitionProperties?: InputMaybe<Array<Scalars['String']>>;
    ignoreRBAC?: InputMaybe<Scalars['Boolean']>;
};
export declare type QueryContentItemArgs = {
    baseLink?: InputMaybe<StringQueryOperatorInput>;
    catalogInfo?: InputMaybe<CatalogInfoFilterInput>;
    children?: InputMaybe<NodeFilterListInput>;
    data?: InputMaybe<ContentItemDataFilterInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    link?: InputMaybe<StringQueryOperatorInput>;
    markdown?: InputMaybe<MarkdownRemarkFilterInput>;
    pageId?: InputMaybe<StringQueryOperatorInput>;
    parent?: InputMaybe<NodeFilterInput>;
    permission?: InputMaybe<StringQueryOperatorInput>;
    seo?: InputMaybe<ContentItemSeoFilterInput>;
    sourcePath?: InputMaybe<StringQueryOperatorInput>;
    type?: InputMaybe<StringQueryOperatorInput>;
};
export declare type QueryContentItemDataArgs = {
    apiVersionId?: InputMaybe<StringQueryOperatorInput>;
    apiVersions?: InputMaybe<ContentItemApiVersionFilterListInput>;
    children?: InputMaybe<NodeFilterListInput>;
    customData?: InputMaybe<ContentItemDataCustomDataFilterInput>;
    customDataString?: InputMaybe<StringQueryOperatorInput>;
    customTemplate?: InputMaybe<StringQueryOperatorInput>;
    definitionId?: InputMaybe<StringQueryOperatorInput>;
    disableEditPage?: InputMaybe<BooleanQueryOperatorInput>;
    disableLastModified?: InputMaybe<BooleanQueryOperatorInput>;
    editPage?: InputMaybe<ContentItemDataEditPageFilterInput>;
    enableToc?: InputMaybe<BooleanQueryOperatorInput>;
    excludeFromSearch?: InputMaybe<BooleanQueryOperatorInput>;
    httpVerb?: InputMaybe<StringQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    image?: InputMaybe<StringQueryOperatorInput>;
    imageLink?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    isDefaultApiVersion?: InputMaybe<BooleanQueryOperatorInput>;
    keywords?: InputMaybe<StringQueryOperatorInput>;
    label?: InputMaybe<StringQueryOperatorInput>;
    lang?: InputMaybe<StringQueryOperatorInput>;
    lastModified?: InputMaybe<StringQueryOperatorInput>;
    matchPath?: InputMaybe<StringQueryOperatorInput>;
    pageLink?: InputMaybe<FileFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
    permission?: InputMaybe<StringQueryOperatorInput>;
    redirect?: InputMaybe<BooleanQueryOperatorInput>;
    redirectFrom?: InputMaybe<StringQueryOperatorInput>;
    redocHasInfoPage?: InputMaybe<BooleanQueryOperatorInput>;
    redocHasSecurityDefinitions?: InputMaybe<BooleanQueryOperatorInput>;
    redocInfoPageId?: InputMaybe<StringQueryOperatorInput>;
    redocInfoPageLink?: InputMaybe<StringQueryOperatorInput>;
    redocItemId?: InputMaybe<StringQueryOperatorInput>;
    redocMenuItems?: InputMaybe<ContentItemDataRedocMenuItemsFilterListInput>;
    redocNextLabel?: InputMaybe<StringQueryOperatorInput>;
    redocNextLink?: InputMaybe<StringQueryOperatorInput>;
    redocPagination?: InputMaybe<StringQueryOperatorInput>;
    redocPrevLabel?: InputMaybe<StringQueryOperatorInput>;
    redocPrevLink?: InputMaybe<StringQueryOperatorInput>;
    redocStoreStr?: InputMaybe<StringQueryOperatorInput>;
    requestLogin?: InputMaybe<BooleanQueryOperatorInput>;
    settings?: InputMaybe<JsonQueryOperatorInput>;
    showNextButton?: InputMaybe<BooleanQueryOperatorInput>;
    showPrevButton?: InputMaybe<BooleanQueryOperatorInput>;
    sidebar?: InputMaybe<FileFilterInput>;
    sitemap?: InputMaybe<SitemapFilterInput>;
    sourcePath?: InputMaybe<StringQueryOperatorInput>;
    staticImageLink?: InputMaybe<FileFilterInput>;
    toc?: InputMaybe<TocInfoFilterInput>;
    tocMaxDepth?: InputMaybe<IntQueryOperatorInput>;
    type?: InputMaybe<StringQueryOperatorInput>;
    versions?: InputMaybe<ContentItemDataVersionsFilterListInput>;
};
export declare type QueryContentItemSeoArgs = {
    children?: InputMaybe<NodeFilterListInput>;
    description?: InputMaybe<StringQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    image?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    jsonLd?: InputMaybe<JsonQueryOperatorInput>;
    keywords?: InputMaybe<StringQueryOperatorInput>;
    lang?: InputMaybe<StringQueryOperatorInput>;
    parent?: InputMaybe<NodeFilterInput>;
    sitemap?: InputMaybe<SitemapFilterInput>;
    title?: InputMaybe<StringQueryOperatorInput>;
};
export declare type QueryDirectoryArgs = {
    absolutePath?: InputMaybe<StringQueryOperatorInput>;
    accessTime?: InputMaybe<DateQueryOperatorInput>;
    atime?: InputMaybe<DateQueryOperatorInput>;
    atimeMs?: InputMaybe<FloatQueryOperatorInput>;
    base?: InputMaybe<StringQueryOperatorInput>;
    birthTime?: InputMaybe<DateQueryOperatorInput>;
    birthtime?: InputMaybe<DateQueryOperatorInput>;
    birthtimeMs?: InputMaybe<FloatQueryOperatorInput>;
    blksize?: InputMaybe<IntQueryOperatorInput>;
    blocks?: InputMaybe<IntQueryOperatorInput>;
    changeTime?: InputMaybe<DateQueryOperatorInput>;
    children?: InputMaybe<NodeFilterListInput>;
    ctime?: InputMaybe<DateQueryOperatorInput>;
    ctimeMs?: InputMaybe<FloatQueryOperatorInput>;
    dev?: InputMaybe<IntQueryOperatorInput>;
    dir?: InputMaybe<StringQueryOperatorInput>;
    ext?: InputMaybe<StringQueryOperatorInput>;
    extension?: InputMaybe<StringQueryOperatorInput>;
    gid?: InputMaybe<IntQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    ino?: InputMaybe<FloatQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    mode?: InputMaybe<IntQueryOperatorInput>;
    modifiedTime?: InputMaybe<DateQueryOperatorInput>;
    mtime?: InputMaybe<DateQueryOperatorInput>;
    mtimeMs?: InputMaybe<FloatQueryOperatorInput>;
    name?: InputMaybe<StringQueryOperatorInput>;
    nlink?: InputMaybe<IntQueryOperatorInput>;
    parent?: InputMaybe<NodeFilterInput>;
    prettySize?: InputMaybe<StringQueryOperatorInput>;
    rdev?: InputMaybe<IntQueryOperatorInput>;
    relativeDirectory?: InputMaybe<StringQueryOperatorInput>;
    relativePath?: InputMaybe<StringQueryOperatorInput>;
    root?: InputMaybe<StringQueryOperatorInput>;
    size?: InputMaybe<IntQueryOperatorInput>;
    sourceInstanceName?: InputMaybe<StringQueryOperatorInput>;
    uid?: InputMaybe<IntQueryOperatorInput>;
};
export declare type QueryFileArgs = {
    absolutePath?: InputMaybe<StringQueryOperatorInput>;
    accessTime?: InputMaybe<DateQueryOperatorInput>;
    atime?: InputMaybe<DateQueryOperatorInput>;
    atimeMs?: InputMaybe<FloatQueryOperatorInput>;
    base?: InputMaybe<StringQueryOperatorInput>;
    birthTime?: InputMaybe<DateQueryOperatorInput>;
    birthtime?: InputMaybe<DateQueryOperatorInput>;
    birthtimeMs?: InputMaybe<FloatQueryOperatorInput>;
    blksize?: InputMaybe<IntQueryOperatorInput>;
    blocks?: InputMaybe<IntQueryOperatorInput>;
    changeTime?: InputMaybe<DateQueryOperatorInput>;
    childContentItem?: InputMaybe<ContentItemFilterInput>;
    childMarkdownRemark?: InputMaybe<MarkdownRemarkFilterInput>;
    children?: InputMaybe<NodeFilterListInput>;
    childrenContentItem?: InputMaybe<ContentItemFilterListInput>;
    childrenMarkdownRemark?: InputMaybe<MarkdownRemarkFilterListInput>;
    ctime?: InputMaybe<DateQueryOperatorInput>;
    ctimeMs?: InputMaybe<FloatQueryOperatorInput>;
    dev?: InputMaybe<IntQueryOperatorInput>;
    dir?: InputMaybe<StringQueryOperatorInput>;
    ext?: InputMaybe<StringQueryOperatorInput>;
    extension?: InputMaybe<StringQueryOperatorInput>;
    gid?: InputMaybe<IntQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    ino?: InputMaybe<FloatQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    mode?: InputMaybe<IntQueryOperatorInput>;
    modifiedTime?: InputMaybe<DateQueryOperatorInput>;
    mtime?: InputMaybe<DateQueryOperatorInput>;
    mtimeMs?: InputMaybe<FloatQueryOperatorInput>;
    name?: InputMaybe<StringQueryOperatorInput>;
    nlink?: InputMaybe<IntQueryOperatorInput>;
    parent?: InputMaybe<NodeFilterInput>;
    prettySize?: InputMaybe<StringQueryOperatorInput>;
    publicURL?: InputMaybe<StringQueryOperatorInput>;
    rdev?: InputMaybe<IntQueryOperatorInput>;
    relativeDirectory?: InputMaybe<StringQueryOperatorInput>;
    relativePath?: InputMaybe<StringQueryOperatorInput>;
    root?: InputMaybe<StringQueryOperatorInput>;
    size?: InputMaybe<IntQueryOperatorInput>;
    sourceInstanceName?: InputMaybe<StringQueryOperatorInput>;
    uid?: InputMaybe<IntQueryOperatorInput>;
};
export declare type QueryMarkdownRemarkArgs = {
    children?: InputMaybe<NodeFilterListInput>;
    excerpt?: InputMaybe<StringQueryOperatorInput>;
    excerptAst?: InputMaybe<JsonQueryOperatorInput>;
    fields?: InputMaybe<MarkdownRemarkFieldsFilterInput>;
    fileAbsolutePath?: InputMaybe<StringQueryOperatorInput>;
    frontmatter?: InputMaybe<MarkdownRemarkFrontmatterFilterInput>;
    headings?: InputMaybe<MarkdownHeadingFilterListInput>;
    html?: InputMaybe<StringQueryOperatorInput>;
    htmlAst?: InputMaybe<JsonQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
    rawMarkdownBody?: InputMaybe<StringQueryOperatorInput>;
    tableOfContents?: InputMaybe<StringQueryOperatorInput>;
    timeToRead?: InputMaybe<IntQueryOperatorInput>;
    wordCount?: InputMaybe<MarkdownWordCountFilterInput>;
};
export declare type QueryMarkdownRemarkFrontmatterArgs = {
    children?: InputMaybe<NodeFilterListInput>;
    description?: InputMaybe<StringQueryOperatorInput>;
    disableLastModified?: InputMaybe<BooleanQueryOperatorInput>;
    editPage?: InputMaybe<MarkdownRemarkFrontmatterEditPageFilterInput>;
    enableToc?: InputMaybe<BooleanQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
    redirectFrom?: InputMaybe<StringQueryOperatorInput>;
    sidebar?: InputMaybe<StringQueryOperatorInput>;
    title?: InputMaybe<StringQueryOperatorInput>;
    toc?: InputMaybe<MarkdownRemarkFrontmatterTocFilterInput>;
    tocMaxDepth?: InputMaybe<IntQueryOperatorInput>;
};
export declare type QueryMdxArgs = {
    children?: InputMaybe<NodeFilterListInput>;
    fields?: InputMaybe<MdxFieldsFilterInput>;
    fileAbsolutePath?: InputMaybe<StringQueryOperatorInput>;
    frontmatter?: InputMaybe<MdxFrontmatterFilterInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
    rawBody?: InputMaybe<StringQueryOperatorInput>;
};
export declare type QueryOasDefinitionArgs = {
    id?: InputMaybe<Scalars['String']>;
};
export declare type QuerySidebarArgs = {
    children?: InputMaybe<NodeFilterListInput>;
    context?: InputMaybe<StringQueryOperatorInput>;
    generationDate?: InputMaybe<FloatQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    items?: InputMaybe<NavItemFilterListInput>;
    labels?: InputMaybe<IntQueryOperatorInput>;
    name?: InputMaybe<StringQueryOperatorInput>;
    pages?: InputMaybe<SidebarPagesFilterListInput>;
    pagesIds?: InputMaybe<StringQueryOperatorInput>;
    pagesLinks?: InputMaybe<StringQueryOperatorInput>;
    parent?: InputMaybe<NodeFilterInput>;
    permission?: InputMaybe<StringQueryOperatorInput>;
};
export declare type QuerySiteArgs = {
    buildTime?: InputMaybe<DateQueryOperatorInput>;
    children?: InputMaybe<NodeFilterListInput>;
    flags?: InputMaybe<SiteFlagsFilterInput>;
    host?: InputMaybe<StringQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
    pathPrefix?: InputMaybe<StringQueryOperatorInput>;
    polyfill?: InputMaybe<BooleanQueryOperatorInput>;
    port?: InputMaybe<IntQueryOperatorInput>;
    siteMetadata?: InputMaybe<SiteSiteMetadataFilterInput>;
};
export declare type QuerySiteBuildMetadataArgs = {
    buildTime?: InputMaybe<DateQueryOperatorInput>;
    children?: InputMaybe<NodeFilterListInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
};
export declare type QuerySiteConfigArgs = {
    children?: InputMaybe<NodeFilterListInput>;
    contentDir?: InputMaybe<StringQueryOperatorInput>;
    customLoginPagePath?: InputMaybe<StringQueryOperatorInput>;
    disableLastModified?: InputMaybe<BooleanQueryOperatorInput>;
    editPage?: InputMaybe<EditPageConfigFilterInput>;
    enableToc?: InputMaybe<BooleanQueryOperatorInput>;
    footer?: InputMaybe<FooterConfigFilterInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    login?: InputMaybe<LoginSettingsFilterInput>;
    logo?: InputMaybe<LogoConfigFilterInput>;
    mulesoftAnypoint?: InputMaybe<MulesoftAnypointConfigFilterInput>;
    nav?: InputMaybe<NavItemFilterListInput>;
    parent?: InputMaybe<NodeFilterInput>;
    redoclyOrgId?: InputMaybe<StringQueryOperatorInput>;
    scripts?: InputMaybe<StringQueryOperatorInput>;
    seo?: InputMaybe<ContentItemSeoFilterInput>;
    showNextButton?: InputMaybe<BooleanQueryOperatorInput>;
    showPrevButton?: InputMaybe<BooleanQueryOperatorInput>;
    siteVersion?: InputMaybe<StringQueryOperatorInput>;
    social?: InputMaybe<SocialFilterInput>;
    stylesheets?: InputMaybe<StringQueryOperatorInput>;
    toc?: InputMaybe<TocInfoFilterInput>;
    tocMaxDepth?: InputMaybe<IntQueryOperatorInput>;
    withRbac?: InputMaybe<BooleanQueryOperatorInput>;
};
export declare type QuerySiteFunctionArgs = {
    absoluteCompiledFilePath?: InputMaybe<StringQueryOperatorInput>;
    children?: InputMaybe<NodeFilterListInput>;
    functionRoute?: InputMaybe<StringQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    matchPath?: InputMaybe<StringQueryOperatorInput>;
    originalAbsoluteFilePath?: InputMaybe<StringQueryOperatorInput>;
    originalRelativeFilePath?: InputMaybe<StringQueryOperatorInput>;
    parent?: InputMaybe<NodeFilterInput>;
    pluginName?: InputMaybe<StringQueryOperatorInput>;
    relativeCompiledFilePath?: InputMaybe<StringQueryOperatorInput>;
};
export declare type QuerySitePageArgs = {
    children?: InputMaybe<NodeFilterListInput>;
    component?: InputMaybe<StringQueryOperatorInput>;
    componentChunkName?: InputMaybe<StringQueryOperatorInput>;
    context?: InputMaybe<SitePageContextFilterInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    internalComponentName?: InputMaybe<StringQueryOperatorInput>;
    isCreatedByStatefulCreatePages?: InputMaybe<BooleanQueryOperatorInput>;
    matchPath?: InputMaybe<StringQueryOperatorInput>;
    parent?: InputMaybe<NodeFilterInput>;
    path?: InputMaybe<StringQueryOperatorInput>;
    pluginCreator?: InputMaybe<SitePluginFilterInput>;
    pluginCreatorId?: InputMaybe<StringQueryOperatorInput>;
};
export declare type QuerySitePluginArgs = {
    browserAPIs?: InputMaybe<StringQueryOperatorInput>;
    children?: InputMaybe<NodeFilterListInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    name?: InputMaybe<StringQueryOperatorInput>;
    nodeAPIs?: InputMaybe<StringQueryOperatorInput>;
    packageJson?: InputMaybe<SitePluginPackageJsonFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
    pluginFilepath?: InputMaybe<StringQueryOperatorInput>;
    pluginOptions?: InputMaybe<SitePluginPluginOptionsFilterInput>;
    resolve?: InputMaybe<StringQueryOperatorInput>;
    ssrAPIs?: InputMaybe<StringQueryOperatorInput>;
    version?: InputMaybe<StringQueryOperatorInput>;
};
export declare type Sidebar = Node & {
    __typename?: 'Sidebar';
    children: Array<Node>;
    context?: Maybe<Scalars['String']>;
    generationDate?: Maybe<Scalars['Float']>;
    id: Scalars['ID'];
    internal: Internal;
    items: Array<NavItem>;
    labels?: Maybe<Scalars['Int']>;
    name: Scalars['String'];
    pages?: Maybe<Array<Maybe<SidebarPages>>>;
    pagesIds: Array<Scalars['String']>;
    pagesLinks: Array<Scalars['String']>;
    parent?: Maybe<Node>;
    permission?: Maybe<Scalars['String']>;
};
export declare type SidebarItemsArgs = {
    ignoreRBAC?: InputMaybe<Scalars['Boolean']>;
};
export declare type SidebarConnection = {
    __typename?: 'SidebarConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<SidebarEdge>;
    group: Array<SidebarGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<Sidebar>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type SidebarConnectionDistinctArgs = {
    field: SidebarFieldsEnum;
};
export declare type SidebarConnectionGroupArgs = {
    field: SidebarFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type SidebarConnectionMaxArgs = {
    field: SidebarFieldsEnum;
};
export declare type SidebarConnectionMinArgs = {
    field: SidebarFieldsEnum;
};
export declare type SidebarConnectionSumArgs = {
    field: SidebarFieldsEnum;
};
export declare type SidebarEdge = {
    __typename?: 'SidebarEdge';
    next?: Maybe<Sidebar>;
    node: Sidebar;
    previous?: Maybe<Sidebar>;
};
export declare enum SidebarFieldsEnum {
    children = "children",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    context = "context",
    generationDate = "generationDate",
    id = "id",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    items = "items",
    items___activateWithSidebar = "items___activateWithSidebar",
    items___apiVersionId = "items___apiVersionId",
    items___expanded = "items___expanded",
    items___external = "items___external",
    items___httpVerb = "items___httpVerb",
    items___icon = "items___icon",
    items___isDefaultApiVersion = "items___isDefaultApiVersion",
    items___items = "items___items",
    items___items___activateWithSidebar = "items___items___activateWithSidebar",
    items___items___apiVersionId = "items___items___apiVersionId",
    items___items___expanded = "items___items___expanded",
    items___items___external = "items___items___external",
    items___items___httpVerb = "items___items___httpVerb",
    items___items___icon = "items___items___icon",
    items___items___isDefaultApiVersion = "items___items___isDefaultApiVersion",
    items___items___items = "items___items___items",
    items___items___items___activateWithSidebar = "items___items___items___activateWithSidebar",
    items___items___items___apiVersionId = "items___items___items___apiVersionId",
    items___items___items___expanded = "items___items___items___expanded",
    items___items___items___external = "items___items___items___external",
    items___items___items___httpVerb = "items___items___items___httpVerb",
    items___items___items___icon = "items___items___items___icon",
    items___items___items___isDefaultApiVersion = "items___items___items___isDefaultApiVersion",
    items___items___items___items = "items___items___items___items",
    items___items___items___label = "items___items___items___label",
    items___items___items___link = "items___items___items___link",
    items___items___items___menuStyle = "items___items___items___menuStyle",
    items___items___items___pageId = "items___items___items___pageId",
    items___items___items___permission = "items___items___items___permission",
    items___items___items___redocFakePage = "items___items___items___redocFakePage",
    items___items___items___redocInfoPageId = "items___items___items___redocInfoPageId",
    items___items___items___redocNextLabel = "items___items___items___redocNextLabel",
    items___items___items___redocNextLink = "items___items___items___redocNextLink",
    items___items___items___redocPrevLabel = "items___items___items___redocPrevLabel",
    items___items___items___redocPrevLink = "items___items___items___redocPrevLink",
    items___items___items___selectFirstItemOnExpand = "items___items___items___selectFirstItemOnExpand",
    items___items___items___separatorLine = "items___items___items___separatorLine",
    items___items___items___sublabel = "items___items___items___sublabel",
    items___items___items___target = "items___items___items___target",
    items___items___items___type = "items___items___items___type",
    items___items___label = "items___items___label",
    items___items___link = "items___items___link",
    items___items___menuStyle = "items___items___menuStyle",
    items___items___pageId = "items___items___pageId",
    items___items___permission = "items___items___permission",
    items___items___redocFakePage = "items___items___redocFakePage",
    items___items___redocInfoPageId = "items___items___redocInfoPageId",
    items___items___redocNextLabel = "items___items___redocNextLabel",
    items___items___redocNextLink = "items___items___redocNextLink",
    items___items___redocPrevLabel = "items___items___redocPrevLabel",
    items___items___redocPrevLink = "items___items___redocPrevLink",
    items___items___selectFirstItemOnExpand = "items___items___selectFirstItemOnExpand",
    items___items___separatorLine = "items___items___separatorLine",
    items___items___sublabel = "items___items___sublabel",
    items___items___target = "items___items___target",
    items___items___type = "items___items___type",
    items___label = "items___label",
    items___link = "items___link",
    items___menuStyle = "items___menuStyle",
    items___pageId = "items___pageId",
    items___permission = "items___permission",
    items___redocFakePage = "items___redocFakePage",
    items___redocInfoPageId = "items___redocInfoPageId",
    items___redocNextLabel = "items___redocNextLabel",
    items___redocNextLink = "items___redocNextLink",
    items___redocPrevLabel = "items___redocPrevLabel",
    items___redocPrevLink = "items___redocPrevLink",
    items___selectFirstItemOnExpand = "items___selectFirstItemOnExpand",
    items___separatorLine = "items___separatorLine",
    items___sublabel = "items___sublabel",
    items___target = "items___target",
    items___type = "items___type",
    labels = "labels",
    name = "name",
    pages = "pages",
    pagesIds = "pagesIds",
    pagesLinks = "pagesLinks",
    pages___expanded = "pages___expanded",
    pages___group = "pages___group",
    pages___label = "pages___label",
    pages___menuStyle = "pages___menuStyle",
    pages___page = "pages___page",
    pages___pages = "pages___pages",
    pages___pages___expanded = "pages___pages___expanded",
    pages___pages___external = "pages___pages___external",
    pages___pages___group = "pages___pages___group",
    pages___pages___href = "pages___pages___href",
    pages___pages___label = "pages___pages___label",
    pages___pages___page = "pages___pages___page",
    pages___pages___pages = "pages___pages___pages",
    pages___pages___pages___expanded = "pages___pages___pages___expanded",
    pages___pages___pages___group = "pages___pages___pages___group",
    pages___pages___pages___label = "pages___pages___pages___label",
    pages___pages___pages___page = "pages___pages___pages___page",
    pages___pages___pages___pages = "pages___pages___pages___pages",
    pages___pages___separator = "pages___pages___separator",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id",
    permission = "permission"
}
export declare type SidebarFilterInput = {
    children?: InputMaybe<NodeFilterListInput>;
    context?: InputMaybe<StringQueryOperatorInput>;
    generationDate?: InputMaybe<FloatQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    items?: InputMaybe<NavItemFilterListInput>;
    labels?: InputMaybe<IntQueryOperatorInput>;
    name?: InputMaybe<StringQueryOperatorInput>;
    pages?: InputMaybe<SidebarPagesFilterListInput>;
    pagesIds?: InputMaybe<StringQueryOperatorInput>;
    pagesLinks?: InputMaybe<StringQueryOperatorInput>;
    parent?: InputMaybe<NodeFilterInput>;
    permission?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SidebarGroupConnection = {
    __typename?: 'SidebarGroupConnection';
    edges: Array<SidebarEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<Sidebar>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type SidebarPages = {
    __typename?: 'SidebarPages';
    expanded?: Maybe<Scalars['Boolean']>;
    group?: Maybe<Scalars['String']>;
    label?: Maybe<Scalars['String']>;
    menuStyle?: Maybe<Scalars['String']>;
    page?: Maybe<Scalars['String']>;
    pages?: Maybe<Array<Maybe<SidebarPagesPages>>>;
};
export declare type SidebarPagesFilterInput = {
    expanded?: InputMaybe<BooleanQueryOperatorInput>;
    group?: InputMaybe<StringQueryOperatorInput>;
    label?: InputMaybe<StringQueryOperatorInput>;
    menuStyle?: InputMaybe<StringQueryOperatorInput>;
    page?: InputMaybe<StringQueryOperatorInput>;
    pages?: InputMaybe<SidebarPagesPagesFilterListInput>;
};
export declare type SidebarPagesFilterListInput = {
    elemMatch?: InputMaybe<SidebarPagesFilterInput>;
};
export declare type SidebarPagesPages = {
    __typename?: 'SidebarPagesPages';
    expanded?: Maybe<Scalars['Boolean']>;
    external?: Maybe<Scalars['Boolean']>;
    group?: Maybe<Scalars['String']>;
    href?: Maybe<Scalars['String']>;
    label?: Maybe<Scalars['String']>;
    page?: Maybe<Scalars['String']>;
    pages?: Maybe<Array<Maybe<SidebarPagesPagesPages>>>;
    separator?: Maybe<Scalars['String']>;
};
export declare type SidebarPagesPagesFilterInput = {
    expanded?: InputMaybe<BooleanQueryOperatorInput>;
    external?: InputMaybe<BooleanQueryOperatorInput>;
    group?: InputMaybe<StringQueryOperatorInput>;
    href?: InputMaybe<StringQueryOperatorInput>;
    label?: InputMaybe<StringQueryOperatorInput>;
    page?: InputMaybe<StringQueryOperatorInput>;
    pages?: InputMaybe<SidebarPagesPagesPagesFilterListInput>;
    separator?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SidebarPagesPagesFilterListInput = {
    elemMatch?: InputMaybe<SidebarPagesPagesFilterInput>;
};
export declare type SidebarPagesPagesPages = {
    __typename?: 'SidebarPagesPagesPages';
    expanded?: Maybe<Scalars['Boolean']>;
    group?: Maybe<Scalars['String']>;
    label?: Maybe<Scalars['String']>;
    page?: Maybe<Scalars['String']>;
    pages?: Maybe<Array<Maybe<SidebarPagesPagesPagesPages>>>;
};
export declare type SidebarPagesPagesPagesFilterInput = {
    expanded?: InputMaybe<BooleanQueryOperatorInput>;
    group?: InputMaybe<StringQueryOperatorInput>;
    label?: InputMaybe<StringQueryOperatorInput>;
    page?: InputMaybe<StringQueryOperatorInput>;
    pages?: InputMaybe<SidebarPagesPagesPagesPagesFilterListInput>;
};
export declare type SidebarPagesPagesPagesFilterListInput = {
    elemMatch?: InputMaybe<SidebarPagesPagesPagesFilterInput>;
};
export declare type SidebarPagesPagesPagesPages = {
    __typename?: 'SidebarPagesPagesPagesPages';
    expanded?: Maybe<Scalars['Boolean']>;
    group?: Maybe<Scalars['String']>;
    label?: Maybe<Scalars['String']>;
    page?: Maybe<Scalars['String']>;
    pages?: Maybe<Array<Maybe<SidebarPagesPagesPagesPagesPages>>>;
};
export declare type SidebarPagesPagesPagesPagesFilterInput = {
    expanded?: InputMaybe<BooleanQueryOperatorInput>;
    group?: InputMaybe<StringQueryOperatorInput>;
    label?: InputMaybe<StringQueryOperatorInput>;
    page?: InputMaybe<StringQueryOperatorInput>;
    pages?: InputMaybe<SidebarPagesPagesPagesPagesPagesFilterListInput>;
};
export declare type SidebarPagesPagesPagesPagesFilterListInput = {
    elemMatch?: InputMaybe<SidebarPagesPagesPagesPagesFilterInput>;
};
export declare type SidebarPagesPagesPagesPagesPages = {
    __typename?: 'SidebarPagesPagesPagesPagesPages';
    expanded?: Maybe<Scalars['Boolean']>;
    group?: Maybe<Scalars['String']>;
    pages?: Maybe<Array<Maybe<SidebarPagesPagesPagesPagesPagesPages>>>;
};
export declare type SidebarPagesPagesPagesPagesPagesFilterInput = {
    expanded?: InputMaybe<BooleanQueryOperatorInput>;
    group?: InputMaybe<StringQueryOperatorInput>;
    pages?: InputMaybe<SidebarPagesPagesPagesPagesPagesPagesFilterListInput>;
};
export declare type SidebarPagesPagesPagesPagesPagesFilterListInput = {
    elemMatch?: InputMaybe<SidebarPagesPagesPagesPagesPagesFilterInput>;
};
export declare type SidebarPagesPagesPagesPagesPagesPages = {
    __typename?: 'SidebarPagesPagesPagesPagesPagesPages';
    expanded?: Maybe<Scalars['Boolean']>;
    group?: Maybe<Scalars['String']>;
    pages?: Maybe<Array<Maybe<SidebarPagesPagesPagesPagesPagesPagesPages>>>;
};
export declare type SidebarPagesPagesPagesPagesPagesPagesFilterInput = {
    expanded?: InputMaybe<BooleanQueryOperatorInput>;
    group?: InputMaybe<StringQueryOperatorInput>;
    pages?: InputMaybe<SidebarPagesPagesPagesPagesPagesPagesPagesFilterListInput>;
};
export declare type SidebarPagesPagesPagesPagesPagesPagesFilterListInput = {
    elemMatch?: InputMaybe<SidebarPagesPagesPagesPagesPagesPagesFilterInput>;
};
export declare type SidebarPagesPagesPagesPagesPagesPagesPages = {
    __typename?: 'SidebarPagesPagesPagesPagesPagesPagesPages';
    expanded?: Maybe<Scalars['Boolean']>;
    group?: Maybe<Scalars['String']>;
    pages?: Maybe<Array<Maybe<SidebarPagesPagesPagesPagesPagesPagesPagesPages>>>;
};
export declare type SidebarPagesPagesPagesPagesPagesPagesPagesFilterInput = {
    expanded?: InputMaybe<BooleanQueryOperatorInput>;
    group?: InputMaybe<StringQueryOperatorInput>;
    pages?: InputMaybe<SidebarPagesPagesPagesPagesPagesPagesPagesPagesFilterListInput>;
};
export declare type SidebarPagesPagesPagesPagesPagesPagesPagesFilterListInput = {
    elemMatch?: InputMaybe<SidebarPagesPagesPagesPagesPagesPagesPagesFilterInput>;
};
export declare type SidebarPagesPagesPagesPagesPagesPagesPagesPages = {
    __typename?: 'SidebarPagesPagesPagesPagesPagesPagesPagesPages';
    label?: Maybe<Scalars['String']>;
};
export declare type SidebarPagesPagesPagesPagesPagesPagesPagesPagesFilterInput = {
    label?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SidebarPagesPagesPagesPagesPagesPagesPagesPagesFilterListInput = {
    elemMatch?: InputMaybe<SidebarPagesPagesPagesPagesPagesPagesPagesPagesFilterInput>;
};
export declare type SidebarSortInput = {
    fields?: InputMaybe<Array<InputMaybe<SidebarFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare type Site = Node & {
    __typename?: 'Site';
    buildTime?: Maybe<Scalars['Date']>;
    children: Array<Node>;
    flags?: Maybe<SiteFlags>;
    host?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    internal: Internal;
    parent?: Maybe<Node>;
    pathPrefix?: Maybe<Scalars['String']>;
    polyfill?: Maybe<Scalars['Boolean']>;
    port?: Maybe<Scalars['Int']>;
    siteMetadata?: Maybe<SiteSiteMetadata>;
};
export declare type SiteBuildTimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type SiteBuildMetadata = Node & {
    __typename?: 'SiteBuildMetadata';
    buildTime?: Maybe<Scalars['Date']>;
    children: Array<Node>;
    id: Scalars['ID'];
    internal: Internal;
    parent?: Maybe<Node>;
};
export declare type SiteBuildMetadataBuildTimeArgs = {
    difference?: InputMaybe<Scalars['String']>;
    formatString?: InputMaybe<Scalars['String']>;
    fromNow?: InputMaybe<Scalars['Boolean']>;
    locale?: InputMaybe<Scalars['String']>;
};
export declare type SiteBuildMetadataConnection = {
    __typename?: 'SiteBuildMetadataConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<SiteBuildMetadataEdge>;
    group: Array<SiteBuildMetadataGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<SiteBuildMetadata>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type SiteBuildMetadataConnectionDistinctArgs = {
    field: SiteBuildMetadataFieldsEnum;
};
export declare type SiteBuildMetadataConnectionGroupArgs = {
    field: SiteBuildMetadataFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type SiteBuildMetadataConnectionMaxArgs = {
    field: SiteBuildMetadataFieldsEnum;
};
export declare type SiteBuildMetadataConnectionMinArgs = {
    field: SiteBuildMetadataFieldsEnum;
};
export declare type SiteBuildMetadataConnectionSumArgs = {
    field: SiteBuildMetadataFieldsEnum;
};
export declare type SiteBuildMetadataEdge = {
    __typename?: 'SiteBuildMetadataEdge';
    next?: Maybe<SiteBuildMetadata>;
    node: SiteBuildMetadata;
    previous?: Maybe<SiteBuildMetadata>;
};
export declare enum SiteBuildMetadataFieldsEnum {
    buildTime = "buildTime",
    children = "children",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    id = "id",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id"
}
export declare type SiteBuildMetadataFilterInput = {
    buildTime?: InputMaybe<DateQueryOperatorInput>;
    children?: InputMaybe<NodeFilterListInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
};
export declare type SiteBuildMetadataGroupConnection = {
    __typename?: 'SiteBuildMetadataGroupConnection';
    edges: Array<SiteBuildMetadataEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<SiteBuildMetadata>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type SiteBuildMetadataSortInput = {
    fields?: InputMaybe<Array<InputMaybe<SiteBuildMetadataFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare type SiteConfig = Node & {
    __typename?: 'SiteConfig';
    children: Array<Node>;
    contentDir: Scalars['String'];
    customLoginPagePath?: Maybe<Scalars['String']>;
    disableLastModified?: Maybe<Scalars['Boolean']>;
    editPage?: Maybe<EditPageConfig>;
    enableToc?: Maybe<Scalars['Boolean']>;
    footer?: Maybe<FooterConfig>;
    id: Scalars['ID'];
    internal: Internal;
    login?: Maybe<LoginSettings>;
    logo?: Maybe<LogoConfig>;
    mulesoftAnypoint?: Maybe<MulesoftAnypointConfig>;
    nav: Array<NavItem>;
    parent?: Maybe<Node>;
    redoclyOrgId?: Maybe<Scalars['String']>;
    scripts: Array<Scalars['String']>;
    seo?: Maybe<ContentItemSeo>;
    showNextButton: Scalars['Boolean'];
    showPrevButton: Scalars['Boolean'];
    siteVersion?: Maybe<Scalars['String']>;
    social?: Maybe<Social>;
    stylesheets: Array<Scalars['String']>;
    toc?: Maybe<TocInfo>;
    tocMaxDepth?: Maybe<Scalars['Int']>;
    withRbac?: Maybe<Scalars['Boolean']>;
};
export declare type SiteConfigNavArgs = {
    ignoreRBAC?: InputMaybe<Scalars['Boolean']>;
};
export declare type SiteConfigConnection = {
    __typename?: 'SiteConfigConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<SiteConfigEdge>;
    group: Array<SiteConfigGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<SiteConfig>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type SiteConfigConnectionDistinctArgs = {
    field: SiteConfigFieldsEnum;
};
export declare type SiteConfigConnectionGroupArgs = {
    field: SiteConfigFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type SiteConfigConnectionMaxArgs = {
    field: SiteConfigFieldsEnum;
};
export declare type SiteConfigConnectionMinArgs = {
    field: SiteConfigFieldsEnum;
};
export declare type SiteConfigConnectionSumArgs = {
    field: SiteConfigFieldsEnum;
};
export declare type SiteConfigEdge = {
    __typename?: 'SiteConfigEdge';
    next?: Maybe<SiteConfig>;
    node: SiteConfig;
    previous?: Maybe<SiteConfig>;
};
export declare enum SiteConfigFieldsEnum {
    children = "children",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    contentDir = "contentDir",
    customLoginPagePath = "customLoginPagePath",
    disableLastModified = "disableLastModified",
    editPage___baseUrl = "editPage___baseUrl",
    editPage___icon = "editPage___icon",
    editPage___text = "editPage___text",
    enableToc = "enableToc",
    footer___columns = "footer___columns",
    footer___columns___group = "footer___columns___group",
    footer___columns___items = "footer___columns___items",
    footer___columns___items___activateWithSidebar = "footer___columns___items___activateWithSidebar",
    footer___columns___items___apiVersionId = "footer___columns___items___apiVersionId",
    footer___columns___items___expanded = "footer___columns___items___expanded",
    footer___columns___items___external = "footer___columns___items___external",
    footer___columns___items___httpVerb = "footer___columns___items___httpVerb",
    footer___columns___items___icon = "footer___columns___items___icon",
    footer___columns___items___isDefaultApiVersion = "footer___columns___items___isDefaultApiVersion",
    footer___columns___items___items = "footer___columns___items___items",
    footer___columns___items___label = "footer___columns___items___label",
    footer___columns___items___link = "footer___columns___items___link",
    footer___columns___items___menuStyle = "footer___columns___items___menuStyle",
    footer___columns___items___pageId = "footer___columns___items___pageId",
    footer___columns___items___permission = "footer___columns___items___permission",
    footer___columns___items___redocFakePage = "footer___columns___items___redocFakePage",
    footer___columns___items___redocInfoPageId = "footer___columns___items___redocInfoPageId",
    footer___columns___items___redocNextLabel = "footer___columns___items___redocNextLabel",
    footer___columns___items___redocNextLink = "footer___columns___items___redocNextLink",
    footer___columns___items___redocPrevLabel = "footer___columns___items___redocPrevLabel",
    footer___columns___items___redocPrevLink = "footer___columns___items___redocPrevLink",
    footer___columns___items___selectFirstItemOnExpand = "footer___columns___items___selectFirstItemOnExpand",
    footer___columns___items___separatorLine = "footer___columns___items___separatorLine",
    footer___columns___items___sublabel = "footer___columns___items___sublabel",
    footer___columns___items___target = "footer___columns___items___target",
    footer___columns___items___type = "footer___columns___items___type",
    footer___columns___label = "footer___columns___label",
    footer___columns___permission = "footer___columns___permission",
    footer___copyrightText = "footer___copyrightText",
    footer___links = "footer___links",
    footer___links___activateWithSidebar = "footer___links___activateWithSidebar",
    footer___links___apiVersionId = "footer___links___apiVersionId",
    footer___links___expanded = "footer___links___expanded",
    footer___links___external = "footer___links___external",
    footer___links___httpVerb = "footer___links___httpVerb",
    footer___links___icon = "footer___links___icon",
    footer___links___isDefaultApiVersion = "footer___links___isDefaultApiVersion",
    footer___links___items = "footer___links___items",
    footer___links___items___activateWithSidebar = "footer___links___items___activateWithSidebar",
    footer___links___items___apiVersionId = "footer___links___items___apiVersionId",
    footer___links___items___expanded = "footer___links___items___expanded",
    footer___links___items___external = "footer___links___items___external",
    footer___links___items___httpVerb = "footer___links___items___httpVerb",
    footer___links___items___icon = "footer___links___items___icon",
    footer___links___items___isDefaultApiVersion = "footer___links___items___isDefaultApiVersion",
    footer___links___items___items = "footer___links___items___items",
    footer___links___items___label = "footer___links___items___label",
    footer___links___items___link = "footer___links___items___link",
    footer___links___items___menuStyle = "footer___links___items___menuStyle",
    footer___links___items___pageId = "footer___links___items___pageId",
    footer___links___items___permission = "footer___links___items___permission",
    footer___links___items___redocFakePage = "footer___links___items___redocFakePage",
    footer___links___items___redocInfoPageId = "footer___links___items___redocInfoPageId",
    footer___links___items___redocNextLabel = "footer___links___items___redocNextLabel",
    footer___links___items___redocNextLink = "footer___links___items___redocNextLink",
    footer___links___items___redocPrevLabel = "footer___links___items___redocPrevLabel",
    footer___links___items___redocPrevLink = "footer___links___items___redocPrevLink",
    footer___links___items___selectFirstItemOnExpand = "footer___links___items___selectFirstItemOnExpand",
    footer___links___items___separatorLine = "footer___links___items___separatorLine",
    footer___links___items___sublabel = "footer___links___items___sublabel",
    footer___links___items___target = "footer___links___items___target",
    footer___links___items___type = "footer___links___items___type",
    footer___links___label = "footer___links___label",
    footer___links___link = "footer___links___link",
    footer___links___menuStyle = "footer___links___menuStyle",
    footer___links___pageId = "footer___links___pageId",
    footer___links___permission = "footer___links___permission",
    footer___links___redocFakePage = "footer___links___redocFakePage",
    footer___links___redocInfoPageId = "footer___links___redocInfoPageId",
    footer___links___redocNextLabel = "footer___links___redocNextLabel",
    footer___links___redocNextLink = "footer___links___redocNextLink",
    footer___links___redocPrevLabel = "footer___links___redocPrevLabel",
    footer___links___redocPrevLink = "footer___links___redocPrevLink",
    footer___links___selectFirstItemOnExpand = "footer___links___selectFirstItemOnExpand",
    footer___links___separatorLine = "footer___links___separatorLine",
    footer___links___sublabel = "footer___links___sublabel",
    footer___links___target = "footer___links___target",
    footer___links___type = "footer___links___type",
    id = "id",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    login___label = "login___label",
    login___menu = "login___menu",
    login___menu___activateWithSidebar = "login___menu___activateWithSidebar",
    login___menu___apiVersionId = "login___menu___apiVersionId",
    login___menu___expanded = "login___menu___expanded",
    login___menu___external = "login___menu___external",
    login___menu___httpVerb = "login___menu___httpVerb",
    login___menu___icon = "login___menu___icon",
    login___menu___isDefaultApiVersion = "login___menu___isDefaultApiVersion",
    login___menu___items = "login___menu___items",
    login___menu___items___activateWithSidebar = "login___menu___items___activateWithSidebar",
    login___menu___items___apiVersionId = "login___menu___items___apiVersionId",
    login___menu___items___expanded = "login___menu___items___expanded",
    login___menu___items___external = "login___menu___items___external",
    login___menu___items___httpVerb = "login___menu___items___httpVerb",
    login___menu___items___icon = "login___menu___items___icon",
    login___menu___items___isDefaultApiVersion = "login___menu___items___isDefaultApiVersion",
    login___menu___items___items = "login___menu___items___items",
    login___menu___items___label = "login___menu___items___label",
    login___menu___items___link = "login___menu___items___link",
    login___menu___items___menuStyle = "login___menu___items___menuStyle",
    login___menu___items___pageId = "login___menu___items___pageId",
    login___menu___items___permission = "login___menu___items___permission",
    login___menu___items___redocFakePage = "login___menu___items___redocFakePage",
    login___menu___items___redocInfoPageId = "login___menu___items___redocInfoPageId",
    login___menu___items___redocNextLabel = "login___menu___items___redocNextLabel",
    login___menu___items___redocNextLink = "login___menu___items___redocNextLink",
    login___menu___items___redocPrevLabel = "login___menu___items___redocPrevLabel",
    login___menu___items___redocPrevLink = "login___menu___items___redocPrevLink",
    login___menu___items___selectFirstItemOnExpand = "login___menu___items___selectFirstItemOnExpand",
    login___menu___items___separatorLine = "login___menu___items___separatorLine",
    login___menu___items___sublabel = "login___menu___items___sublabel",
    login___menu___items___target = "login___menu___items___target",
    login___menu___items___type = "login___menu___items___type",
    login___menu___label = "login___menu___label",
    login___menu___link = "login___menu___link",
    login___menu___menuStyle = "login___menu___menuStyle",
    login___menu___pageId = "login___menu___pageId",
    login___menu___permission = "login___menu___permission",
    login___menu___redocFakePage = "login___menu___redocFakePage",
    login___menu___redocInfoPageId = "login___menu___redocInfoPageId",
    login___menu___redocNextLabel = "login___menu___redocNextLabel",
    login___menu___redocNextLink = "login___menu___redocNextLink",
    login___menu___redocPrevLabel = "login___menu___redocPrevLabel",
    login___menu___redocPrevLink = "login___menu___redocPrevLink",
    login___menu___selectFirstItemOnExpand = "login___menu___selectFirstItemOnExpand",
    login___menu___separatorLine = "login___menu___separatorLine",
    login___menu___sublabel = "login___menu___sublabel",
    login___menu___target = "login___menu___target",
    login___menu___type = "login___menu___type",
    login___userAvatar___claim = "login___userAvatar___claim",
    login___userAvatar___fallbackLettersClaim = "login___userAvatar___fallbackLettersClaim",
    login___userLabel___claim = "login___userLabel___claim",
    login___userLabel___fallback = "login___userLabel___fallback",
    logo___altText = "logo___altText",
    logo___href = "logo___href",
    logo___image = "logo___image",
    mulesoftAnypoint___appClientId = "mulesoftAnypoint___appClientId",
    mulesoftAnypoint___orgId = "mulesoftAnypoint___orgId",
    nav = "nav",
    nav___activateWithSidebar = "nav___activateWithSidebar",
    nav___apiVersionId = "nav___apiVersionId",
    nav___expanded = "nav___expanded",
    nav___external = "nav___external",
    nav___httpVerb = "nav___httpVerb",
    nav___icon = "nav___icon",
    nav___isDefaultApiVersion = "nav___isDefaultApiVersion",
    nav___items = "nav___items",
    nav___items___activateWithSidebar = "nav___items___activateWithSidebar",
    nav___items___apiVersionId = "nav___items___apiVersionId",
    nav___items___expanded = "nav___items___expanded",
    nav___items___external = "nav___items___external",
    nav___items___httpVerb = "nav___items___httpVerb",
    nav___items___icon = "nav___items___icon",
    nav___items___isDefaultApiVersion = "nav___items___isDefaultApiVersion",
    nav___items___items = "nav___items___items",
    nav___items___items___activateWithSidebar = "nav___items___items___activateWithSidebar",
    nav___items___items___apiVersionId = "nav___items___items___apiVersionId",
    nav___items___items___expanded = "nav___items___items___expanded",
    nav___items___items___external = "nav___items___items___external",
    nav___items___items___httpVerb = "nav___items___items___httpVerb",
    nav___items___items___icon = "nav___items___items___icon",
    nav___items___items___isDefaultApiVersion = "nav___items___items___isDefaultApiVersion",
    nav___items___items___items = "nav___items___items___items",
    nav___items___items___label = "nav___items___items___label",
    nav___items___items___link = "nav___items___items___link",
    nav___items___items___menuStyle = "nav___items___items___menuStyle",
    nav___items___items___pageId = "nav___items___items___pageId",
    nav___items___items___permission = "nav___items___items___permission",
    nav___items___items___redocFakePage = "nav___items___items___redocFakePage",
    nav___items___items___redocInfoPageId = "nav___items___items___redocInfoPageId",
    nav___items___items___redocNextLabel = "nav___items___items___redocNextLabel",
    nav___items___items___redocNextLink = "nav___items___items___redocNextLink",
    nav___items___items___redocPrevLabel = "nav___items___items___redocPrevLabel",
    nav___items___items___redocPrevLink = "nav___items___items___redocPrevLink",
    nav___items___items___selectFirstItemOnExpand = "nav___items___items___selectFirstItemOnExpand",
    nav___items___items___separatorLine = "nav___items___items___separatorLine",
    nav___items___items___sublabel = "nav___items___items___sublabel",
    nav___items___items___target = "nav___items___items___target",
    nav___items___items___type = "nav___items___items___type",
    nav___items___label = "nav___items___label",
    nav___items___link = "nav___items___link",
    nav___items___menuStyle = "nav___items___menuStyle",
    nav___items___pageId = "nav___items___pageId",
    nav___items___permission = "nav___items___permission",
    nav___items___redocFakePage = "nav___items___redocFakePage",
    nav___items___redocInfoPageId = "nav___items___redocInfoPageId",
    nav___items___redocNextLabel = "nav___items___redocNextLabel",
    nav___items___redocNextLink = "nav___items___redocNextLink",
    nav___items___redocPrevLabel = "nav___items___redocPrevLabel",
    nav___items___redocPrevLink = "nav___items___redocPrevLink",
    nav___items___selectFirstItemOnExpand = "nav___items___selectFirstItemOnExpand",
    nav___items___separatorLine = "nav___items___separatorLine",
    nav___items___sublabel = "nav___items___sublabel",
    nav___items___target = "nav___items___target",
    nav___items___type = "nav___items___type",
    nav___label = "nav___label",
    nav___link = "nav___link",
    nav___menuStyle = "nav___menuStyle",
    nav___pageId = "nav___pageId",
    nav___permission = "nav___permission",
    nav___redocFakePage = "nav___redocFakePage",
    nav___redocInfoPageId = "nav___redocInfoPageId",
    nav___redocNextLabel = "nav___redocNextLabel",
    nav___redocNextLink = "nav___redocNextLink",
    nav___redocPrevLabel = "nav___redocPrevLabel",
    nav___redocPrevLink = "nav___redocPrevLink",
    nav___selectFirstItemOnExpand = "nav___selectFirstItemOnExpand",
    nav___separatorLine = "nav___separatorLine",
    nav___sublabel = "nav___sublabel",
    nav___target = "nav___target",
    nav___type = "nav___type",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id",
    redoclyOrgId = "redoclyOrgId",
    scripts = "scripts",
    seo___children = "seo___children",
    seo___children___children = "seo___children___children",
    seo___children___children___children = "seo___children___children___children",
    seo___children___children___id = "seo___children___children___id",
    seo___children___id = "seo___children___id",
    seo___children___internal___content = "seo___children___internal___content",
    seo___children___internal___contentDigest = "seo___children___internal___contentDigest",
    seo___children___internal___description = "seo___children___internal___description",
    seo___children___internal___fieldOwners = "seo___children___internal___fieldOwners",
    seo___children___internal___ignoreType = "seo___children___internal___ignoreType",
    seo___children___internal___mediaType = "seo___children___internal___mediaType",
    seo___children___internal___owner = "seo___children___internal___owner",
    seo___children___internal___type = "seo___children___internal___type",
    seo___children___parent___children = "seo___children___parent___children",
    seo___children___parent___id = "seo___children___parent___id",
    seo___description = "seo___description",
    seo___id = "seo___id",
    seo___image = "seo___image",
    seo___internal___content = "seo___internal___content",
    seo___internal___contentDigest = "seo___internal___contentDigest",
    seo___internal___description = "seo___internal___description",
    seo___internal___fieldOwners = "seo___internal___fieldOwners",
    seo___internal___ignoreType = "seo___internal___ignoreType",
    seo___internal___mediaType = "seo___internal___mediaType",
    seo___internal___owner = "seo___internal___owner",
    seo___internal___type = "seo___internal___type",
    seo___jsonLd = "seo___jsonLd",
    seo___keywords = "seo___keywords",
    seo___lang = "seo___lang",
    seo___parent___children = "seo___parent___children",
    seo___parent___children___children = "seo___parent___children___children",
    seo___parent___children___id = "seo___parent___children___id",
    seo___parent___id = "seo___parent___id",
    seo___parent___internal___content = "seo___parent___internal___content",
    seo___parent___internal___contentDigest = "seo___parent___internal___contentDigest",
    seo___parent___internal___description = "seo___parent___internal___description",
    seo___parent___internal___fieldOwners = "seo___parent___internal___fieldOwners",
    seo___parent___internal___ignoreType = "seo___parent___internal___ignoreType",
    seo___parent___internal___mediaType = "seo___parent___internal___mediaType",
    seo___parent___internal___owner = "seo___parent___internal___owner",
    seo___parent___internal___type = "seo___parent___internal___type",
    seo___parent___parent___children = "seo___parent___parent___children",
    seo___parent___parent___id = "seo___parent___parent___id",
    seo___sitemap___changefreq = "seo___sitemap___changefreq",
    seo___sitemap___lastmod = "seo___sitemap___lastmod",
    seo___sitemap___priority = "seo___sitemap___priority",
    seo___title = "seo___title",
    showNextButton = "showNextButton",
    showPrevButton = "showPrevButton",
    siteVersion = "siteVersion",
    social___twitter = "social___twitter",
    stylesheets = "stylesheets",
    tocMaxDepth = "tocMaxDepth",
    toc___enable = "toc___enable",
    toc___headings = "toc___headings",
    toc___headings___depth = "toc___headings___depth",
    toc___headings___id = "toc___headings___id",
    toc___headings___value = "toc___headings___value",
    toc___maxDepth = "toc___maxDepth",
    withRbac = "withRbac"
}
export declare type SiteConfigFilterInput = {
    children?: InputMaybe<NodeFilterListInput>;
    contentDir?: InputMaybe<StringQueryOperatorInput>;
    customLoginPagePath?: InputMaybe<StringQueryOperatorInput>;
    disableLastModified?: InputMaybe<BooleanQueryOperatorInput>;
    editPage?: InputMaybe<EditPageConfigFilterInput>;
    enableToc?: InputMaybe<BooleanQueryOperatorInput>;
    footer?: InputMaybe<FooterConfigFilterInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    login?: InputMaybe<LoginSettingsFilterInput>;
    logo?: InputMaybe<LogoConfigFilterInput>;
    mulesoftAnypoint?: InputMaybe<MulesoftAnypointConfigFilterInput>;
    nav?: InputMaybe<NavItemFilterListInput>;
    parent?: InputMaybe<NodeFilterInput>;
    redoclyOrgId?: InputMaybe<StringQueryOperatorInput>;
    scripts?: InputMaybe<StringQueryOperatorInput>;
    seo?: InputMaybe<ContentItemSeoFilterInput>;
    showNextButton?: InputMaybe<BooleanQueryOperatorInput>;
    showPrevButton?: InputMaybe<BooleanQueryOperatorInput>;
    siteVersion?: InputMaybe<StringQueryOperatorInput>;
    social?: InputMaybe<SocialFilterInput>;
    stylesheets?: InputMaybe<StringQueryOperatorInput>;
    toc?: InputMaybe<TocInfoFilterInput>;
    tocMaxDepth?: InputMaybe<IntQueryOperatorInput>;
    withRbac?: InputMaybe<BooleanQueryOperatorInput>;
};
export declare type SiteConfigGroupConnection = {
    __typename?: 'SiteConfigGroupConnection';
    edges: Array<SiteConfigEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<SiteConfig>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type SiteConfigSortInput = {
    fields?: InputMaybe<Array<InputMaybe<SiteConfigFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare type SiteConnection = {
    __typename?: 'SiteConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<SiteEdge>;
    group: Array<SiteGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<Site>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type SiteConnectionDistinctArgs = {
    field: SiteFieldsEnum;
};
export declare type SiteConnectionGroupArgs = {
    field: SiteFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type SiteConnectionMaxArgs = {
    field: SiteFieldsEnum;
};
export declare type SiteConnectionMinArgs = {
    field: SiteFieldsEnum;
};
export declare type SiteConnectionSumArgs = {
    field: SiteFieldsEnum;
};
export declare type SiteEdge = {
    __typename?: 'SiteEdge';
    next?: Maybe<Site>;
    node: Site;
    previous?: Maybe<Site>;
};
export declare enum SiteFieldsEnum {
    buildTime = "buildTime",
    children = "children",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    flags___DEV_SSR = "flags___DEV_SSR",
    flags___FAST_DEV = "flags___FAST_DEV",
    flags___LAZY_IMAGES = "flags___LAZY_IMAGES",
    flags___PARALLEL_SOURCING = "flags___PARALLEL_SOURCING",
    flags___PRESERVE_FILE_DOWNLOAD_CACHE = "flags___PRESERVE_FILE_DOWNLOAD_CACHE",
    flags___PRESERVE_WEBPACK_CACHE = "flags___PRESERVE_WEBPACK_CACHE",
    host = "host",
    id = "id",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id",
    pathPrefix = "pathPrefix",
    polyfill = "polyfill",
    port = "port",
    siteMetadata___contentDir = "siteMetadata___contentDir",
    siteMetadata___description = "siteMetadata___description",
    siteMetadata___image = "siteMetadata___image",
    siteMetadata___keywords = "siteMetadata___keywords",
    siteMetadata___lang = "siteMetadata___lang",
    siteMetadata___logoAltText = "siteMetadata___logoAltText",
    siteMetadata___logoHref = "siteMetadata___logoHref",
    siteMetadata___siteUrl = "siteMetadata___siteUrl",
    siteMetadata___title = "siteMetadata___title"
}
export declare type SiteFilterInput = {
    buildTime?: InputMaybe<DateQueryOperatorInput>;
    children?: InputMaybe<NodeFilterListInput>;
    flags?: InputMaybe<SiteFlagsFilterInput>;
    host?: InputMaybe<StringQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
    pathPrefix?: InputMaybe<StringQueryOperatorInput>;
    polyfill?: InputMaybe<BooleanQueryOperatorInput>;
    port?: InputMaybe<IntQueryOperatorInput>;
    siteMetadata?: InputMaybe<SiteSiteMetadataFilterInput>;
};
export declare type SiteFlags = {
    __typename?: 'SiteFlags';
    DEV_SSR?: Maybe<Scalars['Boolean']>;
    FAST_DEV?: Maybe<Scalars['Boolean']>;
    LAZY_IMAGES?: Maybe<Scalars['Boolean']>;
    PARALLEL_SOURCING?: Maybe<Scalars['Boolean']>;
    PRESERVE_FILE_DOWNLOAD_CACHE?: Maybe<Scalars['Boolean']>;
    PRESERVE_WEBPACK_CACHE?: Maybe<Scalars['Boolean']>;
};
export declare type SiteFlagsFilterInput = {
    DEV_SSR?: InputMaybe<BooleanQueryOperatorInput>;
    FAST_DEV?: InputMaybe<BooleanQueryOperatorInput>;
    LAZY_IMAGES?: InputMaybe<BooleanQueryOperatorInput>;
    PARALLEL_SOURCING?: InputMaybe<BooleanQueryOperatorInput>;
    PRESERVE_FILE_DOWNLOAD_CACHE?: InputMaybe<BooleanQueryOperatorInput>;
    PRESERVE_WEBPACK_CACHE?: InputMaybe<BooleanQueryOperatorInput>;
};
export declare type SiteFunction = Node & {
    __typename?: 'SiteFunction';
    absoluteCompiledFilePath: Scalars['String'];
    children: Array<Node>;
    functionRoute: Scalars['String'];
    id: Scalars['ID'];
    internal: Internal;
    matchPath?: Maybe<Scalars['String']>;
    originalAbsoluteFilePath: Scalars['String'];
    originalRelativeFilePath: Scalars['String'];
    parent?: Maybe<Node>;
    pluginName: Scalars['String'];
    relativeCompiledFilePath: Scalars['String'];
};
export declare type SiteFunctionConnection = {
    __typename?: 'SiteFunctionConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<SiteFunctionEdge>;
    group: Array<SiteFunctionGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<SiteFunction>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type SiteFunctionConnectionDistinctArgs = {
    field: SiteFunctionFieldsEnum;
};
export declare type SiteFunctionConnectionGroupArgs = {
    field: SiteFunctionFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type SiteFunctionConnectionMaxArgs = {
    field: SiteFunctionFieldsEnum;
};
export declare type SiteFunctionConnectionMinArgs = {
    field: SiteFunctionFieldsEnum;
};
export declare type SiteFunctionConnectionSumArgs = {
    field: SiteFunctionFieldsEnum;
};
export declare type SiteFunctionEdge = {
    __typename?: 'SiteFunctionEdge';
    next?: Maybe<SiteFunction>;
    node: SiteFunction;
    previous?: Maybe<SiteFunction>;
};
export declare enum SiteFunctionFieldsEnum {
    absoluteCompiledFilePath = "absoluteCompiledFilePath",
    children = "children",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    functionRoute = "functionRoute",
    id = "id",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    matchPath = "matchPath",
    originalAbsoluteFilePath = "originalAbsoluteFilePath",
    originalRelativeFilePath = "originalRelativeFilePath",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id",
    pluginName = "pluginName",
    relativeCompiledFilePath = "relativeCompiledFilePath"
}
export declare type SiteFunctionFilterInput = {
    absoluteCompiledFilePath?: InputMaybe<StringQueryOperatorInput>;
    children?: InputMaybe<NodeFilterListInput>;
    functionRoute?: InputMaybe<StringQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    matchPath?: InputMaybe<StringQueryOperatorInput>;
    originalAbsoluteFilePath?: InputMaybe<StringQueryOperatorInput>;
    originalRelativeFilePath?: InputMaybe<StringQueryOperatorInput>;
    parent?: InputMaybe<NodeFilterInput>;
    pluginName?: InputMaybe<StringQueryOperatorInput>;
    relativeCompiledFilePath?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SiteFunctionGroupConnection = {
    __typename?: 'SiteFunctionGroupConnection';
    edges: Array<SiteFunctionEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<SiteFunction>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type SiteFunctionSortInput = {
    fields?: InputMaybe<Array<InputMaybe<SiteFunctionFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare type SiteGroupConnection = {
    __typename?: 'SiteGroupConnection';
    edges: Array<SiteEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<Site>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type SitePage = Node & {
    __typename?: 'SitePage';
    children: Array<Node>;
    component: Scalars['String'];
    componentChunkName: Scalars['String'];
    context?: Maybe<SitePageContext>;
    id: Scalars['ID'];
    internal: Internal;
    internalComponentName: Scalars['String'];
    isCreatedByStatefulCreatePages?: Maybe<Scalars['Boolean']>;
    matchPath?: Maybe<Scalars['String']>;
    parent?: Maybe<Node>;
    path: Scalars['String'];
    pluginCreator?: Maybe<SitePlugin>;
    pluginCreatorId?: Maybe<Scalars['String']>;
};
export declare type SitePageConnection = {
    __typename?: 'SitePageConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<SitePageEdge>;
    group: Array<SitePageGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<SitePage>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type SitePageConnectionDistinctArgs = {
    field: SitePageFieldsEnum;
};
export declare type SitePageConnectionGroupArgs = {
    field: SitePageFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type SitePageConnectionMaxArgs = {
    field: SitePageFieldsEnum;
};
export declare type SitePageConnectionMinArgs = {
    field: SitePageFieldsEnum;
};
export declare type SitePageConnectionSumArgs = {
    field: SitePageFieldsEnum;
};
export declare type SitePageContext = {
    __typename?: 'SitePageContext';
    apiVersionId?: Maybe<Scalars['String']>;
    apiVersions?: Maybe<Array<Maybe<SitePageContextApiVersions>>>;
    data?: Maybe<SitePageContextData>;
    id?: Maybe<Scalars['String']>;
    isDefaultApiVersion?: Maybe<Scalars['Boolean']>;
    isLanding?: Maybe<Scalars['Boolean']>;
    link?: Maybe<Scalars['String']>;
    pageBaseUrl?: Maybe<Scalars['String']>;
    pageId?: Maybe<Scalars['String']>;
    seo?: Maybe<SitePageContextSeo>;
    sidebarName?: Maybe<Scalars['String']>;
    toc?: Maybe<SitePageContextToc>;
    type?: Maybe<Scalars['String']>;
};
export declare type SitePageContextApiVersions = {
    __typename?: 'SitePageContextApiVersions';
    definitionId?: Maybe<Scalars['String']>;
    id?: Maybe<Scalars['String']>;
    isDefault?: Maybe<Scalars['Boolean']>;
    title?: Maybe<Scalars['String']>;
};
export declare type SitePageContextApiVersionsFilterInput = {
    definitionId?: InputMaybe<StringQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    isDefault?: InputMaybe<BooleanQueryOperatorInput>;
    title?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePageContextApiVersionsFilterListInput = {
    elemMatch?: InputMaybe<SitePageContextApiVersionsFilterInput>;
};
export declare type SitePageContextData = {
    __typename?: 'SitePageContextData';
    description?: Maybe<Scalars['String']>;
    editPage?: Maybe<SitePageContextDataEditPage>;
    foobar?: Maybe<Scalars['String']>;
    imageLink?: Maybe<Scalars['String']>;
    original_imageLink?: Maybe<Scalars['String']>;
    original_pageLink?: Maybe<Scalars['String']>;
    original_staticImageLink?: Maybe<Scalars['String']>;
    pageLink?: Maybe<Scalars['String']>;
    redirectFrom?: Maybe<Array<Maybe<Scalars['String']>>>;
    seo?: Maybe<SitePageContextDataSeo>;
    sidebar?: Maybe<Scalars['String']>;
    staticImageLink?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    toc?: Maybe<SitePageContextDataToc>;
};
export declare type SitePageContextDataEditPage = {
    __typename?: 'SitePageContextDataEditPage';
    disable?: Maybe<Scalars['Boolean']>;
};
export declare type SitePageContextDataEditPageFilterInput = {
    disable?: InputMaybe<BooleanQueryOperatorInput>;
};
export declare type SitePageContextDataFilterInput = {
    description?: InputMaybe<StringQueryOperatorInput>;
    editPage?: InputMaybe<SitePageContextDataEditPageFilterInput>;
    foobar?: InputMaybe<StringQueryOperatorInput>;
    imageLink?: InputMaybe<StringQueryOperatorInput>;
    original_imageLink?: InputMaybe<StringQueryOperatorInput>;
    original_pageLink?: InputMaybe<StringQueryOperatorInput>;
    original_staticImageLink?: InputMaybe<StringQueryOperatorInput>;
    pageLink?: InputMaybe<StringQueryOperatorInput>;
    redirectFrom?: InputMaybe<StringQueryOperatorInput>;
    seo?: InputMaybe<SitePageContextDataSeoFilterInput>;
    sidebar?: InputMaybe<StringQueryOperatorInput>;
    staticImageLink?: InputMaybe<StringQueryOperatorInput>;
    title?: InputMaybe<StringQueryOperatorInput>;
    toc?: InputMaybe<SitePageContextDataTocFilterInput>;
};
export declare type SitePageContextDataSeo = {
    __typename?: 'SitePageContextDataSeo';
    description?: Maybe<Scalars['String']>;
    image?: Maybe<Scalars['String']>;
    keywords?: Maybe<Scalars['String']>;
    lang?: Maybe<Scalars['String']>;
    original_image?: Maybe<Scalars['String']>;
    sitemap?: Maybe<SitePageContextDataSeoSitemap>;
    title?: Maybe<Scalars['String']>;
};
export declare type SitePageContextDataSeoFilterInput = {
    description?: InputMaybe<StringQueryOperatorInput>;
    image?: InputMaybe<StringQueryOperatorInput>;
    keywords?: InputMaybe<StringQueryOperatorInput>;
    lang?: InputMaybe<StringQueryOperatorInput>;
    original_image?: InputMaybe<StringQueryOperatorInput>;
    sitemap?: InputMaybe<SitePageContextDataSeoSitemapFilterInput>;
    title?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePageContextDataSeoSitemap = {
    __typename?: 'SitePageContextDataSeoSitemap';
    changefreq?: Maybe<Scalars['String']>;
    lastmod?: Maybe<Scalars['Date']>;
    priority?: Maybe<Scalars['Float']>;
};
export declare type SitePageContextDataSeoSitemapFilterInput = {
    changefreq?: InputMaybe<StringQueryOperatorInput>;
    lastmod?: InputMaybe<DateQueryOperatorInput>;
    priority?: InputMaybe<FloatQueryOperatorInput>;
};
export declare type SitePageContextDataToc = {
    __typename?: 'SitePageContextDataToc';
    enable?: Maybe<Scalars['Boolean']>;
};
export declare type SitePageContextDataTocFilterInput = {
    enable?: InputMaybe<BooleanQueryOperatorInput>;
};
export declare type SitePageContextFilterInput = {
    apiVersionId?: InputMaybe<StringQueryOperatorInput>;
    apiVersions?: InputMaybe<SitePageContextApiVersionsFilterListInput>;
    data?: InputMaybe<SitePageContextDataFilterInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    isDefaultApiVersion?: InputMaybe<BooleanQueryOperatorInput>;
    isLanding?: InputMaybe<BooleanQueryOperatorInput>;
    link?: InputMaybe<StringQueryOperatorInput>;
    pageBaseUrl?: InputMaybe<StringQueryOperatorInput>;
    pageId?: InputMaybe<StringQueryOperatorInput>;
    seo?: InputMaybe<SitePageContextSeoFilterInput>;
    sidebarName?: InputMaybe<StringQueryOperatorInput>;
    toc?: InputMaybe<SitePageContextTocFilterInput>;
    type?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePageContextSeo = {
    __typename?: 'SitePageContextSeo';
    description?: Maybe<Scalars['String']>;
    image?: Maybe<Scalars['String']>;
    keywords?: Maybe<Scalars['String']>;
    lang?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
};
export declare type SitePageContextSeoFilterInput = {
    description?: InputMaybe<StringQueryOperatorInput>;
    image?: InputMaybe<StringQueryOperatorInput>;
    keywords?: InputMaybe<StringQueryOperatorInput>;
    lang?: InputMaybe<StringQueryOperatorInput>;
    title?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePageContextToc = {
    __typename?: 'SitePageContextToc';
    enable?: Maybe<Scalars['Boolean']>;
    headings?: Maybe<Array<Maybe<SitePageContextTocHeadings>>>;
    maxDepth?: Maybe<Scalars['Int']>;
};
export declare type SitePageContextTocFilterInput = {
    enable?: InputMaybe<BooleanQueryOperatorInput>;
    headings?: InputMaybe<SitePageContextTocHeadingsFilterListInput>;
    maxDepth?: InputMaybe<IntQueryOperatorInput>;
};
export declare type SitePageContextTocHeadings = {
    __typename?: 'SitePageContextTocHeadings';
    depth?: Maybe<Scalars['Int']>;
    id?: Maybe<Scalars['String']>;
    value?: Maybe<Scalars['String']>;
};
export declare type SitePageContextTocHeadingsFilterInput = {
    depth?: InputMaybe<IntQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    value?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePageContextTocHeadingsFilterListInput = {
    elemMatch?: InputMaybe<SitePageContextTocHeadingsFilterInput>;
};
export declare type SitePageEdge = {
    __typename?: 'SitePageEdge';
    next?: Maybe<SitePage>;
    node: SitePage;
    previous?: Maybe<SitePage>;
};
export declare enum SitePageFieldsEnum {
    children = "children",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    component = "component",
    componentChunkName = "componentChunkName",
    context___apiVersionId = "context___apiVersionId",
    context___apiVersions = "context___apiVersions",
    context___apiVersions___definitionId = "context___apiVersions___definitionId",
    context___apiVersions___id = "context___apiVersions___id",
    context___apiVersions___isDefault = "context___apiVersions___isDefault",
    context___apiVersions___title = "context___apiVersions___title",
    context___data___description = "context___data___description",
    context___data___editPage___disable = "context___data___editPage___disable",
    context___data___foobar = "context___data___foobar",
    context___data___imageLink = "context___data___imageLink",
    context___data___original_imageLink = "context___data___original_imageLink",
    context___data___original_pageLink = "context___data___original_pageLink",
    context___data___original_staticImageLink = "context___data___original_staticImageLink",
    context___data___pageLink = "context___data___pageLink",
    context___data___redirectFrom = "context___data___redirectFrom",
    context___data___seo___description = "context___data___seo___description",
    context___data___seo___image = "context___data___seo___image",
    context___data___seo___keywords = "context___data___seo___keywords",
    context___data___seo___lang = "context___data___seo___lang",
    context___data___seo___original_image = "context___data___seo___original_image",
    context___data___seo___title = "context___data___seo___title",
    context___data___sidebar = "context___data___sidebar",
    context___data___staticImageLink = "context___data___staticImageLink",
    context___data___title = "context___data___title",
    context___data___toc___enable = "context___data___toc___enable",
    context___id = "context___id",
    context___isDefaultApiVersion = "context___isDefaultApiVersion",
    context___isLanding = "context___isLanding",
    context___link = "context___link",
    context___pageBaseUrl = "context___pageBaseUrl",
    context___pageId = "context___pageId",
    context___seo___description = "context___seo___description",
    context___seo___image = "context___seo___image",
    context___seo___keywords = "context___seo___keywords",
    context___seo___lang = "context___seo___lang",
    context___seo___title = "context___seo___title",
    context___sidebarName = "context___sidebarName",
    context___toc___enable = "context___toc___enable",
    context___toc___headings = "context___toc___headings",
    context___toc___headings___depth = "context___toc___headings___depth",
    context___toc___headings___id = "context___toc___headings___id",
    context___toc___headings___value = "context___toc___headings___value",
    context___toc___maxDepth = "context___toc___maxDepth",
    context___type = "context___type",
    id = "id",
    internalComponentName = "internalComponentName",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    isCreatedByStatefulCreatePages = "isCreatedByStatefulCreatePages",
    matchPath = "matchPath",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id",
    path = "path",
    pluginCreatorId = "pluginCreatorId",
    pluginCreator___browserAPIs = "pluginCreator___browserAPIs",
    pluginCreator___children = "pluginCreator___children",
    pluginCreator___children___children = "pluginCreator___children___children",
    pluginCreator___children___children___children = "pluginCreator___children___children___children",
    pluginCreator___children___children___id = "pluginCreator___children___children___id",
    pluginCreator___children___id = "pluginCreator___children___id",
    pluginCreator___children___internal___content = "pluginCreator___children___internal___content",
    pluginCreator___children___internal___contentDigest = "pluginCreator___children___internal___contentDigest",
    pluginCreator___children___internal___description = "pluginCreator___children___internal___description",
    pluginCreator___children___internal___fieldOwners = "pluginCreator___children___internal___fieldOwners",
    pluginCreator___children___internal___ignoreType = "pluginCreator___children___internal___ignoreType",
    pluginCreator___children___internal___mediaType = "pluginCreator___children___internal___mediaType",
    pluginCreator___children___internal___owner = "pluginCreator___children___internal___owner",
    pluginCreator___children___internal___type = "pluginCreator___children___internal___type",
    pluginCreator___children___parent___children = "pluginCreator___children___parent___children",
    pluginCreator___children___parent___id = "pluginCreator___children___parent___id",
    pluginCreator___id = "pluginCreator___id",
    pluginCreator___internal___content = "pluginCreator___internal___content",
    pluginCreator___internal___contentDigest = "pluginCreator___internal___contentDigest",
    pluginCreator___internal___description = "pluginCreator___internal___description",
    pluginCreator___internal___fieldOwners = "pluginCreator___internal___fieldOwners",
    pluginCreator___internal___ignoreType = "pluginCreator___internal___ignoreType",
    pluginCreator___internal___mediaType = "pluginCreator___internal___mediaType",
    pluginCreator___internal___owner = "pluginCreator___internal___owner",
    pluginCreator___internal___type = "pluginCreator___internal___type",
    pluginCreator___name = "pluginCreator___name",
    pluginCreator___nodeAPIs = "pluginCreator___nodeAPIs",
    pluginCreator___packageJson___author = "pluginCreator___packageJson___author",
    pluginCreator___packageJson___dependencies = "pluginCreator___packageJson___dependencies",
    pluginCreator___packageJson___dependencies___name = "pluginCreator___packageJson___dependencies___name",
    pluginCreator___packageJson___dependencies___version = "pluginCreator___packageJson___dependencies___version",
    pluginCreator___packageJson___description = "pluginCreator___packageJson___description",
    pluginCreator___packageJson___devDependencies = "pluginCreator___packageJson___devDependencies",
    pluginCreator___packageJson___devDependencies___name = "pluginCreator___packageJson___devDependencies___name",
    pluginCreator___packageJson___devDependencies___version = "pluginCreator___packageJson___devDependencies___version",
    pluginCreator___packageJson___keywords = "pluginCreator___packageJson___keywords",
    pluginCreator___packageJson___license = "pluginCreator___packageJson___license",
    pluginCreator___packageJson___main = "pluginCreator___packageJson___main",
    pluginCreator___packageJson___name = "pluginCreator___packageJson___name",
    pluginCreator___packageJson___peerDependencies = "pluginCreator___packageJson___peerDependencies",
    pluginCreator___packageJson___peerDependencies___name = "pluginCreator___packageJson___peerDependencies___name",
    pluginCreator___packageJson___peerDependencies___version = "pluginCreator___packageJson___peerDependencies___version",
    pluginCreator___packageJson___version = "pluginCreator___packageJson___version",
    pluginCreator___parent___children = "pluginCreator___parent___children",
    pluginCreator___parent___children___children = "pluginCreator___parent___children___children",
    pluginCreator___parent___children___id = "pluginCreator___parent___children___id",
    pluginCreator___parent___id = "pluginCreator___parent___id",
    pluginCreator___parent___internal___content = "pluginCreator___parent___internal___content",
    pluginCreator___parent___internal___contentDigest = "pluginCreator___parent___internal___contentDigest",
    pluginCreator___parent___internal___description = "pluginCreator___parent___internal___description",
    pluginCreator___parent___internal___fieldOwners = "pluginCreator___parent___internal___fieldOwners",
    pluginCreator___parent___internal___ignoreType = "pluginCreator___parent___internal___ignoreType",
    pluginCreator___parent___internal___mediaType = "pluginCreator___parent___internal___mediaType",
    pluginCreator___parent___internal___owner = "pluginCreator___parent___internal___owner",
    pluginCreator___parent___internal___type = "pluginCreator___parent___internal___type",
    pluginCreator___parent___parent___children = "pluginCreator___parent___parent___children",
    pluginCreator___parent___parent___id = "pluginCreator___parent___parent___id",
    pluginCreator___pluginFilepath = "pluginCreator___pluginFilepath",
    pluginCreator___pluginOptions___allExtensions = "pluginCreator___pluginOptions___allExtensions",
    pluginCreator___pluginOptions___buttonText = "pluginCreator___pluginOptions___buttonText",
    pluginCreator___pluginOptions___cache_busting_mode = "pluginCreator___pluginOptions___cache_busting_mode",
    pluginCreator___pluginOptions___configPath = "pluginCreator___pluginOptions___configPath",
    pluginCreator___pluginOptions___createLinkInHead = "pluginCreator___pluginOptions___createLinkInHead",
    pluginCreator___pluginOptions___crossOrigin = "pluginCreator___pluginOptions___crossOrigin",
    pluginCreator___pluginOptions___displayName = "pluginCreator___pluginOptions___displayName",
    pluginCreator___pluginOptions___enable = "pluginCreator___pluginOptions___enable",
    pluginCreator___pluginOptions___entryLimit = "pluginCreator___pluginOptions___entryLimit",
    pluginCreator___pluginOptions___excludePattern = "pluginCreator___pluginOptions___excludePattern",
    pluginCreator___pluginOptions___fileName = "pluginCreator___pluginOptions___fileName",
    pluginCreator___pluginOptions___icons = "pluginCreator___pluginOptions___icons",
    pluginCreator___pluginOptions___icons___sizes = "pluginCreator___pluginOptions___icons___sizes",
    pluginCreator___pluginOptions___icons___src = "pluginCreator___pluginOptions___icons___src",
    pluginCreator___pluginOptions___icons___type = "pluginCreator___pluginOptions___icons___type",
    pluginCreator___pluginOptions___include_favicon = "pluginCreator___pluginOptions___include_favicon",
    pluginCreator___pluginOptions___isTSX = "pluginCreator___pluginOptions___isTSX",
    pluginCreator___pluginOptions___jsxPragma = "pluginCreator___pluginOptions___jsxPragma",
    pluginCreator___pluginOptions___legacy = "pluginCreator___pluginOptions___legacy",
    pluginCreator___pluginOptions___minify = "pluginCreator___pluginOptions___minify",
    pluginCreator___pluginOptions___name = "pluginCreator___pluginOptions___name",
    pluginCreator___pluginOptions___namespace = "pluginCreator___pluginOptions___namespace",
    pluginCreator___pluginOptions___offsetY___element = "pluginCreator___pluginOptions___offsetY___element",
    pluginCreator___pluginOptions___output = "pluginCreator___pluginOptions___output",
    pluginCreator___pluginOptions___path = "pluginCreator___pluginOptions___path",
    pluginCreator___pluginOptions___pathCheck = "pluginCreator___pluginOptions___pathCheck",
    pluginCreator___pluginOptions___plugins = "pluginCreator___pluginOptions___plugins",
    pluginCreator___pluginOptions___plugins___browserAPIs = "pluginCreator___pluginOptions___plugins___browserAPIs",
    pluginCreator___pluginOptions___plugins___id = "pluginCreator___pluginOptions___plugins___id",
    pluginCreator___pluginOptions___plugins___name = "pluginCreator___pluginOptions___plugins___name",
    pluginCreator___pluginOptions___plugins___nodeAPIs = "pluginCreator___pluginOptions___plugins___nodeAPIs",
    pluginCreator___pluginOptions___plugins___pluginFilepath = "pluginCreator___pluginOptions___plugins___pluginFilepath",
    pluginCreator___pluginOptions___plugins___resolve = "pluginCreator___pluginOptions___plugins___resolve",
    pluginCreator___pluginOptions___plugins___ssrAPIs = "pluginCreator___pluginOptions___plugins___ssrAPIs",
    pluginCreator___pluginOptions___plugins___version = "pluginCreator___pluginOptions___plugins___version",
    pluginCreator___pluginOptions___publicDir = "pluginCreator___pluginOptions___publicDir",
    pluginCreator___pluginOptions___pure = "pluginCreator___pluginOptions___pure",
    pluginCreator___pluginOptions___query = "pluginCreator___pluginOptions___query",
    pluginCreator___pluginOptions___siteUrl = "pluginCreator___pluginOptions___siteUrl",
    pluginCreator___pluginOptions___stripHash = "pluginCreator___pluginOptions___stripHash",
    pluginCreator___pluginOptions___theme_color_in_head = "pluginCreator___pluginOptions___theme_color_in_head",
    pluginCreator___pluginOptions___toasterDuration = "pluginCreator___pluginOptions___toasterDuration",
    pluginCreator___pluginOptions___toasterText = "pluginCreator___pluginOptions___toasterText",
    pluginCreator___pluginOptions___tooltipText = "pluginCreator___pluginOptions___tooltipText",
    pluginCreator___pluginOptions___transpileTemplateLiterals = "pluginCreator___pluginOptions___transpileTemplateLiterals",
    pluginCreator___resolve = "pluginCreator___resolve",
    pluginCreator___ssrAPIs = "pluginCreator___ssrAPIs",
    pluginCreator___version = "pluginCreator___version"
}
export declare type SitePageFilterInput = {
    children?: InputMaybe<NodeFilterListInput>;
    component?: InputMaybe<StringQueryOperatorInput>;
    componentChunkName?: InputMaybe<StringQueryOperatorInput>;
    context?: InputMaybe<SitePageContextFilterInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    internalComponentName?: InputMaybe<StringQueryOperatorInput>;
    isCreatedByStatefulCreatePages?: InputMaybe<BooleanQueryOperatorInput>;
    matchPath?: InputMaybe<StringQueryOperatorInput>;
    parent?: InputMaybe<NodeFilterInput>;
    path?: InputMaybe<StringQueryOperatorInput>;
    pluginCreator?: InputMaybe<SitePluginFilterInput>;
    pluginCreatorId?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePageGroupConnection = {
    __typename?: 'SitePageGroupConnection';
    edges: Array<SitePageEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<SitePage>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type SitePageSortInput = {
    fields?: InputMaybe<Array<InputMaybe<SitePageFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare type SitePlugin = Node & {
    __typename?: 'SitePlugin';
    browserAPIs?: Maybe<Array<Maybe<Scalars['String']>>>;
    children: Array<Node>;
    id: Scalars['ID'];
    internal: Internal;
    name?: Maybe<Scalars['String']>;
    nodeAPIs?: Maybe<Array<Maybe<Scalars['String']>>>;
    packageJson?: Maybe<SitePluginPackageJson>;
    parent?: Maybe<Node>;
    pluginFilepath?: Maybe<Scalars['String']>;
    pluginOptions?: Maybe<SitePluginPluginOptions>;
    resolve?: Maybe<Scalars['String']>;
    ssrAPIs?: Maybe<Array<Maybe<Scalars['String']>>>;
    version?: Maybe<Scalars['String']>;
};
export declare type SitePluginConnection = {
    __typename?: 'SitePluginConnection';
    distinct: Array<Scalars['String']>;
    edges: Array<SitePluginEdge>;
    group: Array<SitePluginGroupConnection>;
    max?: Maybe<Scalars['Float']>;
    min?: Maybe<Scalars['Float']>;
    nodes: Array<SitePlugin>;
    pageInfo: PageInfo;
    sum?: Maybe<Scalars['Float']>;
    totalCount: Scalars['Int'];
};
export declare type SitePluginConnectionDistinctArgs = {
    field: SitePluginFieldsEnum;
};
export declare type SitePluginConnectionGroupArgs = {
    field: SitePluginFieldsEnum;
    limit?: InputMaybe<Scalars['Int']>;
    skip?: InputMaybe<Scalars['Int']>;
};
export declare type SitePluginConnectionMaxArgs = {
    field: SitePluginFieldsEnum;
};
export declare type SitePluginConnectionMinArgs = {
    field: SitePluginFieldsEnum;
};
export declare type SitePluginConnectionSumArgs = {
    field: SitePluginFieldsEnum;
};
export declare type SitePluginEdge = {
    __typename?: 'SitePluginEdge';
    next?: Maybe<SitePlugin>;
    node: SitePlugin;
    previous?: Maybe<SitePlugin>;
};
export declare enum SitePluginFieldsEnum {
    browserAPIs = "browserAPIs",
    children = "children",
    children___children = "children___children",
    children___children___children = "children___children___children",
    children___children___children___children = "children___children___children___children",
    children___children___children___id = "children___children___children___id",
    children___children___id = "children___children___id",
    children___children___internal___content = "children___children___internal___content",
    children___children___internal___contentDigest = "children___children___internal___contentDigest",
    children___children___internal___description = "children___children___internal___description",
    children___children___internal___fieldOwners = "children___children___internal___fieldOwners",
    children___children___internal___ignoreType = "children___children___internal___ignoreType",
    children___children___internal___mediaType = "children___children___internal___mediaType",
    children___children___internal___owner = "children___children___internal___owner",
    children___children___internal___type = "children___children___internal___type",
    children___children___parent___children = "children___children___parent___children",
    children___children___parent___id = "children___children___parent___id",
    children___id = "children___id",
    children___internal___content = "children___internal___content",
    children___internal___contentDigest = "children___internal___contentDigest",
    children___internal___description = "children___internal___description",
    children___internal___fieldOwners = "children___internal___fieldOwners",
    children___internal___ignoreType = "children___internal___ignoreType",
    children___internal___mediaType = "children___internal___mediaType",
    children___internal___owner = "children___internal___owner",
    children___internal___type = "children___internal___type",
    children___parent___children = "children___parent___children",
    children___parent___children___children = "children___parent___children___children",
    children___parent___children___id = "children___parent___children___id",
    children___parent___id = "children___parent___id",
    children___parent___internal___content = "children___parent___internal___content",
    children___parent___internal___contentDigest = "children___parent___internal___contentDigest",
    children___parent___internal___description = "children___parent___internal___description",
    children___parent___internal___fieldOwners = "children___parent___internal___fieldOwners",
    children___parent___internal___ignoreType = "children___parent___internal___ignoreType",
    children___parent___internal___mediaType = "children___parent___internal___mediaType",
    children___parent___internal___owner = "children___parent___internal___owner",
    children___parent___internal___type = "children___parent___internal___type",
    children___parent___parent___children = "children___parent___parent___children",
    children___parent___parent___id = "children___parent___parent___id",
    id = "id",
    internal___content = "internal___content",
    internal___contentDigest = "internal___contentDigest",
    internal___description = "internal___description",
    internal___fieldOwners = "internal___fieldOwners",
    internal___ignoreType = "internal___ignoreType",
    internal___mediaType = "internal___mediaType",
    internal___owner = "internal___owner",
    internal___type = "internal___type",
    name = "name",
    nodeAPIs = "nodeAPIs",
    packageJson___author = "packageJson___author",
    packageJson___dependencies = "packageJson___dependencies",
    packageJson___dependencies___name = "packageJson___dependencies___name",
    packageJson___dependencies___version = "packageJson___dependencies___version",
    packageJson___description = "packageJson___description",
    packageJson___devDependencies = "packageJson___devDependencies",
    packageJson___devDependencies___name = "packageJson___devDependencies___name",
    packageJson___devDependencies___version = "packageJson___devDependencies___version",
    packageJson___keywords = "packageJson___keywords",
    packageJson___license = "packageJson___license",
    packageJson___main = "packageJson___main",
    packageJson___name = "packageJson___name",
    packageJson___peerDependencies = "packageJson___peerDependencies",
    packageJson___peerDependencies___name = "packageJson___peerDependencies___name",
    packageJson___peerDependencies___version = "packageJson___peerDependencies___version",
    packageJson___version = "packageJson___version",
    parent___children = "parent___children",
    parent___children___children = "parent___children___children",
    parent___children___children___children = "parent___children___children___children",
    parent___children___children___id = "parent___children___children___id",
    parent___children___id = "parent___children___id",
    parent___children___internal___content = "parent___children___internal___content",
    parent___children___internal___contentDigest = "parent___children___internal___contentDigest",
    parent___children___internal___description = "parent___children___internal___description",
    parent___children___internal___fieldOwners = "parent___children___internal___fieldOwners",
    parent___children___internal___ignoreType = "parent___children___internal___ignoreType",
    parent___children___internal___mediaType = "parent___children___internal___mediaType",
    parent___children___internal___owner = "parent___children___internal___owner",
    parent___children___internal___type = "parent___children___internal___type",
    parent___children___parent___children = "parent___children___parent___children",
    parent___children___parent___id = "parent___children___parent___id",
    parent___id = "parent___id",
    parent___internal___content = "parent___internal___content",
    parent___internal___contentDigest = "parent___internal___contentDigest",
    parent___internal___description = "parent___internal___description",
    parent___internal___fieldOwners = "parent___internal___fieldOwners",
    parent___internal___ignoreType = "parent___internal___ignoreType",
    parent___internal___mediaType = "parent___internal___mediaType",
    parent___internal___owner = "parent___internal___owner",
    parent___internal___type = "parent___internal___type",
    parent___parent___children = "parent___parent___children",
    parent___parent___children___children = "parent___parent___children___children",
    parent___parent___children___id = "parent___parent___children___id",
    parent___parent___id = "parent___parent___id",
    parent___parent___internal___content = "parent___parent___internal___content",
    parent___parent___internal___contentDigest = "parent___parent___internal___contentDigest",
    parent___parent___internal___description = "parent___parent___internal___description",
    parent___parent___internal___fieldOwners = "parent___parent___internal___fieldOwners",
    parent___parent___internal___ignoreType = "parent___parent___internal___ignoreType",
    parent___parent___internal___mediaType = "parent___parent___internal___mediaType",
    parent___parent___internal___owner = "parent___parent___internal___owner",
    parent___parent___internal___type = "parent___parent___internal___type",
    parent___parent___parent___children = "parent___parent___parent___children",
    parent___parent___parent___id = "parent___parent___parent___id",
    pluginFilepath = "pluginFilepath",
    pluginOptions___allExtensions = "pluginOptions___allExtensions",
    pluginOptions___buttonText = "pluginOptions___buttonText",
    pluginOptions___cache_busting_mode = "pluginOptions___cache_busting_mode",
    pluginOptions___configPath = "pluginOptions___configPath",
    pluginOptions___createLinkInHead = "pluginOptions___createLinkInHead",
    pluginOptions___crossOrigin = "pluginOptions___crossOrigin",
    pluginOptions___displayName = "pluginOptions___displayName",
    pluginOptions___enable = "pluginOptions___enable",
    pluginOptions___entryLimit = "pluginOptions___entryLimit",
    pluginOptions___excludePattern = "pluginOptions___excludePattern",
    pluginOptions___fileName = "pluginOptions___fileName",
    pluginOptions___icons = "pluginOptions___icons",
    pluginOptions___icons___sizes = "pluginOptions___icons___sizes",
    pluginOptions___icons___src = "pluginOptions___icons___src",
    pluginOptions___icons___type = "pluginOptions___icons___type",
    pluginOptions___include_favicon = "pluginOptions___include_favicon",
    pluginOptions___isTSX = "pluginOptions___isTSX",
    pluginOptions___jsxPragma = "pluginOptions___jsxPragma",
    pluginOptions___legacy = "pluginOptions___legacy",
    pluginOptions___minify = "pluginOptions___minify",
    pluginOptions___name = "pluginOptions___name",
    pluginOptions___namespace = "pluginOptions___namespace",
    pluginOptions___offsetY___element = "pluginOptions___offsetY___element",
    pluginOptions___output = "pluginOptions___output",
    pluginOptions___path = "pluginOptions___path",
    pluginOptions___pathCheck = "pluginOptions___pathCheck",
    pluginOptions___plugins = "pluginOptions___plugins",
    pluginOptions___plugins___browserAPIs = "pluginOptions___plugins___browserAPIs",
    pluginOptions___plugins___id = "pluginOptions___plugins___id",
    pluginOptions___plugins___name = "pluginOptions___plugins___name",
    pluginOptions___plugins___nodeAPIs = "pluginOptions___plugins___nodeAPIs",
    pluginOptions___plugins___pluginFilepath = "pluginOptions___plugins___pluginFilepath",
    pluginOptions___plugins___pluginOptions___buttonText = "pluginOptions___plugins___pluginOptions___buttonText",
    pluginOptions___plugins___pluginOptions___configPath = "pluginOptions___plugins___pluginOptions___configPath",
    pluginOptions___plugins___pluginOptions___enable = "pluginOptions___plugins___pluginOptions___enable",
    pluginOptions___plugins___pluginOptions___toasterDuration = "pluginOptions___plugins___pluginOptions___toasterDuration",
    pluginOptions___plugins___pluginOptions___toasterText = "pluginOptions___plugins___pluginOptions___toasterText",
    pluginOptions___plugins___pluginOptions___tooltipText = "pluginOptions___plugins___pluginOptions___tooltipText",
    pluginOptions___plugins___resolve = "pluginOptions___plugins___resolve",
    pluginOptions___plugins___ssrAPIs = "pluginOptions___plugins___ssrAPIs",
    pluginOptions___plugins___version = "pluginOptions___plugins___version",
    pluginOptions___publicDir = "pluginOptions___publicDir",
    pluginOptions___pure = "pluginOptions___pure",
    pluginOptions___query = "pluginOptions___query",
    pluginOptions___siteUrl = "pluginOptions___siteUrl",
    pluginOptions___stripHash = "pluginOptions___stripHash",
    pluginOptions___theme_color_in_head = "pluginOptions___theme_color_in_head",
    pluginOptions___toasterDuration = "pluginOptions___toasterDuration",
    pluginOptions___toasterText = "pluginOptions___toasterText",
    pluginOptions___tooltipText = "pluginOptions___tooltipText",
    pluginOptions___transpileTemplateLiterals = "pluginOptions___transpileTemplateLiterals",
    resolve = "resolve",
    ssrAPIs = "ssrAPIs",
    version = "version"
}
export declare type SitePluginFilterInput = {
    browserAPIs?: InputMaybe<StringQueryOperatorInput>;
    children?: InputMaybe<NodeFilterListInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    internal?: InputMaybe<InternalFilterInput>;
    name?: InputMaybe<StringQueryOperatorInput>;
    nodeAPIs?: InputMaybe<StringQueryOperatorInput>;
    packageJson?: InputMaybe<SitePluginPackageJsonFilterInput>;
    parent?: InputMaybe<NodeFilterInput>;
    pluginFilepath?: InputMaybe<StringQueryOperatorInput>;
    pluginOptions?: InputMaybe<SitePluginPluginOptionsFilterInput>;
    resolve?: InputMaybe<StringQueryOperatorInput>;
    ssrAPIs?: InputMaybe<StringQueryOperatorInput>;
    version?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePluginGroupConnection = {
    __typename?: 'SitePluginGroupConnection';
    edges: Array<SitePluginEdge>;
    field: Scalars['String'];
    fieldValue?: Maybe<Scalars['String']>;
    nodes: Array<SitePlugin>;
    pageInfo: PageInfo;
    totalCount: Scalars['Int'];
};
export declare type SitePluginPackageJson = {
    __typename?: 'SitePluginPackageJson';
    author?: Maybe<Scalars['String']>;
    dependencies?: Maybe<Array<Maybe<SitePluginPackageJsonDependencies>>>;
    description?: Maybe<Scalars['String']>;
    devDependencies?: Maybe<Array<Maybe<SitePluginPackageJsonDevDependencies>>>;
    keywords?: Maybe<Array<Maybe<Scalars['String']>>>;
    license?: Maybe<Scalars['String']>;
    main?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    peerDependencies?: Maybe<Array<Maybe<SitePluginPackageJsonPeerDependencies>>>;
    version?: Maybe<Scalars['String']>;
};
export declare type SitePluginPackageJsonDependencies = {
    __typename?: 'SitePluginPackageJsonDependencies';
    name?: Maybe<Scalars['String']>;
    version?: Maybe<Scalars['String']>;
};
export declare type SitePluginPackageJsonDependenciesFilterInput = {
    name?: InputMaybe<StringQueryOperatorInput>;
    version?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePluginPackageJsonDependenciesFilterListInput = {
    elemMatch?: InputMaybe<SitePluginPackageJsonDependenciesFilterInput>;
};
export declare type SitePluginPackageJsonDevDependencies = {
    __typename?: 'SitePluginPackageJsonDevDependencies';
    name?: Maybe<Scalars['String']>;
    version?: Maybe<Scalars['String']>;
};
export declare type SitePluginPackageJsonDevDependenciesFilterInput = {
    name?: InputMaybe<StringQueryOperatorInput>;
    version?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePluginPackageJsonDevDependenciesFilterListInput = {
    elemMatch?: InputMaybe<SitePluginPackageJsonDevDependenciesFilterInput>;
};
export declare type SitePluginPackageJsonFilterInput = {
    author?: InputMaybe<StringQueryOperatorInput>;
    dependencies?: InputMaybe<SitePluginPackageJsonDependenciesFilterListInput>;
    description?: InputMaybe<StringQueryOperatorInput>;
    devDependencies?: InputMaybe<SitePluginPackageJsonDevDependenciesFilterListInput>;
    keywords?: InputMaybe<StringQueryOperatorInput>;
    license?: InputMaybe<StringQueryOperatorInput>;
    main?: InputMaybe<StringQueryOperatorInput>;
    name?: InputMaybe<StringQueryOperatorInput>;
    peerDependencies?: InputMaybe<SitePluginPackageJsonPeerDependenciesFilterListInput>;
    version?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePluginPackageJsonPeerDependencies = {
    __typename?: 'SitePluginPackageJsonPeerDependencies';
    name?: Maybe<Scalars['String']>;
    version?: Maybe<Scalars['String']>;
};
export declare type SitePluginPackageJsonPeerDependenciesFilterInput = {
    name?: InputMaybe<StringQueryOperatorInput>;
    version?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePluginPackageJsonPeerDependenciesFilterListInput = {
    elemMatch?: InputMaybe<SitePluginPackageJsonPeerDependenciesFilterInput>;
};
export declare type SitePluginPluginOptions = {
    __typename?: 'SitePluginPluginOptions';
    allExtensions?: Maybe<Scalars['Boolean']>;
    buttonText?: Maybe<Scalars['String']>;
    cache_busting_mode?: Maybe<Scalars['String']>;
    configPath?: Maybe<Scalars['String']>;
    createLinkInHead?: Maybe<Scalars['Boolean']>;
    crossOrigin?: Maybe<Scalars['String']>;
    displayName?: Maybe<Scalars['Boolean']>;
    enable?: Maybe<Scalars['Boolean']>;
    entryLimit?: Maybe<Scalars['Int']>;
    excludePattern?: Maybe<Scalars['String']>;
    fileName?: Maybe<Scalars['Boolean']>;
    icons?: Maybe<Array<Maybe<SitePluginPluginOptionsIcons>>>;
    include_favicon?: Maybe<Scalars['Boolean']>;
    isTSX?: Maybe<Scalars['Boolean']>;
    jsxPragma?: Maybe<Scalars['String']>;
    legacy?: Maybe<Scalars['Boolean']>;
    minify?: Maybe<Scalars['Boolean']>;
    name?: Maybe<Scalars['String']>;
    namespace?: Maybe<Scalars['String']>;
    offsetY?: Maybe<SitePluginPluginOptionsOffsetY>;
    output?: Maybe<Scalars['String']>;
    path?: Maybe<Scalars['String']>;
    pathCheck?: Maybe<Scalars['Boolean']>;
    plugins?: Maybe<Array<Maybe<SitePluginPluginOptionsPlugins>>>;
    publicDir?: Maybe<Scalars['String']>;
    pure?: Maybe<Scalars['Boolean']>;
    query?: Maybe<Scalars['String']>;
    siteUrl?: Maybe<Scalars['String']>;
    stripHash?: Maybe<Scalars['Boolean']>;
    theme_color_in_head?: Maybe<Scalars['Boolean']>;
    toasterDuration?: Maybe<Scalars['Int']>;
    toasterText?: Maybe<Scalars['String']>;
    tooltipText?: Maybe<Scalars['String']>;
    transpileTemplateLiterals?: Maybe<Scalars['Boolean']>;
};
export declare type SitePluginPluginOptionsFilterInput = {
    allExtensions?: InputMaybe<BooleanQueryOperatorInput>;
    buttonText?: InputMaybe<StringQueryOperatorInput>;
    cache_busting_mode?: InputMaybe<StringQueryOperatorInput>;
    configPath?: InputMaybe<StringQueryOperatorInput>;
    createLinkInHead?: InputMaybe<BooleanQueryOperatorInput>;
    crossOrigin?: InputMaybe<StringQueryOperatorInput>;
    displayName?: InputMaybe<BooleanQueryOperatorInput>;
    enable?: InputMaybe<BooleanQueryOperatorInput>;
    entryLimit?: InputMaybe<IntQueryOperatorInput>;
    excludePattern?: InputMaybe<StringQueryOperatorInput>;
    fileName?: InputMaybe<BooleanQueryOperatorInput>;
    icons?: InputMaybe<SitePluginPluginOptionsIconsFilterListInput>;
    include_favicon?: InputMaybe<BooleanQueryOperatorInput>;
    isTSX?: InputMaybe<BooleanQueryOperatorInput>;
    jsxPragma?: InputMaybe<StringQueryOperatorInput>;
    legacy?: InputMaybe<BooleanQueryOperatorInput>;
    minify?: InputMaybe<BooleanQueryOperatorInput>;
    name?: InputMaybe<StringQueryOperatorInput>;
    namespace?: InputMaybe<StringQueryOperatorInput>;
    offsetY?: InputMaybe<SitePluginPluginOptionsOffsetYFilterInput>;
    output?: InputMaybe<StringQueryOperatorInput>;
    path?: InputMaybe<StringQueryOperatorInput>;
    pathCheck?: InputMaybe<BooleanQueryOperatorInput>;
    plugins?: InputMaybe<SitePluginPluginOptionsPluginsFilterListInput>;
    publicDir?: InputMaybe<StringQueryOperatorInput>;
    pure?: InputMaybe<BooleanQueryOperatorInput>;
    query?: InputMaybe<StringQueryOperatorInput>;
    siteUrl?: InputMaybe<StringQueryOperatorInput>;
    stripHash?: InputMaybe<BooleanQueryOperatorInput>;
    theme_color_in_head?: InputMaybe<BooleanQueryOperatorInput>;
    toasterDuration?: InputMaybe<IntQueryOperatorInput>;
    toasterText?: InputMaybe<StringQueryOperatorInput>;
    tooltipText?: InputMaybe<StringQueryOperatorInput>;
    transpileTemplateLiterals?: InputMaybe<BooleanQueryOperatorInput>;
};
export declare type SitePluginPluginOptionsIcons = {
    __typename?: 'SitePluginPluginOptionsIcons';
    sizes?: Maybe<Scalars['String']>;
    src?: Maybe<Scalars['String']>;
    type?: Maybe<Scalars['String']>;
};
export declare type SitePluginPluginOptionsIconsFilterInput = {
    sizes?: InputMaybe<StringQueryOperatorInput>;
    src?: InputMaybe<StringQueryOperatorInput>;
    type?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePluginPluginOptionsIconsFilterListInput = {
    elemMatch?: InputMaybe<SitePluginPluginOptionsIconsFilterInput>;
};
export declare type SitePluginPluginOptionsOffsetY = {
    __typename?: 'SitePluginPluginOptionsOffsetY';
    element?: Maybe<Scalars['String']>;
};
export declare type SitePluginPluginOptionsOffsetYFilterInput = {
    element?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePluginPluginOptionsPlugins = {
    __typename?: 'SitePluginPluginOptionsPlugins';
    browserAPIs?: Maybe<Array<Maybe<Scalars['String']>>>;
    id?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    nodeAPIs?: Maybe<Array<Maybe<Scalars['String']>>>;
    pluginFilepath?: Maybe<Scalars['String']>;
    pluginOptions?: Maybe<SitePluginPluginOptionsPluginsPluginOptions>;
    resolve?: Maybe<Scalars['String']>;
    ssrAPIs?: Maybe<Array<Maybe<Scalars['String']>>>;
    version?: Maybe<Scalars['String']>;
};
export declare type SitePluginPluginOptionsPluginsFilterInput = {
    browserAPIs?: InputMaybe<StringQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    name?: InputMaybe<StringQueryOperatorInput>;
    nodeAPIs?: InputMaybe<StringQueryOperatorInput>;
    pluginFilepath?: InputMaybe<StringQueryOperatorInput>;
    pluginOptions?: InputMaybe<SitePluginPluginOptionsPluginsPluginOptionsFilterInput>;
    resolve?: InputMaybe<StringQueryOperatorInput>;
    ssrAPIs?: InputMaybe<StringQueryOperatorInput>;
    version?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePluginPluginOptionsPluginsFilterListInput = {
    elemMatch?: InputMaybe<SitePluginPluginOptionsPluginsFilterInput>;
};
export declare type SitePluginPluginOptionsPluginsPluginOptions = {
    __typename?: 'SitePluginPluginOptionsPluginsPluginOptions';
    buttonText?: Maybe<Scalars['String']>;
    configPath?: Maybe<Scalars['String']>;
    enable?: Maybe<Scalars['Boolean']>;
    offsetY?: Maybe<SitePluginPluginOptionsPluginsPluginOptionsOffsetY>;
    toasterDuration?: Maybe<Scalars['Int']>;
    toasterText?: Maybe<Scalars['String']>;
    tooltipText?: Maybe<Scalars['String']>;
};
export declare type SitePluginPluginOptionsPluginsPluginOptionsFilterInput = {
    buttonText?: InputMaybe<StringQueryOperatorInput>;
    configPath?: InputMaybe<StringQueryOperatorInput>;
    enable?: InputMaybe<BooleanQueryOperatorInput>;
    offsetY?: InputMaybe<SitePluginPluginOptionsPluginsPluginOptionsOffsetYFilterInput>;
    toasterDuration?: InputMaybe<IntQueryOperatorInput>;
    toasterText?: InputMaybe<StringQueryOperatorInput>;
    tooltipText?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePluginPluginOptionsPluginsPluginOptionsOffsetY = {
    __typename?: 'SitePluginPluginOptionsPluginsPluginOptionsOffsetY';
    element?: Maybe<Scalars['String']>;
};
export declare type SitePluginPluginOptionsPluginsPluginOptionsOffsetYFilterInput = {
    element?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SitePluginSortInput = {
    fields?: InputMaybe<Array<InputMaybe<SitePluginFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare type SiteSiteMetadata = {
    __typename?: 'SiteSiteMetadata';
    contentDir?: Maybe<Scalars['String']>;
    description: Scalars['String'];
    image: Scalars['String'];
    keywords: Scalars['String'];
    lang?: Maybe<Scalars['String']>;
    logoAltText?: Maybe<Scalars['String']>;
    logoHref?: Maybe<Scalars['String']>;
    siteUrl?: Maybe<Scalars['String']>;
    title: Scalars['String'];
};
export declare type SiteSiteMetadataFilterInput = {
    contentDir?: InputMaybe<StringQueryOperatorInput>;
    description?: InputMaybe<StringQueryOperatorInput>;
    image?: InputMaybe<StringQueryOperatorInput>;
    keywords?: InputMaybe<StringQueryOperatorInput>;
    lang?: InputMaybe<StringQueryOperatorInput>;
    logoAltText?: InputMaybe<StringQueryOperatorInput>;
    logoHref?: InputMaybe<StringQueryOperatorInput>;
    siteUrl?: InputMaybe<StringQueryOperatorInput>;
    title?: InputMaybe<StringQueryOperatorInput>;
};
export declare type SiteSortInput = {
    fields?: InputMaybe<Array<InputMaybe<SiteFieldsEnum>>>;
    order?: InputMaybe<Array<InputMaybe<SortOrderEnum>>>;
};
export declare type Sitemap = {
    __typename?: 'Sitemap';
    changefreq?: Maybe<Scalars['String']>;
    lastmod?: Maybe<Scalars['Date']>;
    priority?: Maybe<Scalars['Float']>;
};
export declare type SitemapFilterInput = {
    changefreq?: InputMaybe<StringQueryOperatorInput>;
    lastmod?: InputMaybe<DateQueryOperatorInput>;
    priority?: InputMaybe<FloatQueryOperatorInput>;
};
export declare type Social = {
    __typename?: 'Social';
    twitter?: Maybe<Scalars['String']>;
};
export declare type SocialFilterInput = {
    twitter?: InputMaybe<StringQueryOperatorInput>;
};
export declare enum SortOrderEnum {
    ASC = "ASC",
    DESC = "DESC"
}
export declare type StringQueryOperatorInput = {
    eq?: InputMaybe<Scalars['String']>;
    glob?: InputMaybe<Scalars['String']>;
    in?: InputMaybe<Array<InputMaybe<Scalars['String']>>>;
    ne?: InputMaybe<Scalars['String']>;
    nin?: InputMaybe<Array<InputMaybe<Scalars['String']>>>;
    regex?: InputMaybe<Scalars['String']>;
};
export declare type TocHeading = {
    __typename?: 'TocHeading';
    depth?: Maybe<Scalars['Int']>;
    id?: Maybe<Scalars['String']>;
    value?: Maybe<Scalars['String']>;
};
export declare type TocHeadingFilterInput = {
    depth?: InputMaybe<IntQueryOperatorInput>;
    id?: InputMaybe<StringQueryOperatorInput>;
    value?: InputMaybe<StringQueryOperatorInput>;
};
export declare type TocHeadingFilterListInput = {
    elemMatch?: InputMaybe<TocHeadingFilterInput>;
};
export declare type TocInfo = {
    __typename?: 'TocInfo';
    enable?: Maybe<Scalars['Boolean']>;
    headings?: Maybe<Array<Maybe<TocHeading>>>;
    maxDepth?: Maybe<Scalars['Int']>;
};
export declare type TocInfoFilterInput = {
    enable?: InputMaybe<BooleanQueryOperatorInput>;
    headings?: InputMaybe<TocHeadingFilterListInput>;
    maxDepth?: InputMaybe<IntQueryOperatorInput>;
};
export declare type EditPageQueryQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type EditPageQueryQuery = {
    __typename?: 'Query';
    siteConfig?: {
        __typename?: 'SiteConfig';
        editPage?: {
            __typename?: 'EditPageConfig';
            baseUrl?: string | null;
            icon?: string | null;
            text?: string | null;
        } | null;
    } | null;
};
export declare type FooterQueryQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type FooterQueryQuery = {
    __typename?: 'Query';
    siteConfig?: {
        __typename?: 'SiteConfig';
        withRbac?: boolean | null;
        siteVersion?: string | null;
        footer?: {
            __typename?: 'FooterConfig';
            copyrightText?: string | null;
            links?: Array<{
                __typename?: 'NavItem';
                label?: string | null;
                link?: string | null;
                httpVerb?: string | null;
                type?: string | null;
                expanded?: string | null;
                selectFirstItemOnExpand?: boolean | null;
                pageId?: string | null;
                redocPrevLink?: string | null;
                redocPrevLabel?: string | null;
                redocNextLink?: string | null;
                redocNextLabel?: string | null;
                redocFakePage?: boolean | null;
                external?: boolean | null;
                target?: string | null;
                menuStyle?: MenuStyle | null;
                sublabel?: string | null;
                icon?: string | null;
                separatorLine?: boolean | null;
                apiVersionId?: string | null;
                isDefaultApiVersion?: boolean | null;
            }> | null;
            columns: Array<{
                __typename?: 'FooterColumn';
                label?: string | null;
                group?: string | null;
                items: Array<{
                    __typename?: 'NavItem';
                    label?: string | null;
                    link?: string | null;
                    httpVerb?: string | null;
                    type?: string | null;
                    expanded?: string | null;
                    selectFirstItemOnExpand?: boolean | null;
                    pageId?: string | null;
                    redocPrevLink?: string | null;
                    redocPrevLabel?: string | null;
                    redocNextLink?: string | null;
                    redocNextLabel?: string | null;
                    redocFakePage?: boolean | null;
                    external?: boolean | null;
                    target?: string | null;
                    menuStyle?: MenuStyle | null;
                    sublabel?: string | null;
                    icon?: string | null;
                    separatorLine?: boolean | null;
                    apiVersionId?: string | null;
                    isDefaultApiVersion?: boolean | null;
                }>;
            }>;
        } | null;
    } | null;
    site?: {
        __typename?: 'Site';
        pathPrefix?: string | null;
    } | null;
};
export declare type NavQueryQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type NavQueryQuery = {
    __typename?: 'Query';
    site?: {
        __typename?: 'Site';
        pathPrefix?: string | null;
    } | null;
    siteConfig?: {
        __typename?: 'SiteConfig';
        withRbac?: boolean | null;
        logo?: {
            __typename?: 'LogoConfig';
            altText?: string | null;
            image?: string | null;
            href?: string | null;
        } | null;
        nav: Array<{
            __typename?: 'NavItem';
            type?: string | null;
            label?: string | null;
            link?: string | null;
            icon?: string | null;
            target?: string | null;
            external?: boolean | null;
            activateWithSidebar?: string | null;
            items?: Array<{
                __typename?: 'NavItem';
                type?: string | null;
                label?: string | null;
                link?: string | null;
                icon?: string | null;
                target?: string | null;
                external?: boolean | null;
                activateWithSidebar?: string | null;
                items?: Array<{
                    __typename?: 'NavItem';
                    type?: string | null;
                    label?: string | null;
                    link?: string | null;
                    icon?: string | null;
                    target?: string | null;
                    external?: boolean | null;
                    activateWithSidebar?: string | null;
                }> | null;
            }> | null;
        }>;
    } | null;
};
export declare type Unnamed_1_QueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type Unnamed_1_Query = {
    __typename?: 'Query';
    siteConfig?: {
        __typename?: 'SiteConfig';
        stylesheets: Array<string>;
        scripts: Array<string>;
        social?: {
            __typename?: 'Social';
            twitter?: string | null;
        } | null;
        seo?: {
            __typename?: 'ContentItemSeo';
            title?: string | null;
            description?: string | null;
            image?: string | null;
            keywords?: string | null;
            lang?: string | null;
            jsonLd?: any | null;
        } | null;
    } | null;
};
export declare type RedirectToLoginQueryQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type RedirectToLoginQueryQuery = {
    __typename?: 'Query';
    siteConfig?: {
        __typename?: 'SiteConfig';
        customLoginPagePath?: string | null;
    } | null;
};
export declare type Unnamed_2_QueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type Unnamed_2_Query = {
    __typename?: 'Query';
    siteConfig?: {
        __typename?: 'SiteConfig';
        login?: {
            __typename?: 'LoginSettings';
            label: string;
            menu: Array<{
                __typename?: 'NavItem';
                label?: string | null;
                sublabel?: string | null;
                icon?: string | null;
                link?: string | null;
                type?: string | null;
                target?: string | null;
                external?: boolean | null;
                menuStyle?: MenuStyle | null;
                separatorLine?: boolean | null;
            }>;
            userLabel?: {
                __typename?: 'LoginSettingsUserLabel';
                claim: string;
                fallback?: string | null;
            } | null;
            userAvatar?: {
                __typename?: 'LoginSettingsUserAvatar';
                claim: string;
                fallbackLettersClaim?: string | null;
            } | null;
        } | null;
    } | null;
};
export declare type HeaderNavItemFragmentFragment = {
    __typename?: 'NavItem';
    type?: string | null;
    label?: string | null;
    link?: string | null;
    icon?: string | null;
    target?: string | null;
    external?: boolean | null;
    activateWithSidebar?: string | null;
};
export declare type HeaderNavFragmentFragment = {
    __typename?: 'Query';
    siteConfig?: {
        __typename?: 'SiteConfig';
        logo?: {
            __typename?: 'LogoConfig';
            altText?: string | null;
            image?: string | null;
            href?: string | null;
        } | null;
        nav: Array<{
            __typename?: 'NavItem';
            type?: string | null;
            label?: string | null;
            link?: string | null;
            icon?: string | null;
            target?: string | null;
            external?: boolean | null;
            activateWithSidebar?: string | null;
            items?: Array<{
                __typename?: 'NavItem';
                type?: string | null;
                label?: string | null;
                link?: string | null;
                icon?: string | null;
                target?: string | null;
                external?: boolean | null;
                activateWithSidebar?: string | null;
                items?: Array<{
                    __typename?: 'NavItem';
                    type?: string | null;
                    label?: string | null;
                    link?: string | null;
                    icon?: string | null;
                    target?: string | null;
                    external?: boolean | null;
                    activateWithSidebar?: string | null;
                }> | null;
            }> | null;
        }>;
    } | null;
};
export declare type SidebarItemFragmentFragment = {
    __typename?: 'NavItem';
    label?: string | null;
    link?: string | null;
    httpVerb?: string | null;
    type?: string | null;
    expanded?: string | null;
    selectFirstItemOnExpand?: boolean | null;
    pageId?: string | null;
    redocPrevLink?: string | null;
    redocPrevLabel?: string | null;
    redocNextLink?: string | null;
    redocNextLabel?: string | null;
    redocFakePage?: boolean | null;
    external?: boolean | null;
    target?: string | null;
    menuStyle?: MenuStyle | null;
    sublabel?: string | null;
    icon?: string | null;
    separatorLine?: boolean | null;
    apiVersionId?: string | null;
    isDefaultApiVersion?: boolean | null;
};
export declare type SidebarFragmentFragment = {
    __typename?: 'NavItem';
    label?: string | null;
    link?: string | null;
    httpVerb?: string | null;
    type?: string | null;
    expanded?: string | null;
    selectFirstItemOnExpand?: boolean | null;
    pageId?: string | null;
    redocPrevLink?: string | null;
    redocPrevLabel?: string | null;
    redocNextLink?: string | null;
    redocNextLabel?: string | null;
    redocFakePage?: boolean | null;
    external?: boolean | null;
    target?: string | null;
    menuStyle?: MenuStyle | null;
    sublabel?: string | null;
    icon?: string | null;
    separatorLine?: boolean | null;
    apiVersionId?: string | null;
    isDefaultApiVersion?: boolean | null;
    items?: Array<{
        __typename?: 'NavItem';
        label?: string | null;
        link?: string | null;
        httpVerb?: string | null;
        type?: string | null;
        expanded?: string | null;
        selectFirstItemOnExpand?: boolean | null;
        pageId?: string | null;
        redocPrevLink?: string | null;
        redocPrevLabel?: string | null;
        redocNextLink?: string | null;
        redocNextLabel?: string | null;
        redocFakePage?: boolean | null;
        external?: boolean | null;
        target?: string | null;
        menuStyle?: MenuStyle | null;
        sublabel?: string | null;
        icon?: string | null;
        separatorLine?: boolean | null;
        apiVersionId?: string | null;
        isDefaultApiVersion?: boolean | null;
        items?: Array<{
            __typename?: 'NavItem';
            label?: string | null;
            link?: string | null;
            httpVerb?: string | null;
            type?: string | null;
            expanded?: string | null;
            selectFirstItemOnExpand?: boolean | null;
            pageId?: string | null;
            redocPrevLink?: string | null;
            redocPrevLabel?: string | null;
            redocNextLink?: string | null;
            redocNextLabel?: string | null;
            redocFakePage?: boolean | null;
            external?: boolean | null;
            target?: string | null;
            menuStyle?: MenuStyle | null;
            sublabel?: string | null;
            icon?: string | null;
            separatorLine?: boolean | null;
            apiVersionId?: string | null;
            isDefaultApiVersion?: boolean | null;
            items?: Array<{
                __typename?: 'NavItem';
                label?: string | null;
                link?: string | null;
                httpVerb?: string | null;
                type?: string | null;
                expanded?: string | null;
                selectFirstItemOnExpand?: boolean | null;
                pageId?: string | null;
                redocPrevLink?: string | null;
                redocPrevLabel?: string | null;
                redocNextLink?: string | null;
                redocNextLabel?: string | null;
                redocFakePage?: boolean | null;
                external?: boolean | null;
                target?: string | null;
                menuStyle?: MenuStyle | null;
                sublabel?: string | null;
                icon?: string | null;
                separatorLine?: boolean | null;
                apiVersionId?: string | null;
                isDefaultApiVersion?: boolean | null;
                items?: Array<{
                    __typename?: 'NavItem';
                    label?: string | null;
                    link?: string | null;
                    httpVerb?: string | null;
                    type?: string | null;
                    expanded?: string | null;
                    selectFirstItemOnExpand?: boolean | null;
                    pageId?: string | null;
                    redocPrevLink?: string | null;
                    redocPrevLabel?: string | null;
                    redocNextLink?: string | null;
                    redocNextLabel?: string | null;
                    redocFakePage?: boolean | null;
                    external?: boolean | null;
                    target?: string | null;
                    menuStyle?: MenuStyle | null;
                    sublabel?: string | null;
                    icon?: string | null;
                    separatorLine?: boolean | null;
                    apiVersionId?: string | null;
                    isDefaultApiVersion?: boolean | null;
                    items?: Array<{
                        __typename?: 'NavItem';
                        label?: string | null;
                        link?: string | null;
                        httpVerb?: string | null;
                        type?: string | null;
                        expanded?: string | null;
                        selectFirstItemOnExpand?: boolean | null;
                        pageId?: string | null;
                        redocPrevLink?: string | null;
                        redocPrevLabel?: string | null;
                        redocNextLink?: string | null;
                        redocNextLabel?: string | null;
                        redocFakePage?: boolean | null;
                        external?: boolean | null;
                        target?: string | null;
                        menuStyle?: MenuStyle | null;
                        sublabel?: string | null;
                        icon?: string | null;
                        separatorLine?: boolean | null;
                        apiVersionId?: string | null;
                        isDefaultApiVersion?: boolean | null;
                        items?: Array<{
                            __typename?: 'NavItem';
                            label?: string | null;
                            link?: string | null;
                            httpVerb?: string | null;
                            type?: string | null;
                            expanded?: string | null;
                            selectFirstItemOnExpand?: boolean | null;
                            pageId?: string | null;
                            redocPrevLink?: string | null;
                            redocPrevLabel?: string | null;
                            redocNextLink?: string | null;
                            redocNextLabel?: string | null;
                            redocFakePage?: boolean | null;
                            external?: boolean | null;
                            target?: string | null;
                            menuStyle?: MenuStyle | null;
                            sublabel?: string | null;
                            icon?: string | null;
                            separatorLine?: boolean | null;
                            apiVersionId?: string | null;
                            isDefaultApiVersion?: boolean | null;
                            items?: Array<{
                                __typename?: 'NavItem';
                                label?: string | null;
                                link?: string | null;
                                httpVerb?: string | null;
                                type?: string | null;
                                expanded?: string | null;
                                selectFirstItemOnExpand?: boolean | null;
                                pageId?: string | null;
                                redocPrevLink?: string | null;
                                redocPrevLabel?: string | null;
                                redocNextLink?: string | null;
                                redocNextLabel?: string | null;
                                redocFakePage?: boolean | null;
                                external?: boolean | null;
                                target?: string | null;
                                menuStyle?: MenuStyle | null;
                                sublabel?: string | null;
                                icon?: string | null;
                                separatorLine?: boolean | null;
                                apiVersionId?: string | null;
                                isDefaultApiVersion?: boolean | null;
                            }> | null;
                        }> | null;
                    }> | null;
                }> | null;
            }> | null;
        }> | null;
    }> | null;
};
export declare type FooterFragmentFragment = {
    __typename?: 'Query';
    siteConfig?: {
        __typename?: 'SiteConfig';
        siteVersion?: string | null;
        footer?: {
            __typename?: 'FooterConfig';
            copyrightText?: string | null;
            links?: Array<{
                __typename?: 'NavItem';
                label?: string | null;
                link?: string | null;
                httpVerb?: string | null;
                type?: string | null;
                expanded?: string | null;
                selectFirstItemOnExpand?: boolean | null;
                pageId?: string | null;
                redocPrevLink?: string | null;
                redocPrevLabel?: string | null;
                redocNextLink?: string | null;
                redocNextLabel?: string | null;
                redocFakePage?: boolean | null;
                external?: boolean | null;
                target?: string | null;
                menuStyle?: MenuStyle | null;
                sublabel?: string | null;
                icon?: string | null;
                separatorLine?: boolean | null;
                apiVersionId?: string | null;
                isDefaultApiVersion?: boolean | null;
            }> | null;
            columns: Array<{
                __typename?: 'FooterColumn';
                label?: string | null;
                group?: string | null;
                items: Array<{
                    __typename?: 'NavItem';
                    label?: string | null;
                    link?: string | null;
                    httpVerb?: string | null;
                    type?: string | null;
                    expanded?: string | null;
                    selectFirstItemOnExpand?: boolean | null;
                    pageId?: string | null;
                    redocPrevLink?: string | null;
                    redocPrevLabel?: string | null;
                    redocNextLink?: string | null;
                    redocNextLabel?: string | null;
                    redocFakePage?: boolean | null;
                    external?: boolean | null;
                    target?: string | null;
                    menuStyle?: MenuStyle | null;
                    sublabel?: string | null;
                    icon?: string | null;
                    separatorLine?: boolean | null;
                    apiVersionId?: string | null;
                    isDefaultApiVersion?: boolean | null;
                }>;
            }>;
        } | null;
    } | null;
};
export declare type Unnamed_3_QueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type Unnamed_3_Query = {
    __typename?: 'Query';
    site?: {
        __typename?: 'Site';
        pathPrefix?: string | null;
    } | null;
    siteConfig?: {
        __typename?: 'SiteConfig';
        withRbac?: boolean | null;
        showPrevButton: boolean;
        showNextButton: boolean;
    } | null;
    allSidebar: {
        __typename?: 'SidebarConnection';
        nodes: Array<{
            __typename?: 'Sidebar';
            name: string;
            context?: string | null;
            items: Array<{
                __typename?: 'NavItem';
                label?: string | null;
                link?: string | null;
                httpVerb?: string | null;
                type?: string | null;
                expanded?: string | null;
                selectFirstItemOnExpand?: boolean | null;
                pageId?: string | null;
                redocPrevLink?: string | null;
                redocPrevLabel?: string | null;
                redocNextLink?: string | null;
                redocNextLabel?: string | null;
                redocFakePage?: boolean | null;
                external?: boolean | null;
                target?: string | null;
                menuStyle?: MenuStyle | null;
                sublabel?: string | null;
                icon?: string | null;
                separatorLine?: boolean | null;
                apiVersionId?: string | null;
                isDefaultApiVersion?: boolean | null;
                items?: Array<{
                    __typename?: 'NavItem';
                    label?: string | null;
                    link?: string | null;
                    httpVerb?: string | null;
                    type?: string | null;
                    expanded?: string | null;
                    selectFirstItemOnExpand?: boolean | null;
                    pageId?: string | null;
                    redocPrevLink?: string | null;
                    redocPrevLabel?: string | null;
                    redocNextLink?: string | null;
                    redocNextLabel?: string | null;
                    redocFakePage?: boolean | null;
                    external?: boolean | null;
                    target?: string | null;
                    menuStyle?: MenuStyle | null;
                    sublabel?: string | null;
                    icon?: string | null;
                    separatorLine?: boolean | null;
                    apiVersionId?: string | null;
                    isDefaultApiVersion?: boolean | null;
                    items?: Array<{
                        __typename?: 'NavItem';
                        label?: string | null;
                        link?: string | null;
                        httpVerb?: string | null;
                        type?: string | null;
                        expanded?: string | null;
                        selectFirstItemOnExpand?: boolean | null;
                        pageId?: string | null;
                        redocPrevLink?: string | null;
                        redocPrevLabel?: string | null;
                        redocNextLink?: string | null;
                        redocNextLabel?: string | null;
                        redocFakePage?: boolean | null;
                        external?: boolean | null;
                        target?: string | null;
                        menuStyle?: MenuStyle | null;
                        sublabel?: string | null;
                        icon?: string | null;
                        separatorLine?: boolean | null;
                        apiVersionId?: string | null;
                        isDefaultApiVersion?: boolean | null;
                        items?: Array<{
                            __typename?: 'NavItem';
                            label?: string | null;
                            link?: string | null;
                            httpVerb?: string | null;
                            type?: string | null;
                            expanded?: string | null;
                            selectFirstItemOnExpand?: boolean | null;
                            pageId?: string | null;
                            redocPrevLink?: string | null;
                            redocPrevLabel?: string | null;
                            redocNextLink?: string | null;
                            redocNextLabel?: string | null;
                            redocFakePage?: boolean | null;
                            external?: boolean | null;
                            target?: string | null;
                            menuStyle?: MenuStyle | null;
                            sublabel?: string | null;
                            icon?: string | null;
                            separatorLine?: boolean | null;
                            apiVersionId?: string | null;
                            isDefaultApiVersion?: boolean | null;
                            items?: Array<{
                                __typename?: 'NavItem';
                                label?: string | null;
                                link?: string | null;
                                httpVerb?: string | null;
                                type?: string | null;
                                expanded?: string | null;
                                selectFirstItemOnExpand?: boolean | null;
                                pageId?: string | null;
                                redocPrevLink?: string | null;
                                redocPrevLabel?: string | null;
                                redocNextLink?: string | null;
                                redocNextLabel?: string | null;
                                redocFakePage?: boolean | null;
                                external?: boolean | null;
                                target?: string | null;
                                menuStyle?: MenuStyle | null;
                                sublabel?: string | null;
                                icon?: string | null;
                                separatorLine?: boolean | null;
                                apiVersionId?: string | null;
                                isDefaultApiVersion?: boolean | null;
                                items?: Array<{
                                    __typename?: 'NavItem';
                                    label?: string | null;
                                    link?: string | null;
                                    httpVerb?: string | null;
                                    type?: string | null;
                                    expanded?: string | null;
                                    selectFirstItemOnExpand?: boolean | null;
                                    pageId?: string | null;
                                    redocPrevLink?: string | null;
                                    redocPrevLabel?: string | null;
                                    redocNextLink?: string | null;
                                    redocNextLabel?: string | null;
                                    redocFakePage?: boolean | null;
                                    external?: boolean | null;
                                    target?: string | null;
                                    menuStyle?: MenuStyle | null;
                                    sublabel?: string | null;
                                    icon?: string | null;
                                    separatorLine?: boolean | null;
                                    apiVersionId?: string | null;
                                    isDefaultApiVersion?: boolean | null;
                                    items?: Array<{
                                        __typename?: 'NavItem';
                                        label?: string | null;
                                        link?: string | null;
                                        httpVerb?: string | null;
                                        type?: string | null;
                                        expanded?: string | null;
                                        selectFirstItemOnExpand?: boolean | null;
                                        pageId?: string | null;
                                        redocPrevLink?: string | null;
                                        redocPrevLabel?: string | null;
                                        redocNextLink?: string | null;
                                        redocNextLabel?: string | null;
                                        redocFakePage?: boolean | null;
                                        external?: boolean | null;
                                        target?: string | null;
                                        menuStyle?: MenuStyle | null;
                                        sublabel?: string | null;
                                        icon?: string | null;
                                        separatorLine?: boolean | null;
                                        apiVersionId?: string | null;
                                        isDefaultApiVersion?: boolean | null;
                                        items?: Array<{
                                            __typename?: 'NavItem';
                                            label?: string | null;
                                            link?: string | null;
                                            httpVerb?: string | null;
                                            type?: string | null;
                                            expanded?: string | null;
                                            selectFirstItemOnExpand?: boolean | null;
                                            pageId?: string | null;
                                            redocPrevLink?: string | null;
                                            redocPrevLabel?: string | null;
                                            redocNextLink?: string | null;
                                            redocNextLabel?: string | null;
                                            redocFakePage?: boolean | null;
                                            external?: boolean | null;
                                            target?: string | null;
                                            menuStyle?: MenuStyle | null;
                                            sublabel?: string | null;
                                            icon?: string | null;
                                            separatorLine?: boolean | null;
                                            apiVersionId?: string | null;
                                            isDefaultApiVersion?: boolean | null;
                                        }> | null;
                                    }> | null;
                                }> | null;
                            }> | null;
                        }> | null;
                    }> | null;
                }> | null;
            }>;
        }>;
    };
};
export declare type RedocOpQueryQueryVariables = Exact<{
    pageId: Scalars['String'];
}>;
export declare type RedocOpQueryQuery = {
    __typename?: 'Query';
    contentItem?: {
        __typename?: 'ContentItem';
        type?: string | null;
        link: string;
        data?: {
            __typename?: 'ContentItemData';
            redocStoreStr?: string | null;
            redocHasSecurityDefinitions?: boolean | null;
            redocInfoPageLink?: string | null;
            redocItemId?: string | null;
            redocHasInfoPage?: boolean | null;
            settings?: any | null;
            requestLogin?: boolean | null;
            lastModified?: string | null;
        } | null;
        seo?: {
            __typename?: 'ContentItemSeo';
            title?: string | null;
        } | null;
    } | null;
};
export declare type MarkdownQueryQueryVariables = Exact<{
    pageId: Scalars['String'];
    id: Scalars['String'];
}>;
export declare type MarkdownQueryQuery = {
    __typename?: 'Query';
    markdownRemark?: {
        __typename?: 'MarkdownRemark';
        html?: string | null;
        headings?: Array<{
            __typename?: 'MarkdownHeading';
            value?: string | null;
            depth?: number | null;
        } | null> | null;
    } | null;
    contentItem?: {
        __typename?: 'ContentItem';
        data?: {
            __typename?: 'ContentItemData';
            lastModified?: string | null;
            enableToc?: boolean | null;
            disableLastModified?: boolean | null;
            tocMaxDepth?: number | null;
            requestLogin?: boolean | null;
        } | null;
    } | null;
    siteConfig?: {
        __typename?: 'SiteConfig';
        enableToc?: boolean | null;
        disableLastModified?: boolean | null;
        tocMaxDepth?: number | null;
    } | null;
};
export declare type Unnamed_4_QueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type Unnamed_4_Query = {
    __typename?: 'Query';
    siteConfig?: {
        __typename?: 'SiteConfig';
        withRbac?: boolean | null;
    } | null;
    site?: {
        __typename?: 'Site';
        pathPrefix?: string | null;
    } | null;
    apiCatalog: Array<{
        __typename?: 'ApiCatalogApi';
        title: string;
        link: string;
        permission?: string | null;
        versions: Array<{
            __typename?: 'ApiCatalogVersion';
            metadata?: any | null;
            summary: string;
            link?: string | null;
            isDefault?: boolean | null;
        }>;
        defaultVersion: {
            __typename?: 'ApiCatalogVersion';
            metadata?: any | null;
            summary: string;
            link?: string | null;
            isDefault?: boolean | null;
        };
    }>;
};
export declare type Unnamed_5_QueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type Unnamed_5_Query = {
    __typename?: 'Query';
    config?: {
        __typename?: 'SiteConfig';
        redoclyOrgId?: string | null;
        mulesoftAnypoint?: {
            __typename?: 'MulesoftAnypointConfig';
            appClientId?: string | null;
            orgId?: string | null;
        } | null;
    } | null;
};
export declare type Unnamed_6_QueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type Unnamed_6_Query = {
    __typename?: 'Query';
    siteConfig?: {
        __typename?: 'SiteConfig';
        withRbac?: boolean | null;
    } | null;
    site?: {
        __typename?: 'Site';
        pathPrefix?: string | null;
    } | null;
    apis: Array<{
        __typename?: 'OASDefinitionInfo';
        id?: string | null;
        definitionId: string;
        link?: string | null;
        sourcePath?: string | null;
        info?: any | null;
        data?: any | null;
        definitionProperties?: any | null;
        permission?: string | null;
        versions?: Array<{
            __typename?: 'OASDefinitionVersionInfo';
            definitionId: string;
            isDefault?: boolean | null;
            id?: string | null;
            title?: string | null;
            link?: string | null;
        }> | null;
    }>;
};
export declare type Unnamed_7_QueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type Unnamed_7_Query = {
    __typename?: 'Query';
    siteConfig?: {
        __typename?: 'SiteConfig';
        withRbac?: boolean | null;
    } | null;
    site?: {
        __typename?: 'Site';
        pathPrefix?: string | null;
    } | null;
    sidebars: {
        __typename?: 'SidebarConnection';
        nodes: Array<{
            __typename?: 'Sidebar';
            name: string;
            context?: string | null;
            items: Array<{
                __typename?: 'NavItem';
                link?: string | null;
                label?: string | null;
            }>;
        }>;
    };
};
